=encoding utf8

=head1 NAME

Locale::CLDR::Locales::Kn - Package for language Kannada

=cut

package Locale::CLDR::Locales::Kn;
# This file auto generated from Data\common\main\kn.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Root');
has 'display_name_language' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		 sub {
			 my %languages = (
				'aa' => 'ಅಫಾರ್',
 				'ab' => 'ಅಬ್ಖಾಜಿಯನ್',
 				'ace' => 'ಅಛಿನೀಸ್',
 				'ach' => 'ಅಕೋಲಿ',
 				'ada' => 'ಅಡಂಗ್ಮೆ',
 				'ady' => 'ಅಡೈಘೆ',
 				'ae' => 'ಅವೆಸ್ಟನ್',
 				'af' => 'ಆಫ್ರಿಕಾನ್ಸ್',
 				'afh' => 'ಆಫ್ರಿಹಿಲಿ',
 				'agq' => 'ಅಘೆಮ್',
 				'ain' => 'ಐನು',
 				'ak' => 'ಅಕಾನ್',
 				'akk' => 'ಅಕ್ಕಾಡಿಯನ್',
 				'ale' => 'ಅಲೆಯುಟ್',
 				'alt' => 'ದಕ್ಷಿಣ ಅಲ್ಟಾಯ್',
 				'am' => 'ಅಂಹರಿಕ್',
 				'an' => 'ಅರಗೊನೀಸ್',
 				'ang' => 'ಪ್ರಾಚೀನ ಇಂಗ್ಲೀಷ್',
 				'ann' => 'ಒಬೊಲೊ',
 				'anp' => 'ಆಂಗಿಕಾ',
 				'ar' => 'ಅರೇಬಿಕ್',
 				'ar_001' => 'ಆಧುನಿಕ ಪ್ರಮಾಣಿತ ಅರೇಬಿಕ್',
 				'arc' => 'ಅರಾಮಿಕ್',
 				'arn' => 'ಮಪುಚೆ',
 				'arp' => 'ಅರಪಾಹೋ',
 				'ars' => 'ನ್ಯಾಜ್ಡಿ ಅರೇಬಿಕ್',
 				'arw' => 'ಅರಾವಾಕ್',
 				'as' => 'ಅಸ್ಸಾಮೀಸ್',
 				'asa' => 'ಅಸು',
 				'ast' => 'ಆಸ್ಟುರಿಯನ್',
 				'atj' => 'ಅತಿಕಮೆಕ್',
 				'av' => 'ಅವರಿಕ್',
 				'awa' => 'ಅವಧಿ',
 				'ay' => 'ಅಯ್ಮಾರಾ',
 				'az' => 'ಅಜೆರ್ಬೈಜಾನಿ',
 				'az@alt=short' => 'ಅಝೆರಿ',
 				'ba' => 'ಬಶ್ಕಿರ್',
 				'bal' => 'ಬಲೂಚಿ',
 				'ban' => 'ಬಲಿನೀಸ್',
 				'bas' => 'ಬಸಾ',
 				'be' => 'ಬೆಲರೂಸಿಯನ್',
 				'bej' => 'ಬೇಜಾ',
 				'bem' => 'ಬೆಂಬಾ',
 				'bez' => 'ಬೆನ',
 				'bg' => 'ಬಲ್ಗೇರಿಯನ್',
 				'bgc' => 'ಹರ್ಯಾನ್ವಿ',
 				'bgn' => 'ಪಶ್ಚಿಮ ಬಲೊಚಿ',
 				'bho' => 'ಭೋಜಪುರಿ',
 				'bi' => 'ಬಿಸ್ಲಾಮಾ',
 				'bik' => 'ಬಿಕೊಲ್',
 				'bin' => 'ಬಿನಿ',
 				'bla' => 'ಸಿಕ್ಸಿಕಾ',
 				'blo' => 'ಅನೀ',
 				'bm' => 'ಬಂಬಾರಾ',
 				'bn' => 'ಬಾಂಗ್ಲಾ',
 				'bo' => 'ಟಿಬೇಟಿಯನ್',
 				'br' => 'ಬ್ರೆಟನ್',
 				'bra' => 'ಬ್ರಜ್',
 				'brx' => 'ಬೋಡೊ',
 				'bs' => 'ಬೋಸ್ನಿಯನ್',
 				'bua' => 'ಬುರಿಯಟ್',
 				'bug' => 'ಬುಗಿನೀಸ್',
 				'byn' => 'ಬ್ಲಿನ್',
 				'ca' => 'ಕೆಟಲಾನ್',
 				'cad' => 'ಕ್ಯಾಡ್ಡೋ',
 				'car' => 'ಕಾರಿಬ್',
 				'cay' => 'ಕಯುಗಾ',
 				'cch' => 'ಅಟ್ಸಮ್',
 				'ccp' => 'ಚಕ್ಮಾ',
 				'ce' => 'ಚಚೆನ್',
 				'ceb' => 'ಸೆಬುವಾನೊ',
 				'cgg' => 'ಚಿಗಾ',
 				'ch' => 'ಕಮೊರೊ',
 				'chb' => 'ಚಿಬ್ಚಾ',
 				'chg' => 'ಚಗಟಾಯ್',
 				'chk' => 'ಚೂಕಿಸೆ',
 				'chm' => 'ಮಾರಿ',
 				'chn' => 'ಚಿನೂಕ್ ಜಾರ್ಗೋನ್',
 				'cho' => 'ಚೋಕ್ಟಾವ್',
 				'chp' => 'ಚಿಪೆವ್ಯಾನ್',
 				'chr' => 'ಚೆರೋಕಿ',
 				'chy' => 'ಚೀಯೆನ್ನೇ',
 				'ckb' => 'ಮಧ್ಯ ಕುರ್ದಿಶ್',
 				'ckb@alt=variant' => 'ಕುರ್ದಿಶ್, ಸೊರಾನಿ',
 				'clc' => 'ಚಿಲ್ಕೋಟಿನ್',
 				'co' => 'ಕೋರ್ಸಿಕನ್',
 				'cop' => 'ಕೊಪ್ಟಿಕ್',
 				'cr' => 'ಕ್ರೀ',
 				'crg' => 'ಮಿಚಿಫ್',
 				'crh' => 'ಕ್ರಿಮೀಯನ್ ಟರ್ಕಿಷ್',
 				'crj' => 'ದಕ್ಷಿಣ ಪೂರ್ವ ಕ್ರೀ',
 				'crk' => 'ಪ್ಲೇನ್ಸ್ ಕ್ರೀ',
 				'crl' => 'ಉತ್ತರ ಪೂರ್ವ ಕ್ರೀ',
 				'crm' => 'ಮೂಸ್ ಕ್ರೀ',
 				'crr' => 'ಕೆರೊಲಿನಾ ಅಲ್ಗೊಂಕ್ವಿಯನ್',
 				'crs' => 'ಸೆಸೆಲ್ವಾ ಕ್ರಯೋಲ್ ಫ್ರೆಂಚ್',
 				'cs' => 'ಜೆಕ್',
 				'csb' => 'ಕಶುಬಿಯನ್',
 				'csw' => 'ಸ್ವಾಂಪಿ ಕ್ರೀ',
 				'cu' => 'ಚರ್ಚ್ ಸ್ಲಾವಿಕ್',
 				'cv' => 'ಚುವಾಶ್',
 				'cy' => 'ವೆಲ್ಶ್',
 				'da' => 'ಡ್ಯಾನಿಶ್',
 				'dak' => 'ಡಕೋಟಾ',
 				'dar' => 'ದರ್ಗ್ವಾ',
 				'dav' => 'ಟೈಟ',
 				'de' => 'ಜರ್ಮನ್',
 				'de_AT' => 'ಆಸ್ಟ್ರಿಯನ್ ಜರ್ಮನ್',
 				'de_CH' => 'ಸ್ವಿಸ್ ಹೈ ಜರ್ಮನ್',
 				'del' => 'ಡೆಲಾವೇರ್',
 				'den' => 'ಸ್ಲೇವ್',
 				'dgr' => 'ಡೋಗ್ರಿಬ್',
 				'din' => 'ಡಿಂಕಾ',
 				'dje' => 'ಜರ್ಮಾ',
 				'doi' => 'ಡೋಗ್ರಿ',
 				'dsb' => 'ಲೋವರ್ ಸರ್ಬಿಯನ್',
 				'dua' => 'ಡುವಾಲಾ',
 				'dum' => 'ಮಧ್ಯ ಡಚ್',
 				'dv' => 'ದಿವೆಹಿ',
 				'dyo' => 'ಜೊಲ-ಫೊನ್ಯಿ',
 				'dyu' => 'ಡ್ಯೂಲಾ',
 				'dz' => 'ಜೋಂಗ್‌ಖಾ',
 				'dzg' => 'ಡಜಾಗ',
 				'ebu' => 'ಎಂಬು',
 				'ee' => 'ಈವ್',
 				'efi' => 'ಎಫಿಕ್',
 				'egy' => 'ಪ್ರಾಚೀನ ಈಜಿಪ್ಟಿಯನ್',
 				'eka' => 'ಎಕಾಜುಕ್',
 				'el' => 'ಗ್ರೀಕ್',
 				'elx' => 'ಎಲಾಮೈಟ್',
 				'en' => 'ಇಂಗ್ಲಿಷ್',
 				'en_AU' => 'ಆಸ್ಟ್ರೇಲಿಯನ್ ಇಂಗ್ಲಿಷ್',
 				'en_CA' => 'ಕೆನೆಡಿಯನ್ ಇಂಗ್ಲಿಷ್',
 				'en_GB' => 'ಬ್ರಿಟಿಷ್ ಇಂಗ್ಲಿಷ್',
 				'en_GB@alt=short' => 'ಯು.ಕೆ. ಇಂಗ್ಲಿಷ್',
 				'en_US' => 'ಅಮೆರಿಕನ್ ಇಂಗ್ಲಿಷ್',
 				'en_US@alt=short' => 'ಯು.ಎಸ್. ಇಂಗ್ಲಿಷ್',
 				'enm' => 'ಮಧ್ಯ ಇಂಗ್ಲೀಷ್',
 				'eo' => 'ಎಸ್ಪೆರಾಂಟೊ',
 				'es' => 'ಸ್ಪ್ಯಾನಿಷ್',
 				'es_419' => 'ಲ್ಯಾಟಿನ್ ಅಮೇರಿಕನ್ ಸ್ಪ್ಯಾನಿಷ್',
 				'es_ES' => 'ಯುರೋಪಿಯನ್ ಸ್ಪ್ಯಾನಿಷ್',
 				'es_MX' => 'ಮೆಕ್ಸಿಕನ್ ಸ್ಪ್ಯಾನಿಷ್',
 				'et' => 'ಎಸ್ಟೊನಿಯನ್',
 				'eu' => 'ಬಾಸ್ಕ್',
 				'ewo' => 'ಇವಾಂಡೋ',
 				'fa' => 'ಪರ್ಶಿಯನ್',
 				'fa_AF' => 'ದರಿ',
 				'fan' => 'ಫಾಂಗ್',
 				'fat' => 'ಫಾಂಟಿ',
 				'ff' => 'ಫುಲಾ',
 				'fi' => 'ಫಿನ್ನಿಶ್',
 				'fil' => 'ಫಿಲಿಪಿನೊ',
 				'fj' => 'ಫಿಜಿಯನ್',
 				'fo' => 'ಫರೋಸಿ',
 				'fon' => 'ಫೋನ್',
 				'fr' => 'ಫ್ರೆಂಚ್',
 				'fr_CA' => 'ಕೆನೆಡಿಯನ್ ಫ್ರೆಂಚ್',
 				'fr_CH' => 'ಸ್ವಿಸ್ ಫ್ರೆಂಚ್',
 				'frc' => 'ಕಾಜುನ್ ಫ್ರೆಂಚ್',
 				'frm' => 'ಮಧ್ಯ ಫ್ರೆಂಚ್',
 				'fro' => 'ಪ್ರಾಚೀನ ಫ್ರೆಂಚ್',
 				'frr' => 'ಉತ್ತರ ಫ್ರಿಸಿಯನ್',
 				'frs' => 'ಪೂರ್ವ ಫ್ರಿಸಿಯನ್',
 				'fur' => 'ಫ್ರಿಯುಲಿಯನ್',
 				'fy' => 'ಪಶ್ಚಿಮ ಫ್ರಿಸಿಯನ್',
 				'ga' => 'ಐರಿಷ್',
 				'gaa' => 'ಗ',
 				'gag' => 'ಗಗೌಜ್',
 				'gan' => 'ಗಾನ್ ಚೀನೀಸ್',
 				'gay' => 'ಗಾಯೋ',
 				'gba' => 'ಗ್ಬಾಯಾ',
 				'gd' => 'ಸ್ಕಾಟಿಶ್ ಗೆಲಿಕ್',
 				'gez' => 'ಗೀಝ್',
 				'gil' => 'ಗಿಲ್ಬರ್ಟೀಸ್',
 				'gl' => 'ಗ್ಯಾಲಿಶಿಯನ್',
 				'gmh' => 'ಮಧ್ಯ ಹೈ ಜರ್ಮನ್',
 				'gn' => 'ಗೌರಾನಿ',
 				'goh' => 'ಪ್ರಾಚೀನ ಹೈ ಜರ್ಮನ್',
 				'gon' => 'ಗೊಂಡಿ',
 				'gor' => 'ಗೊರೊಂಟಾಲೋ',
 				'got' => 'ಗೋಥಿಕ್',
 				'grb' => 'ಗ್ರೇಬೋ',
 				'grc' => 'ಪ್ರಾಚೀನ ಗ್ರೀಕ್',
 				'gsw' => 'ಸ್ವಿಸ್ ಜರ್ಮನ್',
 				'gu' => 'ಗುಜರಾತಿ',
 				'guz' => 'ಗುಸಿ',
 				'gv' => 'ಮ್ಯಾಂಕ್ಸ್',
 				'gwi' => 'ಗ್ವಿಚ್‌ಇನ್',
 				'ha' => 'ಹೌಸಾ',
 				'hai' => 'ಹೈಡಾ',
 				'hak' => 'ಹಕ್',
 				'haw' => 'ಹವಾಯಿಯನ್',
 				'hax' => 'ದಕ್ಷಿಣ ಹೈಡಾ',
 				'he' => 'ಹೀಬ್ರೂ',
 				'hi' => 'ಹಿಂದಿ',
 				'hi_Latn@alt=variant' => 'ಹಿಂಗ್ಲಿಷ್',
 				'hil' => 'ಹಿಲಿಗೇನನ್',
 				'hit' => 'ಹಿಟ್ಟಿಟೆ',
 				'hmn' => 'ಮೋಂಗ್',
 				'ho' => 'ಹಿರಿ ಮೊಟು',
 				'hr' => 'ಕ್ರೊಯೇಶಿಯನ್',
 				'hsb' => 'ಅಪ್ಪರ್ ಸರ್ಬಿಯನ್',
 				'hsn' => 'ಶಯಾಂಗ್ ಚೀನೀಸೇ',
 				'ht' => 'ಹೈಟಿಯನ್ ಕ್ರಿಯೋಲಿ',
 				'hu' => 'ಹಂಗೇರಿಯನ್',
 				'hup' => 'ಹೂಪಾ',
 				'hur' => 'ಹಾಲ್ಕೊಮೆಲೆಮ್',
 				'hy' => 'ಅರ್ಮೇನಿಯನ್',
 				'hz' => 'ಹೆರೆರೊ',
 				'ia' => 'ಇಂಟರ್‌ಲಿಂಗ್ವಾ',
 				'iba' => 'ಇಬಾನ್',
 				'ibb' => 'ಇಬಿಬಿಯೋ',
 				'id' => 'ಇಂಡೋನೇಶಿಯನ್',
 				'ie' => 'ಇಂಟರ್‌ಲಿಂಗ್',
 				'ig' => 'ಇಗ್ಬೊ',
 				'ii' => 'ಸಿಚುಅನ್ ಯಿ',
 				'ik' => 'ಇನುಪಿಯಾಕ್',
 				'ikt' => 'ಪಶ್ಚಿಮ ಕೆನಡಿಯನ್ ಇನುಕ್ಟಿಟುಟ್',
 				'ilo' => 'ಇಲ್ಲಿಕೋ',
 				'inh' => 'ಇಂಗುಷ್',
 				'io' => 'ಇಡೊ',
 				'is' => 'ಐಸ್‌ಲ್ಯಾಂಡಿಕ್',
 				'it' => 'ಇಟಾಲಿಯನ್',
 				'iu' => 'ಇನುಕ್ಟಿಟುಟ್',
 				'ja' => 'ಜಾಪನೀಸ್',
 				'jbo' => 'ಲೊಜ್ಬಾನ್',
 				'jgo' => 'ನೊಂಬಾ',
 				'jmc' => 'ಮ್ಯಕಮೆ',
 				'jpr' => 'ಜೂಡಿಯೋ-ಪರ್ಶಿಯನ್',
 				'jrb' => 'ಜೂಡಿಯೋ-ಅರೇಬಿಕ್',
 				'jv' => 'ಜಾವಾನೀಸ್',
 				'ka' => 'ಜಾರ್ಜಿಯನ್',
 				'kaa' => 'ಕಾರಾ-ಕಲ್ಪಾಕ್',
 				'kab' => 'ಕಬೈಲ್',
 				'kac' => 'ಕಚಿನ್',
 				'kaj' => 'ಜ್ಜು',
 				'kam' => 'ಕಂಬಾ',
 				'kaw' => 'ಕಾವಿ',
 				'kbd' => 'ಕಬರ್ಡಿಯನ್',
 				'kcg' => 'ಟ್ಯಾಪ್',
 				'kde' => 'ಮ್ಯಾಕೊಂಡ್',
 				'kea' => 'ಕಬುವೆರ್ಡಿಯನು',
 				'kfo' => 'ಕೋರೋ',
 				'kg' => 'ಕಾಂಗೋ',
 				'kgp' => 'ಕೈಗಂಗ್',
 				'kha' => 'ಖಾಸಿ',
 				'kho' => 'ಖೋಟಾನೀಸ್',
 				'khq' => 'ಕೊಯ್ರ ಚೀನಿ',
 				'ki' => 'ಕಿಕುಯು',
 				'kj' => 'ಕ್ವಾನ್‌ಯಾಮಾ',
 				'kk' => 'ಕಝಕ್',
 				'kkj' => 'ಕಾಕೊ',
 				'kl' => 'ಕಲಾಲ್ಲಿಸುಟ್',
 				'kln' => 'ಕಲೆಂಜಿನ್',
 				'km' => 'ಖಮೇರ್',
 				'kmb' => 'ಕಿಂಬುಂಡು',
 				'kn' => 'ಕನ್ನಡ',
 				'ko' => 'ಕೊರಿಯನ್',
 				'koi' => 'ಕೋಮಿ-ಪರ್ಮ್ಯಕ್',
 				'kok' => 'ಕೊಂಕಣಿ',
 				'kos' => 'ಕೊಸರಿಯನ್',
 				'kpe' => 'ಕಪೆಲ್ಲೆ',
 				'kr' => 'ಕನುರಿ',
 				'krc' => 'ಕರಚಯ್-ಬಲ್ಕಾರ್',
 				'krl' => 'ಕರೇಲಿಯನ್',
 				'kru' => 'ಕುರುಖ್',
 				'ks' => 'ಕಾಶ್ಮೀರಿ',
 				'ksb' => 'ಶಂಬಲ',
 				'ksf' => 'ಬಫಿಯ',
 				'ksh' => 'ಕಲೊಗ್ನಿಯನ್',
 				'ku' => 'ಕುರ್ದಿಷ್',
 				'kum' => 'ಕುಮೈಕ್',
 				'kut' => 'ಕುಟೇನಾಯ್',
 				'kv' => 'ಕೋಮಿ',
 				'kw' => 'ಕಾರ್ನಿಷ್',
 				'kwk' => 'ಕ್ವಾಕ್‌ವಾಲಾ',
 				'kxv' => 'ಕುವಿ',
 				'ky' => 'ಕಿರ್ಗಿಜ್',
 				'la' => 'ಲ್ಯಾಟಿನ್',
 				'lad' => 'ಲ್ಯಾಡಿನೋ',
 				'lag' => 'ಲಾಂಗಿ',
 				'lah' => 'ಲಹಂಡಾ',
 				'lam' => 'ಲಂಬಾ',
 				'lb' => 'ಲಕ್ಸಂಬರ್ಗಿಷ್',
 				'lez' => 'ಲೆಜ್ಘಿಯನ್',
 				'lg' => 'ಗಾಂಡಾ',
 				'li' => 'ಲಿಂಬರ್ಗಿಶ್',
 				'lij' => 'ಲಿಗುರಿಯನ್',
 				'lil' => 'ಲಿಲ್ಲೂವೆಟ್',
 				'lkt' => 'ಲಕೊಟ',
 				'lmo' => 'ಲೋಂಬರ್ಡ್',
 				'ln' => 'ಲಿಂಗಾಲ',
 				'lo' => 'ಲಾವೋ',
 				'lol' => 'ಮೊಂಗೋ',
 				'lou' => 'ಲೂಯಿಸಿಯಾನ ಕ್ರಿಯೋಲ್',
 				'loz' => 'ಲೋಝಿ',
 				'lrc' => 'ಉತ್ತರ ಲೂರಿ',
 				'lsm' => 'ಸಾಮಿಯಾ',
 				'lt' => 'ಲಿಥುವೇನಿಯನ್',
 				'lu' => 'ಲೂಬಾ-ಕಟಾಂಗಾ',
 				'lua' => 'ಲುಬ-ಲುಲಾ',
 				'lui' => 'ಲೂಯಿಸೆನೋ',
 				'lun' => 'ಲುಂಡಾ',
 				'luo' => 'ಲುವೋ',
 				'lus' => 'ಮಿಝೋ',
 				'luy' => 'ಲುಯಿಯ',
 				'lv' => 'ಲಾಟ್ವಿಯನ್',
 				'mad' => 'ಮದುರೀಸ್',
 				'mag' => 'ಮಗಾಹಿ',
 				'mai' => 'ಮೈಥಿಲಿ',
 				'mak' => 'ಮಕಾಸರ್',
 				'man' => 'ಮಂಡಿಂಗೊ',
 				'mas' => 'ಮಸಾಯ್',
 				'mdf' => 'ಮೋಕ್ಷ',
 				'mdr' => 'ಮಂದಾರ್',
 				'men' => 'ಮೆಂಡೆ',
 				'mer' => 'ಮೆರು',
 				'mfe' => 'ಮೊರಿಸನ್',
 				'mg' => 'ಮಲಗಾಸಿ',
 				'mga' => 'ಮಧ್ಯ ಐರಿಷ್',
 				'mgh' => 'ಮ್ಯಖುವಾ- ಮೀಟ್ಟೊ',
 				'mgo' => 'ಮೆಟಾ',
 				'mh' => 'ಮಾರ್ಶಲ್ಲೀಸ್',
 				'mi' => 'ಮಾವೋರಿ',
 				'mic' => 'ಮಿಕ್‌ಮ್ಯಾಕ್',
 				'min' => 'ಮಿನಂಗ್‌ಕಬಾವು',
 				'mk' => 'ಮೆಸಿಡೋನಿಯನ್',
 				'ml' => 'ಮಲಯಾಳಂ',
 				'mn' => 'ಮಂಗೋಲಿಯನ್',
 				'mnc' => 'ಮಂಚು',
 				'mni' => 'ಮಣಿಪುರಿ',
 				'moe' => 'ಇನ್ನು-ಐಮುನ್',
 				'moh' => 'ಮೊಹಾವ್ಕ್',
 				'mos' => 'ಮೊಸ್ಸಿ',
 				'mr' => 'ಮರಾಠಿ',
 				'ms' => 'ಮಲಯ್',
 				'mt' => 'ಮಾಲ್ಟೀಸ್',
 				'mua' => 'ಮುಂಡಂಗ್',
 				'mul' => 'ಬಹುಸಂಖ್ಯೆಯ ಭಾಷೆಗಳು',
 				'mus' => 'ಕ್ರೀಕ್',
 				'mwl' => 'ಮಿರಾಂಡೀಸ್',
 				'mwr' => 'ಮಾರ್ವಾಡಿ',
 				'my' => 'ಬರ್ಮೀಸ್',
 				'myv' => 'ಎರ್ಝ್ಯಾ',
 				'mzn' => 'ಮಜಂದೆರಾನಿ',
 				'na' => 'ನೌರು',
 				'nan' => 'ನಾನ್',
 				'nap' => 'ನಿಯಾಪೊಲಿಟನ್',
 				'naq' => 'ನಮ',
 				'nb' => 'ನಾರ್ವೆಜಿಯನ್ ಬೊಕ್ಮಲ್',
 				'nd' => 'ಉತ್ತರ ದೆಬೆಲೆ',
 				'nds' => 'ಲೋ ಜರ್ಮನ್',
 				'nds_NL' => 'ಲೋ ಸ್ಯಾಕ್ಸನ್',
 				'ne' => 'ನೇಪಾಳಿ',
 				'new' => 'ನೇವಾರೀ',
 				'ng' => 'ಡೋಂಗಾ',
 				'nia' => 'ನಿಯಾಸ್',
 				'niu' => 'ನಿಯುವನ್',
 				'nl' => 'ಡಚ್',
 				'nl_BE' => 'ಫ್ಲೆಮಿಷ್',
 				'nmg' => 'ಖ್ವಾಸಿಯೊ',
 				'nn' => 'ನಾರ್ವೇಜಿಯನ್ ನೈನಾರ್ಸ್ಕ್',
 				'nnh' => 'ನಿಂಬೂನ್',
 				'no' => 'ನಾರ್ವೇಜಿಯನ್',
 				'nog' => 'ನೊಗಾಯ್',
 				'non' => 'ಪ್ರಾಚೀನ ನೋರ್ಸ್',
 				'nqo' => 'ಎನ್‌ಕೋ',
 				'nr' => 'ದಕ್ಷಿಣ ದೆಬೆಲೆ',
 				'nso' => 'ಉತ್ತರ ಸೋಥೋ',
 				'nus' => 'ನೂಯರ್',
 				'nv' => 'ನವಾಜೊ',
 				'nwc' => 'ಶಾಸ್ತ್ರೀಯ ನೇವಾರಿ',
 				'ny' => 'ನ್ಯಾಂಜಾ',
 				'nym' => 'ನ್ಯಾಮ್‌ವೆಂಜಿ',
 				'nyn' => 'ನ್ಯಾನ್‌ಕೋಲೆ',
 				'nyo' => 'ನ್ಯೋರೋ',
 				'nzi' => 'ಜೀಮಾ',
 				'oc' => 'ಒಸಿಟನ್',
 				'oj' => 'ಒಜಿಬ್ವಾ',
 				'ojb' => 'ವಾಯುವ್ಯ ಓಜಿಬ್ವಾ',
 				'ojc' => 'ಮಧ್ಯ ಓಜಿಬ್ವಾ',
 				'ojs' => 'ಓಜಿ-ಕ್ರೀ',
 				'ojw' => 'ಪಶ್ಚಿಮ ಓಜಿಬ್ವಾ',
 				'oka' => 'ಒಕನಾಗನ್',
 				'om' => 'ಒರೊಮೊ',
 				'or' => 'ಒಡಿಯ',
 				'os' => 'ಒಸ್ಸೆಟಿಕ್',
 				'osa' => 'ಓಸಾಜ್',
 				'ota' => 'ಒಟ್ಟೋಮನ್ ತುರ್ಕಿಷ್',
 				'pa' => 'ಪಂಜಾಬಿ',
 				'pag' => 'ಪಂಗಾಸಿನನ್',
 				'pal' => 'ಪಹ್ಲವಿ',
 				'pam' => 'ಪಂಪಾಂಗಾ',
 				'pap' => 'ಪಪಿಯಾಮೆಂಟೊ',
 				'pau' => 'ಪಲುಆನ್',
 				'pcm' => 'ನೈಜೀರಿಯನ್ ಪಿಡ್ಗಿನ್',
 				'peo' => 'ಪ್ರಾಚೀನ ಪರ್ಶಿಯನ್',
 				'phn' => 'ಫೀನಿಷಿಯನ್',
 				'pi' => 'ಪಾಲಿ',
 				'pis' => 'ಪಿಜಿನ್',
 				'pl' => 'ಪೊಲಿಶ್',
 				'pon' => 'ಪೋನ್‌‌ಪಿಯನ್',
 				'pqm' => 'ಮ್ಯಾಲಿಸೀಟ್-ಪಸ್ಸಾಮಕ್ವಾಡ್ಡಿ',
 				'prg' => 'ಪ್ರಶಿಯನ್',
 				'pro' => 'ಪ್ರಾಚೀನ ಪ್ರೊವೆನ್ಶಿಯಲ್',
 				'ps' => 'ಪಾಷ್ಟೋ',
 				'ps@alt=variant' => 'ಪುಶ್ತೋ',
 				'pt' => 'ಪೋರ್ಚುಗೀಸ್',
 				'pt_BR' => 'ಬ್ರೆಜಿಲಿಯನ್ ಪೋರ್ಚುಗೀಸ್',
 				'pt_PT' => 'ಯೂರೋಪಿಯನ್ ಪೋರ್ಚುಗೀಸ್',
 				'qu' => 'ಕ್ವೆಚುವಾ',
 				'quc' => 'ಕಿಷೆ',
 				'raj' => 'ರಾಜಸ್ಥಾನಿ',
 				'rap' => 'ರಾಪಾನುಯಿ',
 				'rar' => 'ರಾರೋಟೊಂಗನ್',
 				'rhg' => 'ರೋಹಿಂಗ್ಯಾ',
 				'rm' => 'ರೊಮಾನ್ಶ್',
 				'rn' => 'ರುಂಡಿ',
 				'ro' => 'ರೊಮೇನಿಯನ್',
 				'ro_MD' => 'ಮಾಲ್ಡೇವಿಯನ್',
 				'rof' => 'ರೊಂಬೊ',
 				'rom' => 'ರೋಮಾನಿ',
 				'ru' => 'ರಷ್ಯನ್',
 				'rup' => 'ಅರೋಮಾನಿಯನ್',
 				'rw' => 'ಕಿನ್ಯಾರ್‌ವಾಂಡಾ',
 				'rwk' => 'ರುವ',
 				'sa' => 'ಸಂಸ್ಕೃತ',
 				'sad' => 'ಸಂಡಾವೇ',
 				'sah' => 'ಸಖಾ',
 				'sam' => 'ಸಮರಿಟನ್ ಅರಾಮಿಕ್',
 				'saq' => 'ಸಂಬುರು',
 				'sas' => 'ಸಸಾಕ್',
 				'sat' => 'ಸಂತಾಲಿ',
 				'sba' => 'ನಂಬೇ',
 				'sbp' => 'ಸಂಗು',
 				'sc' => 'ಸರ್ಡೀನಿಯನ್',
 				'scn' => 'ಸಿಸಿಲಿಯನ್',
 				'sco' => 'ಸ್ಕೋಟ್ಸ್',
 				'sd' => 'ಸಿಂಧಿ',
 				'sdh' => 'ದಕ್ಷಿಣ ಕುರ್ದಿಶ್',
 				'se' => 'ಉತ್ತರ ಸಾಮಿ',
 				'seh' => 'ಸೆನ',
 				'sel' => 'ಸೆಲ್ಕಪ್',
 				'ses' => 'ಕೊಯ್ರಬೊರೊ ಸೆನ್ನಿ',
 				'sg' => 'ಸಾಂಗೋ',
 				'sga' => 'ಪ್ರಾಚೀನ ಐರಿಷ್',
 				'sh' => 'ಸರ್ಬೋ-ಕ್ರೊಯೇಶಿಯನ್',
 				'shi' => 'ಟಷೆಲ್‍ಹಿಟ್',
 				'shn' => 'ಶಾನ್',
 				'si' => 'ಸಿಂಹಳ',
 				'sid' => 'ಸಿಡಾಮೋ',
 				'sk' => 'ಸ್ಲೋವಾಕ್',
 				'sl' => 'ಸ್ಲೋವೇನಿಯನ್',
 				'slh' => 'ದಕ್ಷಿಣ ಲುಶೂಟ್‌ಸೀಡ್',
 				'sm' => 'ಸಮೋವನ್',
 				'sma' => 'ದಕ್ಷಿಣ ಸಾಮಿ',
 				'smj' => 'ಲೂಲ್ ಸಾಮಿ',
 				'smn' => 'ಇನಾರಿ ಸಮೀ',
 				'sms' => 'ಸ್ಕೋಟ್ ಸಾಮಿ',
 				'sn' => 'ಶೋನಾ',
 				'snk' => 'ಸೋನಿಂಕೆ',
 				'so' => 'ಸೊಮಾಲಿ',
 				'sog' => 'ಸೋಗ್ಡಿಯನ್',
 				'sq' => 'ಅಲ್ಬೇನಿಯನ್',
 				'sr' => 'ಸೆರ್ಬಿಯನ್',
 				'srn' => 'ಸ್ರಾನನ್ ಟೋಂಗೋ',
 				'srr' => 'ಸೇರೇರ್',
 				'ss' => 'ಸ್ವಾತಿ',
 				'ssy' => 'ಸಹೊ',
 				'st' => 'ದಕ್ಷಿಣ ಸೋಥೋ',
 				'str' => 'ಸ್ಟ್ರೇಟ್ಸ್ ಸೆಲಿಶ್',
 				'su' => 'ಸುಂಡಾನೀಸ್',
 				'suk' => 'ಸುಕುಮಾ',
 				'sus' => 'ಸುಸು',
 				'sux' => 'ಸುಮೇರಿಯನ್',
 				'sv' => 'ಸ್ವೀಡಿಷ್',
 				'sw' => 'ಸ್ವಹಿಲಿ',
 				'sw_CD' => 'ಕಾಂಗೊ ಸ್ವಹಿಲಿ',
 				'swb' => 'ಕೊಮೊರಿಯನ್',
 				'syc' => 'ಶಾಸ್ತ್ರೀಯ ಸಿರಿಯಕ್',
 				'syr' => 'ಸಿರಿಯಾಕ್',
 				'szl' => 'ಸಿಲೆಸಿಯನ್',
 				'ta' => 'ತಮಿಳು',
 				'tce' => 'ದಕ್ಷಿಣ ಟಚ್‌ವನ್',
 				'te' => 'ತೆಲುಗು',
 				'tem' => 'ಟಿಮ್ನೆ',
 				'teo' => 'ಟೆಸೊ',
 				'ter' => 'ಟೆರೆನೋ',
 				'tet' => 'ಟೇಟಮ್',
 				'tg' => 'ತಾಜಿಕ್',
 				'tgx' => 'ಟಾಗಿಶ್',
 				'th' => 'ಥಾಯ್',
 				'tht' => 'ಟಾಹ್ಲ್ಟನ್',
 				'ti' => 'ಟಿಗ್ರಿನ್ಯಾ',
 				'tig' => 'ಟೈಗ್ರೆ',
 				'tiv' => 'ಟಿವ್',
 				'tk' => 'ಟರ್ಕ್‌ಮೆನ್',
 				'tkl' => 'ಟೊಕೆಲಾವ್',
 				'tl' => 'ಟ್ಯಾಗಲೋಗ್',
 				'tlh' => 'ಕ್ಲಿಂಗನ್',
 				'tli' => 'ಟ್ಲಿಂಗಿಟ್',
 				'tmh' => 'ಟಮಾಷೆಕ್',
 				'tn' => 'ಸ್ವಾನಾ',
 				'to' => 'ಟೋಂಗನ್',
 				'tog' => 'ನ್ಯಾಸಾ ಟೋಂಗಾ',
 				'tok' => 'ಟೋಕಿ ಪೋನಾ',
 				'tpi' => 'ಟೋಕ್ ಪಿಸಿನ್',
 				'tr' => 'ಟರ್ಕಿಶ್',
 				'trv' => 'ಟರೊಕೊ',
 				'ts' => 'ಸೋಂಗಾ',
 				'tsi' => 'ಸಿಂಶಿಯನ್',
 				'tt' => 'ಟಾಟರ್',
 				'ttm' => 'ಉತ್ತರ ಟಚ್‌ವನ್',
 				'tum' => 'ತುಂಬುಕಾ',
 				'tvl' => 'ಟುವಾಲು',
 				'tw' => 'ಟ್ವಿ',
 				'twq' => 'ಟಸವಕ್',
 				'ty' => 'ಟಹೀಟಿಯನ್',
 				'tyv' => 'ಟುವಿನಿಯನ್',
 				'tzm' => 'ಮಧ್ಯ ಅಟ್ಲಾಸ್ ಟಮಜೈಟ್',
 				'udm' => 'ಉಡ್‌ಮುರ್ಟ್',
 				'ug' => 'ಉಯಿಘರ್',
 				'ug@alt=variant' => 'ಉಯ್‌ಗರ್',
 				'uga' => 'ಉಗಾರಿಟಿಕ್',
 				'uk' => 'ಉಕ್ರೇನಿಯನ್',
 				'umb' => 'ಉಂಬುಂಡು',
 				'und' => 'ಅಪರಿಚಿತ ಭಾಷೆ',
 				'ur' => 'ಉರ್ದು',
 				'uz' => 'ಉಜ್ಬೇಕ್',
 				'vai' => 'ವಾಯಿ',
 				've' => 'ವೆಂಡಾ',
 				'vec' => 'ವೆನಿಶಿಯನ್',
 				'vi' => 'ವಿಯೆಟ್ನಾಮೀಸ್',
 				'vmw' => 'ಮಖುವಾ',
 				'vo' => 'ವೋಲಾಪುಕ್',
 				'vot' => 'ವೋಟಿಕ್',
 				'vun' => 'ವುಂಜೊ',
 				'wa' => 'ವಾಲೂನ್',
 				'wae' => 'ವಾಲ್ಸರ್',
 				'wal' => 'ವಲಾಯ್ತಾ',
 				'war' => 'ವರಾಯ್',
 				'was' => 'ವಾಷೋ',
 				'wbp' => 'ವಾರ್ಲ್‌ಪಿರಿ',
 				'wo' => 'ವೋಲೋಫ್',
 				'wuu' => 'ವು ಚೈನೀಸ್',
 				'xal' => 'ಕಲ್ಮೈಕ್',
 				'xh' => 'ಕ್ಸೋಸ',
 				'xnr' => 'ಕಂಗ್ರಿ',
 				'xog' => 'ಸೊಗ',
 				'yao' => 'ಯಾವೊ',
 				'yap' => 'ಯಪೀಸೆ',
 				'yav' => 'ಯಾಂಗ್ಬೆನ್',
 				'ybb' => 'ಯೆಂಬಾ',
 				'yi' => 'ಯಿಡ್ಡಿಶ್',
 				'yo' => 'ಯೊರುಬಾ',
 				'yrl' => 'ನಿಂಗಾಟು',
 				'yue' => 'ಕ್ಯಾಂಟನೀಸ್',
 				'yue@alt=menu' => 'ಚೈನೀಸ್, ಕ್ಯಾಂಟೊನೀಸ್',
 				'za' => 'ಝೂವಾಂಗ್',
 				'zap' => 'ಝೋಪೊಟೆಕ್',
 				'zbl' => 'ಬ್ಲಿಸ್ಸಿಂಬಲ್ಸ್',
 				'zen' => 'ಝೆನಾಗಾ',
 				'zgh' => 'ಸ್ಟ್ಯಾಂಡರ್ಡ್ ಮೊರೊಕ್ಕನ್ ಟಮಜೈಟ್',
 				'zh' => 'ಚೈನೀಸ್',
 				'zh@alt=menu' => 'ಚೈನೀಸ್, ಮ್ಯಾಂಡರಿನ್',
 				'zh_Hans' => 'ಸರಳೀಕೃತ ಚೈನೀಸ್',
 				'zh_Hans@alt=long' => 'ಸರಳೀಕೃತ ಮ್ಯಾಂಡರಿನ್ ಚೈನೀಸ್',
 				'zh_Hant' => 'ಸಾಂಪ್ರದಾಯಿಕ ಚೈನೀಸ್',
 				'zh_Hant@alt=long' => 'ಸಾಂಪ್ರದಾಯಿಕ ಮ್ಯಾಂಡರಿನ್ ಚೈನೀಸ್',
 				'zu' => 'ಜುಲು',
 				'zun' => 'ಝೂನಿ',
 				'zxx' => 'ಯಾವುದೇ ಭಾಷಾಸಂಬಂಧಿ ವಿಷಯವಿಲ್ಲ',
 				'zza' => 'ಜಾಝಾ',

			);
			if (@_) {
				return $languages{$_[0]};
			}
			return \%languages;
		}
	},
);

has 'display_name_script' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		sub {
			my %scripts = (
			'Adlm' => 'ಆ್ಯಡ್ಲಮ್',
 			'Arab' => 'ಅರೇಬಿಕ್',
 			'Arab@alt=variant' => 'ಪರ್ಸೊ-ಅರೇಬಿಕ್',
 			'Aran' => 'ನಸ್ಟಾಲಿಕ್',
 			'Armi' => 'ಇಂಪೀರಿಯಲ್ ಅರೆಮಾಯಿಕ್',
 			'Armn' => 'ಅರ್ಮೇನಿಯನ್',
 			'Avst' => 'ಅವೆಸ್ತಾನ್',
 			'Bali' => 'ಬಾಲಿನೀಸ್',
 			'Batk' => 'ಬಾಟಕ್',
 			'Beng' => 'ಬೆಂಗಾಲಿ',
 			'Blis' => 'ಬ್ಲಿಸ್‌ಸಿಂಬಲ್ಸ್',
 			'Bopo' => 'ಬೋಪೊಮೋಫೋ',
 			'Brah' => 'ಬ್ರಾಹ್ಮಿ',
 			'Brai' => 'ಬ್ರೈಲ್',
 			'Bugi' => 'ಬಗಿನೀಸ್',
 			'Buhd' => 'ಬುಹಿದ್',
 			'Cakm' => 'ಚಕ್ಮಾ',
 			'Cans' => 'ಯುನಿಫೈಯ್ಡ್ ಕೆನೆಡಿಯನ್ ಅಬೊರಿಜಿನಲ್ ಸಿಲ್ಯಾಬಿಕ್ಸ್',
 			'Cari' => 'ಕರೇನ್',
 			'Cham' => 'ಚಾಮ್',
 			'Cher' => 'ಚೆರೋಕೀ',
 			'Cirt' => 'ಸಿರ್ಥ್',
 			'Copt' => 'ಕಾಪ್ಟಿಕ್',
 			'Cprt' => 'ಸಿಪ್ರಿಯಾಟ್',
 			'Cyrl' => 'ಸಿರಿಲಿಕ್',
 			'Cyrs' => 'ಪ್ರಾಚೀನ ಚರ್ಚ್ ಸ್ಲೋವಾನಿಕ್ ಸಿರಿಲಿಕ್',
 			'Deva' => 'ದೇವನಾಗರಿ',
 			'Dsrt' => 'ಡಸರ್ಟ್',
 			'Egyd' => 'ಈಜಿಪ್ಟಿಯನ್ ಡೆಮೋಟಿಕ್',
 			'Egyh' => 'ಈಜಿಪ್ಟಿಯನ್ ಹಯಾರಿಟಿಕ್',
 			'Egyp' => 'ಈಜಿಪ್ಟಿಯನ್ ಹೀರೋಗ್ಲಿಫ್ಸ್',
 			'Ethi' => 'ಇಥಿಯೋಪಿಕ್',
 			'Geok' => 'ಜಾರ್ಜಿಯನ್ ಖುಸ್ತುರಿ',
 			'Geor' => 'ಜಾರ್ಜಿಯನ್',
 			'Glag' => 'ಗ್ಲಾಗೋಲಿಟಿಕ್',
 			'Goth' => 'ಗೋತಿಕ್',
 			'Grek' => 'ಗ್ರೀಕ್',
 			'Gujr' => 'ಗುಜರಾತಿ',
 			'Guru' => 'ಗುರ್ಮುಖಿ',
 			'Hanb' => 'ಬೋಪೋಮೊಫೋ ಜೊತೆಗೆ ಹಾನ್',
 			'Hang' => 'ಹ್ಯಾಂಗುಲ್',
 			'Hani' => 'ಹಾನ್',
 			'Hano' => 'ಹನೂನೂ',
 			'Hans' => 'ಸರಳೀಕೃತ',
 			'Hans@alt=stand-alone' => 'ಸರಳೀಕೃತ ಹಾನ್',
 			'Hant' => 'ಸಾಂಪ್ರದಾಯಿಕ',
 			'Hant@alt=stand-alone' => 'ಸಾಂಪ್ರದಾಯಿಕ ಹಾನ್',
 			'Hebr' => 'ಹೀಬ್ರೂ',
 			'Hira' => 'ಹಿರಾಗನ',
 			'Hmng' => 'ಪಹವ್ ಹ್ಮೋಂಗ್',
 			'Hrkt' => 'ಜಪಾನೀಸ್ ಸಿಲಬರೀಸ್',
 			'Hung' => 'ಪ್ರಾಚೀನ ಹಂಗೇರಿಯನ್',
 			'Inds' => 'ಸಿಂಧೂ',
 			'Ital' => 'ಪ್ರಾಚೀನ್ ಇಟಾಲಿಕ್',
 			'Jamo' => 'ಜಮೋ',
 			'Java' => 'ಜಾವನೀಸ್',
 			'Jpan' => 'ಜಾಪನೀಸ್',
 			'Kali' => 'ಕೆಯಾ ಲಿ',
 			'Kana' => 'ಕಟಕಾನಾ',
 			'Khar' => 'ಖರೋಶ್ತಿ',
 			'Khmr' => 'ಖಮೇರ್',
 			'Knda' => 'ಕನ್ನಡ',
 			'Kore' => 'ಕೊರಿಯನ್',
 			'Kthi' => 'ಕೈಥಿ',
 			'Lana' => 'ಲಾನಾ',
 			'Laoo' => 'ಲಾವೋ',
 			'Latf' => 'ಫ್ರಾಕ್ತರ್ ಲ್ಯಾಟಿನ್',
 			'Latg' => 'ಗೇಲಿಕ್ ಲ್ಯಾಟಿನ್',
 			'Latn' => 'ಲ್ಯಾಟಿನ್',
 			'Lepc' => 'ಲೆಪ್ಚಾ',
 			'Limb' => 'ಲಿಂಬು',
 			'Lina' => 'ಲೀನಯರ್ ಎ',
 			'Linb' => 'ಲೀನಯರ್ ಬಿ',
 			'Lyci' => 'ಲೈಸಿಯನ್',
 			'Lydi' => 'ಲಿಡಿಯನ್',
 			'Mand' => 'ಮಂಡೇಯನ್',
 			'Mani' => 'ಮನಿಚೈಯನ್',
 			'Maya' => 'ಮಯಾನ್ ಹೀರೋಗ್ಲಿಫ್ಸ್',
 			'Mero' => 'ಮೆರೊಯಿಟಿಕ್',
 			'Mlym' => 'ಮಲಯಾಳಂ',
 			'Mong' => 'ಮಂಗೋಲಿಯನ್',
 			'Moon' => 'ಮೂನ್',
 			'Mtei' => 'ಮೈತಿ ಮಯೆಕ್',
 			'Mymr' => 'ಮ್ಯಾನ್ಮಾರ್',
 			'Nkoo' => 'ಎನ್‍ಕೋ',
 			'Ogam' => 'ಓಘಮ್',
 			'Olck' => 'ಓಲ್ ಚಿಕಿ',
 			'Orkh' => 'ಓರ್ಖೋನ್',
 			'Orya' => 'ಒಡಿಯಾ',
 			'Osma' => 'ಓಸ್ಮಾನ್ಯಾ',
 			'Perm' => 'ಪ್ರಾಚೀನ ಪೆರ್ಮಿಕ್',
 			'Phag' => 'ಫಾಗ್ಸ್-ಪಾ',
 			'Phli' => 'ಇನ್ಸ್‌ಕ್ರಿಪ್ಶನಲ್ ಪಾಹ್ಲವಿ',
 			'Phlp' => 'ಸಾಲ್ಟರ್ ಪಾಹ್ಲವಿ',
 			'Phlv' => 'ಬುಕ್ ಪಾಹ್ಲವಿ',
 			'Phnx' => 'ಫೀನಿಶಿಯನ್',
 			'Plrd' => 'ಪೊಲ್ಲಾರ್ಡ್ ಫೊನೆಟಿಕ್',
 			'Prti' => 'ಇನ್ಸ್‌ಕ್ರಿಪ್ಶನಲ್ ಪಾರ್ಥಿಯನ್',
 			'Rjng' => 'ರೆಜಾಂಗ್',
 			'Rohg' => 'ಹನೀಫಿ',
 			'Roro' => 'ರೋಂಗೋರೋಂಗೋ',
 			'Runr' => 'ರೂನಿಕ್',
 			'Samr' => 'ಸಮಾರಿಟನ್',
 			'Sara' => 'ಸರಾಟಿ',
 			'Saur' => 'ಸೌರಾಷ್ಟ್ರ',
 			'Sgnw' => 'ಸೈನ್‌ರೈಟಿಂಗ್',
 			'Shaw' => 'ಶಾವಿಯಾನ್',
 			'Sinh' => 'ಸಿಂಹಳ',
 			'Sund' => 'ಸುಂಡಾನೀಸ್',
 			'Sylo' => 'ಸೈಲೋಟಿ ನಗ್ರಿ',
 			'Syrc' => 'ಸಿರಿಯಾಕ್',
 			'Syre' => 'ಎಸ್ಟ್ರಾಂಜಿಲೋ ಸಿರಿಯಾಕ್',
 			'Syrj' => 'ಪಶ್ಚಿಮ ಸಿರಿಯಾಕ್',
 			'Syrn' => 'ಪೂರ್ವ ಸಿರಿಯಾಕ್',
 			'Tagb' => 'ಟಾಗ್ಬಾನವಾ',
 			'Tale' => 'ಥಾಯ್ ಲಿ',
 			'Talu' => 'ನ್ಯೂ ಥಾಯ್ ಲುಇ',
 			'Taml' => 'ತಮಿಳು',
 			'Tavt' => 'ಥಾಯ್ ವಿಯೆಟ್',
 			'Telu' => 'ತೆಲುಗು',
 			'Teng' => 'ತೆಂಗ್‌ವಾರ್',
 			'Tfng' => 'ಟಿಫಿನಾಘ್',
 			'Tglg' => 'ಟ್ಯಾಗಲೋಗ್',
 			'Thaa' => 'ಥಾನಾ',
 			'Thai' => 'ಥಾಯ್',
 			'Tibt' => 'ಟಿಬೇಟನ್',
 			'Ugar' => 'ಉಗಾರಿಟಿಕ್',
 			'Vaii' => 'ವಾಯ್',
 			'Visp' => 'ವಿಸಿಬಲ್ ಸ್ಪೀಚ್',
 			'Xpeo' => 'ಪ್ರಾಚೀನ ಪರ್ಶಿಯನ್',
 			'Xsux' => 'ಸುಮೇರೋ-ಅಕ್ಕಾಡಿಯನ್ ಕ್ಯೂನಿಫಾರ್ಮ್',
 			'Yiii' => 'ಯಿ',
 			'Zinh' => 'ಇನ್‍ಹೆರಿಟೆಡ್',
 			'Zmth' => 'ಗಣಿತ ಸಂಕೇತಲಿಪಿ',
 			'Zsye' => 'ಎಮೋಜಿ',
 			'Zsym' => 'ಸಂಕೇತಗಳು',
 			'Zxxx' => 'ಅಲಿಖಿತ',
 			'Zyyy' => 'ಸಾಮಾನ್ಯ',
 			'Zzzz' => 'ಅಪರಿಚಿತ ಲಿಪಿ',

			);
			if ( @_ ) {
				return $scripts{$_[0]};
			}
			return \%scripts;
		}
	}
);

has 'display_name_region' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'001' => 'ಪ್ರಪಂಚ',
 			'002' => 'ಆಫ್ರಿಕಾ',
 			'003' => 'ಉತ್ತರ ಅಮೇರಿಕಾ',
 			'005' => 'ದಕ್ಷಿಣ ಅಮೇರಿಕಾ',
 			'009' => 'ಓಶಿಯೇನಿಯಾ',
 			'011' => 'ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ',
 			'013' => 'ಮಧ್ಯ ಅಮೇರಿಕಾ',
 			'014' => 'ಪೂರ್ವ ಆಫ್ರಿಕಾ',
 			'015' => 'ಉತ್ತರ ಆಫ್ರಿಕಾ',
 			'017' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ',
 			'018' => 'ಆಫ್ರಿಕಾದ ದಕ್ಷಿಣ ಭಾಗ',
 			'019' => 'ಅಮೆರಿಕಾಸ್',
 			'021' => 'ಅಮೇರಿಕಾದ ಉತ್ತರ ಭಾಗ',
 			'029' => 'ಕೆರೀಬಿಯನ್',
 			'030' => 'ಪೂರ್ವ ಏಷ್ಯಾ',
 			'034' => 'ದಕ್ಷಿಣ ಏಷ್ಯಾ',
 			'035' => 'ಆಗ್ನೇಯ ಏಷ್ಯಾ',
 			'039' => 'ದಕ್ಷಿಣ ಯೂರೋಪ್',
 			'053' => 'ಆಸ್ಟ್ರೇಲೇಷ್ಯಾ',
 			'054' => 'ಮೆಲನೇಷಿಯಾ',
 			'057' => 'ಮೈಕ್ರೋನೇಶಿಯನ್ ಪ್ರದೇಶ',
 			'061' => 'ಪಾಲಿನೇಷ್ಯಾ',
 			'142' => 'ಏಷ್ಯಾ',
 			'143' => 'ಮಧ್ಯ ಏಷ್ಯಾ',
 			'145' => 'ಪಶ್ಚಿಮ ಏಷ್ಯಾ',
 			'150' => 'ಯೂರೋಪ್',
 			'151' => 'ಪೂರ್ವ ಯೂರೋಪ್',
 			'154' => 'ಉತ್ತರ ಯೂರೋಪ್',
 			'155' => 'ಪಶ್ಚಿಮ ಯೂರೋಪ್',
 			'202' => 'ಉಪ-ಸಹಾರನ್ ಆಫ್ರಿಕಾ',
 			'419' => 'ಲ್ಯಾಟಿನ್ ಅಮೇರಿಕಾ',
 			'AC' => 'ಅಸೆನ್ಶನ್ ದ್ವೀಪ',
 			'AD' => 'ಅಂಡೋರಾ',
 			'AE' => 'ಯುನೈಟೆಡ್ ಅರಬ್ ಎಮಿರೇಟ್ಸ್',
 			'AF' => 'ಅಫಘಾನಿಸ್ಥಾನ',
 			'AG' => 'ಆಂಟಿಗುವಾ ಮತ್ತು ಬರ್ಬುಡಾ',
 			'AI' => 'ಆಂಗ್ವಿಲ್ಲಾ',
 			'AL' => 'ಅಲ್ಬೇನಿಯಾ',
 			'AM' => 'ಆರ್ಮೇನಿಯ',
 			'AO' => 'ಅಂಗೋಲಾ',
 			'AQ' => 'ಅಂಟಾರ್ಟಿಕಾ',
 			'AR' => 'ಅರ್ಜೆಂಟಿನಾ',
 			'AS' => 'ಅಮೇರಿಕನ್ ಸಮೋವಾ',
 			'AT' => 'ಆಸ್ಟ್ರಿಯಾ',
 			'AU' => 'ಆಸ್ಟ್ರೇಲಿಯಾ',
 			'AW' => 'ಅರುಬಾ',
 			'AX' => 'ಆಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳು',
 			'AZ' => 'ಅಜರ್ಬೈಜಾನ್',
 			'BA' => 'ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ',
 			'BB' => 'ಬಾರ್ಬಡೋಸ್',
 			'BD' => 'ಬಾಂಗ್ಲಾದೇಶ',
 			'BE' => 'ಬೆಲ್ಜಿಯಮ್',
 			'BF' => 'ಬುರ್ಕಿನಾ ಫಾಸೊ',
 			'BG' => 'ಬಲ್ಗೇರಿಯಾ',
 			'BH' => 'ಬಹ್ರೇನ್',
 			'BI' => 'ಬುರುಂಡಿ',
 			'BJ' => 'ಬೆನಿನ್',
 			'BL' => 'ಸೇಂಟ್ ಬಾರ್ಥೆಲೆಮಿ',
 			'BM' => 'ಬರ್ಮುಡಾ',
 			'BN' => 'ಬ್ರೂನಿ',
 			'BO' => 'ಬೊಲಿವಿಯಾ',
 			'BQ' => 'ಕೆರೀಬಿಯನ್ ನೆದರ್‌ಲ್ಯಾಂಡ್ಸ್',
 			'BR' => 'ಬ್ರೆಜಿಲ್',
 			'BS' => 'ಬಹಾಮಾಸ್',
 			'BT' => 'ಭೂತಾನ್',
 			'BV' => 'ಬೋವೆಟ್ ದ್ವೀಪ',
 			'BW' => 'ಬೋಟ್ಸ್‌ವಾನಾ',
 			'BY' => 'ಬೆಲಾರಸ್',
 			'BZ' => 'ಬೆಲಿಜ್',
 			'CA' => 'ಕೆನಡಾ',
 			'CC' => 'ಕೊಕೊಸ್ (ಕೀಲಿಂಗ್) ದ್ವೀಪಗಳು',
 			'CD' => 'ಕಾಂಗೋ - ಕಿನ್ಶಾಸಾ',
 			'CD@alt=variant' => 'ಕಾಂಗೋ (DRC)',
 			'CF' => 'ಮಧ್ಯ ಆಫ್ರಿಕಾ ಗಣರಾಜ್ಯ',
 			'CG' => 'ಕಾಂಗೋ - ಬ್ರಾಜಾವಿಲ್ಲೇ',
 			'CG@alt=variant' => 'ಕಾಂಗೋ (ಗಣರಾಜ್ಯ)',
 			'CH' => 'ಸ್ವಿಟ್ಜರ್ಲ್ಯಾಂಡ್',
 			'CI' => 'ಕೋತ್ ದ್‘ಇವಾರ್',
 			'CI@alt=variant' => 'ಐವರಿ ಕೋಸ್ಟ್',
 			'CK' => 'ಕುಕ್ ದ್ವೀಪಗಳು',
 			'CL' => 'ಚಿಲಿ',
 			'CM' => 'ಕ್ಯಾಮರೂನ್',
 			'CN' => 'ಚೀನಾ',
 			'CO' => 'ಕೊಲಂಬಿಯಾ',
 			'CP' => 'ಕ್ಲಿಪ್ಪರ್‌ಟಾನ್ ದ್ವೀಪ',
 			'CR' => 'ಕೊಸ್ಟಾ ರಿಕಾ',
 			'CU' => 'ಕ್ಯೂಬಾ',
 			'CV' => 'ಕೇಪ್ ವರ್ಡೆ',
 			'CW' => 'ಕುರಾಕಾವ್',
 			'CX' => 'ಕ್ರಿಸ್ಮಸ್ ದ್ವೀಪ',
 			'CY' => 'ಸೈಪ್ರಸ್',
 			'CZ' => 'ಝೆಕಿಯಾ',
 			'CZ@alt=variant' => 'ಜೆಕ್ ಗಣರಾಜ್ಯ',
 			'DE' => 'ಜರ್ಮನಿ',
 			'DG' => 'ಡೈಗೋ ಗಾರ್ಸಿಯ',
 			'DJ' => 'ಜಿಬೂಟಿ',
 			'DK' => 'ಡೆನ್ಮಾರ್ಕ್',
 			'DM' => 'ಡೊಮಿನಿಕಾ',
 			'DO' => 'ಡೊಮೆನಿಕನ್ ರಿಪಬ್ಲಿಕ್',
 			'DZ' => 'ಅಲ್ಜೀರಿಯ',
 			'EA' => 'ಸೆಯುಟಾ ಹಾಗೂ ಮೆಲಿಲ್ಲಾ',
 			'EC' => 'ಈಕ್ವೆಡಾರ್',
 			'EE' => 'ಎಸ್ಟೋನಿಯಾ',
 			'EG' => 'ಈಜಿಪ್ಟ್',
 			'EH' => 'ಪಶ್ಚಿಮ ಸಹಾರಾ',
 			'ER' => 'ಎರಿಟ್ರಿಯಾ',
 			'ES' => 'ಸ್ಪೇನ್',
 			'ET' => 'ಇಥಿಯೋಪಿಯಾ',
 			'EU' => 'ಯುರೋಪಿಯನ್ ಒಕ್ಕೂಟ',
 			'EZ' => 'ಯೂರೋಝೋನ್‌',
 			'FI' => 'ಫಿನ್‌ಲ್ಯಾಂಡ್',
 			'FJ' => 'ಫಿಜಿ',
 			'FK' => 'ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳು',
 			'FK@alt=variant' => 'ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳು (ಇಸ್ಲಾಸ್ ಮಾಲ್ವಿನಸ್)',
 			'FM' => 'ಮೈಕ್ರೋನೇಶಿಯಾ',
 			'FO' => 'ಫರೋ ದ್ವೀಪಗಳು',
 			'FR' => 'ಫ್ರಾನ್ಸ್',
 			'GA' => 'ಗೆಬೊನ್',
 			'GB' => 'ಯುನೈಟೆಡ್ ಕಿಂಗ್‌ಡಮ್',
 			'GB@alt=short' => 'ಯು.ಕೆ.',
 			'GD' => 'ಗ್ರೆನೆಡಾ',
 			'GE' => 'ಜಾರ್ಜಿಯಾ',
 			'GF' => 'ಫ್ರೆಂಚ್ ಗಯಾನಾ',
 			'GG' => 'ಗುರ್ನ್‌ಸೆ',
 			'GH' => 'ಘಾನಾ',
 			'GI' => 'ಗಿಬ್ರಾಲ್ಟರ್',
 			'GL' => 'ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್',
 			'GM' => 'ಗ್ಯಾಂಬಿಯಾ',
 			'GN' => 'ಗಿನಿ',
 			'GP' => 'ಗುಡೆಲೋಪ್',
 			'GQ' => 'ಈಕ್ವೆಟೋರಿಯಲ್ ಗಿನಿ',
 			'GR' => 'ಗ್ರೀಸ್',
 			'GS' => 'ದಕ್ಷಿಣ ಜಾರ್ಜಿಯಾ ಮತ್ತು ದಕ್ಷಿಣ ಸ್ಯಾಂಡ್‍ವಿಚ್ ದ್ವೀಪಗಳು',
 			'GT' => 'ಗ್ವಾಟೆಮಾಲಾ',
 			'GU' => 'ಗುವಾಮ್',
 			'GW' => 'ಗಿನಿ-ಬಿಸ್ಸಾವ್',
 			'GY' => 'ಗಯಾನಾ',
 			'HK' => 'ಹಾಂಗ್ ಕಾಂಗ್ ಎಸ್ಎಆರ್ ಚೈನಾ',
 			'HK@alt=short' => 'ಹಾಂಗ್ ಕಾಂಗ್',
 			'HM' => 'ಹರ್ಡ್ ಮತ್ತು ಮ್ಯಾಕ್‌ಡೋನಾಲ್ಡ್ ದ್ವೀಪಗಳು',
 			'HN' => 'ಹೊಂಡುರಾಸ್',
 			'HR' => 'ಕ್ರೊಯೇಷಿಯಾ',
 			'HT' => 'ಹೈಟಿ',
 			'HU' => 'ಹಂಗೇರಿ',
 			'IC' => 'ಕ್ಯಾನರಿ ದ್ವೀಪಗಳು',
 			'ID' => 'ಇಂಡೋನೇಶಿಯಾ',
 			'IE' => 'ಐರ್ಲೆಂಡ್',
 			'IL' => 'ಇಸ್ರೇಲ್',
 			'IM' => 'ಐಲ್ ಆಫ್ ಮ್ಯಾನ್',
 			'IN' => 'ಭಾರತ',
 			'IO' => 'ಬ್ರಿಟೀಷ್ ಹಿಂದೂ ಮಹಾಸಾಗರದ ಪ್ರದೇಶ',
 			'IO@alt=chagos' => 'ಚಾಗೋಸ್ ದ್ವೀಪಸಮೂಹ',
 			'IQ' => 'ಇರಾಕ್',
 			'IR' => 'ಇರಾನ್',
 			'IS' => 'ಐಸ್‌ಲ್ಯಾಂಡ್',
 			'IT' => 'ಇಟಲಿ',
 			'JE' => 'ಜೆರ್ಸಿ',
 			'JM' => 'ಜಮೈಕಾ',
 			'JO' => 'ಜೋರ್ಡಾನ್',
 			'JP' => 'ಜಪಾನ್',
 			'KE' => 'ಕೀನ್ಯಾ',
 			'KG' => 'ಕಿರ್ಗಿಸ್ಥಾನ್',
 			'KH' => 'ಕಾಂಬೋಡಿಯಾ',
 			'KI' => 'ಕಿರಿಬಾಟಿ',
 			'KM' => 'ಕೊಮೊರೊಸ್',
 			'KN' => 'ಸೇಂಟ್ ಕಿಟ್ಸ್ ಮತ್ತು ನೆವಿಸ್',
 			'KP' => 'ಉತ್ತರ ಕೊರಿಯಾ',
 			'KR' => 'ದಕ್ಷಿಣ ಕೊರಿಯಾ',
 			'KW' => 'ಕುವೈತ್',
 			'KY' => 'ಕೇಮನ್ ದ್ವೀಪಗಳು',
 			'KZ' => 'ಕಝಾಕಿಸ್ಥಾನ್',
 			'LA' => 'ಲಾವೋಸ್',
 			'LB' => 'ಲೆಬನಾನ್',
 			'LC' => 'ಸೇಂಟ್ ಲೂಸಿಯಾ',
 			'LI' => 'ಲಿಚೆನ್‌ಸ್ಟೈನ್',
 			'LK' => 'ಶ್ರೀಲಂಕಾ',
 			'LR' => 'ಲಿಬೇರಿಯಾ',
 			'LS' => 'ಲೆಸೊಥೊ',
 			'LT' => 'ಲಿಥುವೇನಿಯಾ',
 			'LU' => 'ಲಕ್ಸೆಂಬರ್ಗ್',
 			'LV' => 'ಲಾಟ್ವಿಯಾ',
 			'LY' => 'ಲಿಬಿಯಾ',
 			'MA' => 'ಮೊರಾಕ್ಕೊ',
 			'MC' => 'ಮೊನಾಕೊ',
 			'MD' => 'ಮೊಲ್ಡೋವಾ',
 			'ME' => 'ಮೊಂಟೆನೆಗ್ರೋ',
 			'MF' => 'ಸೇಂಟ್ ಮಾರ್ಟಿನ್',
 			'MG' => 'ಮಡಗಾಸ್ಕರ್',
 			'MH' => 'ಮಾರ್ಷಲ್ ದ್ವೀಪಗಳು',
 			'MK' => 'ಉತ್ತರ ಮ್ಯಾಸಿಡೋನಿಯಾ',
 			'ML' => 'ಮಾಲಿ',
 			'MM' => 'ಮಯನ್ಮಾರ್ (ಬರ್ಮಾ)',
 			'MN' => 'ಮಂಗೋಲಿಯಾ',
 			'MO' => 'ಮಕಾವು ಎಸ್ಎಆರ್ ಚೈನಾ',
 			'MO@alt=short' => 'ಮಕಾವು',
 			'MP' => 'ಉತ್ತರ ಮರಿಯಾನಾ ದ್ವೀಪಗಳು',
 			'MQ' => 'ಮಾರ್ಟಿನಿಕ್',
 			'MR' => 'ಮಾರಿಟೇನಿಯಾ',
 			'MS' => 'ಮಾಂಟ್‌ಸೆರಟ್',
 			'MT' => 'ಮಾಲ್ಟಾ',
 			'MU' => 'ಮಾರಿಷಸ್',
 			'MV' => 'ಮಾಲ್ಡೀವ್ಸ್',
 			'MW' => 'ಮಲಾವಿ',
 			'MX' => 'ಮೆಕ್ಸಿಕೊ',
 			'MY' => 'ಮಲೇಶಿಯಾ',
 			'MZ' => 'ಮೊಜಾಂಬಿಕ್',
 			'NA' => 'ನಮೀಬಿಯಾ',
 			'NC' => 'ನ್ಯೂ ಕ್ಯಾಲಿಡೋನಿಯಾ',
 			'NE' => 'ನೈಜರ್',
 			'NF' => 'ನಾರ್ಫೋಕ್ ದ್ವೀಪ',
 			'NG' => 'ನೈಜೀರಿಯಾ',
 			'NI' => 'ನಿಕಾರಾಗುವಾ',
 			'NL' => 'ನೆದರ್‌ಲ್ಯಾಂಡ್ಸ್',
 			'NO' => 'ನಾರ್ವೆ',
 			'NP' => 'ನೇಪಾಳ',
 			'NR' => 'ನೌರು',
 			'NU' => 'ನಿಯು',
 			'NZ' => 'ನ್ಯೂಜಿಲೆಂಡ್',
 			'NZ@alt=variant' => 'ಔಟೆರೋವಾ ನ್ಯೂಜಿಲೆಂಡ್',
 			'OM' => 'ಓಮನ್',
 			'PA' => 'ಪನಾಮಾ',
 			'PE' => 'ಪೆರು',
 			'PF' => 'ಫ್ರೆಂಚ್ ಪಾಲಿನೇಷ್ಯಾ',
 			'PG' => 'ಪಪುವಾ ನ್ಯೂಗಿನಿಯಾ',
 			'PH' => 'ಫಿಲಿಫೈನ್ಸ್',
 			'PK' => 'ಪಾಕಿಸ್ತಾನ',
 			'PL' => 'ಪೋಲ್ಯಾಂಡ್',
 			'PM' => 'ಸೇಂಟ್ ಪಿಯರ್ ಮತ್ತು ಮಿಕ್ವೆಲನ್',
 			'PN' => 'ಪಿಟ್‌ಕೈರ್ನ್ ದ್ವೀಪಗಳು',
 			'PR' => 'ಪ್ಯೂರ್ಟೋ ರಿಕೊ',
 			'PS' => 'ಪ್ಯಾಲೇಸ್ಟೇನಿಯನ್ ಪ್ರದೇಶಗಳು',
 			'PS@alt=short' => 'ಪ್ಯಾಲೆಸ್ಟೈನ್',
 			'PT' => 'ಪೋರ್ಚುಗಲ್',
 			'PW' => 'ಪಲಾವು',
 			'PY' => 'ಪರಾಗ್ವೇ',
 			'QA' => 'ಖತಾರ್',
 			'QO' => 'ಔಟ್ ಲೈಯಿಂಗ್ ಓಷಿಯಾನಿಯಾ',
 			'RE' => 'ರಿಯೂನಿಯನ್',
 			'RO' => 'ರೊಮೇನಿಯಾ',
 			'RS' => 'ಸೆರ್ಬಿಯಾ',
 			'RU' => 'ರಷ್ಯಾ',
 			'RW' => 'ರುವಾಂಡಾ',
 			'SA' => 'ಸೌದಿ ಅರೇಬಿಯಾ',
 			'SB' => 'ಸಾಲೊಮನ್ ದ್ವೀಪಗಳು',
 			'SC' => 'ಸೀಶೆಲ್ಲೆಸ್',
 			'SD' => 'ಸುಡಾನ್',
 			'SE' => 'ಸ್ವೀಡನ್',
 			'SG' => 'ಸಿಂಗಪುರ್',
 			'SH' => 'ಸೇಂಟ್ ಹೆಲೆನಾ',
 			'SI' => 'ಸ್ಲೋವೇನಿಯಾ',
 			'SJ' => 'ಸ್ವಾಲ್ಬಾರ್ಡ್ ಮತ್ತು ಜಾನ್ ಮೆಯನ್',
 			'SK' => 'ಸ್ಲೊವಾಕಿಯಾ',
 			'SL' => 'ಸಿಯೆರ್ರಾ ಲಿಯೋನ್',
 			'SM' => 'ಸ್ಯಾನ್ ಮೆರಿನೋ',
 			'SN' => 'ಸೆನೆಗಲ್',
 			'SO' => 'ಸೊಮಾಲಿಯಾ',
 			'SR' => 'ಸುರಿನಾಮ್',
 			'SS' => 'ದಕ್ಷಿಣ ಸುಡಾನ್',
 			'ST' => 'ಸಾವೋ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪಿ',
 			'SV' => 'ಎಲ್ ಸಾಲ್ವೇಡಾರ್',
 			'SX' => 'ಸಿಂಟ್ ಮಾರ್ಟೆನ್',
 			'SY' => 'ಸಿರಿಯಾ',
 			'SZ' => 'ಎಸ್ವಾಟಿನಿ',
 			'SZ@alt=variant' => 'ಸ್ವಾಜಿಲ್ಯಾಂಡ್‌',
 			'TA' => 'ಟ್ರಿಸ್ತನ್ ಡಾ ಕುನ್ಹಾ',
 			'TC' => 'ಟರ್ಕ್ಸ್ ಮತ್ತು ಕೈಕೋಸ್ ದ್ವೀಪಗಳು',
 			'TD' => 'ಚಾದ್',
 			'TF' => 'ಫ್ರೆಂಚ್ ದಕ್ಷಿಣ ಪ್ರದೇಶಗಳು',
 			'TG' => 'ಟೋಗೋ',
 			'TH' => 'ಥೈಲ್ಯಾಂಡ್',
 			'TJ' => 'ತಜಿಕಿಸ್ತಾನ್',
 			'TK' => 'ಟೊಕೆಲಾವ್',
 			'TL' => 'ಟಿಮೋರ್ ಲೆಸ್ಟೆ',
 			'TL@alt=variant' => 'ಪೂರ್ವ ಟಿಮೋರ್',
 			'TM' => 'ತುರ್ಕಮೆನಿಸ್ತಾನ್',
 			'TN' => 'ಟುನೀಶಿಯ',
 			'TO' => 'ಟೊಂಗಾ',
 			'TR' => 'ತುರ್ಕಿಯೆ',
 			'TT' => 'ಟ್ರಿನಿಡಾಡ್ ಮತ್ತು ಟೊಬಾಗೊ',
 			'TV' => 'ಟುವಾಲು',
 			'TW' => 'ತೈವಾನ್',
 			'TZ' => 'ತಾಂಜೇನಿಯಾ',
 			'UA' => 'ಉಕ್ರೈನ್',
 			'UG' => 'ಉಗಾಂಡಾ',
 			'UM' => 'ಯುಎಸ್‌ ಔಟ್‌ಲೇಯಿಂಗ್ ದ್ವೀಪಗಳು',
 			'UN' => 'ಸಂಯುಕ್ತ ಸಂಸ್ಥಾನಗಳು',
 			'UN@alt=short' => 'ಯುಎನ್',
 			'US' => 'ಯುನೈಟೆಡ್ ಸ್ಟೇಟ್ಸ್',
 			'US@alt=short' => 'ಯು.ಎಸ್',
 			'UY' => 'ಉರುಗ್ವೆ',
 			'UZ' => 'ಉಜ್ಬೇಕಿಸ್ಥಾನ್',
 			'VA' => 'ವ್ಯಾಟಿಕನ್ ಸಿಟಿ',
 			'VC' => 'ಸೇಂಟ್. ವಿನ್ಸೆಂಟ್ ಮತ್ತು ಗ್ರೆನೆಡೈನ್ಸ್',
 			'VE' => 'ವೆನೆಜುವೆಲಾ',
 			'VG' => 'ಬ್ರಿಟಿಷ್ ವರ್ಜಿನ್ ದ್ವೀಪಗಳು',
 			'VI' => 'ಯು.ಎಸ್. ವರ್ಜಿನ್ ದ್ವೀಪಗಳು',
 			'VN' => 'ವಿಯೆಟ್ನಾಮ್',
 			'VU' => 'ವನೌಟು',
 			'WF' => 'ವಾಲಿಸ್ ಮತ್ತು ಫುಟುನಾ',
 			'WS' => 'ಸಮೋವಾ',
 			'XA' => 'ಸ್ಯುಡೊ ಉಚ್ಛಾರಣೆಗಳು',
 			'XB' => 'ಸ್ಯುಡೊ-ಬಿಡಿ',
 			'XK' => 'ಕೊಸೊವೊ',
 			'YE' => 'ಯೆಮನ್',
 			'YT' => 'ಮಯೊಟ್ಟೆ',
 			'ZA' => 'ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ',
 			'ZM' => 'ಜಾಂಬಿಯ',
 			'ZW' => 'ಜಿಂಬಾಬ್ವೆ',
 			'ZZ' => 'ಅಜ್ಞಾತ ಪ್ರದೇಶ',

		}
	},
);

has 'display_name_variant' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'PINYIN' => 'ಪಿನ್‌ಯಿನ್ ರೋಮನೈಸೇಶನ್',
 			'WADEGILE' => 'ವೇಡ್-ಗೈಲ್ಸ್ ರೋಮನೈಸೇಶನ್',

		}
	},
);

has 'display_name_key' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => 'ಕ್ಯಾಲೆಂಡರ್',
 			'cf' => 'ಕರೆನ್ಸಿ ಸ್ವರೂಪ',
 			'colalternate' => 'ಸಂಕೇತಗಳ ವಿಂಗಡಣೆಯನ್ನು ಕಡೆಗಣಿಸಿ',
 			'colbackwards' => 'ತಿರುಗು ಮುರುಗಾದ ಉಚ್ಛಾರಣೆಯ ವಿಂಗಡಣೆ',
 			'colcasefirst' => 'ದೊಡ್ಡಕ್ಷರ/ಸಣ್ಣಕ್ಷರ ಕ್ರಮಗೊಳಿಸುವಿಕೆ',
 			'colcaselevel' => 'ಕೇಸ್-ಸೆನ್ಸಿಟೀವ್ ವಿಂಗಡಣೆ',
 			'collation' => 'ವಿಂಗಡಣೆ ಕ್ರಮ',
 			'colnormalization' => 'ಸಾಮಾನ್ಯ ವಿಂಗಡಣೆ',
 			'colnumeric' => 'ಸಂಖ್ಯೆ ವಿಂಗಡಣೆ',
 			'colstrength' => 'ವಿಂಗಡಣೆ ಸಾಮರ್ಥ್ಯ',
 			'currency' => 'ಕರೆನ್ಸಿ',
 			'hc' => 'ಕಾಲ ಚಕ್ರ (12 ವಿರುದ್ಧ 24)',
 			'lb' => 'ಲೈನ್ ಬ್ರೇಕ್ ಶೈಲಿ',
 			'ms' => 'ಮಾಪನ ವ್ಯವಸ್ಥೆ',
 			'numbers' => 'ಸಂಖ್ಯೆಗಳು',
 			'timezone' => 'ಸಮಯ ವಲಯ',
 			'va' => 'ಸ್ಥಳೀಯ ಭಿನ್ನತೆ',
 			'x' => 'ಖಾಸಗಿ ಬಳಕೆ',

		}
	},
);

has 'display_name_type' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[Str]],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => {
 				'buddhist' => q{ಬೌದ್ಧರ ಕ್ಯಾಲೆಂಡರ್},
 				'chinese' => q{ಚೈನೀಸ್ ಕ್ಯಾಲೆಂಡರ್},
 				'coptic' => q{ಕೋಪ್ಟಿಕ್ ಕ್ಯಾಲೆಂಡರ್},
 				'dangi' => q{ಡಾಂಗಿ ಕ್ಯಾಲೆಂಡರ್},
 				'ethiopic' => q{ಇಥಿಯೋಪಿಕ್ ಕ್ಯಾಲೆಂಡರ್},
 				'ethiopic-amete-alem' => q{ಇಥಿಯೋಪಿಕ್ ಅಮೆಟೆ ಅಲೆಮ್ ಕ್ಯಾಲೆಂಡರ್},
 				'gregorian' => q{ಗ್ರೆಗೋರಿಯನ್ ಕ್ಯಾಲೆಂಡರ್},
 				'hebrew' => q{ಹೀಬ್ರೂ ಕ್ಯಾಲೆಂಡರ್},
 				'indian' => q{ಭಾರತೀಯ ರಾಷ್ಟ್ರೀಯ ಕ್ಯಾಲೆಂಡರ್},
 				'islamic' => q{ಇಸ್ಲಾಮಿಕ್ ಕ್ಯಾಲೆಂಡರ್},
 				'islamic-civil' => q{ಇಸ್ಲಾಮಿಕ್-ಸಿವಿಲ್ ಕ್ಯಾಲೆಂಡರ್},
 				'islamic-rgsa' => q{ಇಸ್ಲಾಮಿಕ್‌ ಕ್ಯಾಲೆಂಡರ್‌ (ಸೌದಿ ಅರೇಬಿಯಾ, ಸೈಟಿಂಗ್‌)bia, sighting)},
 				'islamic-umalqura' => q{ಇಸ್ಲಾಮಿಕ್ ಕ್ಯಾಲೆಂಡರ್ (ಉಮ್ ಅಲ್-ಖುರಾ)},
 				'iso8601' => q{ISO-8601 ಕ್ಯಾಲೆಂಡರ್},
 				'japanese' => q{ಜಪಾನೀಸ್ ಕ್ಯಾಲೆಂಡರ್},
 				'persian' => q{ಪರ್ಷಿಯನ್ ಕ್ಯಾಲೆಂಡರ್},
 				'roc' => q{ಮಿಂಗೋ ಕ್ಯಾಲೆಂಡರ್},
 			},
 			'cf' => {
 				'account' => q{ಅಕೌಂಟಿಂಗ್ ಕರೆನ್ಸಿ ಸ್ವರೂಪ},
 				'standard' => q{ಪ್ರಮಾಣಿತ ಕರೆನ್ಸಿ ಸ್ವರೂಪ},
 			},
 			'colalternate' => {
 				'non-ignorable' => q{ಚಿಹ್ನೆಗಳನ್ನು ವಿಂಗಡಿಸಿ},
 				'shifted' => q{ನಿರ್ಲಕ್ಷಿಸಿದ ಚಿಹ್ನೆಗಳನ್ನು ವಿಂಗಡಿಸಿ},
 			},
 			'colbackwards' => {
 				'no' => q{ಉಚ್ಛಾರಣೆಯನ್ನು ಸಾಮಾನ್ಯವಾಗಿ ವಿಂಗಡಿಸಿ},
 				'yes' => q{ತಿರುಗು ಮುರುಗಾದ ಉಚ್ಛಾರಣೆಗಳನ್ನು ವಿಂಗಡಿಸಿ},
 			},
 			'colcasefirst' => {
 				'lower' => q{ಮೊದಲು ಲೋವರ್‌ಕೇಸ್ ಅನ್ನು ವಿಂಗಡಿಸಿ},
 				'no' => q{ಸಾಮಾನ್ಯ ಕೇಸ್ ಕ್ರಮವನ್ನು ವಿಂಗಡಿಸಿ},
 				'upper' => q{ಮೊದಲು ಅಪ್ಪರ್‌ಕೇಸ್ ಅನ್ನು ವಿಂಗಡಿಸಿ},
 			},
 			'colcaselevel' => {
 				'no' => q{ಕೇಸ್ ಇನ್‌ಸೆಂಟೀವ್ ಅನ್ನು ವಿಂಗಡಿಸಿ},
 				'yes' => q{ಕೇಸ್‌ ಸೆನ್ಸಿಟೀವ್‌‌ ವಿಂಗಡಿಸಿ},
 			},
 			'collation' => {
 				'big5han' => q{ಸಾಂಪ್ರದಾಯಿಕ ಚೀನಾದ ಅನುಕ್ರಮ ವಿನ್ಯಾಸ - ದೊಡ್ಡ ಐದು},
 				'compat' => q{ಹೊಂದಾಣಿಕೆಯ ಸಲುವಾಗಿ ಹಿಂದಿನ ವಿಂಗಡಣಾ ಕ್ರಮ},
 				'dictionary' => q{ಡಿಕ್ಷನರಿ ಅನುಕ್ರಮ ವಿನ್ಯಾಸ},
 				'ducet' => q{ಡೀಫಾಲ್ಟ್ ಯೂನಿಕೋಡ್ ವಿಂಗಡಣೆ ಕ್ರಮ},
 				'eor' => q{ಯುರೋಪಿನ ಅನುಕ್ರಮ ನಿಯಮಗಳು},
 				'gb2312han' => q{ಸರಳೀಕೃತ ಚೈನೀಸ್ ವಿಂಗಡಣೆ ಕ್ರಮ - GB2312},
 				'phonebook' => q{ಫೋನ್‌ಬುಕ್ ವಿಂಗಡಣೆ ಕ್ರಮ},
 				'phonetic' => q{ಉಚ್ಛಾರಣಾನುರೂಪವಾಗಿ ವಿಂಗಡಣೆ ಕ್ರಮ},
 				'pinyin' => q{ಪಿನ್‌ಯಿನ್ ವಿಂಗಡಣೆ ಕ್ರಮ},
 				'search' => q{ಸಾಮಾನ್ಯ- ಉದ್ದೇಶ ಹುಡುಕಾಟ},
 				'searchjl' => q{ಹಂಗುಲ್ ಆದ್ಯಕ್ಷರ ವ್ಯಂಜನದ ಮೂಲಕ ಹುಡುಕಿ},
 				'standard' => q{ಪ್ರಮಾಣೀಕೃತ ವಿಂಗಡಣೆ ಕ್ರಮ},
 				'stroke' => q{ಸ್ಟ್ರೋಕ್ ವಿಂಗಡಣೆ ಕ್ರಮ},
 				'traditional' => q{ಸಾಂಪ್ರದಾಯಿಕ ವಿಂಗಡಣೆ ಕ್ರಮ},
 				'unihan' => q{ರ್ಯಾಡಿಕಲ್-ಸ್ಟ್ರೋಕ್ ವಿಂಗಡಣೆ ಕ್ರಮ},
 			},
 			'colnormalization' => {
 				'no' => q{ಸಾಮಾನ್ಯ ಸ್ಥಿತಿಯನ್ನು ಹೊರತುಪಡಿಸಿ ವಿಂಗಡಿಸಿ},
 				'yes' => q{ಸಾಮಾನ್ಯವಾದ ಯೂನಿಕೋಡ್ ಅನ್ನು ವಿಂಗಡಿಸಿ},
 			},
 			'colnumeric' => {
 				'no' => q{ಅಂಕೆಗಳನ್ನು ಪ್ರತ್ಯೇಕವಾಗಿ ವಿಂಗಡಿಸಿ},
 				'yes' => q{ಅಂಕೆಗಳನ್ನು ಸಂಖ್ಯಾತ್ಮಕವಾಗಿ ವಿಂಗಡಿಸಿ},
 			},
 			'colstrength' => {
 				'identical' => q{ಎಲ್ಲವನ್ನೂ ವಿಂಗಡಿಸಿ},
 				'primary' => q{ವಿಂಗಡಣೆ ಆಧರಿಸಿದ ಅಕ್ಷರಗಳನ್ನು ಮಾತ್ರ},
 				'quaternary' => q{ಉಚ್ಛಾರಣೆ/ಕೇಸ್/ಅಳತೆ/ಕಾನಾ ವಿಂಗಡಿಸಿ},
 				'secondary' => q{ಉಚ್ಛಾರಣೆಗಳನ್ನು ವಿಂಗಡಿಸಿ},
 				'tertiary' => q{ಉಚ್ಛಾರಣೆ/ಕೇಸ್/ಅಳತೆ ವಿಂಗಡಿಸಿ},
 			},
 			'd0' => {
 				'fwidth' => q{ಪೂರ್ಣಅಗಲಕ್ಕೆ},
 				'hwidth' => q{ಅರೆಅಗಲಕ್ಕೆ},
 				'npinyin' => q{ಸಂಖ್ಯೆ},
 			},
 			'hc' => {
 				'h11' => q{12 ಗಂಟೆ ವ್ಯವಸ್ಥೆ (0–11)},
 				'h12' => q{12 ಗಂಟೆ ವ್ಯವಸ್ಥೆ (1–12)},
 				'h23' => q{24 ಗಂಟೆ ವ್ಯವಸ್ಥೆ (0–23)},
 				'h24' => q{24 ಗಂಟೆ ವ್ಯವಸ್ಥೆ (1–24)},
 			},
 			'lb' => {
 				'loose' => q{ಲೂಸ್ ಲೈನ್ ಬ್ರೇಕ್ ಶೈಲಿ},
 				'normal' => q{ಸಾಮಾನ್ಯ ಲೈನ್ ಬ್ರೇಕ್ ಶೈಲಿ},
 				'strict' => q{ಕಟ್ಟುನಿಟ್ಟಾದ ಲೈನ್ ಬ್ರೇಕ್ ಶೈಲಿ},
 			},
 			'm0' => {
 				'bgn' => q{ಯುಎಸ್ ಬಿಜಿಎನ್ ಲಿಪ್ಯಂತರಣ},
 				'ungegn' => q{ಯುಎಸ್ ಜಿಇಜಿಎನ್ ಲಿಪ್ಯಂತರಣ},
 			},
 			'ms' => {
 				'metric' => q{ಮೆಟ್ರಿಕ್ ಪದ್ಧತಿ},
 				'uksystem' => q{ಇಂಪಿರಿಯಲ್ ಮಾಪನ ವ್ಯವಸ್ಥೆ},
 				'ussystem' => q{ಅಮೇರಿಕಾದ ಮಾಪನಾ ವ್ಯವಸ್ಥೆ},
 			},
 			'numbers' => {
 				'arab' => q{ಅರೇಬಿಕ್-ಇಂಡಿಕ್ ಅಂಕೆಗಳು},
 				'arabext' => q{ವಿಸ್ತರಿಸಲಾದ ಅರೇಬಿಕ್-ಇಂಡಿಕ್ ಅಂಕೆಗಳು},
 				'armn' => q{ಆರ್ಮೇನಿಯಾದ ಸಂಖ್ಯೆಗಳು},
 				'armnlow' => q{ಅರ್ಮೇನಿಯಾದ ಸಣ್ಣಕ್ಷರ ಸಂಖ್ಯೆಗಳು},
 				'beng' => q{ಬಾಂಗ್ಲಾ ಅಂಕೆಗಳು},
 				'cakm' => q{ಚಕ್ಮಾ ಅಂಕೆಗಳು},
 				'deva' => q{ದೇವನಾಗರಿ ಅಂಕೆಗಳು},
 				'ethi' => q{ಇಥಿಯೋಪಿಯಾದ ಸಂಖ್ಯೆಗಳು},
 				'finance' => q{ಆರ್ಥಿಕ ಸಂಖ್ಯೆಗಳು},
 				'fullwide' => q{ಪೂರ್ಣ ಅಗಲವಾದ ಸಂಖ್ಯೆಗಳು},
 				'geor' => q{ಜಾರ್ಜಿಯಾದ ಸಂಖ್ಯೆಗಳು},
 				'grek' => q{ಗ್ರೀಕ್ ಸಂಖ್ಯೆಗಳು},
 				'greklow' => q{ಗ್ರೀಕ್ ಲೋವರ್‌ಕೇಸ್ ಸಂಖ್ಯೆಗಳು},
 				'gujr' => q{ಗುಜರಾತಿ ಅಂಕೆಗಳು},
 				'guru' => q{ಗುರ್ಮುಖಿ ಅಂಕೆಗಳು},
 				'hanidec' => q{ಚೀನಾದ ದಶಮಾಂಶ ಸಂಖ್ಯೆಗಳು},
 				'hans' => q{ಸರಳೀಕೃತ ಚೀನಿ ಸಂಖ್ಯೆಗಳು},
 				'hansfin' => q{ಸರಳೀಕೃತ ಚೀನಿ ಆರ್ಥಿಕ ಸಂಖ್ಯೆಗಳು},
 				'hant' => q{ಸಾಂಪ್ರದಾಯಿಕ ಚೀನಿ ಸಂಖ್ಯೆಗಳು},
 				'hantfin' => q{ಸಾಂಪ್ರದಾಯಿಕ ಚೀನಿ ಆರ್ಥಿಕ ಸಂಖ್ಯೆಗಳು},
 				'hebr' => q{ಹೀಬ್ರೂ ಸಂಖ್ಯೆಗಳು},
 				'java' => q{ಜಾವಾನೀಸ್ ಅಂಕೆಗಳು},
 				'jpan' => q{ಜಪಾನೀ ಸಂಖ್ಯೆಗಳು},
 				'jpanfin' => q{ಜಪಾನೀ ಆರ್ಥಿಕ ಸಂಖ್ಯೆಗಳು},
 				'khmr' => q{ಖಮೆ ಅಂಕೆಗಳು},
 				'knda' => q{ಕನ್ನಡ ಅಂಕೆಗಳು},
 				'laoo' => q{ಲಾವೋ ಅಂಕೆಗಳು},
 				'latn' => q{ಪಾಶ್ಚಿಮಾತ್ಯ ಅಂಕೆಗಳು},
 				'mlym' => q{ಮಲಯಾಳಂ ಅಂಕಿಗಳು},
 				'mong' => q{ಮಂಗೋಲಿಯಾದ ಅಂಕೆಗಳು},
 				'mtei' => q{ಮೈಟಿ ಮಯೆಕ್ ಅಂಕೆಗಳು},
 				'mymr' => q{ಮ್ಯಾನ್ಮಾರ್ ಅಂಕೆಗಳು},
 				'native' => q{ಸ್ಥಳೀಯ ಅಂಕೆಗಳು},
 				'olck' => q{ಓಲ್ ಚಿಕಿ ಅಂಕೆಗಳು},
 				'orya' => q{ಒರಿಯಾ ಅಂಕೆಗಳು},
 				'roman' => q{ರೋಮನ್ ಸಂಖ್ಯೆಗಳು},
 				'romanlow' => q{ರೋಮನ್ ಲೋವರ್‌ಕೇಸ್ ಸಂಖ್ಯೆಗಳು},
 				'taml' => q{ಸಾಂಪ್ರದಾಯಿಕ ತಮಿಳು ಸಂಖ್ಯೆಗಳು},
 				'tamldec' => q{ತಮಿಳು ಅಂಕೆಗಳು},
 				'telu' => q{ತೆಲುಗು ಅಂಕೆಗಳು},
 				'thai' => q{ಥಾಯ್ ಅಂಕೆಗಳು},
 				'tibt' => q{ಟಿಬೇಟಿಯನ್ ಅಂಕೆಗಳು},
 				'traditional' => q{ಸಾಂಪ್ರದಾಯಿಕ ಸಂಖ್ಯೆಗಳು},
 				'vaii' => q{ವಾಯ್ ಅಂಕೆಗಳು},
 			},

		}
	},
);

has 'display_name_measurement_system' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'metric' => q{ಮೆಟ್ರಿಕ್},
 			'UK' => q{ಯುಕೆ},
 			'US' => q{ಯುಎಸ್},

		}
	},
);

has 'display_name_code_patterns' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'language' => 'ಭಾಷೆ: {0}',
 			'script' => 'ಲಿಪಿ : {0}',
 			'region' => 'ಪ್ರದೇಶ: {0}',

		}
	},
);

has 'characters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> $^V ge v5.18.0
	? eval <<'EOT'
	sub {
		no warnings 'experimental::regex_sets';
		return {
			auxiliary => qr{[‌‍ ೞ]},
			index => ['ಅ', 'ಆ', 'ಇ', 'ಈ', 'ಉ', 'ಊ', 'ಋ', 'ೠ', 'ಌ', 'ೡ', 'ಎ', 'ಏ', 'ಐ', 'ಒ', 'ಓ', 'ಔ', 'ಕ', 'ಖ', 'ಗ', 'ಘ', 'ಙ', 'ಚ', 'ಛ', 'ಜ', 'ಝ', 'ಞ', 'ಟ', 'ಠ', 'ಡ', 'ಢ', 'ಣ', 'ತ', 'ಥ', 'ದ', 'ಧ', 'ನ', 'ಪ', 'ಫ', 'ಬ', 'ಭ', 'ಮ', 'ಯ', 'ರ', 'ಱ', 'ಲ', 'ವ', 'ಶ', 'ಷ', 'ಸ', 'ಹ', 'ಳ', 'ೞ'],
			main => qr{[಼ ಅ ಆ ಇ ಈ ಉ ಊ ಋ ೠ ಌ ೡ ಎ ಏ ಐ ಒ ಓ ಔ ಂ ಃ ಕ ಖ ಗ ಘ ಙ ಚ ಛ ಜ ಝ ಞ ಟ ಠ ಡ ಢ ಣ ತ ಥ ದ ಧ ನ ಪ ಫ ಬ ಭ ಮ ಯ ರ ಱ ಲ ವ ಶ ಷ ಸ ಹ ಳ ಽ ಾ ಿ ೀ ು ೂ ೃ ೄ ೆ ೇ ೈ ೊ ೋ ೌ ್ ೕ ೖ]},
			numbers => qr{[\- ‑ , . % ‰ + 0೦ 1೧ 2೨ 3೩ 4೪ 5೫ 6೬ 7೭ 8೮ 9೯]},
			punctuation => qr{[\- ‐‑ – — , ; \: ! ? . … '‘’ "“” ( ) \[ \] § @ * / \& # † ‡ ′ ″]},
		};
	},
EOT
: sub {
		return { index => ['ಅ', 'ಆ', 'ಇ', 'ಈ', 'ಉ', 'ಊ', 'ಋ', 'ೠ', 'ಌ', 'ೡ', 'ಎ', 'ಏ', 'ಐ', 'ಒ', 'ಓ', 'ಔ', 'ಕ', 'ಖ', 'ಗ', 'ಘ', 'ಙ', 'ಚ', 'ಛ', 'ಜ', 'ಝ', 'ಞ', 'ಟ', 'ಠ', 'ಡ', 'ಢ', 'ಣ', 'ತ', 'ಥ', 'ದ', 'ಧ', 'ನ', 'ಪ', 'ಫ', 'ಬ', 'ಭ', 'ಮ', 'ಯ', 'ರ', 'ಱ', 'ಲ', 'ವ', 'ಶ', 'ಷ', 'ಸ', 'ಹ', 'ಳ', 'ೞ'], };
},
);


has 'units' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[HashRef[Str]]],
	init_arg	=> undef,
	default		=> sub { {
				'long' => {
					# Long Unit Identifier
					'' => {
						'name' => q(ಕಾರ್ಡಿನಲ್ ನಿರ್ದೇಶನ),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(ಕಾರ್ಡಿನಲ್ ನಿರ್ದೇಶನ),
					},
					# Long Unit Identifier
					'1024p1' => {
						'1' => q(ಕಿಬಿ {0}),
					},
					# Core Unit Identifier
					'1024p1' => {
						'1' => q(ಕಿಬಿ {0}),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(ಮೆಬಿ {0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(ಮೆಬಿ {0}),
					},
					# Long Unit Identifier
					'1024p3' => {
						'1' => q(ಜಿಬಿ {0}),
					},
					# Core Unit Identifier
					'1024p3' => {
						'1' => q(ಜಿಬಿ {0}),
					},
					# Long Unit Identifier
					'1024p4' => {
						'1' => q(ಟೆಬಿ {0}),
					},
					# Core Unit Identifier
					'1024p4' => {
						'1' => q(ಟೆಬಿ {0}),
					},
					# Long Unit Identifier
					'1024p5' => {
						'1' => q(ಪೆಬಿ {0}),
					},
					# Core Unit Identifier
					'1024p5' => {
						'1' => q(ಪೆಬಿ {0}),
					},
					# Long Unit Identifier
					'1024p6' => {
						'1' => q(ಎಕ್ಸ್ ಬಿ{0}),
					},
					# Core Unit Identifier
					'1024p6' => {
						'1' => q(ಎಕ್ಸ್ ಬಿ{0}),
					},
					# Long Unit Identifier
					'1024p7' => {
						'1' => q(ಝೆಬಿ{0}),
					},
					# Core Unit Identifier
					'1024p7' => {
						'1' => q(ಝೆಬಿ{0}),
					},
					# Long Unit Identifier
					'1024p8' => {
						'1' => q(ಯೊಬಿ{0}),
					},
					# Core Unit Identifier
					'1024p8' => {
						'1' => q(ಯೊಬಿ{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ಡೆಸಿ {0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ಡೆಸಿ {0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ಪಿಕೋ {0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ಪಿಕೋ {0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ಫೆಮ್ಟೋ {0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ಫೆಮ್ಟೋ {0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ಅಟ್ಟೋ {0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ಅಟ್ಟೋ {0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ಸೆಂಟಿ {0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ಸೆಂಟಿ {0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ಝೆಪ್ಟೋ {0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ಝೆಪ್ಟೋ {0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ಯೊಕ್ಟೋ {0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ಯೊಕ್ಟೋ {0}),
					},
					# Long Unit Identifier
					'10p-27' => {
						'1' => q(ರೋಂಟೊ{0}),
					},
					# Core Unit Identifier
					'27' => {
						'1' => q(ರೋಂಟೊ{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(ಮಿಲಿ{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(ಮಿಲಿ{0}),
					},
					# Long Unit Identifier
					'10p-30' => {
						'1' => q(ಕ್ವೆಕ್ಟೋ{0}),
					},
					# Core Unit Identifier
					'30' => {
						'1' => q(ಕ್ವೆಕ್ಟೋ{0}),
					},
					# Long Unit Identifier
					'10p-6' => {
						'1' => q(ಮೈಕ್ರೋ {0}),
					},
					# Core Unit Identifier
					'6' => {
						'1' => q(ಮೈಕ್ರೋ {0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ನ್ಯಾನೋ {0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ನ್ಯಾನೋ {0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ಡೆಕಾ {0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ಡೆಕಾ {0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(ಟೆರಾ {0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(ಟೆರಾ {0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(ಪೆಟಾ {0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(ಪೆಟಾ {0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(ಎಕ್ಸಾ {0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(ಎಕ್ಸಾ {0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ಹೆಕ್ಟೋ {0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ಹೆಕ್ಟೋ {0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(ಝೆಟ್ಟಾ {0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(ಝೆಟ್ಟಾ {0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(ಯೊಟ್ಟಾ {0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(ಯೊಟ್ಟಾ {0}),
					},
					# Long Unit Identifier
					'10p27' => {
						'1' => q(ರೋನಾ{0}),
					},
					# Core Unit Identifier
					'10p27' => {
						'1' => q(ರೋನಾ{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(ಕಿಲೋ {0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(ಕಿಲೋ {0}),
					},
					# Long Unit Identifier
					'10p30' => {
						'1' => q(ಕ್ವೆಟ್ಟಾ{0}),
					},
					# Core Unit Identifier
					'10p30' => {
						'1' => q(ಕ್ವೆಟ್ಟಾ{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(ಮೆಗಾ {0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(ಮೆಗಾ {0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(ಗಿಗಾ {0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(ಗಿಗಾ {0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'1' => q(neuter),
						'one' => q({0} ಜಿ-ಫೋರ್ಸ್),
						'other' => q({0} ಜಿ-ಫೋರ್ಸ್),
					},
					# Core Unit Identifier
					'g-force' => {
						'1' => q(neuter),
						'one' => q({0} ಜಿ-ಫೋರ್ಸ್),
						'other' => q({0} ಜಿ-ಫೋರ್ಸ್),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'1' => q(neuter),
						'name' => q(ಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಸೆಕೆಂಡ್‌ ಸ್ಕ್ವೇರ್‌ಗಳಿಗೆ),
						'one' => q({0} ಮೀಟರ್‌ ಪ್ರತಿ ಸೆಕೆಂಡ್‌ ಸ್ಕ್ವೇರ್‌ಗಳಿಗೆ),
						'other' => q({0} ಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಸೆಕೆಂಡ್‌ ಸ್ಕ್ವೇರ್‌ಗಳಿಗೆ),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'1' => q(neuter),
						'name' => q(ಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಸೆಕೆಂಡ್‌ ಸ್ಕ್ವೇರ್‌ಗಳಿಗೆ),
						'one' => q({0} ಮೀಟರ್‌ ಪ್ರತಿ ಸೆಕೆಂಡ್‌ ಸ್ಕ್ವೇರ್‌ಗಳಿಗೆ),
						'other' => q({0} ಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಸೆಕೆಂಡ್‌ ಸ್ಕ್ವೇರ್‌ಗಳಿಗೆ),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'1' => q(neuter),
						'name' => q(ಆರ್ಕ್‌ಮಿನಿಟ್‌ಗಳು),
						'one' => q({0} ಆರ್ಕ್‌ಮಿನಿಟ್),
						'other' => q({0} ಆರ್ಕ್‌ಮಿನಿಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'1' => q(neuter),
						'name' => q(ಆರ್ಕ್‌ಮಿನಿಟ್‌ಗಳು),
						'one' => q({0} ಆರ್ಕ್‌ಮಿನಿಟ್),
						'other' => q({0} ಆರ್ಕ್‌ಮಿನಿಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'1' => q(neuter),
						'name' => q(ಆರ್ಕ್‌ಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ಆರ್ಕ್‌ಸೆಕೆಂಡ್),
						'other' => q({0} ಆರ್ಕ್‌ಸೆಕೆಂಡುಗಳು),
					},
					# Core Unit Identifier
					'arc-second' => {
						'1' => q(neuter),
						'name' => q(ಆರ್ಕ್‌ಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ಆರ್ಕ್‌ಸೆಕೆಂಡ್),
						'other' => q({0} ಆರ್ಕ್‌ಸೆಕೆಂಡುಗಳು),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'1' => q(neuter),
						'one' => q({0} ಡಿಗ್ರಿಯು),
						'other' => q({0}ಡಿಗ್ರಿಗಳು),
					},
					# Core Unit Identifier
					'degree' => {
						'1' => q(neuter),
						'one' => q({0} ಡಿಗ್ರಿಯು),
						'other' => q({0}ಡಿಗ್ರಿಗಳು),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'1' => q(neuter),
						'one' => q({0} ರೇಡಿಯಾನ್‌),
						'other' => q({0} ರೇಡಿಯಾನ್‌ಗಳು),
					},
					# Core Unit Identifier
					'radian' => {
						'1' => q(neuter),
						'one' => q({0} ರೇಡಿಯಾನ್‌),
						'other' => q({0} ರೇಡಿಯಾನ್‌ಗಳು),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'1' => q(neuter),
						'name' => q(ತಿರುಗುವಿಕೆ),
						'one' => q({0} ತಿರುಗುವಿಕೆಯು),
						'other' => q({0} ತಿರುಗುವಿಕೆಗಳು),
					},
					# Core Unit Identifier
					'revolution' => {
						'1' => q(neuter),
						'name' => q(ತಿರುಗುವಿಕೆ),
						'one' => q({0} ತಿರುಗುವಿಕೆಯು),
						'other' => q({0} ತಿರುಗುವಿಕೆಗಳು),
					},
					# Long Unit Identifier
					'area-acre' => {
						'one' => q({0} ಎಕರೆ),
						'other' => q({0} ಎಕರೆಗಳು),
					},
					# Core Unit Identifier
					'acre' => {
						'one' => q({0} ಎಕರೆ),
						'other' => q({0} ಎಕರೆಗಳು),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'name' => q(ಡುನಮ್ಸ್‌),
						'one' => q({0} ಡುನಮ್‌),
						'other' => q({0} ಡುನಮ್‌ಗಳು),
					},
					# Core Unit Identifier
					'dunam' => {
						'name' => q(ಡುನಮ್ಸ್‌),
						'one' => q({0} ಡುನಮ್‌),
						'other' => q({0} ಡುನಮ್‌ಗಳು),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'1' => q(neuter),
						'one' => q({0} ಹೆಕ್ಟೇರ್),
						'other' => q({0} ಹೆಕ್ಟೇರುಗಳು),
					},
					# Core Unit Identifier
					'hectare' => {
						'1' => q(neuter),
						'one' => q({0} ಹೆಕ್ಟೇರ್),
						'other' => q({0} ಹೆಕ್ಟೇರುಗಳು),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'1' => q(neuter),
						'name' => q(ಚದರ ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಚದರ ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಚದರ ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಚದರ ಸೆಂಟಿಮೀಟರ್‌‌ಗೆ {0}),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'1' => q(neuter),
						'name' => q(ಚದರ ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಚದರ ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಚದರ ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಚದರ ಸೆಂಟಿಮೀಟರ್‌‌ಗೆ {0}),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'one' => q({0} ಚದರಡಿ),
						'other' => q({0} ಚದರಡಿ),
					},
					# Core Unit Identifier
					'square-foot' => {
						'one' => q({0} ಚದರಡಿ),
						'other' => q({0} ಚದರಡಿ),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(ಚದರ ಅಂಗುಲಗಳು),
						'one' => q({0} ಚದರ ಅಂಗುಲ),
						'other' => q({0} ಚದರ ಅಂಗುಲಗಳು),
						'per' => q({0} ಪ್ರತಿ ಚದರ ಇಂಚಿಗೆ),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(ಚದರ ಅಂಗುಲಗಳು),
						'one' => q({0} ಚದರ ಅಂಗುಲ),
						'other' => q({0} ಚದರ ಅಂಗುಲಗಳು),
						'per' => q({0} ಪ್ರತಿ ಚದರ ಇಂಚಿಗೆ),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಚದರ ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಚದರ ಕಿಲೋಮೀಟರ್),
						'other' => q({0} ಚದರ ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಚದರ ಕಿಲೋಮೀಟರ್‌ಗೆ {0}),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಚದರ ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಚದರ ಕಿಲೋಮೀಟರ್),
						'other' => q({0} ಚದರ ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಚದರ ಕಿಲೋಮೀಟರ್‌ಗೆ {0}),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'1' => q(neuter),
						'name' => q(ಚದರ ಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಚದರ ಮೀಟರ್),
						'other' => q({0} ಚದರ ಮೀಟರ್‌ಗಳು),
						'per' => q(ಚದರ ಮೀಟರ್‌ಗೆ {0}),
					},
					# Core Unit Identifier
					'square-meter' => {
						'1' => q(neuter),
						'name' => q(ಚದರ ಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಚದರ ಮೀಟರ್),
						'other' => q({0} ಚದರ ಮೀಟರ್‌ಗಳು),
						'per' => q(ಚದರ ಮೀಟರ್‌ಗೆ {0}),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'one' => q({0} ಚದರ ಮೈಲು),
						'other' => q({0} ಚದರ ಮೈಲುಗಳು),
						'per' => q(ಪ್ರತಿ ಚದರ ಮೈಲಿಗೆ {0}),
					},
					# Core Unit Identifier
					'square-mile' => {
						'one' => q({0} ಚದರ ಮೈಲು),
						'other' => q({0} ಚದರ ಮೈಲುಗಳು),
						'per' => q(ಪ್ರತಿ ಚದರ ಮೈಲಿಗೆ {0}),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(ಚದರ ಗಜಗಳು),
						'one' => q({0} ಚದರ ಗಜ),
						'other' => q({0} ಚದರ ಗಜಗಳು),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(ಚದರ ಗಜಗಳು),
						'one' => q({0} ಚದರ ಗಜ),
						'other' => q({0} ಚದರ ಗಜಗಳು),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'1' => q(neuter),
						'one' => q({0} ವಸ್ತು),
						'other' => q({0} ವಸ್ತುಗಳು),
					},
					# Core Unit Identifier
					'item' => {
						'1' => q(neuter),
						'one' => q({0} ವಸ್ತು),
						'other' => q({0} ವಸ್ತುಗಳು),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'1' => q(neuter),
						'one' => q({0} ಕಾರಟ್‌),
						'other' => q({0} ಕಾರಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'karat' => {
						'1' => q(neuter),
						'one' => q({0} ಕಾರಟ್‌),
						'other' => q({0} ಕಾರಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'1' => q(neuter),
						'name' => q(ಪ್ರತಿ ಡೆಸಿಲೀಟರ್‌ಗೆ ಮಿಲಿಗ್ರಾಂಗಳು),
						'one' => q({0} ಪ್ರತಿ ಡೆಸಿಲೀಟರ್‌ಗೆ ಮಿಲಿಗ್ರಾಂ),
						'other' => q({0} ಪ್ರತಿ ಡೆಸಿಲೀಟರ್‌ಗೆ ಮಿಲಿಗ್ರಾಂಗಳು),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'1' => q(neuter),
						'name' => q(ಪ್ರತಿ ಡೆಸಿಲೀಟರ್‌ಗೆ ಮಿಲಿಗ್ರಾಂಗಳು),
						'one' => q({0} ಪ್ರತಿ ಡೆಸಿಲೀಟರ್‌ಗೆ ಮಿಲಿಗ್ರಾಂ),
						'other' => q({0} ಪ್ರತಿ ಡೆಸಿಲೀಟರ್‌ಗೆ ಮಿಲಿಗ್ರಾಂಗಳು),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಮೋಲ್‌ಗಳು ಪ್ರತಿ ಲೀಟರ್‌ಗೆ),
						'one' => q({0} ಮಿಲಿಮೋಲ್‌ ಪ್ರತಿ ಲೀಟರ್‌ಗೆ),
						'other' => q({0} ಮಿಲಿಮೋಲ್‌ಗಳು ಪ್ರತಿ ಲೀಟರ್‌‌ಗೆ),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಮೋಲ್‌ಗಳು ಪ್ರತಿ ಲೀಟರ್‌ಗೆ),
						'one' => q({0} ಮಿಲಿಮೋಲ್‌ ಪ್ರತಿ ಲೀಟರ್‌ಗೆ),
						'other' => q({0} ಮಿಲಿಮೋಲ್‌ಗಳು ಪ್ರತಿ ಲೀಟರ್‌‌ಗೆ),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'1' => q(neuter),
						'name' => q(ಮೋಲ್‌ಗಳು),
						'one' => q({0} ಮೋಲ್‌ಗಳು),
						'other' => q({0} ಮೋಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'mole' => {
						'1' => q(neuter),
						'name' => q(ಮೋಲ್‌ಗಳು),
						'one' => q({0} ಮೋಲ್‌ಗಳು),
						'other' => q({0} ಮೋಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'1' => q(neuter),
						'one' => q({0} ಶೇಕಡಾವು),
						'other' => q({0} ಶೇಕಡಾ),
					},
					# Core Unit Identifier
					'percent' => {
						'1' => q(neuter),
						'one' => q({0} ಶೇಕಡಾವು),
						'other' => q({0} ಶೇಕಡಾ),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'1' => q(neuter),
						'one' => q({0} ಪ್ರತಿ ಸಾವಿರವು),
						'other' => q({0} ಪ್ರತಿ ಸಾವಿರಕ್ಕೆ),
					},
					# Core Unit Identifier
					'permille' => {
						'1' => q(neuter),
						'one' => q({0} ಪ್ರತಿ ಸಾವಿರವು),
						'other' => q({0} ಪ್ರತಿ ಸಾವಿರಕ್ಕೆ),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'1' => q(neuter),
						'name' => q(ಪ್ರತಿ ಮಿಲಿಯನ್ ಭಾಗಗಳು),
						'one' => q({0} ಪ್ರತಿ ಮಿಲಿಯನ್ ಭಾಗವು),
						'other' => q({0} ಪ್ರತಿ ಮಿಲಿಯನ್ ಭಾಗಗಳು),
					},
					# Core Unit Identifier
					'permillion' => {
						'1' => q(neuter),
						'name' => q(ಪ್ರತಿ ಮಿಲಿಯನ್ ಭಾಗಗಳು),
						'one' => q({0} ಪ್ರತಿ ಮಿಲಿಯನ್ ಭಾಗವು),
						'other' => q({0} ಪ್ರತಿ ಮಿಲಿಯನ್ ಭಾಗಗಳು),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'1' => q(neuter),
						'name' => q(ಪರ್‌ಮಿರಿಯಾಡ್),
						'one' => q({0} ಪರ್‌ಮಿರಿಯಾಡ್),
						'other' => q({0} ಪರ್‌ಮಿರಿಯಾಡ್‌),
					},
					# Core Unit Identifier
					'permyriad' => {
						'1' => q(neuter),
						'name' => q(ಪರ್‌ಮಿರಿಯಾಡ್),
						'one' => q({0} ಪರ್‌ಮಿರಿಯಾಡ್),
						'other' => q({0} ಪರ್‌ಮಿರಿಯಾಡ್‌),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'1' => q(neuter),
						'name' => q(ಪಾರ್ಟ್ಸ್ ಪರ್ ಬಿಲಿಯನ್),
						'one' => q({0} ಪಾರ್ಟ್ಸ್ ಪರ್ ಬಿಲಿಯನ್),
						'other' => q({0} ಪಾರ್ಟ್ಸ್ ಪರ್ ಬಿಲಿಯನ್),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'1' => q(neuter),
						'name' => q(ಪಾರ್ಟ್ಸ್ ಪರ್ ಬಿಲಿಯನ್),
						'one' => q({0} ಪಾರ್ಟ್ಸ್ ಪರ್ ಬಿಲಿಯನ್),
						'other' => q({0} ಪಾರ್ಟ್ಸ್ ಪರ್ ಬಿಲಿಯನ್),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ ಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ ಲೀಟರ್‌ಗಳು),
						'other' => q({0} ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ ಲೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ ಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ ಲೀಟರ್‌ಗಳು),
						'other' => q({0} ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ ಲೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಲೀಟರ್‌ಗಳು ಪ್ರತಿ ಕಿಲೋಮೀಟರಿಗೆ),
						'one' => q({0} ಲೀಟರ್ ಪ್ರತಿ ಕಿಲೋಮೀಟರ್‌ಗೆ),
						'other' => q({0} ಪ್ರತಿ ಕಿಲೋಮೀಟರ್‌‌ಗೆ ಲೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಲೀಟರ್‌ಗಳು ಪ್ರತಿ ಕಿಲೋಮೀಟರಿಗೆ),
						'one' => q({0} ಲೀಟರ್ ಪ್ರತಿ ಕಿಲೋಮೀಟರ್‌ಗೆ),
						'other' => q({0} ಪ್ರತಿ ಕಿಲೋಮೀಟರ್‌‌ಗೆ ಲೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(ಪ್ರತಿ ಗ್ಯಾಲನ್‌‌ಗೆ ಮೈಲಿಗಳು),
						'one' => q({0} ಪ್ರತಿ ಗ್ಯಾಲನ್‌‌ಗೆ ಮೈಲಿ),
						'other' => q({0} ಪ್ರತಿ ಗ್ಯಾಲನ್‌ಗೆ ಮೈಲಿಗಳು),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(ಪ್ರತಿ ಗ್ಯಾಲನ್‌‌ಗೆ ಮೈಲಿಗಳು),
						'one' => q({0} ಪ್ರತಿ ಗ್ಯಾಲನ್‌‌ಗೆ ಮೈಲಿ),
						'other' => q({0} ಪ್ರತಿ ಗ್ಯಾಲನ್‌ಗೆ ಮೈಲಿಗಳು),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(ಪ್ರತಿ Imp ಗ್ಯಾಲನ್‌ಗೆ ಮೈಲಿಗಳು),
						'one' => q({0} ಪ್ರತಿ Imp ಗ್ಯಾಲನ್‌ಗೆ ಮೈಲಿ),
						'other' => q({0} ಪ್ರತಿ Imp ಗ್ಯಾಲನ್‌ಗೆ ಮೈಲಿಗಳು),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(ಪ್ರತಿ Imp ಗ್ಯಾಲನ್‌ಗೆ ಮೈಲಿಗಳು),
						'one' => q({0} ಪ್ರತಿ Imp ಗ್ಯಾಲನ್‌ಗೆ ಮೈಲಿ),
						'other' => q({0} ಪ್ರತಿ Imp ಗ್ಯಾಲನ್‌ಗೆ ಮೈಲಿಗಳು),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0} ಪೂರ್ವ),
						'north' => q({0} ಉತ್ತರ),
						'south' => q({0} ದಕ್ಷಿಣ),
						'west' => q({0} ಪಶ್ಚಿಮ),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0} ಪೂರ್ವ),
						'north' => q({0} ಉತ್ತರ),
						'south' => q({0} ದಕ್ಷಿಣ),
						'west' => q({0} ಪಶ್ಚಿಮ),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'1' => q(neuter),
						'name' => q(ಬಿಟ್‌ಗಳು),
						'one' => q({0} ಬಿಟ್‌),
						'other' => q({0} ಬಿಟ್‍ಗಳು),
					},
					# Core Unit Identifier
					'bit' => {
						'1' => q(neuter),
						'name' => q(ಬಿಟ್‌ಗಳು),
						'one' => q({0} ಬಿಟ್‌),
						'other' => q({0} ಬಿಟ್‍ಗಳು),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'1' => q(neuter),
						'name' => q(ಬೈಟ್‌ಗಳು),
						'one' => q({0} ಬೈಟ್‌),
						'other' => q({0} ಬೈಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'byte' => {
						'1' => q(neuter),
						'name' => q(ಬೈಟ್‌ಗಳು),
						'one' => q({0} ಬೈಟ್‌),
						'other' => q({0} ಬೈಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'1' => q(neuter),
						'name' => q(ಗಿಗಾಬಿಟ್‌ಗಳು),
						'one' => q({0} ಗಿಗಾಬಿಟ್‌),
						'other' => q({0} ಗಿಗಾಬಿಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'gigabit' => {
						'1' => q(neuter),
						'name' => q(ಗಿಗಾಬಿಟ್‌ಗಳು),
						'one' => q({0} ಗಿಗಾಬಿಟ್‌),
						'other' => q({0} ಗಿಗಾಬಿಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'1' => q(neuter),
						'name' => q(ಗಿಗಾಬೈಟ್‌ಗಳು),
						'one' => q({0} ಗಿಗಾಬೈಟ್‌),
						'other' => q({0} ಗಿಗಾಬೈಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'1' => q(neuter),
						'name' => q(ಗಿಗಾಬೈಟ್‌ಗಳು),
						'one' => q({0} ಗಿಗಾಬೈಟ್‌),
						'other' => q({0} ಗಿಗಾಬೈಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಬಿಟ್‌ಗಳು),
						'one' => q({0} ಕಿಲೋಬಿಟ್‌),
						'other' => q({0} ಕಿಲೋಬಿಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'kilobit' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಬಿಟ್‌ಗಳು),
						'one' => q({0} ಕಿಲೋಬಿಟ್‌),
						'other' => q({0} ಕಿಲೋಬಿಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಬೈಟ್‌ಗಳು),
						'one' => q({0} ಕಿಲೋಬೈಟ್‌),
						'other' => q({0} ಕಿಲೋಬೈಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಬೈಟ್‌ಗಳು),
						'one' => q({0} ಕಿಲೋಬೈಟ್‌),
						'other' => q({0} ಕಿಲೋಬೈಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾಬಿಟ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾಬಿಟ್‌),
						'other' => q({0} ಮೆಗಾಬಿಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'megabit' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾಬಿಟ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾಬಿಟ್‌),
						'other' => q({0} ಮೆಗಾಬಿಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾಬೈಟ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾಬೈಟ್‌),
						'other' => q({0} ಮೆಗಾಬೈಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'megabyte' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾಬೈಟ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾಬೈಟ್‌),
						'other' => q({0} ಮೆಗಾಬೈಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'1' => q(neuter),
						'name' => q(ಪೆಟಾಬೈಟ್‌ಗಳು),
						'one' => q({0} ಪೆಟಾಬೈಟ್‌),
						'other' => q({0} ಪೆಟಾಬೈಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'petabyte' => {
						'1' => q(neuter),
						'name' => q(ಪೆಟಾಬೈಟ್‌ಗಳು),
						'one' => q({0} ಪೆಟಾಬೈಟ್‌),
						'other' => q({0} ಪೆಟಾಬೈಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'1' => q(neuter),
						'name' => q(ಟೆರಾಬಿಟ್‌ಗಳು),
						'one' => q({0} ಟೆರಾಬಿಟ್‌),
						'other' => q({0} ಟೆರಾಬಿಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'terabit' => {
						'1' => q(neuter),
						'name' => q(ಟೆರಾಬಿಟ್‌ಗಳು),
						'one' => q({0} ಟೆರಾಬಿಟ್‌),
						'other' => q({0} ಟೆರಾಬಿಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'1' => q(neuter),
						'name' => q(ಟೆರಾಬೈಟ್‌ಗಳು),
						'one' => q({0} ಟೆರಾಬೈಟ್‌),
						'other' => q({0} ಟೆರಾಬೈಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'terabyte' => {
						'1' => q(neuter),
						'name' => q(ಟೆರಾಬೈಟ್‌ಗಳು),
						'one' => q({0} ಟೆರಾಬೈಟ್‌),
						'other' => q({0} ಟೆರಾಬೈಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'duration-century' => {
						'1' => q(neuter),
						'name' => q(ಶತಮಾನಗಳು),
						'one' => q({0} ಶತಮಾನವು),
						'other' => q({0}ಶತಮಾನಗಳು),
					},
					# Core Unit Identifier
					'century' => {
						'1' => q(neuter),
						'name' => q(ಶತಮಾನಗಳು),
						'one' => q({0} ಶತಮಾನವು),
						'other' => q({0}ಶತಮಾನಗಳು),
					},
					# Long Unit Identifier
					'duration-day' => {
						'1' => q(neuter),
						'one' => q({0} ದಿನವು),
						'other' => q({0} ದಿನಗಳು),
						'per' => q({0} ಪ್ರತಿ ದಿನಕ್ಕೆ),
					},
					# Core Unit Identifier
					'day' => {
						'1' => q(neuter),
						'one' => q({0} ದಿನವು),
						'other' => q({0} ದಿನಗಳು),
						'per' => q({0} ಪ್ರತಿ ದಿನಕ್ಕೆ),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'1' => q(neuter),
						'name' => q(ದಶಕಗಳು),
						'one' => q({0} ದಶಕವು),
						'other' => q({0} ದಶಕಗಳು),
					},
					# Core Unit Identifier
					'decade' => {
						'1' => q(neuter),
						'name' => q(ದಶಕಗಳು),
						'one' => q({0} ದಶಕವು),
						'other' => q({0} ದಶಕಗಳು),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'1' => q(neuter),
						'one' => q({0} ಗಂಟೆಯು),
						'other' => q({0} ಗಂಟೆಗಳು),
						'per' => q(ಪ್ರತಿ ಗಂಟೆಗೆ {0}),
					},
					# Core Unit Identifier
					'hour' => {
						'1' => q(neuter),
						'one' => q({0} ಗಂಟೆಯು),
						'other' => q({0} ಗಂಟೆಗಳು),
						'per' => q(ಪ್ರತಿ ಗಂಟೆಗೆ {0}),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'1' => q(neuter),
						'name' => q(ಮೈಕ್ರೊಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ಮೈಕ್ರೊಸೆಕೆಂಡ್),
						'other' => q({0} ಮೈಕ್ರೊಸೆಕೆಂಡುಗಳು),
					},
					# Core Unit Identifier
					'microsecond' => {
						'1' => q(neuter),
						'name' => q(ಮೈಕ್ರೊಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ಮೈಕ್ರೊಸೆಕೆಂಡ್),
						'other' => q({0} ಮೈಕ್ರೊಸೆಕೆಂಡುಗಳು),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'1' => q(neuter),
						'one' => q({0} ಮಿಲಿಸೆಕೆಂಡ್),
						'other' => q({0} ಮಿಲಿಸೆಕೆಂಡುಗಳು),
					},
					# Core Unit Identifier
					'millisecond' => {
						'1' => q(neuter),
						'one' => q({0} ಮಿಲಿಸೆಕೆಂಡ್),
						'other' => q({0} ಮಿಲಿಸೆಕೆಂಡುಗಳು),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'1' => q(neuter),
						'one' => q({0} ನಿಮಿಷವು),
						'other' => q({0} ನಿಮಿಷಗಳು),
						'per' => q(ಪ್ರತಿ ನಿಮಿಷಕ್ಕೆ {0}),
					},
					# Core Unit Identifier
					'minute' => {
						'1' => q(neuter),
						'one' => q({0} ನಿಮಿಷವು),
						'other' => q({0} ನಿಮಿಷಗಳು),
						'per' => q(ಪ್ರತಿ ನಿಮಿಷಕ್ಕೆ {0}),
					},
					# Long Unit Identifier
					'duration-month' => {
						'1' => q(neuter),
						'one' => q({0} ತಿಂಗಳು),
						'other' => q({0} ತಿಂಗಳು),
						'per' => q(ಪ್ರತಿ ತಿಂಗಳಿಗೆ {0}),
					},
					# Core Unit Identifier
					'month' => {
						'1' => q(neuter),
						'one' => q({0} ತಿಂಗಳು),
						'other' => q({0} ತಿಂಗಳು),
						'per' => q(ಪ್ರತಿ ತಿಂಗಳಿಗೆ {0}),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'1' => q(neuter),
						'name' => q(ನ್ಯಾನೊಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ನ್ಯಾನೊಸೆಕೆಂಡ್),
						'other' => q({0} ನ್ಯಾನೊಸೆಕೆಂಡುಗಳು),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'1' => q(neuter),
						'name' => q(ನ್ಯಾನೊಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ನ್ಯಾನೊಸೆಕೆಂಡ್),
						'other' => q({0} ನ್ಯಾನೊಸೆಕೆಂಡುಗಳು),
					},
					# Long Unit Identifier
					'duration-night' => {
						'1' => q(neuter),
						'name' => q(ರಾತ್ರಿಗಳು),
						'one' => q({0} ರಾತ್ರಿ),
						'other' => q({0} ರಾತ್ರಿಗಳು),
						'per' => q({0} ಪ್ರತಿ ರಾತ್ರಿಗೆ),
					},
					# Core Unit Identifier
					'night' => {
						'1' => q(neuter),
						'name' => q(ರಾತ್ರಿಗಳು),
						'one' => q({0} ರಾತ್ರಿ),
						'other' => q({0} ರಾತ್ರಿಗಳು),
						'per' => q({0} ಪ್ರತಿ ರಾತ್ರಿಗೆ),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'1' => q(neuter),
						'name' => q(ತ್ರೈಮಾಸಿಕಗಳು),
						'one' => q({0} ತ್ರೈಮಾಸಿಕವು),
						'other' => q({0} ತ್ರೈಮಾಸಿಕಗಳು),
						'per' => q({0}/ತ್ರೈಮಾಸಿಕಗಳಿಗೆ),
					},
					# Core Unit Identifier
					'quarter' => {
						'1' => q(neuter),
						'name' => q(ತ್ರೈಮಾಸಿಕಗಳು),
						'one' => q({0} ತ್ರೈಮಾಸಿಕವು),
						'other' => q({0} ತ್ರೈಮಾಸಿಕಗಳು),
						'per' => q({0}/ತ್ರೈಮಾಸಿಕಗಳಿಗೆ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'1' => q(neuter),
						'one' => q({0} ಸೆಕೆಂಡ್),
						'other' => q({0} ಸೆಕೆಂಡುಗಳು),
						'per' => q(ಪ್ರತಿ ಸೆಕೆಂಡ್‌ಗೆ {0}),
					},
					# Core Unit Identifier
					'second' => {
						'1' => q(neuter),
						'one' => q({0} ಸೆಕೆಂಡ್),
						'other' => q({0} ಸೆಕೆಂಡುಗಳು),
						'per' => q(ಪ್ರತಿ ಸೆಕೆಂಡ್‌ಗೆ {0}),
					},
					# Long Unit Identifier
					'duration-week' => {
						'1' => q(neuter),
						'one' => q({0} ವಾರವು),
						'other' => q({0} ವಾರಗಳು),
						'per' => q({0} ಪ್ರತಿ ವಾರಕ್ಕೆ),
					},
					# Core Unit Identifier
					'week' => {
						'1' => q(neuter),
						'one' => q({0} ವಾರವು),
						'other' => q({0} ವಾರಗಳು),
						'per' => q({0} ಪ್ರತಿ ವಾರಕ್ಕೆ),
					},
					# Long Unit Identifier
					'duration-year' => {
						'1' => q(neuter),
						'one' => q({0} ವರ್ಷವು),
						'other' => q({0} ವರ್ಷಗಳು),
						'per' => q(ಪ್ರತಿ ವರ್ಷಕ್ಕೆ {0}),
					},
					# Core Unit Identifier
					'year' => {
						'1' => q(neuter),
						'one' => q({0} ವರ್ಷವು),
						'other' => q({0} ವರ್ಷಗಳು),
						'per' => q(ಪ್ರತಿ ವರ್ಷಕ್ಕೆ {0}),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'1' => q(neuter),
						'name' => q(ಆ್ಯಂಪಿಯರ್‌ಗಳು),
						'one' => q({0} ಆ್ಯಂಪಿಯರ್),
						'other' => q({0} ಆ್ಯಂಪಿಯರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'ampere' => {
						'1' => q(neuter),
						'name' => q(ಆ್ಯಂಪಿಯರ್‌ಗಳು),
						'one' => q({0} ಆ್ಯಂಪಿಯರ್),
						'other' => q({0} ಆ್ಯಂಪಿಯರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಆ್ಯಂಪಿಯರ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿಆ್ಯಂಪಿಯರ್),
						'other' => q({0} ಮಿಲಿಆ್ಯಂಪಿಯರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'milliampere' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಆ್ಯಂಪಿಯರ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿಆ್ಯಂಪಿಯರ್),
						'other' => q({0} ಮಿಲಿಆ್ಯಂಪಿಯರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'1' => q(neuter),
						'one' => q({0} ಓಂ),
						'other' => q({0} ಓಂಗಳು),
					},
					# Core Unit Identifier
					'ohm' => {
						'1' => q(neuter),
						'one' => q({0} ಓಂ),
						'other' => q({0} ಓಂಗಳು),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'1' => q(neuter),
						'name' => q(ವೋಲ್ಟ್‌‌ಗಳು),
						'one' => q({0} ವೋಲ್ಟ್‌),
						'other' => q({0} ವೋಲ್ಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'volt' => {
						'1' => q(neuter),
						'name' => q(ವೋಲ್ಟ್‌‌ಗಳು),
						'one' => q({0} ವೋಲ್ಟ್‌),
						'other' => q({0} ವೋಲ್ಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(ಬ್ರಿಟಿಷ್ ಉಷ್ಣ ಘಟಕಗಳು),
						'one' => q({0} ಬ್ರಿಟಿಷ್ ಉಷ್ಣ ಘಟಕ),
						'other' => q({0} ಬ್ರಿಟಿಷ್ ಉಷ್ಣ ಘಟಕಗಳು),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(ಬ್ರಿಟಿಷ್ ಉಷ್ಣ ಘಟಕಗಳು),
						'one' => q({0} ಬ್ರಿಟಿಷ್ ಉಷ್ಣ ಘಟಕ),
						'other' => q({0} ಬ್ರಿಟಿಷ್ ಉಷ್ಣ ಘಟಕಗಳು),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'1' => q(neuter),
						'name' => q(ಕ್ಯಾಲೋರಿಗಳು),
						'one' => q({0} ಕ್ಯಾಲೋರಿ),
						'other' => q({0} ಕ್ಯಾಲೋರಿಗಳು),
					},
					# Core Unit Identifier
					'calorie' => {
						'1' => q(neuter),
						'name' => q(ಕ್ಯಾಲೋರಿಗಳು),
						'one' => q({0} ಕ್ಯಾಲೋರಿ),
						'other' => q({0} ಕ್ಯಾಲೋರಿಗಳು),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'name' => q(ಎಲೆಕ್ಟ್ರಾನ್‌ವೋಲ್ಟ್‌ಗಳು),
						'one' => q({0} ಎಲೆಕ್ಟ್ರಾನ್‌ವೋಲ್ಟ್‌),
						'other' => q({0} ಎಲೆಕ್ಟ್ರಾನ್‌ವೋಲ್ಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'name' => q(ಎಲೆಕ್ಟ್ರಾನ್‌ವೋಲ್ಟ್‌ಗಳು),
						'one' => q({0} ಎಲೆಕ್ಟ್ರಾನ್‌ವೋಲ್ಟ್‌),
						'other' => q({0} ಎಲೆಕ್ಟ್ರಾನ್‌ವೋಲ್ಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(ಕ್ಯಾಲೊರಿಗಳು),
						'one' => q({0} ಕ್ಯಾಲೊರಿ),
						'other' => q({0} ಕ್ಯಾಲೊರಿಗಳು),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(ಕ್ಯಾಲೊರಿಗಳು),
						'one' => q({0} ಕ್ಯಾಲೊರಿ),
						'other' => q({0} ಕ್ಯಾಲೊರಿಗಳು),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'1' => q(neuter),
						'one' => q({0} ಜೌಲ್‌),
						'other' => q({0} ಜೌಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'joule' => {
						'1' => q(neuter),
						'one' => q({0} ಜೌಲ್‌),
						'other' => q({0} ಜೌಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಕ್ಯಾಲೋರಿಗಳು),
						'one' => q({0} ಕಿಲೋಕ್ಯಾಲೋರಿ),
						'other' => q({0} ಕಿಲೋಕ್ಯಾಲೋರಿಗಳು),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಕ್ಯಾಲೋರಿಗಳು),
						'one' => q({0} ಕಿಲೋಕ್ಯಾಲೋರಿ),
						'other' => q({0} ಕಿಲೋಕ್ಯಾಲೋರಿಗಳು),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಜೌಲ್‌‌ಗಳು),
						'one' => q({0} ಕಿಲೋಜೌಲ್‌),
						'other' => q({0} ಕಿಲೋಜೌಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಜೌಲ್‌‌ಗಳು),
						'one' => q({0} ಕಿಲೋಜೌಲ್‌),
						'other' => q({0} ಕಿಲೋಜೌಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋವ್ಯಾಟ್‌-ಗಂಟೆಗಳು),
						'one' => q({0} ಕಿಲೋವ್ಯಾಟ್‌-ಗಂಟೆ),
						'other' => q({0} ಕಿಲೋವ್ಯಾಟ್‌-ಗಂಟೆಗಳು),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋವ್ಯಾಟ್‌-ಗಂಟೆಗಳು),
						'one' => q({0} ಕಿಲೋವ್ಯಾಟ್‌-ಗಂಟೆ),
						'other' => q({0} ಕಿಲೋವ್ಯಾಟ್‌-ಗಂಟೆಗಳು),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋವ್ಯಾಟ್-ಗಂಟೆಗಳು ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ),
						'one' => q({0} ಕಿಲೋವ್ಯಾಟ್-ಗಂಟೆ ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ),
						'other' => q({0} ಕಿಲೋವ್ಯಾಟ್-ಗಂಟೆಗಳು ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋವ್ಯಾಟ್-ಗಂಟೆಗಳು ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ),
						'one' => q({0} ಕಿಲೋವ್ಯಾಟ್-ಗಂಟೆ ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ),
						'other' => q({0} ಕಿಲೋವ್ಯಾಟ್-ಗಂಟೆಗಳು ಪ್ರತಿ 100 ಕಿಲೋಮೀಟರ್‌ಗಳಿಗೆ),
					},
					# Long Unit Identifier
					'force-newton' => {
						'1' => q(neuter),
						'name' => q(ನ್ಯೂಟನ್‌ಗಳು),
						'one' => q({0} ನ್ಯೂಟನ್),
						'other' => q({0} ನ್ಯೂಟನ್‌ಗಳು),
					},
					# Core Unit Identifier
					'newton' => {
						'1' => q(neuter),
						'name' => q(ನ್ಯೂಟನ್‌ಗಳು),
						'one' => q({0} ನ್ಯೂಟನ್),
						'other' => q({0} ನ್ಯೂಟನ್‌ಗಳು),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ಪೌಂಡ್ಸ್ ಆಫ್ ಫೋರ್ಸ್),
						'one' => q({0} ಪೌಂಡ್ ಆಫ್ ಫೋರ್ಸ್),
						'other' => q({0} ಪೌಂಡ್ಸ್ ಆಫ್ ಫೋರ್ಸ್),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ಪೌಂಡ್ಸ್ ಆಫ್ ಫೋರ್ಸ್),
						'one' => q({0} ಪೌಂಡ್ ಆಫ್ ಫೋರ್ಸ್),
						'other' => q({0} ಪೌಂಡ್ಸ್ ಆಫ್ ಫೋರ್ಸ್),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'1' => q(neuter),
						'name' => q(ಗಿಗಾಹರ್ಟ್ಸ್‌),
						'one' => q({0} ಗಿಗಾಹರ್ಟ್ಸ್‌),
						'other' => q({0} ಗಿಗಾಹರ್ಟ್ಸ್‌),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'1' => q(neuter),
						'name' => q(ಗಿಗಾಹರ್ಟ್ಸ್‌),
						'one' => q({0} ಗಿಗಾಹರ್ಟ್ಸ್‌),
						'other' => q({0} ಗಿಗಾಹರ್ಟ್ಸ್‌),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'1' => q(neuter),
						'one' => q({0} ಹರ್ಟ್ಸ್‌),
						'other' => q({0} ಹರ್ಟ್ಸ್‌),
					},
					# Core Unit Identifier
					'hertz' => {
						'1' => q(neuter),
						'one' => q({0} ಹರ್ಟ್ಸ್‌),
						'other' => q({0} ಹರ್ಟ್ಸ್‌),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಹರ್ಟ್ಸ್‌),
						'one' => q({0} ಕಿಲೋಹರ್ಟ್ಸ್‌),
						'other' => q({0} ಕಿಲೋಹರ್ಟ್ಸ್‌),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಹರ್ಟ್ಸ್‌),
						'one' => q({0} ಕಿಲೋಹರ್ಟ್ಸ್‌),
						'other' => q({0} ಕಿಲೋಹರ್ಟ್ಸ್‌),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾಹರ್ಟ್ಸ್),
						'one' => q({0} ಮೆಗಾಹರ್ಟ್ಸ್),
						'other' => q({0} ಮೆಗಾಹರ್ಟ್ಸ್),
					},
					# Core Unit Identifier
					'megahertz' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾಹರ್ಟ್ಸ್),
						'one' => q({0} ಮೆಗಾಹರ್ಟ್ಸ್),
						'other' => q({0} ಮೆಗಾಹರ್ಟ್ಸ್),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'one' => q({0} ಡಾಟ್‌),
						'other' => q({0} ಡಾಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'dot' => {
						'one' => q({0} ಡಾಟ್‌),
						'other' => q({0} ಡಾಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(ಡಾಟ್ಸ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
						'one' => q({0} ಡಾಟ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಡಾಟ್ಸ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(ಡಾಟ್ಸ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
						'one' => q({0} ಡಾಟ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಡಾಟ್ಸ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(ಡಾಟ್ಸ್ ಪರ್ ಇಂಚ್),
						'one' => q({0} ಡಾಟ್ ಪರ್ ಇಂಚ್),
						'other' => q({0} ಡಾಟ್ಸ್ ಪರ್ ಇಂಚ್),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(ಡಾಟ್ಸ್ ಪರ್ ಇಂಚ್),
						'one' => q({0} ಡಾಟ್ ಪರ್ ಇಂಚ್),
						'other' => q({0} ಡಾಟ್ಸ್ ಪರ್ ಇಂಚ್),
					},
					# Long Unit Identifier
					'graphics-em' => {
						'1' => q(neuter),
						'name' => q(ಟೈಪೊಗ್ರಾಫಿಕ್ em),
						'one' => q({0} em),
						'other' => q({0} ems ಗಳು),
					},
					# Core Unit Identifier
					'em' => {
						'1' => q(neuter),
						'name' => q(ಟೈಪೊಗ್ರಾಫಿಕ್ em),
						'one' => q({0} em),
						'other' => q({0} ems ಗಳು),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'1' => q(neuter),
						'one' => q({0} ಮೆಗಾಪಿಕ್ಸೆಲ್),
						'other' => q({0} ಮೆಗಾಪಿಕ್ಸೆಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'megapixel' => {
						'1' => q(neuter),
						'one' => q({0} ಮೆಗಾಪಿಕ್ಸೆಲ್),
						'other' => q({0} ಮೆಗಾಪಿಕ್ಸೆಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'1' => q(neuter),
						'one' => q({0} ಪಿಕ್ಸೆಲ್),
						'other' => q({0} ಪಿಕ್ಸೆಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'pixel' => {
						'1' => q(neuter),
						'one' => q({0} ಪಿಕ್ಸೆಲ್),
						'other' => q({0} ಪಿಕ್ಸೆಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'1' => q(neuter),
						'name' => q(ಪಿಕ್ಸೆಲ್ಸ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
						'one' => q({0} ಪಿಕ್ಸೆಲ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಪಿಕ್ಸೆಲ್ಸ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'1' => q(neuter),
						'name' => q(ಪಿಕ್ಸೆಲ್ಸ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
						'one' => q({0} ಪಿಕ್ಸೆಲ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಪಿಕ್ಸೆಲ್ಸ್ ಪರ್ ಸೆಂಟಿಮೀಟರ್),
					},
					# Long Unit Identifier
					'graphics-pixel-per-inch' => {
						'name' => q(ಪಿಕ್ಸೆಲ್ಸ್ ಪರ್ ಇಂಚ್),
						'one' => q({0} ಪಿಕ್ಸೆಲ್ ಪರ್ ಇಂಚ್),
						'other' => q({0} ಪಿಕ್ಸೆಲ್ಸ್ ಪರ್ ಇಂಚ್),
					},
					# Core Unit Identifier
					'pixel-per-inch' => {
						'name' => q(ಪಿಕ್ಸೆಲ್ಸ್ ಪರ್ ಇಂಚ್),
						'one' => q({0} ಪಿಕ್ಸೆಲ್ ಪರ್ ಇಂಚ್),
						'other' => q({0} ಪಿಕ್ಸೆಲ್ಸ್ ಪರ್ ಇಂಚ್),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(ಅಸ್ಟ್ರಾನಾಮಿಕಲ್ ಯೂನಿಟ್‌ಗಳು),
						'one' => q({0} ಅಸ್ಟ್ರಾನಾಮಿಕಲ್ ಯೂನಿಟ್),
						'other' => q({0} ಅಸ್ಟ್ರಾನಾಮಿಕಲ್ ಯೂನಿಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(ಅಸ್ಟ್ರಾನಾಮಿಕಲ್ ಯೂನಿಟ್‌ಗಳು),
						'one' => q({0} ಅಸ್ಟ್ರಾನಾಮಿಕಲ್ ಯೂನಿಟ್),
						'other' => q({0} ಅಸ್ಟ್ರಾನಾಮಿಕಲ್ ಯೂನಿಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'1' => q(neuter),
						'name' => q(ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಸೆಂಟಿಮೀಟರ್‌ಗೆ {0}),
					},
					# Core Unit Identifier
					'centimeter' => {
						'1' => q(neuter),
						'name' => q(ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಸೆಂಟಿಮೀಟರ್‌ಗೆ {0}),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'1' => q(neuter),
						'name' => q(ಡೆಸಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಡೆಸಿಮೀಟರ್),
						'other' => q({0} ಡೆಸಿಮೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'decimeter' => {
						'1' => q(neuter),
						'name' => q(ಡೆಸಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಡೆಸಿಮೀಟರ್),
						'other' => q({0} ಡೆಸಿಮೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'name' => q(ಭೂಮಿಯ ತ್ರಿಜ್ಯ),
						'one' => q({0} ಭೂಮಿಯ ತ್ರಿಜ್ಯ),
						'other' => q({0} ಭೂಮಿಯ ತ್ರಿಜ್ಯ),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'name' => q(ಭೂಮಿಯ ತ್ರಿಜ್ಯ),
						'one' => q({0} ಭೂಮಿಯ ತ್ರಿಜ್ಯ),
						'other' => q({0} ಭೂಮಿಯ ತ್ರಿಜ್ಯ),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'one' => q({0} ಫ್ಯಾಥಮ್),
						'other' => q({0} ಫ್ಯಾಥಮ್ಸ್),
					},
					# Core Unit Identifier
					'fathom' => {
						'one' => q({0} ಫ್ಯಾಥಮ್),
						'other' => q({0} ಫ್ಯಾಥಮ್ಸ್),
					},
					# Long Unit Identifier
					'length-foot' => {
						'one' => q({0} ಅಡಿ),
						'other' => q({0} ಅಡಿ),
						'per' => q(ಪ್ರತಿ ಅಡಿಗೆ {0}),
					},
					# Core Unit Identifier
					'foot' => {
						'one' => q({0} ಅಡಿ),
						'other' => q({0} ಅಡಿ),
						'per' => q(ಪ್ರತಿ ಅಡಿಗೆ {0}),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'one' => q({0} ಫರ್ಲಾಂಗ್),
						'other' => q({0} ಫರ್ಲಾಂಗ್ಸ್),
					},
					# Core Unit Identifier
					'furlong' => {
						'one' => q({0} ಫರ್ಲಾಂಗ್),
						'other' => q({0} ಫರ್ಲಾಂಗ್ಸ್),
					},
					# Long Unit Identifier
					'length-inch' => {
						'one' => q({0} ಅಂಗುಲ),
						'other' => q({0} ಅಂಗುಲಗಳು),
						'per' => q(ಪ್ರತಿ ಅಂಗುಲಕ್ಕೆ {0}),
					},
					# Core Unit Identifier
					'inch' => {
						'one' => q({0} ಅಂಗುಲ),
						'other' => q({0} ಅಂಗುಲಗಳು),
						'per' => q(ಪ್ರತಿ ಅಂಗುಲಕ್ಕೆ {0}),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'1' => q(neuter),
						'one' => q({0} ಕಿಲೋಮೀಟರ್),
						'other' => q({0} ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಕಿಲೋಮೀಟ‍ರ್‌ಗೆ {0}),
					},
					# Core Unit Identifier
					'kilometer' => {
						'1' => q(neuter),
						'one' => q({0} ಕಿಲೋಮೀಟರ್),
						'other' => q({0} ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಕಿಲೋಮೀಟ‍ರ್‌ಗೆ {0}),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'one' => q({0} ಬೆಳಕಿನ ವರ್ಷ),
						'other' => q({0} ಬೆಳಕಿನ ವರ್ಷಗಳು),
					},
					# Core Unit Identifier
					'light-year' => {
						'one' => q({0} ಬೆಳಕಿನ ವರ್ಷ),
						'other' => q({0} ಬೆಳಕಿನ ವರ್ಷಗಳು),
					},
					# Long Unit Identifier
					'length-meter' => {
						'1' => q(neuter),
						'name' => q(ಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಮೀಟರ್),
						'other' => q({0} ಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಮೀಟರ್‌ಗೆ {0}),
					},
					# Core Unit Identifier
					'meter' => {
						'1' => q(neuter),
						'name' => q(ಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಮೀಟರ್),
						'other' => q({0} ಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಮೀಟರ್‌ಗೆ {0}),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'1' => q(neuter),
						'name' => q(ಮೈಕ್ರೊಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಮೈಕ್ರೊಮೀಟರ್),
						'other' => q({0} ಮೈಕ್ರೊಮೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'micrometer' => {
						'1' => q(neuter),
						'name' => q(ಮೈಕ್ರೊಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಮೈಕ್ರೊಮೀಟರ್),
						'other' => q({0} ಮೈಕ್ರೊಮೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'length-mile' => {
						'one' => q({0} ಮೈಲು),
						'other' => q({0} ಮೈಲುಗಳು),
					},
					# Core Unit Identifier
					'mile' => {
						'one' => q({0} ಮೈಲು),
						'other' => q({0} ಮೈಲುಗಳು),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'1' => q(neuter),
						'name' => q(ಸ್ಕ್ಯಾಂಡಿನೇವಿಯನ್-ಮೈಲುಗಳು),
						'one' => q({0} ಸ್ಕ್ಯಾಂಡಿನೇವಿಯನ್-ಮೈಲು),
						'other' => q({0} ಸ್ಕ್ಯಾಂಡಿನೇವಿಯನ್-ಮೈಲುಗಳು),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'1' => q(neuter),
						'name' => q(ಸ್ಕ್ಯಾಂಡಿನೇವಿಯನ್-ಮೈಲುಗಳು),
						'one' => q({0} ಸ್ಕ್ಯಾಂಡಿನೇವಿಯನ್-ಮೈಲು),
						'other' => q({0} ಸ್ಕ್ಯಾಂಡಿನೇವಿಯನ್-ಮೈಲುಗಳು),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿಮೀಟರ್),
						'other' => q({0} ಮಿಲಿಮೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'millimeter' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿಮೀಟರ್),
						'other' => q({0} ಮಿಲಿಮೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'1' => q(neuter),
						'name' => q(ನ್ಯಾನೊಮೀಟರ್‌‌ಗಳು),
						'one' => q({0} ನ್ಯಾನೊಮೀಟರ್‌),
						'other' => q({0} ನ್ಯಾನೊಮೀಟರ್‌‌ಗಳು),
					},
					# Core Unit Identifier
					'nanometer' => {
						'1' => q(neuter),
						'name' => q(ನ್ಯಾನೊಮೀಟರ್‌‌ಗಳು),
						'one' => q({0} ನ್ಯಾನೊಮೀಟರ್‌),
						'other' => q({0} ನ್ಯಾನೊಮೀಟರ್‌‌ಗಳು),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ನಾಟಿಕಲ್ ಮೈಲುಗಳು),
						'one' => q({0} ನಾಟಿಕಲ್ ಮೈಲು),
						'other' => q({0} ನಾಟಿಕಲ್ ಮೈಲುಗಳು),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ನಾಟಿಕಲ್ ಮೈಲುಗಳು),
						'one' => q({0} ನಾಟಿಕಲ್ ಮೈಲು),
						'other' => q({0} ನಾಟಿಕಲ್ ಮೈಲುಗಳು),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(ಪಾರ್‌ಸೆಕೆಂಡ್‌ಗಳು),
						'one' => q({0} ಪಾರ್‌ಸೆಕೆಂ),
						'other' => q({0} ಪಾರ್‌ಸೆಕೆಂಡ್‌ಗಳು),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(ಪಾರ್‌ಸೆಕೆಂಡ್‌ಗಳು),
						'one' => q({0} ಪಾರ್‌ಸೆಕೆಂ),
						'other' => q({0} ಪಾರ್‌ಸೆಕೆಂಡ್‌ಗಳು),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'1' => q(neuter),
						'name' => q(ಪಿಕೋಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಪಿಕೋಮೀಟರ್),
						'other' => q({0} ಪಿಕೋಮೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'picometer' => {
						'1' => q(neuter),
						'name' => q(ಪಿಕೋಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಪಿಕೋಮೀಟರ್),
						'other' => q({0} ಪಿಕೋಮೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'length-point' => {
						'1' => q(neuter),
						'one' => q({0} ಪಾಯಿಂಟ್),
						'other' => q({0} ಪಾಯಿಂಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'point' => {
						'1' => q(neuter),
						'one' => q({0} ಪಾಯಿಂಟ್),
						'other' => q({0} ಪಾಯಿಂಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'one' => q({0} ಸೋಲಾರ್‌ ರೇಡಿಯಸ್‌),
						'other' => q({0} ಸೋಲಾರ್‌ ರೇಡಿ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'one' => q({0} ಸೋಲಾರ್‌ ರೇಡಿಯಸ್‌),
						'other' => q({0} ಸೋಲಾರ್‌ ರೇಡಿ),
					},
					# Long Unit Identifier
					'length-yard' => {
						'one' => q({0} ಗಜ),
						'other' => q({0} ಗಜಗಳು),
					},
					# Core Unit Identifier
					'yard' => {
						'one' => q({0} ಗಜ),
						'other' => q({0} ಗಜಗಳು),
					},
					# Long Unit Identifier
					'light-candela' => {
						'1' => q(neuter),
						'name' => q(ಕ್ಯಾಂಡಿಲಾ),
						'one' => q({0} ಕ್ಯಾಂಡಿಲಾವು),
						'other' => q({0} ಕ್ಯಾಂಡಿಲಾ),
					},
					# Core Unit Identifier
					'candela' => {
						'1' => q(neuter),
						'name' => q(ಕ್ಯಾಂಡಿಲಾ),
						'one' => q({0} ಕ್ಯಾಂಡಿಲಾವು),
						'other' => q({0} ಕ್ಯಾಂಡಿಲಾ),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'1' => q(neuter),
						'name' => q(ಲೂಮೆನ್),
						'one' => q({0} ಲೂಮೆನ್),
						'other' => q({0} ಲೂಮೆನ್),
					},
					# Core Unit Identifier
					'lumen' => {
						'1' => q(neuter),
						'name' => q(ಲೂಮೆನ್),
						'one' => q({0} ಲೂಮೆನ್),
						'other' => q({0} ಲೂಮೆನ್),
					},
					# Long Unit Identifier
					'light-lux' => {
						'1' => q(neuter),
						'name' => q(ಲಕ್ಸ್‌‌),
						'one' => q({0} ಲಕ್ಸ್‌‌),
						'other' => q({0} ಲಕ್ಸ್‌‌),
					},
					# Core Unit Identifier
					'lux' => {
						'1' => q(neuter),
						'name' => q(ಲಕ್ಸ್‌‌),
						'one' => q({0} ಲಕ್ಸ್‌‌),
						'other' => q({0} ಲಕ್ಸ್‌‌),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'one' => q({0} ಸೌರ ಪ್ರಕಾಶಗಳು),
						'other' => q({0} ಸೌರ ಪ್ರಕಾಶಗಳು),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'one' => q({0} ಸೌರ ಪ್ರಕಾಶಗಳು),
						'other' => q({0} ಸೌರ ಪ್ರಕಾಶಗಳು),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'1' => q(neuter),
						'one' => q({0} ಕ್ಯಾರೆಟ್‌),
						'other' => q({0} ಕ್ಯಾರೆಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'carat' => {
						'1' => q(neuter),
						'one' => q({0} ಕ್ಯಾರೆಟ್‌),
						'other' => q({0} ಕ್ಯಾರೆಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'one' => q({0} ಡಿಎ),
						'other' => q({0} ಡಿಎ),
					},
					# Core Unit Identifier
					'dalton' => {
						'one' => q({0} ಡಿಎ),
						'other' => q({0} ಡಿಎ),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'name' => q(ಭೂಮಿಯ ದ್ರವ್ಯರಾಶಿಗಳು),
						'one' => q({0} ಭೂಮಿಯ ದ್ರವ್ಯರಾಶಿ),
						'other' => q({0} ಭೂಮಿಯ ದ್ರವ್ಯರಾಶಿಗಳು),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'name' => q(ಭೂಮಿಯ ದ್ರವ್ಯರಾಶಿಗಳು),
						'one' => q({0} ಭೂಮಿಯ ದ್ರವ್ಯರಾಶಿ),
						'other' => q({0} ಭೂಮಿಯ ದ್ರವ್ಯರಾಶಿಗಳು),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'1' => q(neuter),
						'one' => q({0} ಗ್ರಾಂ),
						'other' => q({0} ಗ್ರಾಂಗಳು),
						'per' => q({0} ಪ್ರತಿ ಗ್ರಾಂಗೆ),
					},
					# Core Unit Identifier
					'gram' => {
						'1' => q(neuter),
						'one' => q({0} ಗ್ರಾಂ),
						'other' => q({0} ಗ್ರಾಂಗಳು),
						'per' => q({0} ಪ್ರತಿ ಗ್ರಾಂಗೆ),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಗ್ರಾಂಗಳು),
						'one' => q({0} ಕಿಲೋಗ್ರಾಂ),
						'other' => q({0} ಕಿಲೋಗ್ರಾಂಗಳು),
						'per' => q({0} ಪ್ರತಿ ಕಿಲೋಗ್ರಾಂಗೆ),
					},
					# Core Unit Identifier
					'kilogram' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಗ್ರಾಂಗಳು),
						'one' => q({0} ಕಿಲೋಗ್ರಾಂ),
						'other' => q({0} ಕಿಲೋಗ್ರಾಂಗಳು),
						'per' => q({0} ಪ್ರತಿ ಕಿಲೋಗ್ರಾಂಗೆ),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'1' => q(neuter),
						'name' => q(ಮೈಕ್ರೋ ಗ್ರಾಂಗಳು),
						'one' => q({0} ಮೈಕ್ರೋ ಗ್ರಾಂ),
						'other' => q({0} ಮೈಕ್ರೋ ಗ್ರಾಂಗಳು),
					},
					# Core Unit Identifier
					'microgram' => {
						'1' => q(neuter),
						'name' => q(ಮೈಕ್ರೋ ಗ್ರಾಂಗಳು),
						'one' => q({0} ಮೈಕ್ರೋ ಗ್ರಾಂ),
						'other' => q({0} ಮೈಕ್ರೋ ಗ್ರಾಂಗಳು),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿ ಗ್ರಾಂಗಳು),
						'one' => q({0} ಮಿಲಿ ಗ್ರಾಂ),
						'other' => q({0} ಮಿಲಿ ಗ್ರಾಂಗಳು),
					},
					# Core Unit Identifier
					'milligram' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿ ಗ್ರಾಂಗಳು),
						'one' => q({0} ಮಿಲಿ ಗ್ರಾಂ),
						'other' => q({0} ಮಿಲಿ ಗ್ರಾಂಗಳು),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(ಔನ್ಸ್‌ಗಳು),
						'one' => q({0} ಔನ್ಸ್),
						'other' => q({0} ಔನ್ಸ್‌ಗಳು),
						'per' => q({0} ಪ್ರತಿ ಔನ್ಸ್‌ಗೆ),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(ಔನ್ಸ್‌ಗಳು),
						'one' => q({0} ಔನ್ಸ್),
						'other' => q({0} ಔನ್ಸ್‌ಗಳು),
						'per' => q({0} ಪ್ರತಿ ಔನ್ಸ್‌ಗೆ),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ಟ್ರಾಯ್ ಔನ್ಸ್‌ಗಳು),
						'one' => q({0} ಟ್ರಾಯ್ ಔನ್ಸ್),
						'other' => q({0} ಟ್ರಾಯ್ ಔನ್ಸ್‌ಗಳು),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ಟ್ರಾಯ್ ಔನ್ಸ್‌ಗಳು),
						'one' => q({0} ಟ್ರಾಯ್ ಔನ್ಸ್),
						'other' => q({0} ಟ್ರಾಯ್ ಔನ್ಸ್‌ಗಳು),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'name' => q(ಪೌಂಡ್‌ಗಳು),
						'one' => q({0} ಪೌಂಡ್),
						'other' => q({0} ಪೌಂಡ್‌ಗಳು),
						'per' => q({0} ಪ್ರತಿ ಪೌಂಡ್‌ಗೆ),
					},
					# Core Unit Identifier
					'pound' => {
						'name' => q(ಪೌಂಡ್‌ಗಳು),
						'one' => q({0} ಪೌಂಡ್),
						'other' => q({0} ಪೌಂಡ್‌ಗಳು),
						'per' => q({0} ಪ್ರತಿ ಪೌಂಡ್‌ಗೆ),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'name' => q(ಸೋಲಾರ್‌ ಮಾಸ್‌),
						'one' => q({0} ಸೋಲಾರ್‌ ಮಾಸ್‌),
						'other' => q({0} ಸೋಲಾರ್ ಮಾಸ್‌ಗಳು),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'name' => q(ಸೋಲಾರ್‌ ಮಾಸ್‌),
						'one' => q({0} ಸೋಲಾರ್‌ ಮಾಸ್‌),
						'other' => q({0} ಸೋಲಾರ್ ಮಾಸ್‌ಗಳು),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'one' => q({0} ಕಲ್ಲು),
						'other' => q({0} ಕಲ್ಲುಗಳು),
					},
					# Core Unit Identifier
					'stone' => {
						'one' => q({0} ಕಲ್ಲು),
						'other' => q({0} ಕಲ್ಲುಗಳು),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(ಟನ್‌ಗಳು),
						'one' => q({0} ಟನ್‌),
						'other' => q({0} ಟನ್‌ಗಳು),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(ಟನ್‌ಗಳು),
						'one' => q({0} ಟನ್‌),
						'other' => q({0} ಟನ್‌ಗಳು),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'1' => q(neuter),
						'name' => q(ಮೆಟ್ರಿಕ್‌‌ ಟನ್‌ಗಳು),
						'one' => q({0} ಮೆಟ್ರಿಕ್‌ ಟನ್‌),
						'other' => q({0} ಮೆಟ್ರಿಕ್‌‌ ಟನ್‌‌ಗಳು),
					},
					# Core Unit Identifier
					'tonne' => {
						'1' => q(neuter),
						'name' => q(ಮೆಟ್ರಿಕ್‌‌ ಟನ್‌ಗಳು),
						'one' => q({0} ಮೆಟ್ರಿಕ್‌ ಟನ್‌),
						'other' => q({0} ಮೆಟ್ರಿಕ್‌‌ ಟನ್‌‌ಗಳು),
					},
					# Long Unit Identifier
					'per' => {
						'1' => q(ಪ್ರತಿ {1} ಗೆ {0}),
					},
					# Core Unit Identifier
					'per' => {
						'1' => q(ಪ್ರತಿ {1} ಗೆ {0}),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'1' => q(neuter),
						'name' => q(ಗಿಗಾವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ಗಿಗಾವ್ಯಾಟ್‌),
						'other' => q({0} ಗಿಗಾವ್ಯಾಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'1' => q(neuter),
						'name' => q(ಗಿಗಾವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ಗಿಗಾವ್ಯಾಟ್‌),
						'other' => q({0} ಗಿಗಾವ್ಯಾಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(ಹಾರ್ಸ್‌ಪವರ್),
						'one' => q({0} ಹಾರ್ಸ್‌ಪವರ್),
						'other' => q({0} ಹಾರ್ಸ್‌ಪವರ್),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(ಹಾರ್ಸ್‌ಪವರ್),
						'one' => q({0} ಹಾರ್ಸ್‌ಪವರ್),
						'other' => q({0} ಹಾರ್ಸ್‌ಪವರ್),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ಕಿಲೋವ್ಯಾಟ್),
						'other' => q({0} ಕಿಲೋವ್ಯಾಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ಕಿಲೋವ್ಯಾಟ್),
						'other' => q({0} ಕಿಲೋವ್ಯಾಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾವ್ಯಾಟ್‌),
						'other' => q({0} ಮೆಗಾವ್ಯಾಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'megawatt' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾವ್ಯಾಟ್‌),
						'other' => q({0} ಮೆಗಾವ್ಯಾಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿವ್ಯಾಟ್‌),
						'other' => q({0} ಮಿಲಿವ್ಯಾಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿವ್ಯಾಟ್‌),
						'other' => q({0} ಮಿಲಿವ್ಯಾಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'power-watt' => {
						'1' => q(neuter),
						'one' => q({0} ವ್ಯಾಟ್),
						'other' => q({0} ವ್ಯಾಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'watt' => {
						'1' => q(neuter),
						'one' => q({0} ವ್ಯಾಟ್),
						'other' => q({0} ವ್ಯಾಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'power2' => {
						'1' => q(ಚದರ {0}),
						'one' => q(ಚದರವು {0}),
						'other' => q(ಚದರಗಳು {0}),
					},
					# Core Unit Identifier
					'power2' => {
						'1' => q(ಚದರ {0}),
						'one' => q(ಚದರವು {0}),
						'other' => q(ಚದರಗಳು {0}),
					},
					# Long Unit Identifier
					'power3' => {
						'1' => q(ಕ್ಯೂ. {0}),
						'one' => q(ಕ್ಯೂಬಿಕ್ {0}),
						'other' => q(ಕ್ಯೂಬಿಕ್‌ಗಳು {0}),
					},
					# Core Unit Identifier
					'power3' => {
						'1' => q(ಕ್ಯೂ. {0}),
						'one' => q(ಕ್ಯೂಬಿಕ್ {0}),
						'other' => q(ಕ್ಯೂಬಿಕ್‌ಗಳು {0}),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'1' => q(neuter),
						'one' => q({0} ವಾತಾವರಣ),
						'other' => q({0} ವಾತಾವರಣಗಳು),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'1' => q(neuter),
						'one' => q({0} ವಾತಾವರಣ),
						'other' => q({0} ವಾತಾವರಣಗಳು),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'1' => q(neuter),
						'name' => q(ಬಾರ್‌ಗಳು),
						'one' => q({0} ಬಾರ್‌),
						'other' => q({0} ಬಾರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'bar' => {
						'1' => q(neuter),
						'name' => q(ಬಾರ್‌ಗಳು),
						'one' => q({0} ಬಾರ್‌),
						'other' => q({0} ಬಾರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'1' => q(neuter),
						'name' => q(ಹೆಕ್ಟೋಪ್ಯಾಸ್ಕಲ್‌ಗಳು),
						'one' => q({0} ಹೆಕ್ಟೋಪ್ಯಾಸ್ಕಲ್),
						'other' => q({0} ಹೆಕ್ಟೋಪಾಸ್ಕಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'1' => q(neuter),
						'name' => q(ಹೆಕ್ಟೋಪ್ಯಾಸ್ಕಲ್‌ಗಳು),
						'one' => q({0} ಹೆಕ್ಟೋಪ್ಯಾಸ್ಕಲ್),
						'other' => q({0} ಹೆಕ್ಟೋಪಾಸ್ಕಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'name' => q(ಮರ್ಕ್ಯುರಿ ಅಂಗುಲಗಳು),
						'one' => q({0} ಮರ್ಕ್ಯುರಿ ಅಂಗುಲ),
						'other' => q({0} ಮರ್ಕ್ಯುರಿ ಅಂಗುಲಗಳು),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'name' => q(ಮರ್ಕ್ಯುರಿ ಅಂಗುಲಗಳು),
						'one' => q({0} ಮರ್ಕ್ಯುರಿ ಅಂಗುಲ),
						'other' => q({0} ಮರ್ಕ್ಯುರಿ ಅಂಗುಲಗಳು),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಪಾಸ್ಕಲ್‌ಗಳು),
						'one' => q({0} ಕಿಲೋಪಾಸ್ಕಲ್‌),
						'other' => q({0} ಕಿಲೋಪಾಸ್ಕಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಪಾಸ್ಕಲ್‌ಗಳು),
						'one' => q({0} ಕಿಲೋಪಾಸ್ಕಲ್‌),
						'other' => q({0} ಕಿಲೋಪಾಸ್ಕಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾಪಾಸ್ಕಲ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾಪಾಸ್ಕಲ್‌),
						'other' => q({0} ಮೆಗಾಪಾಸ್ಕಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'megapascal' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾಪಾಸ್ಕಲ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾಪಾಸ್ಕಲ್‌),
						'other' => q({0} ಮೆಗಾಪಾಸ್ಕಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಬಾರ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿಬಾರ್),
						'other' => q({0} ಮಿಲಿಬಾರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'millibar' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಬಾರ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿಬಾರ್),
						'other' => q({0} ಮಿಲಿಬಾರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'1' => q(neuter),
						'name' => q(ಮರ್ಕ್ಯುರಿ ಮಿಲಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಮರ್ಕ್ಯುರಿ ಮಿಲಿಮೀಟರ್‌),
						'other' => q({0} ಮರ್ಕ್ಯುರಿ ಮಿಲಿಮೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'1' => q(neuter),
						'name' => q(ಮರ್ಕ್ಯುರಿ ಮಿಲಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಮರ್ಕ್ಯುರಿ ಮಿಲಿಮೀಟರ್‌),
						'other' => q({0} ಮರ್ಕ್ಯುರಿ ಮಿಲಿಮೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'pressure-pascal' => {
						'1' => q(neuter),
						'name' => q(ಪಾಸ್ಕಲ್‌ಗಳು),
						'one' => q({0} ಪಾಸ್ಕಲ್‌),
						'other' => q({0} ಪಾಸ್ಕಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'pascal' => {
						'1' => q(neuter),
						'name' => q(ಪಾಸ್ಕಲ್‌ಗಳು),
						'one' => q({0} ಪಾಸ್ಕಲ್‌),
						'other' => q({0} ಪಾಸ್ಕಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(ಪೌಂಡ್ಸ್-ಫೋರ್ಸ್ ಪ್ರತಿ ಚದರ ಇಂಚಿಗೆ),
						'one' => q({0} ಪೌಂಡ್-ಫೋರ್ಸ್ ಪ್ರತಿ ಚದರ ಇಂಚಿಗೆ),
						'other' => q({0} ಪೌಂಡ್-ಫೋರ್ಸ್ ಪ್ರತಿ ಚದರ ಇಂಚಿಗೆ),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(ಪೌಂಡ್ಸ್-ಫೋರ್ಸ್ ಪ್ರತಿ ಚದರ ಇಂಚಿಗೆ),
						'one' => q({0} ಪೌಂಡ್-ಫೋರ್ಸ್ ಪ್ರತಿ ಚದರ ಇಂಚಿಗೆ),
						'other' => q({0} ಪೌಂಡ್-ಫೋರ್ಸ್ ಪ್ರತಿ ಚದರ ಇಂಚಿಗೆ),
					},
					# Long Unit Identifier
					'speed-beaufort' => {
						'name' => q(ಬ್ಯೂಫೋರ್ಟ್),
						'one' => q(ಬ್ಯೂಫೋರ್ಟ್ {0}),
						'other' => q(ಬ್ಯೂಫೋರ್ಟ್ {0}),
					},
					# Core Unit Identifier
					'beaufort' => {
						'name' => q(ಬ್ಯೂಫೋರ್ಟ್),
						'one' => q(ಬ್ಯೂಫೋರ್ಟ್ {0}),
						'other' => q(ಬ್ಯೂಫೋರ್ಟ್ {0}),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಗಂಟೆಗೆ),
						'one' => q({0} ಕಿಲೋಮೀಟರ್ ಪ್ರತಿ ಗಂಟೆಗೆ),
						'other' => q({0} ಕಿಲೋಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಗಂಟೆಗೆ),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'1' => q(neuter),
						'name' => q(ಕಿಲೋಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಗಂಟೆಗೆ),
						'one' => q({0} ಕಿಲೋಮೀಟರ್ ಪ್ರತಿ ಗಂಟೆಗೆ),
						'other' => q({0} ಕಿಲೋಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಗಂಟೆಗೆ),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'name' => q(ನಾಟ್‌ಗಳು),
						'one' => q({0} ನಾಟ್),
						'other' => q({0} ನಾಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'knot' => {
						'name' => q(ನಾಟ್‌ಗಳು),
						'one' => q({0} ನಾಟ್),
						'other' => q({0} ನಾಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'1' => q(neuter),
						'name' => q(ಲೈಟ್),
						'one' => q({0} ಲೈಟ್),
						'other' => q({0} ಲೈಟ್),
					},
					# Core Unit Identifier
					'light-speed' => {
						'1' => q(neuter),
						'name' => q(ಲೈಟ್),
						'one' => q({0} ಲೈಟ್),
						'other' => q({0} ಲೈಟ್),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'1' => q(neuter),
						'name' => q(ಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಸೆಕೆಂಡ್‌ಗೆ),
						'one' => q({0} ಮೀಟರ್‌ ಪ್ರತಿ ಸೆಕೆಂಡ್‌ಗೆ),
						'other' => q({0} ಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಸೆಕೆಂಡ್‌ಗೆ),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'1' => q(neuter),
						'name' => q(ಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಸೆಕೆಂಡ್‌ಗೆ),
						'one' => q({0} ಮೀಟರ್‌ ಪ್ರತಿ ಸೆಕೆಂಡ್‌ಗೆ),
						'other' => q({0} ಮೀಟರ್‌ಗಳು ಪ್ರತಿ ಸೆಕೆಂಡ್‌ಗೆ),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(ಮೈಲುಗಳು ಪ್ರತಿ ಗಂಟೆಗೆ),
						'one' => q({0} ಮೈಲು ಪ್ರತಿ ಗಂಟೆಗೆ),
						'other' => q({0} ಗಂಟೆಗೆ ಮೈಲುಗಳು),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(ಮೈಲುಗಳು ಪ್ರತಿ ಗಂಟೆಗೆ),
						'one' => q({0} ಮೈಲು ಪ್ರತಿ ಗಂಟೆಗೆ),
						'other' => q({0} ಗಂಟೆಗೆ ಮೈಲುಗಳು),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'1' => q(neuter),
						'name' => q(ಡಿಗ್ರಿ ಸೆಲ್ಶಿಯಸ್),
						'one' => q({0} ಡಿಗ್ರಿ ಸೆಲ್ಶಿಯಸ್),
						'other' => q({0} ಡಿಗ್ರಿ ಸೆಲ್ಶಿಯಸ್),
					},
					# Core Unit Identifier
					'celsius' => {
						'1' => q(neuter),
						'name' => q(ಡಿಗ್ರಿ ಸೆಲ್ಶಿಯಸ್),
						'one' => q({0} ಡಿಗ್ರಿ ಸೆಲ್ಶಿಯಸ್),
						'other' => q({0} ಡಿಗ್ರಿ ಸೆಲ್ಶಿಯಸ್),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(ಡಿಗ್ರಿ ಫ್ಯಾರೆನ್‌ಹಿಟ್),
						'one' => q({0}ಡಿಗ್ರಿ ಫ್ಯಾರೆನ್‌ಹಿಟ್),
						'other' => q({0}ಡಿಗ್ರಿ ಫ್ಯಾರೆನ್‌ಹಿಟ್),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(ಡಿಗ್ರಿ ಫ್ಯಾರೆನ್‌ಹಿಟ್),
						'one' => q({0}ಡಿಗ್ರಿ ಫ್ಯಾರೆನ್‌ಹಿಟ್),
						'other' => q({0}ಡಿಗ್ರಿ ಫ್ಯಾರೆನ್‌ಹಿಟ್),
					},
					# Long Unit Identifier
					'temperature-generic' => {
						'1' => q(neuter),
						'one' => q({0} ಡಿಗ್ರಿ),
						'other' => q({0}°),
					},
					# Core Unit Identifier
					'generic' => {
						'1' => q(neuter),
						'one' => q({0} ಡಿಗ್ರಿ),
						'other' => q({0}°),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'1' => q(neuter),
						'name' => q(ಕೆಲ್ವಿನ್‌ಗಳು),
						'one' => q({0} ಕೆಲ್ವಿನ್),
						'other' => q({0} ಕೆಲ್ವಿನ್‍ಗಳು),
					},
					# Core Unit Identifier
					'kelvin' => {
						'1' => q(neuter),
						'name' => q(ಕೆಲ್ವಿನ್‌ಗಳು),
						'one' => q({0} ಕೆಲ್ವಿನ್),
						'other' => q({0} ಕೆಲ್ವಿನ್‍ಗಳು),
					},
					# Long Unit Identifier
					'times' => {
						'1' => q({0}-{1}),
					},
					# Core Unit Identifier
					'times' => {
						'1' => q({0}-{1}),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'1' => q(neuter),
						'name' => q(ನ್ಯೂಟನ್-ಮೀಟರ್),
						'one' => q({0} ನ್ಯೂಟನ್-ಮೀಟರ್),
						'other' => q({0} ನ್ಯೂಟನ್-ಮೀಟರ್),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'1' => q(neuter),
						'name' => q(ನ್ಯೂಟನ್-ಮೀಟರ್),
						'one' => q({0} ನ್ಯೂಟನ್-ಮೀಟರ್),
						'other' => q({0} ನ್ಯೂಟನ್-ಮೀಟರ್),
					},
					# Long Unit Identifier
					'torque-pound-force-foot' => {
						'name' => q(ಪೌಂಡ್-ಫೋರ್ಸ್-ಅಡಿ),
						'one' => q({0} ಪೌಂಡ್-ಫೋರ್ಸ್-ಅಡಿ),
						'other' => q({0} ಪೌಂಡ್-ಫೋರ್ಸ್-ಅಡಿ),
					},
					# Core Unit Identifier
					'pound-force-foot' => {
						'name' => q(ಪೌಂಡ್-ಫೋರ್ಸ್-ಅಡಿ),
						'one' => q({0} ಪೌಂಡ್-ಫೋರ್ಸ್-ಅಡಿ),
						'other' => q({0} ಪೌಂಡ್-ಫೋರ್ಸ್-ಅಡಿ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ಎಕರೆ-ಅಡಿ),
						'one' => q({0} ಎಕರೆ-ಅಡಿ),
						'other' => q({0} ಎಕರೆ-ಅಡಿ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ಎಕರೆ-ಅಡಿ),
						'one' => q({0} ಎಕರೆ-ಅಡಿ),
						'other' => q({0} ಎಕರೆ-ಅಡಿ),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(ಬ್ಯಾರೆಲ್‌ಗಳು),
						'one' => q({0} ಬ್ಯಾರೆಲ್),
						'other' => q({0} ಬ್ಯಾರೆಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(ಬ್ಯಾರೆಲ್‌ಗಳು),
						'one' => q({0} ಬ್ಯಾರೆಲ್),
						'other' => q({0} ಬ್ಯಾರೆಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-bushel' => {
						'one' => q({0} ಬುಶಲ್),
						'other' => q({0} ಬುಶಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'bushel' => {
						'one' => q({0} ಬುಶಲ್),
						'other' => q({0} ಬುಶಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'1' => q(neuter),
						'name' => q(ಸೆಂಟಿಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಸೆಂಟಿಲೀಟರ್),
						'other' => q({0} ಸೆಂಟಿಲೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'centiliter' => {
						'1' => q(neuter),
						'name' => q(ಸೆಂಟಿಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಸೆಂಟಿಲೀಟರ್),
						'other' => q({0} ಸೆಂಟಿಲೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'1' => q(neuter),
						'name' => q(ಕ್ಯೂಬಿಕ್ ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಕ್ಯೂಬಿಕ್ ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಕ್ಯೂಬಿಕ್ ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಕ್ಯೂಬಿಕ್ ಸೆಂಟಿಮೀಟರ್‌ಗಳಿಗೆ {0}),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'1' => q(neuter),
						'name' => q(ಕ್ಯೂಬಿಕ್ ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಕ್ಯೂಬಿಕ್ ಸೆಂಟಿಮೀಟರ್),
						'other' => q({0} ಕ್ಯೂಬಿಕ್ ಸೆಂಟಿಮೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಕ್ಯೂಬಿಕ್ ಸೆಂಟಿಮೀಟರ್‌ಗಳಿಗೆ {0}),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ಘನ ಅಡಿ),
						'one' => q({0} ಘನ ಅಡಿ),
						'other' => q({0} ಘನ ಅಡಿ),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ಘನ ಅಡಿ),
						'one' => q({0} ಘನ ಅಡಿ),
						'other' => q({0} ಘನ ಅಡಿ),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(ಘನ ಅಂಗುಲಗಳು),
						'one' => q({0} ಘನ ಅಂಗುಲ),
						'other' => q({0} ಘನ ಅಂಗುಲಗಳು),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(ಘನ ಅಂಗುಲಗಳು),
						'one' => q({0} ಘನ ಅಂಗುಲ),
						'other' => q({0} ಘನ ಅಂಗುಲಗಳು),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಘನ ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಘನ ಕಿಲೋಮೀಟರ್),
						'other' => q({0} ಘನ ಕಿಲೋಮೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'1' => q(neuter),
						'name' => q(ಘನ ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಘನ ಕಿಲೋಮೀಟರ್),
						'other' => q({0} ಘನ ಕಿಲೋಮೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'1' => q(neuter),
						'name' => q(ಘನ ಮೀಟರುಗಳು),
						'one' => q({0} ಘನ ಮೀಟರ್),
						'other' => q({0} ಘನ ಮೀಟರುಗಳು),
						'per' => q({0} ಪ್ರತಿ ಘನ ಮೀಟರುಗಳಿಗೆ),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'1' => q(neuter),
						'name' => q(ಘನ ಮೀಟರುಗಳು),
						'one' => q({0} ಘನ ಮೀಟರ್),
						'other' => q({0} ಘನ ಮೀಟರುಗಳು),
						'per' => q({0} ಪ್ರತಿ ಘನ ಮೀಟರುಗಳಿಗೆ),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(ಘನ ಮೈಲುಗಳು),
						'one' => q({0} ಘನ ಮೈಲು),
						'other' => q({0} ಘನ ಮೈಲುಗಳು),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(ಘನ ಮೈಲುಗಳು),
						'one' => q({0} ಘನ ಮೈಲು),
						'other' => q({0} ಘನ ಮೈಲುಗಳು),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(ಘನ ಗಜಗಳು),
						'one' => q({0} ಘನ ಗಜ),
						'other' => q({0} ಘನ ಗಜಗಳು),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(ಘನ ಗಜಗಳು),
						'one' => q({0} ಘನ ಗಜ),
						'other' => q({0} ಘನ ಗಜಗಳು),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'one' => q({0} ಕಪ್‍),
						'other' => q({0} ಕಪ್‍ಗಳು),
					},
					# Core Unit Identifier
					'cup' => {
						'one' => q({0} ಕಪ್‍),
						'other' => q({0} ಕಪ್‍ಗಳು),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'1' => q(neuter),
						'name' => q(ಮೆಟ್ರಿಕ್‌ ಕಪ್‌ಗಳು),
						'one' => q({0} ಮೆಟ್ರಿಕ್‌ ಕಪ್‌),
						'other' => q({0} ಮೆಟ್ರಿಕ್‌ ಕಪ್‌ಗಳು),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'1' => q(neuter),
						'name' => q(ಮೆಟ್ರಿಕ್‌ ಕಪ್‌ಗಳು),
						'one' => q({0} ಮೆಟ್ರಿಕ್‌ ಕಪ್‌),
						'other' => q({0} ಮೆಟ್ರಿಕ್‌ ಕಪ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'1' => q(neuter),
						'name' => q(ಡೆಸಿಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಡೆಸಿಲೀಟರ್‌),
						'other' => q({0} ಡೆಸಿಲೀಟರ್‌‌ಗಳು),
					},
					# Core Unit Identifier
					'deciliter' => {
						'1' => q(neuter),
						'name' => q(ಡೆಸಿಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಡೆಸಿಲೀಟರ್‌),
						'other' => q({0} ಡೆಸಿಲೀಟರ್‌‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'name' => q(ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
						'one' => q({0} ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
						'other' => q({0} ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'name' => q(ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
						'one' => q({0} ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
						'other' => q({0} ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'name' => q(ಇಂಪಿರಿಯಲ್ ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
						'one' => q({0} ಇಂಪಿರಿಯಲ್ ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
						'other' => q({0} ಇಂಪಿರಿಯಲ್ ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'name' => q(ಇಂಪಿರಿಯಲ್ ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
						'one' => q({0} ಇಂಪಿರಿಯಲ್ ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
						'other' => q({0} ಇಂಪಿರಿಯಲ್ ಡೆಸರ್ಟ್ ಸ್ಪೂನ್),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'name' => q(ಡ್ರಾಮ್),
						'one' => q({0} ಡ್ರಾಮ್),
						'other' => q({0} ಡ್ರಾಮ್),
					},
					# Core Unit Identifier
					'dram' => {
						'name' => q(ಡ್ರಾಮ್),
						'one' => q({0} ಡ್ರಾಮ್),
						'other' => q({0} ಡ್ರಾಮ್),
					},
					# Long Unit Identifier
					'volume-drop' => {
						'name' => q(ಡ್ರಾಪ್ಸ್),
						'one' => q({0} ಡ್ರಾಪ್),
						'other' => q({0} ಡ್ರಾಪ್ಸ್),
					},
					# Core Unit Identifier
					'drop' => {
						'name' => q(ಡ್ರಾಪ್ಸ್),
						'one' => q({0} ಡ್ರಾಪ್),
						'other' => q({0} ಡ್ರಾಪ್ಸ್),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(ಫ್ಲೂಡ್ ಔನ್ಸ್‌ಗಳು),
						'one' => q({0} ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್),
						'other' => q({0} ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್‌ಗಳು),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(ಫ್ಲೂಡ್ ಔನ್ಸ್‌ಗಳು),
						'one' => q({0} ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್),
						'other' => q({0} ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(ಇಂಪಿರಿಯಲ್ ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್‌ಗಳು),
						'one' => q({0} ಇಂಪಿರಿಯಲ್ ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್‌),
						'other' => q({0} ಇಂಪಿರಿಯಲ್ ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್‌ಗಳು),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(ಇಂಪಿರಿಯಲ್ ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್‌ಗಳು),
						'one' => q({0} ಇಂಪಿರಿಯಲ್ ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್‌),
						'other' => q({0} ಇಂಪಿರಿಯಲ್ ಫ್ಲೂಯ್ಡ್ ಔನ್ಸ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(ಗ್ಯಾಲನ್‌‌ಗಳು),
						'one' => q({0} ಗ್ಯಾಲನ್‌),
						'other' => q({0} ಗ್ಯಾಲನ್‌ಗಳು),
						'per' => q({0} ಪ್ರತಿ ಗ್ಯಾಲನ್‍ಗೆ),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(ಗ್ಯಾಲನ್‌‌ಗಳು),
						'one' => q({0} ಗ್ಯಾಲನ್‌),
						'other' => q({0} ಗ್ಯಾಲನ್‌ಗಳು),
						'per' => q({0} ಪ್ರತಿ ಗ್ಯಾಲನ್‍ಗೆ),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'one' => q({0} Imp ಗ್ಯಾಲನ್),
						'other' => q({0} Imp ಗ್ಯಾಲನ್),
						'per' => q({0} / Imp ಗ್ಯಾಲನ್),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'one' => q({0} Imp ಗ್ಯಾಲನ್),
						'other' => q({0} Imp ಗ್ಯಾಲನ್),
						'per' => q({0} / Imp ಗ್ಯಾಲನ್),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'1' => q(neuter),
						'name' => q(ಹೆಕ್ಟೋಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಹೆಕ್ಟೋಲೀಟರ್),
						'other' => q({0} ಹೆಕ್ಟೋಲೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'1' => q(neuter),
						'name' => q(ಹೆಕ್ಟೋಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಹೆಕ್ಟೋಲೀಟರ್),
						'other' => q({0} ಹೆಕ್ಟೋಲೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'1' => q(neuter),
						'name' => q(ಲೀಟರ್‌‌ಗಳು),
						'one' => q({0} ಲೀಟರ್),
						'other' => q({0} ಲೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಲೀಟರ್‌ಗೆ {0}),
					},
					# Core Unit Identifier
					'liter' => {
						'1' => q(neuter),
						'name' => q(ಲೀಟರ್‌‌ಗಳು),
						'one' => q({0} ಲೀಟರ್),
						'other' => q({0} ಲೀಟರ್‌ಗಳು),
						'per' => q(ಪ್ರತಿ ಲೀಟರ್‌ಗೆ {0}),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾ ಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾ ಲೀಟರ್‌),
						'other' => q({0} ಮೆಗಾ ಲೀಟರ್‌‌ಗಳು),
					},
					# Core Unit Identifier
					'megaliter' => {
						'1' => q(neuter),
						'name' => q(ಮೆಗಾ ಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಮೆಗಾ ಲೀಟರ್‌),
						'other' => q({0} ಮೆಗಾ ಲೀಟರ್‌‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿಲೀಟರ್),
						'other' => q({0} ಮಿಲಿಲೀಟರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'milliliter' => {
						'1' => q(neuter),
						'name' => q(ಮಿಲಿಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಮಿಲಿಲೀಟರ್),
						'other' => q({0} ಮಿಲಿಲೀಟರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-pint' => {
						'name' => q(ಪಿಂಟ್‌ಗಳು),
						'one' => q({0} ಪಿಂಟ್‌),
						'other' => q({0} ಪಿಂಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'pint' => {
						'name' => q(ಪಿಂಟ್‌ಗಳು),
						'one' => q({0} ಪಿಂಟ್‌),
						'other' => q({0} ಪಿಂಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'1' => q(neuter),
						'name' => q(ಮೆಟ್ರಿಕ್ ಪಿಂಟ್‌ಗಳು),
						'one' => q({0} ಮೆಟ್ರಿಕ್ ಪಿಂಟ್),
						'other' => q({0} ಮೆಟ್ರಿಕ್ ಪಿಂಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'1' => q(neuter),
						'name' => q(ಮೆಟ್ರಿಕ್ ಪಿಂಟ್‌ಗಳು),
						'one' => q({0} ಮೆಟ್ರಿಕ್ ಪಿಂಟ್),
						'other' => q({0} ಮೆಟ್ರಿಕ್ ಪಿಂಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'name' => q(ಕಾಲುಭಾಗಗಳು),
						'one' => q({0} ಕಾಲುಭಾಗ),
						'other' => q({0} ಕಾಲುಭಾಗಗಳು),
					},
					# Core Unit Identifier
					'quart' => {
						'name' => q(ಕಾಲುಭಾಗಗಳು),
						'one' => q({0} ಕಾಲುಭಾಗ),
						'other' => q({0} ಕಾಲುಭಾಗಗಳು),
					},
					# Long Unit Identifier
					'volume-quart-imperial' => {
						'name' => q(ಇಂಪಿರಿಯಲ್ ಕ್ವಾರ್ಟ್),
						'one' => q({0} ಇಂಪಿರಿಯಲ್ ಕ್ವಾರ್ಟ್),
						'other' => q({0} ಇಂಪಿರಿಯಲ್ ಕ್ವಾರ್ಟ್),
					},
					# Core Unit Identifier
					'quart-imperial' => {
						'name' => q(ಇಂಪಿರಿಯಲ್ ಕ್ವಾರ್ಟ್),
						'one' => q({0} ಇಂಪಿರಿಯಲ್ ಕ್ವಾರ್ಟ್),
						'other' => q({0} ಇಂಪಿರಿಯಲ್ ಕ್ವಾರ್ಟ್),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'name' => q(ಟೇಬಲ್ ಸ್ಪೂನ್‍ಗಳು),
						'one' => q({0} ಟೇಬಲ್ ಸ್ಪೂನ್‍),
						'other' => q({0} ಟೇಬಲ್ ಸ್ಪೂನ್‍‍ಗಳು),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'name' => q(ಟೇಬಲ್ ಸ್ಪೂನ್‍ಗಳು),
						'one' => q({0} ಟೇಬಲ್ ಸ್ಪೂನ್‍),
						'other' => q({0} ಟೇಬಲ್ ಸ್ಪೂನ್‍‍ಗಳು),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'name' => q(ಟೀ ಸ್ಪೂನ್‍ಗಳು),
						'one' => q({0} ಟೀ ಸ್ಪೂನ್‍),
						'other' => q({0} ಟೀ ಸ್ಪೂನ್‍ಗಳು),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'name' => q(ಟೀ ಸ್ಪೂನ್‍ಗಳು),
						'one' => q({0} ಟೀ ಸ್ಪೂನ್‍),
						'other' => q({0} ಟೀ ಸ್ಪೂನ್‍ಗಳು),
					},
				},
				'narrow' => {
					# Long Unit Identifier
					'1024p1' => {
						'1' => q(ಕಿ{0}),
					},
					# Core Unit Identifier
					'1024p1' => {
						'1' => q(ಕಿ{0}),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(ಮೆ{0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(ಮೆ{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ಡೆ. {0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ಡೆ. {0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ಪಿ. {0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ಪಿ. {0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ಫೆ. {0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ಫೆ. {0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ಅ. {0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ಅ. {0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ಸೆಂ. {0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ಸೆಂ. {0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ಝೆ. {0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ಝೆ. {0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ಯೊ. {0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ಯೊ. {0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(ಮಿ. {0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(ಮಿ. {0}),
					},
					# Long Unit Identifier
					'10p-30' => {
						'1' => q(ಕ್ಯೂ{0}),
					},
					# Core Unit Identifier
					'30' => {
						'1' => q(ಕ್ಯೂ{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ನ್ಯಾ. {0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ನ್ಯಾ. {0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ಡೆ. {0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ಡೆ. {0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(ಟೆ. {0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(ಟೆ. {0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(P{0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(P{0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(ಎ. {0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(ಎ. {0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ಹೆ. {0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ಹೆ. {0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(ಝೆಟ್. {0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(ಝೆಟ್. {0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(ಯೊ. {0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(ಯೊ. {0}),
					},
					# Long Unit Identifier
					'10p27' => {
						'1' => q(ಆರ್{0}),
					},
					# Core Unit Identifier
					'10p27' => {
						'1' => q(ಆರ್{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(ಕಿ. {0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(ಕಿ. {0}),
					},
					# Long Unit Identifier
					'10p30' => {
						'1' => q(ಕ್ಯು{0}),
					},
					# Core Unit Identifier
					'10p30' => {
						'1' => q(ಕ್ಯು{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(ಮೆ. {0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(ಮೆ. {0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(ಗಿ. {0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(ಗಿ. {0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'one' => q({0}ಜಿ-ಫೋ.),
						'other' => q({0}ಜಿ-ಫೋ.),
					},
					# Core Unit Identifier
					'g-force' => {
						'one' => q({0}ಜಿ-ಫೋ.),
						'other' => q({0}ಜಿ-ಫೋ.),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'name' => q(m/s²),
						'one' => q({0}ಮೀ/ಸೆ²),
						'other' => q({0}ಮೀ/ಸೆ²),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'name' => q(m/s²),
						'one' => q({0}ಮೀ/ಸೆ²),
						'other' => q({0}ಮೀ/ಸೆ²),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'one' => q({0}′),
						'other' => q({0}′),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'one' => q({0}′),
						'other' => q({0}′),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'one' => q({0}″),
						'other' => q({0}″),
					},
					# Core Unit Identifier
					'arc-second' => {
						'one' => q({0}″),
						'other' => q({0}″),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'one' => q({0}°),
						'other' => q({0}°),
					},
					# Core Unit Identifier
					'degree' => {
						'one' => q({0}°),
						'other' => q({0}°),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'one' => q({0}ರೇಡಿ.),
						'other' => q({0}ರೇಡಿ.),
					},
					# Core Unit Identifier
					'radian' => {
						'one' => q({0}ರೇಡಿ.),
						'other' => q({0}ರೇಡಿ.),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'one' => q({0}ತಿರುಗು),
						'other' => q({0}ತಿರುಗು),
					},
					# Core Unit Identifier
					'revolution' => {
						'one' => q({0}ತಿರುಗು),
						'other' => q({0}ತಿರುಗು),
					},
					# Long Unit Identifier
					'area-acre' => {
						'name' => q(ಎಕರೆ),
					},
					# Core Unit Identifier
					'acre' => {
						'name' => q(ಎಕರೆ),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'one' => q({0}ಡುನಮ್),
						'other' => q({0}ಡುನಮ್),
					},
					# Core Unit Identifier
					'dunam' => {
						'one' => q({0}ಡುನಮ್),
						'other' => q({0}ಡುನಮ್),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'name' => q(ಹೆಕ್ಟೇರ್),
					},
					# Core Unit Identifier
					'hectare' => {
						'name' => q(ಹೆಕ್ಟೇರ್),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'name' => q(ft²),
						'one' => q({0}ಚ.ಅ),
						'other' => q({0}ಚ.ಅ),
					},
					# Core Unit Identifier
					'square-foot' => {
						'name' => q(ft²),
						'one' => q({0}ಚ.ಅ),
						'other' => q({0}ಚ.ಅ),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'one' => q({0} ಚ.ಕಿಮೀ.),
						'other' => q({0} ಚ.ಕಿಮೀ.),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'one' => q({0} ಚ.ಕಿಮೀ.),
						'other' => q({0} ಚ.ಕಿಮೀ.),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'one' => q({0}ಚ.ಮೀ.),
						'other' => q({0}ಚ.ಮೀ.),
					},
					# Core Unit Identifier
					'square-mile' => {
						'one' => q({0}ಚ.ಮೀ.),
						'other' => q({0}ಚ.ಮೀ.),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(ಗ²),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(ಗ²),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'one' => q({0}ವಸ್ತು),
						'other' => q({0}ವಸ್ತು),
					},
					# Core Unit Identifier
					'item' => {
						'one' => q({0}ವಸ್ತು),
						'other' => q({0}ವಸ್ತು),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'one' => q({0}ಕಾರ.),
						'other' => q({0}ಕಾರ.),
					},
					# Core Unit Identifier
					'karat' => {
						'one' => q({0}ಕಾರ.),
						'other' => q({0}ಕಾರ.),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'one' => q({0}ಮಿಗ್ರಾಂ/ಡೆಲೀ),
						'other' => q({0}ಮಿಗ್ರಾಂ/ಡೆಲೀ),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'one' => q({0}ಮಿಗ್ರಾಂ/ಡೆಲೀ),
						'other' => q({0}ಮಿಗ್ರಾಂ/ಡೆಲೀ),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'one' => q({0}ಮೋಲ್),
						'other' => q({0}ಮೋಲ್),
					},
					# Core Unit Identifier
					'mole' => {
						'one' => q({0}ಮೋಲ್),
						'other' => q({0}ಮೋಲ್),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'name' => q(%),
					},
					# Core Unit Identifier
					'percent' => {
						'name' => q(%),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'name' => q(‰),
					},
					# Core Unit Identifier
					'permille' => {
						'name' => q(‰),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(ಭಾಪ್ರಮಿ),
						'one' => q({0}ಭಾಪ್ರಮಿ),
						'other' => q({0}ಭಾಪ್ರಮಿ),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(ಭಾಪ್ರಮಿ),
						'one' => q({0}ಭಾಪ್ರಮಿ),
						'other' => q({0}ಭಾಪ್ರಮಿ),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'name' => q(‱),
					},
					# Core Unit Identifier
					'permyriad' => {
						'name' => q(‱),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(ಲೀ/100ಕಿ.ಮೀ),
						'one' => q({0} ಲೀ/100ಕಿಮೀ),
						'other' => q({0} ಲೀ/100ಕಿಮೀ),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(ಲೀ/100ಕಿ.ಮೀ),
						'one' => q({0} ಲೀ/100ಕಿಮೀ),
						'other' => q({0} ಲೀ/100ಕಿಮೀ),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(ಲೀ/ಕಿಮೀ),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(ಲೀ/ಕಿಮೀ),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(ಪ್ರಗ್ಯಾಮೈ),
						'one' => q({0}mpg),
						'other' => q({0}mpg),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(ಪ್ರಗ್ಯಾಮೈ),
						'one' => q({0}mpg),
						'other' => q({0}mpg),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(ಮೈಪ್ರಗ್ರಾಂ ಯುಕೆ),
						'one' => q({0}ಮೈ/ಪ್ರಗ್ರಾಂಯುಕೆ),
						'other' => q({0}ಮೈ/ಪ್ರಗ್ರಾಂಯುಕೆ),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(ಮೈಪ್ರಗ್ರಾಂ ಯುಕೆ),
						'one' => q({0}ಮೈ/ಪ್ರಗ್ರಾಂಯುಕೆ),
						'other' => q({0}ಮೈ/ಪ್ರಗ್ರಾಂಯುಕೆ),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0}ಪೂ),
						'north' => q({0}ಉ),
						'south' => q({0}ದ),
						'west' => q({0}ಪ),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0}ಪೂ),
						'north' => q({0}ಉ),
						'south' => q({0}ದ),
						'west' => q({0}ಪ),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'one' => q({0}ಬಿಟ್),
						'other' => q({0}ಬಿಟ್),
					},
					# Core Unit Identifier
					'bit' => {
						'one' => q({0}ಬಿಟ್),
						'other' => q({0}ಬಿಟ್),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'one' => q({0}ಬೈ),
						'other' => q({0} ಬೈ.),
					},
					# Core Unit Identifier
					'byte' => {
						'one' => q({0}ಬೈ),
						'other' => q({0} ಬೈ.),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(Gb),
						'one' => q({0}ಗಿ.ಬಿ.),
						'other' => q({0}ಗಿ.ಬಿ.),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(Gb),
						'one' => q({0}ಗಿ.ಬಿ.),
						'other' => q({0}ಗಿ.ಬಿ.),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(GB),
						'one' => q({0}ಗಿ.ಬೈ.),
						'other' => q({0}ಗಿ.ಬೈ.),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(GB),
						'one' => q({0}ಗಿ.ಬೈ.),
						'other' => q({0}ಗಿ.ಬೈ.),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'one' => q({0}ಕಿ.ಬಿ.),
						'other' => q({0}ಕಿ.ಬಿ.),
					},
					# Core Unit Identifier
					'kilobit' => {
						'one' => q({0}ಕಿ.ಬಿ.),
						'other' => q({0}ಕಿ.ಬಿ.),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'one' => q({0}ಕಿ.ಬೈ.),
						'other' => q({0}ಕಿ.ಬೈ.),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'one' => q({0}ಕಿ.ಬೈ.),
						'other' => q({0}ಕಿ.ಬೈ.),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'one' => q({0}ಮೆ.ಬಿ.),
						'other' => q({0}ಮೆ.ಬಿ.),
					},
					# Core Unit Identifier
					'megabit' => {
						'one' => q({0}ಮೆ.ಬಿ.),
						'other' => q({0}ಮೆ.ಬಿ.),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(MB),
						'one' => q({0}ಮೆ.ಬೈ.),
						'other' => q({0}ಮೆ.ಬೈ.),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(MB),
						'one' => q({0}ಮೆ.ಬೈ.),
						'other' => q({0}ಮೆ.ಬೈ.),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'name' => q(PB),
						'one' => q({0}ಪೆಬೈ),
						'other' => q({0}ಪೆಬೈ),
					},
					# Core Unit Identifier
					'petabyte' => {
						'name' => q(PB),
						'one' => q({0}ಪೆಬೈ),
						'other' => q({0}ಪೆಬೈ),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'one' => q({0}ಟೆ.ಬಿ.),
						'other' => q({0}ಟೆ.ಬಿ.),
					},
					# Core Unit Identifier
					'terabit' => {
						'one' => q({0}ಟೆ.ಬಿ.),
						'other' => q({0}ಟೆ.ಬಿ.),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'name' => q(TB),
						'one' => q({0}ಟೆ.ಬೈ.),
						'other' => q({0}ಟೆ.ಬೈ.),
					},
					# Core Unit Identifier
					'terabyte' => {
						'name' => q(TB),
						'one' => q({0}ಟೆ.ಬೈ.),
						'other' => q({0}ಟೆ.ಬೈ.),
					},
					# Long Unit Identifier
					'duration-day' => {
						'name' => q(ದಿನ),
						'one' => q({0}ದಿ),
						'other' => q({0}ದಿ),
					},
					# Core Unit Identifier
					'day' => {
						'name' => q(ದಿನ),
						'one' => q({0}ದಿ),
						'other' => q({0}ದಿ),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'name' => q(ದಶಕ),
						'one' => q({0} ದಶಕ),
						'other' => q({0} ದಶಕ),
					},
					# Core Unit Identifier
					'decade' => {
						'name' => q(ದಶಕ),
						'one' => q({0} ದಶಕ),
						'other' => q({0} ದಶಕ),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'name' => q(ಗಂಟೆ),
						'one' => q({0}ಗಂ.),
						'other' => q({0}ಗಂ.),
					},
					# Core Unit Identifier
					'hour' => {
						'name' => q(ಗಂಟೆ),
						'one' => q({0}ಗಂ.),
						'other' => q({0}ಗಂ.),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'name' => q(μsec),
						'one' => q({0}μs),
						'other' => q({0}μs),
					},
					# Core Unit Identifier
					'microsecond' => {
						'name' => q(μsec),
						'one' => q({0}μs),
						'other' => q({0}μs),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'name' => q(ಮಿ.ಸೆ.),
						'one' => q({0}ಮಿ.ಸೆ.),
						'other' => q({0}ಮಿ.ಸೆ.),
					},
					# Core Unit Identifier
					'millisecond' => {
						'name' => q(ಮಿ.ಸೆ.),
						'one' => q({0}ಮಿ.ಸೆ.),
						'other' => q({0}ಮಿ.ಸೆ.),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'name' => q(ನಿಮಿಷ),
						'one' => q({0}ನಿಮಿ),
						'other' => q({0}ನಿಮಿ),
					},
					# Core Unit Identifier
					'minute' => {
						'name' => q(ನಿಮಿಷ),
						'one' => q({0}ನಿಮಿ),
						'other' => q({0}ನಿಮಿ),
					},
					# Long Unit Identifier
					'duration-month' => {
						'one' => q({0}ತಿಂ.),
						'other' => q({0}ತಿಂ.),
					},
					# Core Unit Identifier
					'month' => {
						'one' => q({0}ತಿಂ.),
						'other' => q({0}ತಿಂ.),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'one' => q({0}ನ್ಯಾಸೆ),
						'other' => q({0}ನ್ಯಾಸೆ),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'one' => q({0}ನ್ಯಾಸೆ),
						'other' => q({0}ನ್ಯಾಸೆ),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ರಾತ್ರಿಗಳು),
						'one' => q({0} ರಾತ್ರಿಯು),
						'other' => q({0} ರಾತ್ರಿಗಳು),
						'per' => q({0}/ರಾತ್ರಿಗೆ),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ರಾತ್ರಿಗಳು),
						'one' => q({0} ರಾತ್ರಿಯು),
						'other' => q({0} ರಾತ್ರಿಗಳು),
						'per' => q({0}/ರಾತ್ರಿಗೆ),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'one' => q({0} ತ್ರೈ),
						'other' => q({0}ತ್ರೈ),
					},
					# Core Unit Identifier
					'quarter' => {
						'one' => q({0} ತ್ರೈ),
						'other' => q({0}ತ್ರೈ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'name' => q(ಸೆಕೆಂ),
						'one' => q({0}ಸೆಕೆಂ),
						'other' => q({0} ಸೆಕೆಂ),
					},
					# Core Unit Identifier
					'second' => {
						'name' => q(ಸೆಕೆಂ),
						'one' => q({0}ಸೆಕೆಂ),
						'other' => q({0} ಸೆಕೆಂ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(ವಾರ),
						'one' => q({0}ವಾ),
						'other' => q({0}ವಾ),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(ವಾರ),
						'one' => q({0}ವಾ),
						'other' => q({0}ವಾ),
					},
					# Long Unit Identifier
					'duration-year' => {
						'name' => q(ವ),
						'one' => q({0}ವ),
						'other' => q({0}ವ),
					},
					# Core Unit Identifier
					'year' => {
						'name' => q(ವ),
						'one' => q({0}ವ),
						'other' => q({0}ವ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'one' => q({0}ಆಂ.),
						'other' => q({0}ಆಂ.),
					},
					# Core Unit Identifier
					'ampere' => {
						'one' => q({0}ಆಂ.),
						'other' => q({0}ಆಂ.),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'name' => q(mA),
						'one' => q({0}ಮಿ.ಆಂ),
						'other' => q({0}mA),
					},
					# Core Unit Identifier
					'milliampere' => {
						'name' => q(mA),
						'one' => q({0}ಮಿ.ಆಂ),
						'other' => q({0}mA),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'one' => q({0}Ω),
						'other' => q({0}Ω),
					},
					# Core Unit Identifier
					'ohm' => {
						'one' => q({0}Ω),
						'other' => q({0}Ω),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'one' => q({0}ವೋ),
						'other' => q({0}ವೋ),
					},
					# Core Unit Identifier
					'volt' => {
						'one' => q({0}ವೋ),
						'other' => q({0}ವೋ),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'one' => q({0}Btu),
						'other' => q({0}Btu),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'one' => q({0}Btu),
						'other' => q({0}Btu),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'one' => q({0}ಕ್ಯಾಲೊ),
						'other' => q({0}ಕ್ಯಾಲೊ),
					},
					# Core Unit Identifier
					'calorie' => {
						'one' => q({0}ಕ್ಯಾಲೊ),
						'other' => q({0}ಕ್ಯಾಲೊ),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'one' => q({0}ಎವೋ),
						'other' => q({0}ಎವೋ),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'one' => q({0}ಎವೋ),
						'other' => q({0}ಎವೋ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'one' => q({0}ಕ್ಯಾಲೊ),
						'other' => q({0}ಕ್ಯಾಲೊ),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'one' => q({0}ಕ್ಯಾಲೊ),
						'other' => q({0}ಕ್ಯಾಲೊ),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'one' => q({0}ಜೌ),
						'other' => q({0}ಜೌ),
					},
					# Core Unit Identifier
					'joule' => {
						'one' => q({0}ಜೌ),
						'other' => q({0}ಜೌ),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'one' => q({0}ಕಿ.ಕ್ಯಾ),
						'other' => q({0} ಕಿ.ಕ್ಯಾ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'one' => q({0}ಕಿ.ಕ್ಯಾ),
						'other' => q({0} ಕಿ.ಕ್ಯಾ),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'one' => q({0}ಕಿ.ಜೌ),
						'other' => q({0}ಕಿ.ಜೌ),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'one' => q({0}ಕಿ.ಜೌ),
						'other' => q({0}ಕಿ.ಜೌ),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'one' => q({0}ಕಿವ್ಯಾಗಂ),
						'other' => q({0}ಕಿವ್ಯಾಗಂ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'one' => q({0}ಕಿವ್ಯಾಗಂ),
						'other' => q({0}ಕಿವ್ಯಾಗಂ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'one' => q({0}ಯುಎಸ್ ಥರ್ಮ್ಸ್),
						'other' => q({0}ಯುಎಸ್ ಥರ್ಮ್ಸ್),
					},
					# Core Unit Identifier
					'therm-us' => {
						'one' => q({0}ಯುಎಸ್ ಥರ್ಮ್ಸ್),
						'other' => q({0}ಯುಎಸ್ ಥರ್ಮ್ಸ್),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(ನ್ಯೂ),
						'one' => q({0}ನ್ಯೂ),
						'other' => q({0}ನ್ಯೂ),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(ನ್ಯೂ),
						'one' => q({0}ನ್ಯೂ),
						'other' => q({0}ನ್ಯೂ),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ಎಲ್‌ಬಿಎಫ್),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ಎಲ್‌ಬಿಎಫ್),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'name' => q(GHz),
						'one' => q({0}GHz),
						'other' => q({0}GHz),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'name' => q(GHz),
						'one' => q({0}GHz),
						'other' => q({0}GHz),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'name' => q(ಹರ್ಟ್ಜ್),
						'one' => q({0}ಹರ್ಟ್ಜ್),
						'other' => q({0}ಹರ್ಟ್ಜ್),
					},
					# Core Unit Identifier
					'hertz' => {
						'name' => q(ಹರ್ಟ್ಜ್),
						'one' => q({0}ಹರ್ಟ್ಜ್),
						'other' => q({0}ಹರ್ಟ್ಜ್),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'name' => q(kHz),
						'one' => q({0}ಕಿ.ಹ),
						'other' => q({0}kHz),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'name' => q(kHz),
						'one' => q({0}ಕಿ.ಹ),
						'other' => q({0}kHz),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'name' => q(MHz),
						'one' => q({0}ಮೆ.ಹ),
						'other' => q({0}ಮೆ.ಹ),
					},
					# Core Unit Identifier
					'megahertz' => {
						'name' => q(MHz),
						'one' => q({0}ಮೆ.ಹ),
						'other' => q({0}ಮೆ.ಹ),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'name' => q(ಡಾಟ್),
						'one' => q({0}ಡಾಟ್),
						'other' => q({0}ಡಾಟ್),
					},
					# Core Unit Identifier
					'dot' => {
						'name' => q(ಡಾಟ್),
						'one' => q({0}ಡಾಟ್),
						'other' => q({0}ಡಾಟ್),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'one' => q({0}ಡಿಪಿಸಿಎಂ),
						'other' => q({0}ಡಿಪಿಸಿಎಂ),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'one' => q({0}ಡಿಪಿಸಿಎಂ),
						'other' => q({0}ಡಿಪಿಸಿಎಂ),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'one' => q({0}ಡಿಪಿಐ),
						'other' => q({0}ಡಿಪಿಐ),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'one' => q({0}ಡಿಪಿಐ),
						'other' => q({0}ಡಿಪಿಐ),
					},
					# Long Unit Identifier
					'graphics-em' => {
						'one' => q({0}em),
						'other' => q({0}em),
					},
					# Core Unit Identifier
					'em' => {
						'one' => q({0}em),
						'other' => q({0}em),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'name' => q(MP),
						'one' => q({0}MP),
						'other' => q({0}MP),
					},
					# Core Unit Identifier
					'megapixel' => {
						'name' => q(MP),
						'one' => q({0}MP),
						'other' => q({0}MP),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'name' => q(ಪಿಕ್ಸೆ),
						'one' => q({0}ಪಿಕ್ಸೆ),
						'other' => q({0}ಪಿಕ್ಸೆ),
					},
					# Core Unit Identifier
					'pixel' => {
						'name' => q(ಪಿಕ್ಸೆ),
						'one' => q({0}ಪಿಕ್ಸೆ),
						'other' => q({0}ಪಿಕ್ಸೆ),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'one' => q({0}ppcm),
						'other' => q({0}ppcm),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'one' => q({0}ppcm),
						'other' => q({0}ppcm),
					},
					# Long Unit Identifier
					'graphics-pixel-per-inch' => {
						'one' => q({0}ppi),
						'other' => q({0}ppi),
					},
					# Core Unit Identifier
					'pixel-per-inch' => {
						'one' => q({0}ppi),
						'other' => q({0}ppi),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ಫ್ಯಾಥಮ್),
						'one' => q({0}fth),
						'other' => q({0}fth),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ಫ್ಯಾಥಮ್),
						'one' => q({0}fth),
						'other' => q({0}fth),
					},
					# Long Unit Identifier
					'length-foot' => {
						'one' => q({0} ′),
						'other' => q({0} ′),
					},
					# Core Unit Identifier
					'foot' => {
						'one' => q({0} ′),
						'other' => q({0} ′),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'name' => q(ಫರ್ಲಾಂಗ್),
					},
					# Core Unit Identifier
					'furlong' => {
						'name' => q(ಫರ್ಲಾಂಗ್),
					},
					# Long Unit Identifier
					'length-inch' => {
						'one' => q({0} ″),
						'other' => q({0} ″),
					},
					# Core Unit Identifier
					'inch' => {
						'one' => q({0} ″),
						'other' => q({0} ″),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'name' => q(ಕಿಮೀ),
						'one' => q({0}ಕಿಮೀ),
						'other' => q({0}ಕಿಮೀ),
					},
					# Core Unit Identifier
					'kilometer' => {
						'name' => q(ಕಿಮೀ),
						'one' => q({0}ಕಿಮೀ),
						'other' => q({0}ಕಿಮೀ),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'name' => q(ಬೆ.ವರ್ಷ),
					},
					# Core Unit Identifier
					'light-year' => {
						'name' => q(ಬೆ.ವರ್ಷ),
					},
					# Long Unit Identifier
					'length-meter' => {
						'one' => q({0}ಮೀ),
						'other' => q({0}ಮೀ),
					},
					# Core Unit Identifier
					'meter' => {
						'one' => q({0}ಮೀ),
						'other' => q({0}ಮೀ),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(μm),
						'one' => q({0}μm),
						'other' => q({0}μm),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(μm),
						'one' => q({0}μm),
						'other' => q({0}μm),
					},
					# Long Unit Identifier
					'length-mile' => {
						'one' => q({0}ಮೈ.),
						'other' => q({0}ಮೈ.),
					},
					# Core Unit Identifier
					'mile' => {
						'one' => q({0}ಮೈ.),
						'other' => q({0}ಮೈ.),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'one' => q({0}smi),
						'other' => q({0}smi),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'one' => q({0}smi),
						'other' => q({0}smi),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'one' => q({0}ಮಿಮೀ),
						'other' => q({0}ಮಿಮೀ),
					},
					# Core Unit Identifier
					'millimeter' => {
						'one' => q({0}ಮಿಮೀ),
						'other' => q({0}ಮಿಮೀ),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'one' => q({0}nm),
						'other' => q({0}nm),
					},
					# Core Unit Identifier
					'nanometer' => {
						'one' => q({0}nm),
						'other' => q({0}nm),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(ಪಾರ್‌ಸೆಕೆಂ),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(ಪಾರ್‌ಸೆಕೆಂ),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'one' => q({0}ಪಿಎಂ),
						'other' => q({0}ಪಿಎಂ),
					},
					# Core Unit Identifier
					'picometer' => {
						'one' => q({0}ಪಿಎಂ),
						'other' => q({0}ಪಿಎಂ),
					},
					# Long Unit Identifier
					'length-point' => {
						'one' => q({0}ಪಾಯಿಂಟ್),
						'other' => q({0}ಪಾಯಿಂಟ್),
					},
					# Core Unit Identifier
					'point' => {
						'one' => q({0}ಪಾಯಿಂಟ್),
						'other' => q({0}ಪಾಯಿಂಟ್),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(R☉),
						'one' => q({0}R☉),
						'other' => q({0}R☉),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(R☉),
						'one' => q({0}R☉),
						'other' => q({0}R☉),
					},
					# Long Unit Identifier
					'length-yard' => {
						'one' => q({0}ಗ),
						'other' => q({0} ಗ),
					},
					# Core Unit Identifier
					'yard' => {
						'one' => q({0}ಗ),
						'other' => q({0} ಗ),
					},
					# Long Unit Identifier
					'light-candela' => {
						'one' => q({0}ಕ್ಯಾಂ),
						'other' => q({0}ಕ್ಯಾಂ),
					},
					# Core Unit Identifier
					'candela' => {
						'one' => q({0}ಕ್ಯಾಂ),
						'other' => q({0}ಕ್ಯಾಂ),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'one' => q({0}ಎಲ್ಎಮ್),
						'other' => q({0}ಎಲ್ಎಮ್),
					},
					# Core Unit Identifier
					'lumen' => {
						'one' => q({0}ಎಲ್ಎಮ್),
						'other' => q({0}ಎಲ್ಎಮ್),
					},
					# Long Unit Identifier
					'light-lux' => {
						'one' => q({0}ಎಲ್‌ಎಕ್ಸ್),
						'other' => q({0}ಎಲ್‌ಎಕ್ಸ್),
					},
					# Core Unit Identifier
					'lux' => {
						'one' => q({0}ಎಲ್‌ಎಕ್ಸ್),
						'other' => q({0}ಎಲ್‌ಎಕ್ಸ್),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'name' => q(L☉),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'name' => q(L☉),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'name' => q(ಕ್ಯಾರೆಟ್‌),
						'one' => q({0}ಸಿಡಿ),
						'other' => q({0}ಸಿಡಿ),
					},
					# Core Unit Identifier
					'carat' => {
						'name' => q(ಕ್ಯಾರೆಟ್‌),
						'one' => q({0}ಸಿಡಿ),
						'other' => q({0}ಸಿಡಿ),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'one' => q({0}ಡಿಎ),
						'other' => q({0} ಡಿಎ),
					},
					# Core Unit Identifier
					'dalton' => {
						'one' => q({0}ಡಿಎ),
						'other' => q({0} ಡಿಎ),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'name' => q(M⊕),
						'one' => q({0}M⊕),
						'other' => q({0}M⊕),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'name' => q(M⊕),
						'one' => q({0}M⊕),
						'other' => q({0}M⊕),
					},
					# Long Unit Identifier
					'mass-grain' => {
						'one' => q({0}ಗ್ರೇನ್),
						'other' => q({0}ಗ್ರೇನ್),
					},
					# Core Unit Identifier
					'grain' => {
						'one' => q({0}ಗ್ರೇನ್),
						'other' => q({0}ಗ್ರೇನ್),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'name' => q(ಗ್ರಾಂ),
						'one' => q({0}ಗ್ರಾ),
						'other' => q({0}ಗ್ರಾ),
					},
					# Core Unit Identifier
					'gram' => {
						'name' => q(ಗ್ರಾಂ),
						'one' => q({0}ಗ್ರಾ),
						'other' => q({0}ಗ್ರಾ),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'one' => q({0}ಕೆಜಿ),
						'other' => q({0}ಕೆಜಿ),
					},
					# Core Unit Identifier
					'kilogram' => {
						'one' => q({0}ಕೆಜಿ),
						'other' => q({0}ಕೆಜಿ),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'name' => q(μg),
						'one' => q({0}μg),
						'other' => q({0}μg),
					},
					# Core Unit Identifier
					'microgram' => {
						'name' => q(μg),
						'one' => q({0}μg),
						'other' => q({0}μg),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'one' => q({0}ಮಿ.ಗ್ರಾಂ),
						'other' => q({0}ಮಿ.ಗ್ರಾಂ),
					},
					# Core Unit Identifier
					'milligram' => {
						'one' => q({0}ಮಿ.ಗ್ರಾಂ),
						'other' => q({0}ಮಿ.ಗ್ರಾಂ),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'one' => q({0}ಔ),
						'other' => q({0}ಔ),
					},
					# Core Unit Identifier
					'ounce' => {
						'one' => q({0}ಔ),
						'other' => q({0}ಔ),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ಔ.ಟ್ರಾ),
						'one' => q({0}ಟ್ರಾ.ಔ),
						'other' => q({0}ಟ್ರಾ.ಔ),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ಔ.ಟ್ರಾ),
						'one' => q({0}ಟ್ರಾ.ಔ),
						'other' => q({0}ಟ್ರಾ.ಔ),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'one' => q({0}#),
						'other' => q({0}#),
					},
					# Core Unit Identifier
					'pound' => {
						'one' => q({0}#),
						'other' => q({0}#),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'name' => q(M☉),
						'one' => q({0}M☉),
						'other' => q({0}M☉),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'name' => q(M☉),
						'one' => q({0}M☉),
						'other' => q({0}M☉),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'name' => q(ಕಲ್ಲು),
						'one' => q({0}ಕಲ್ಲು),
						'other' => q({0}ಕಲ್ಲು),
					},
					# Core Unit Identifier
					'stone' => {
						'name' => q(ಕಲ್ಲು),
						'one' => q({0}ಕಲ್ಲು),
						'other' => q({0}ಕಲ್ಲು),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(ಟನ್‍),
						'one' => q({0}ಟನ್‌),
						'other' => q({0}ಟನ್‌),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(ಟನ್‍),
						'one' => q({0}ಟನ್‌),
						'other' => q({0}ಟನ್‌),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'one' => q({0}ಟ),
						'other' => q({0}ಟ),
					},
					# Core Unit Identifier
					'tonne' => {
						'one' => q({0}ಟ),
						'other' => q({0}ಟ),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'one' => q({0}ಗಿ.ವ್ಯಾ),
						'other' => q({0}ಗಿ.ವ್ಯಾ),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'one' => q({0}ಗಿ.ವ್ಯಾ),
						'other' => q({0}ಗಿ.ವ್ಯಾ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'one' => q({0}ಹೆಚ್‌ಪಿ),
						'other' => q({0}ಹೆಚ್‌ಪಿ),
					},
					# Core Unit Identifier
					'horsepower' => {
						'one' => q({0}ಹೆಚ್‌ಪಿ),
						'other' => q({0}ಹೆಚ್‌ಪಿ),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'one' => q({0}ಕಿ.ವ್ಯಾ),
						'other' => q({0}ಕಿ.ವ್ಯಾ),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'one' => q({0}ಕಿ.ವ್ಯಾ),
						'other' => q({0}ಕಿ.ವ್ಯಾ),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'one' => q({0}ಮೆ.ವ್ಯಾ),
						'other' => q({0}ಮೆ.ವ್ಯಾ),
					},
					# Core Unit Identifier
					'megawatt' => {
						'one' => q({0}ಮೆ.ವ್ಯಾ),
						'other' => q({0}ಮೆ.ವ್ಯಾ),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'one' => q({0}ಮಿ.ವ್ಯಾ),
						'other' => q({0}ಮಿ.ವ್ಯಾ),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'one' => q({0}ಮಿ.ವ್ಯಾ),
						'other' => q({0}ಮಿ.ವ್ಯಾ),
					},
					# Long Unit Identifier
					'power-watt' => {
						'one' => q({0}ವ್ಯಾ.),
						'other' => q({0}ವ್ಯಾ.),
					},
					# Core Unit Identifier
					'watt' => {
						'one' => q({0}ವ್ಯಾ.),
						'other' => q({0}ವ್ಯಾ.),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'one' => q({0}ವಾತಾವರಣ),
						'other' => q({0}ವಾತಾವರಣ),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'one' => q({0}ವಾತಾವರಣ),
						'other' => q({0}ವಾತಾವರಣ),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'one' => q({0}ಬಾರ್‌),
						'other' => q({0}ಬಾರ್‌),
					},
					# Core Unit Identifier
					'bar' => {
						'one' => q({0}ಬಾರ್‌),
						'other' => q({0}ಬಾರ್‌),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'one' => q({0}ಹೆ.ಪ್ಯಾ),
						'other' => q({0}ಹೆ.ಪ್ಯಾ),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'one' => q({0}ಹೆ.ಪ್ಯಾ),
						'other' => q({0}ಹೆ.ಪ್ಯಾ),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'one' => q({0}" Hg),
						'other' => q({0}" Hg),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'one' => q({0}" Hg),
						'other' => q({0}" Hg),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'name' => q(kPa),
						'one' => q({0}ಕೆಪಿಎ),
						'other' => q({0}ಕೆಪಿಎ),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'name' => q(kPa),
						'one' => q({0}ಕೆಪಿಎ),
						'other' => q({0}ಕೆಪಿಎ),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'name' => q(MPa),
						'one' => q({0}ಎಂಪಿಎ),
						'other' => q({0}ಎಂಪಿಎ),
					},
					# Core Unit Identifier
					'megapascal' => {
						'name' => q(MPa),
						'one' => q({0}ಎಂಪಿಎ),
						'other' => q({0}ಎಂಪಿಎ),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'one' => q({0}ಮಿ.ಬಾ.),
						'other' => q({0}ಮಿ.ಬಾ.),
					},
					# Core Unit Identifier
					'millibar' => {
						'one' => q({0}ಮಿ.ಬಾ.),
						'other' => q({0}ಮಿ.ಬಾ.),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'one' => q({0}ಮರ್ಕ್ಯು ಮಿಮೀ),
						'other' => q({0}ಮರ್ಕ್ಯು ಮಿಮೀ),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'one' => q({0}ಮರ್ಕ್ಯು ಮಿಮೀ),
						'other' => q({0}ಮರ್ಕ್ಯು ಮಿಮೀ),
					},
					# Long Unit Identifier
					'pressure-pascal' => {
						'one' => q({0}ಪ್ಯಾ),
						'other' => q({0}ಪ್ಯಾ),
					},
					# Core Unit Identifier
					'pascal' => {
						'one' => q({0}ಪ್ಯಾ),
						'other' => q({0}ಪ್ಯಾ),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'one' => q({0}psi),
						'other' => q({0}psi),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'one' => q({0}psi),
						'other' => q({0}psi),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(ಕಿ.ಮೀ/ಗಂ),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(ಕಿ.ಮೀ/ಗಂ),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'one' => q({0}ನಾ),
						'other' => q({0}ನಾ),
					},
					# Core Unit Identifier
					'knot' => {
						'one' => q({0}ನಾ),
						'other' => q({0}ನಾ),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(ಲೈಟ್),
						'one' => q({0} ಲೈಟ್),
						'other' => q({0} ಲೈಟ್),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(ಲೈಟ್),
						'one' => q({0} ಲೈಟ್),
						'other' => q({0} ಲೈಟ್),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'one' => q({0}ಮೀ/ಸೆ.),
						'other' => q({0}ಮೀ/ಸೆ.),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'one' => q({0}ಮೀ/ಸೆ.),
						'other' => q({0}ಮೀ/ಸೆ.),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(ಮೈ/ಗಂ),
						'one' => q({0}ಮೈ/ಗಂ),
						'other' => q({0}ಮೈ/ಗಂ),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(ಮೈ/ಗಂ),
						'one' => q({0}ಮೈ/ಗಂ),
						'other' => q({0}ಮೈ/ಗಂ),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(°ಸೆ),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(°ಸೆ),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'one' => q({0}ನ್ಯೂ.ಮೀ),
						'other' => q({0}ನ್ಯೂ.ಮೀ),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'one' => q({0}ನ್ಯೂ.ಮೀ),
						'other' => q({0}ನ್ಯೂ.ಮೀ),
					},
					# Long Unit Identifier
					'torque-pound-force-foot' => {
						'one' => q({0}ಎಲ್‌ಬಿಎಫ್-ಎಫ್‌ಟಿ),
						'other' => q({0}ಎಲ್‌ಬಿಎಫ್-ಎಫ್‌ಟಿ),
					},
					# Core Unit Identifier
					'pound-force-foot' => {
						'one' => q({0}ಎಲ್‌ಬಿಎಫ್-ಎಫ್‌ಟಿ),
						'other' => q({0}ಎಲ್‌ಬಿಎಫ್-ಎಫ್‌ಟಿ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'one' => q({0}ಎ. ಅ),
						'other' => q({0}ಎ. ಅ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'one' => q({0}ಎ. ಅ),
						'other' => q({0}ಎ. ಅ),
					},
					# Long Unit Identifier
					'volume-bushel' => {
						'one' => q({0}ಬು),
						'other' => q({0}ಬು),
					},
					# Core Unit Identifier
					'bushel' => {
						'one' => q({0}ಬು),
						'other' => q({0}ಬು),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'one' => q({0}ಸೆಂ.ಲೀ),
						'other' => q({0}ಸೆಂ.ಲೀ),
					},
					# Core Unit Identifier
					'centiliter' => {
						'one' => q({0}ಸೆಂ.ಲೀ),
						'other' => q({0}ಸೆಂ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'one' => q({0}ಅಂ³),
						'other' => q({0}ಅಂ³),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'one' => q({0}ಅಂ³),
						'other' => q({0}ಅಂ³),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'one' => q({0}ಕಿಮೀ³),
						'other' => q({0}ಕಿಮೀ³),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'one' => q({0}ಕಿಮೀ³),
						'other' => q({0}ಕಿಮೀ³),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'one' => q({0}ಮೀ³),
						'other' => q({0}ಮೀ³),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'one' => q({0}ಮೀ³),
						'other' => q({0}ಮೀ³),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'one' => q({0}ಮೈ³),
						'other' => q({0}ಮೈ³),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'one' => q({0}ಮೈ³),
						'other' => q({0}ಮೈ³),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'one' => q({0}ಕ),
						'other' => q({0}ಕ),
					},
					# Core Unit Identifier
					'cup' => {
						'one' => q({0}ಕ),
						'other' => q({0}ಕ),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'one' => q({0}ಮೆ.ಕಪ್‌),
						'other' => q({0}ಮೆ.ಕ),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'one' => q({0}ಮೆ.ಕಪ್‌),
						'other' => q({0}ಮೆ.ಕ),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'one' => q({0}ಡೆ.ಲೀ),
						'other' => q({0}ಡೆ.ಲೀ),
					},
					# Core Unit Identifier
					'deciliter' => {
						'one' => q({0}ಡೆ.ಲೀ),
						'other' => q({0}ಡೆ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'one' => q({0}ಡೆಸ್ಪೂ),
						'other' => q({0}ಡೆಸ್ಪೂ),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'one' => q({0}ಡೆಸ್ಪೂ),
						'other' => q({0}ಡೆಸ್ಪೂ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'one' => q({0}dsp-Imp),
						'other' => q({0}dsp-Imp),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'one' => q({0}dsp-Imp),
						'other' => q({0}dsp-Imp),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'one' => q({0}fl.dr.),
						'other' => q({0}fl.dr.),
					},
					# Core Unit Identifier
					'dram' => {
						'one' => q({0}fl.dr.),
						'other' => q({0}fl.dr.),
					},
					# Long Unit Identifier
					'volume-drop' => {
						'one' => q({0}ಡ್ರಾಪ್),
						'other' => q({0}ಡ್ರಾಪ್),
					},
					# Core Unit Identifier
					'drop' => {
						'one' => q({0}ಡ್ರಾಪ್),
						'other' => q({0}ಡ್ರಾಪ್),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'one' => q({0}ಫ್ಲೂ.ಔ),
						'other' => q({0}ಫ್ಲೂ.ಔ),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'one' => q({0}ಫ್ಲೂ.ಔ),
						'other' => q({0}ಫ್ಲೂ.ಔ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'one' => q({0}fl oz Im),
						'other' => q({0}fl oz Im),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'one' => q({0}fl oz Im),
						'other' => q({0}fl oz Im),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'per' => q({0}/ಗ್ಯಾ),
					},
					# Core Unit Identifier
					'gallon' => {
						'per' => q({0}/ಗ್ಯಾ),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'one' => q({0}galIm),
						'other' => q({0}galIm),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'one' => q({0}galIm),
						'other' => q({0}galIm),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'one' => q({0}ಹೆ.ಲೀ),
						'other' => q({0}ಹೆ.ಲೀ),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'one' => q({0}ಹೆ.ಲೀ),
						'other' => q({0}ಹೆ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'name' => q(ಲೀಟರ್),
						'one' => q({0}ಲೀ),
						'other' => q({0}ಲೀ),
					},
					# Core Unit Identifier
					'liter' => {
						'name' => q(ಲೀಟರ್),
						'one' => q({0}ಲೀ),
						'other' => q({0}ಲೀ),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'one' => q({0}ಮಿ.ಲೀ),
						'other' => q({0}ಮಿ.ಲೀ),
					},
					# Core Unit Identifier
					'milliliter' => {
						'one' => q({0}ಮಿ.ಲೀ),
						'other' => q({0}ಮಿ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-pinch' => {
						'one' => q({0}ಪಿಂಚ್),
						'other' => q({0}ಪಿಂಚ್),
					},
					# Core Unit Identifier
					'pinch' => {
						'one' => q({0}ಪಿಂಚ್),
						'other' => q({0}ಪಿಂಚ್),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'one' => q({0}ಮೆ.ಪಿಂ),
						'other' => q({0}ಮೆ.ಪಿಂ),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'one' => q({0}ಮೆ.ಪಿಂ),
						'other' => q({0}ಮೆ.ಪಿಂ),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'one' => q({0}ಕಾ.ಭಾ),
						'other' => q({0}ಕಾ.ಭಾ),
					},
					# Core Unit Identifier
					'quart' => {
						'one' => q({0}ಕಾ.ಭಾ),
						'other' => q({0}ಕಾ.ಭಾ),
					},
					# Long Unit Identifier
					'volume-quart-imperial' => {
						'one' => q({0}qt-Imp.),
						'other' => q({0}qt-Imp.),
					},
					# Core Unit Identifier
					'quart-imperial' => {
						'one' => q({0}qt-Imp.),
						'other' => q({0}qt-Imp.),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'one' => q({0}ಟೇ.ಸ್ಪೂ),
						'other' => q({0}ಟೇ.ಸ್ಪೂ),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'one' => q({0}ಟೇ.ಸ್ಪೂ),
						'other' => q({0}ಟೇ.ಸ್ಪೂ),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'one' => q({0}ಟೀಸ್ಪೂ),
						'other' => q({0}ಟೀಸ್ಪೂ),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'one' => q({0}ಟೀಸ್ಪೂ),
						'other' => q({0}ಟೀಸ್ಪೂ),
					},
				},
				'short' => {
					# Long Unit Identifier
					'' => {
						'name' => q(ದಿಕ್ಕು),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(ದಿಕ್ಕು),
					},
					# Long Unit Identifier
					'1024p1' => {
						'1' => q(ಕಿಬಿ{0}),
					},
					# Core Unit Identifier
					'1024p1' => {
						'1' => q(ಕಿಬಿ{0}),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(ಮೆಬಿ{0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(ಮೆಬಿ{0}),
					},
					# Long Unit Identifier
					'1024p3' => {
						'1' => q(ಜಿ{0}),
					},
					# Core Unit Identifier
					'1024p3' => {
						'1' => q(ಜಿ{0}),
					},
					# Long Unit Identifier
					'1024p4' => {
						'1' => q(ಟಿ{0}),
					},
					# Core Unit Identifier
					'1024p4' => {
						'1' => q(ಟಿ{0}),
					},
					# Long Unit Identifier
					'1024p5' => {
						'1' => q(ಪಿಐ{0}),
					},
					# Core Unit Identifier
					'1024p5' => {
						'1' => q(ಪಿಐ{0}),
					},
					# Long Unit Identifier
					'1024p6' => {
						'1' => q(ಇಐ{0}),
					},
					# Core Unit Identifier
					'1024p6' => {
						'1' => q(ಇಐ{0}),
					},
					# Long Unit Identifier
					'1024p7' => {
						'1' => q(ಝಡ್ ಐ{0}),
					},
					# Core Unit Identifier
					'1024p7' => {
						'1' => q(ಝಡ್ ಐ{0}),
					},
					# Long Unit Identifier
					'1024p8' => {
						'1' => q(ವೈಐ{0}),
					},
					# Core Unit Identifier
					'1024p8' => {
						'1' => q(ವೈಐ{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ಡೆ {0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ಡೆ {0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ಪಿ {0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ಪಿ {0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ಫೆ {0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ಫೆ {0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ಅ {0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ಅ {0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ಸೆಂ {0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ಸೆಂ {0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ಝೆ {0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ಝೆ {0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ಯೊ {0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ಯೊ {0}),
					},
					# Long Unit Identifier
					'10p-27' => {
						'1' => q(ಆರ್{0}),
					},
					# Core Unit Identifier
					'27' => {
						'1' => q(ಆರ್{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(ಮಿ {0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(ಮಿ {0}),
					},
					# Long Unit Identifier
					'10p-30' => {
						'1' => q(ಕ್ಯು{0}),
					},
					# Core Unit Identifier
					'30' => {
						'1' => q(ಕ್ಯು{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ನ್ಯಾ {0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ನ್ಯಾ {0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ಡೆಟ್ {0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ಡೆಟ್ {0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(ಪೆ {0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(ಪೆ {0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ಹೆ {0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ಹೆ {0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(ಕಿ {0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(ಕಿ {0}),
					},
					# Long Unit Identifier
					'10p30' => {
						'1' => q(ಕ್ಯೂ{0}),
					},
					# Core Unit Identifier
					'10p30' => {
						'1' => q(ಕ್ಯೂ{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(ಮೆ {0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(ಮೆ {0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'name' => q(ಜಿ-ಫೋರ್ಸ್),
						'one' => q({0} ಜಿ),
						'other' => q({0} ಜಿ),
					},
					# Core Unit Identifier
					'g-force' => {
						'name' => q(ಜಿ-ಫೋರ್ಸ್),
						'one' => q({0} ಜಿ),
						'other' => q({0} ಜಿ),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'name' => q(ಮೀಟರ್‌ಗಳು/ಸೆ²),
						'one' => q({0} ಮೀ/ಸೆ²),
						'other' => q({0} ಮೀ/ಸೆ²),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'name' => q(ಮೀಟರ್‌ಗಳು/ಸೆ²),
						'one' => q({0} ಮೀ/ಸೆ²),
						'other' => q({0} ಮೀ/ಸೆ²),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'name' => q(ಆರ್ಕ್‌ಮಿನಿ),
						'one' => q({0} ಆರ್ಕ್‌ಮಿನಿ),
						'other' => q({0} ಆರ್ಕ್‌ಮಿನಿ),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'name' => q(ಆರ್ಕ್‌ಮಿನಿ),
						'one' => q({0} ಆರ್ಕ್‌ಮಿನಿ),
						'other' => q({0} ಆರ್ಕ್‌ಮಿನಿ),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'name' => q(ಆರ್ಕ್‌ಸೆಕೆಂ),
						'one' => q({0} ಆರ್ಕ್‌ಸೆಕೆಂ),
						'other' => q({0} ಆರ್ಕ್‌ಸೆಕೆಂ),
					},
					# Core Unit Identifier
					'arc-second' => {
						'name' => q(ಆರ್ಕ್‌ಸೆಕೆಂ),
						'one' => q({0} ಆರ್ಕ್‌ಸೆಕೆಂ),
						'other' => q({0} ಆರ್ಕ್‌ಸೆಕೆಂ),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'name' => q(ಡಿಗ್ರಿಗಳು),
						'one' => q({0} ಡಿ.),
						'other' => q({0} ಡಿ.),
					},
					# Core Unit Identifier
					'degree' => {
						'name' => q(ಡಿಗ್ರಿಗಳು),
						'one' => q({0} ಡಿ.),
						'other' => q({0} ಡಿ.),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'name' => q(ರೇಡಿಯಾನ್‌ಗಳು),
						'one' => q({0} ರೇಡಿ.),
						'other' => q({0} ರೇಡಿ),
					},
					# Core Unit Identifier
					'radian' => {
						'name' => q(ರೇಡಿಯಾನ್‌ಗಳು),
						'one' => q({0} ರೇಡಿ.),
						'other' => q({0} ರೇಡಿ),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'name' => q(ತಿರುಗು),
						'one' => q({0} ತಿರುಗು),
						'other' => q({0} ತಿರುಗು),
					},
					# Core Unit Identifier
					'revolution' => {
						'name' => q(ತಿರುಗು),
						'one' => q({0} ತಿರುಗು),
						'other' => q({0} ತಿರುಗು),
					},
					# Long Unit Identifier
					'area-acre' => {
						'name' => q(ಎಕರೆಗಳು),
						'one' => q({0} ಎಕ.),
						'other' => q({0} ಎಕ.),
					},
					# Core Unit Identifier
					'acre' => {
						'name' => q(ಎಕರೆಗಳು),
						'one' => q({0} ಎಕ.),
						'other' => q({0} ಎಕ.),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'name' => q(ಡುನಮ್‌),
						'one' => q({0} ಡುನಮ್),
						'other' => q({0} ಡುನಮ್),
					},
					# Core Unit Identifier
					'dunam' => {
						'name' => q(ಡುನಮ್‌),
						'one' => q({0} ಡುನಮ್),
						'other' => q({0} ಡುನಮ್),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'name' => q(ಹೆಕ್ಟೇರುಗಳು),
						'one' => q({0} ಹೆ.),
						'other' => q({0} ಹೆ.),
					},
					# Core Unit Identifier
					'hectare' => {
						'name' => q(ಹೆಕ್ಟೇರುಗಳು),
						'one' => q({0} ಹೆ.),
						'other' => q({0} ಹೆ.),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'name' => q(ಸೆಂ.ಮೀ²),
						'one' => q({0} ಸೆಂ.ಮೀ²),
						'other' => q({0} ಸೆಂ.ಮೀ²),
						'per' => q({0}/ಸೆಂ.ಮೀ²),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'name' => q(ಸೆಂ.ಮೀ²),
						'one' => q({0} ಸೆಂ.ಮೀ²),
						'other' => q({0} ಸೆಂ.ಮೀ²),
						'per' => q({0}/ಸೆಂ.ಮೀ²),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'name' => q(ಚದರಡಿ),
						'one' => q({0} ಚ.ಅ),
						'other' => q({0} ಚ.ಅ),
					},
					# Core Unit Identifier
					'square-foot' => {
						'name' => q(ಚದರಡಿ),
						'one' => q({0} ಚ.ಅ),
						'other' => q({0} ಚ.ಅ),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(ಅಂಗುಲಗಳು²),
						'one' => q({0} ಅಂ²),
						'other' => q({0} ಅಂ²),
						'per' => q({0}/ಅಂ²),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(ಅಂಗುಲಗಳು²),
						'one' => q({0} ಅಂ²),
						'other' => q({0} ಅಂ²),
						'per' => q({0}/ಅಂ²),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'name' => q(ಕಿಮೀ²),
						'one' => q({0} ಕಿಮೀ²),
						'other' => q({0} ಕಿಮೀ²),
						'per' => q({0}/ಕಿಮೀ²),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'name' => q(ಕಿಮೀ²),
						'one' => q({0} ಕಿಮೀ²),
						'other' => q({0} ಕಿಮೀ²),
						'per' => q({0}/ಕಿಮೀ²),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'name' => q(ಮೀಟರ್‌ಗಳು²),
						'one' => q({0} ಮೀ²),
						'other' => q({0} ಮೀ²),
						'per' => q({0}/ಮೀ²),
					},
					# Core Unit Identifier
					'square-meter' => {
						'name' => q(ಮೀಟರ್‌ಗಳು²),
						'one' => q({0} ಮೀ²),
						'other' => q({0} ಮೀ²),
						'per' => q({0}/ಮೀ²),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'name' => q(ಚದರ ಮೈಲುಗಳು),
						'one' => q({0} ಚ.ಮೀ.),
						'other' => q({0} ಚ.ಮೀ.),
						'per' => q({0}/ಚ.ಮೀ²),
					},
					# Core Unit Identifier
					'square-mile' => {
						'name' => q(ಚದರ ಮೈಲುಗಳು),
						'one' => q({0} ಚ.ಮೀ.),
						'other' => q({0} ಚ.ಮೀ.),
						'per' => q({0}/ಚ.ಮೀ²),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(ಗಜಗಳು²),
						'one' => q({0} ಗ²),
						'other' => q({0} ಗ²),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(ಗಜಗಳು²),
						'one' => q({0} ಗ²),
						'other' => q({0} ಗ²),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'name' => q(ವಸ್ತು),
						'one' => q({0} ವಸ್ತು),
						'other' => q({0} ವಸ್ತು),
					},
					# Core Unit Identifier
					'item' => {
						'name' => q(ವಸ್ತು),
						'one' => q({0} ವಸ್ತು),
						'other' => q({0} ವಸ್ತು),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'name' => q(ಕಾರಟ್‌ಗಳು),
						'one' => q({0} ಕಾರ.),
						'other' => q({0} ಕಾರ.),
					},
					# Core Unit Identifier
					'karat' => {
						'name' => q(ಕಾರಟ್‌ಗಳು),
						'one' => q({0} ಕಾರ.),
						'other' => q({0} ಕಾರ.),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'name' => q(ಮಿಗ್ರಾಂ/ಡೆಲೀ),
						'one' => q({0} ಮಿಗ್ರಾಂ/ಡೆಲೀ),
						'other' => q({0} ಮಿಗ್ರಾಂ/ಡೆಲೀ),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'name' => q(ಮಿಗ್ರಾಂ/ಡೆಲೀ),
						'one' => q({0} ಮಿಗ್ರಾಂ/ಡೆಲೀ),
						'other' => q({0} ಮಿಗ್ರಾಂ/ಡೆಲೀ),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'name' => q(ಮಿಲ್ಲಿಮೊ/ಲೀಟರ್),
						'one' => q({0} ಮಿಮೊಲ್/ಲೀ),
						'other' => q({0} ಮಿಮೋಲ್/ಲೀ),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'name' => q(ಮಿಲ್ಲಿಮೊ/ಲೀಟರ್),
						'one' => q({0} ಮಿಮೊಲ್/ಲೀ),
						'other' => q({0} ಮಿಮೋಲ್/ಲೀ),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'name' => q(ಮೋಲ್‌),
						'one' => q({0} ಮೋಲ್),
						'other' => q({0} ಮೋಲ್),
					},
					# Core Unit Identifier
					'mole' => {
						'name' => q(ಮೋಲ್‌),
						'one' => q({0} ಮೋಲ್),
						'other' => q({0} ಮೋಲ್),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'name' => q(ಶೇಕಡಾ),
					},
					# Core Unit Identifier
					'percent' => {
						'name' => q(ಶೇಕಡಾ),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'name' => q(ಪ್ರತಿ ಸಾವಿರಕ್ಕೆ),
					},
					# Core Unit Identifier
					'permille' => {
						'name' => q(ಪ್ರತಿ ಸಾವಿರಕ್ಕೆ),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(ಭಾಗಗಳು/ಮಿಲಿಯನ್),
						'one' => q({0} ಭಾಪ್ರಮಿ),
						'other' => q({0} ಭಾಪ್ರಮಿ),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(ಭಾಗಗಳು/ಮಿಲಿಯನ್),
						'one' => q({0} ಭಾಪ್ರಮಿ),
						'other' => q({0} ಭಾಪ್ರಮಿ),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'name' => q(ಪರ್ಮಿರೈಡ್),
					},
					# Core Unit Identifier
					'permyriad' => {
						'name' => q(ಪರ್ಮಿರೈಡ್),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'name' => q(ಪಾರ್ಟ್ಸ್/ಬಿಲಿಯನ್),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'name' => q(ಪಾರ್ಟ್ಸ್/ಬಿಲಿಯನ್),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(ಲೀ/100ಕಿಮೀ),
						'one' => q({0} ಲೀ/100ಕಿಮೀ),
						'other' => q({0} ಲೀ/100ಕಿ.ಮೀ),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(ಲೀ/100ಕಿಮೀ),
						'one' => q({0} ಲೀ/100ಕಿಮೀ),
						'other' => q({0} ಲೀ/100ಕಿ.ಮೀ),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(ಲೀಟರ್‌ಗಳು/ಕಿಮೀ),
						'one' => q({0} ಲೀ/ಕಿ.ಮೀ),
						'other' => q({0} ಲೀ/ಕಿ.ಮೀ),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(ಲೀಟರ್‌ಗಳು/ಕಿಮೀ),
						'one' => q({0} ಲೀ/ಕಿ.ಮೀ),
						'other' => q({0} ಲೀ/ಕಿ.ಮೀ),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(ಮೈಲಿಗಳು/ಗ್ಯಾ),
						'one' => q({0} ಪ್ರಗ್ಯಾಮೈ),
						'other' => q({0} ಪ್ರ.ಗ್ಯಾ.ಮೈ.),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(ಮೈಲಿಗಳು/ಗ್ಯಾ),
						'one' => q({0} ಪ್ರಗ್ಯಾಮೈ),
						'other' => q({0} ಪ್ರ.ಗ್ಯಾ.ಮೈ.),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(ಮೈಲುಗಳು/ಗ್ಯಾಲ್ Imp),
						'one' => q({0} ಮೈಪ್ರಗ್ರಾಂ Imp),
						'other' => q({0} ಮೈಪ್ರಗ್ರಾಂ Imp),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(ಮೈಲುಗಳು/ಗ್ಯಾಲ್ Imp),
						'one' => q({0} ಮೈಪ್ರಗ್ರಾಂ Imp),
						'other' => q({0} ಮೈಪ್ರಗ್ರಾಂ Imp),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0} ಪೂ),
						'north' => q({0} ಉ),
						'south' => q({0} ದ),
						'west' => q({0} ಪ),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0} ಪೂ),
						'north' => q({0} ಉ),
						'south' => q({0} ದ),
						'west' => q({0} ಪ),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'name' => q(ಬಿಟ್‌),
						'one' => q({0} ಬಿಟ್),
						'other' => q({0} ಬಿ.),
					},
					# Core Unit Identifier
					'bit' => {
						'name' => q(ಬಿಟ್‌),
						'one' => q({0} ಬಿಟ್),
						'other' => q({0} ಬಿ.),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'name' => q(ಬೈಟ್),
						'one' => q({0} ಬೈಟ್),
						'other' => q({0} ಬೈ.),
					},
					# Core Unit Identifier
					'byte' => {
						'name' => q(ಬೈಟ್),
						'one' => q({0} ಬೈಟ್),
						'other' => q({0} ಬೈ.),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(ಗಿ.ಬಿ.),
						'one' => q({0} ಗಿ.ಬಿ.),
						'other' => q({0} ಗಿ.ಬಿ.),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(ಗಿ.ಬಿ.),
						'one' => q({0} ಗಿ.ಬಿ.),
						'other' => q({0} ಗಿ.ಬಿ.),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(ಗಿ.ಬೈ.),
						'one' => q({0} ಗಿ.ಬೈ.),
						'other' => q({0} ಗಿ.ಬೈ.),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(ಗಿ.ಬೈ.),
						'one' => q({0} ಗಿ.ಬೈ.),
						'other' => q({0} ಗಿ.ಬೈ.),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'name' => q(ಕಿ.ಬಿ.),
						'one' => q({0} ಕಿ.ಬಿ.),
						'other' => q({0} ಕಿ.ಬಿ.),
					},
					# Core Unit Identifier
					'kilobit' => {
						'name' => q(ಕಿ.ಬಿ.),
						'one' => q({0} ಕಿ.ಬಿ.),
						'other' => q({0} ಕಿ.ಬಿ.),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'name' => q(ಕಿ.ಬೈ.),
						'one' => q({0} ಕಿ.ಬೈ.),
						'other' => q({0} ಕಿ.ಬೈ.),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'name' => q(ಕಿ.ಬೈ.),
						'one' => q({0} ಕಿ.ಬೈ.),
						'other' => q({0} ಕಿ.ಬೈ.),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'name' => q(ಮೆ.ಬಿ.),
						'one' => q({0} ಮೆ.ಬಿ.),
						'other' => q({0} ಮೆ.ಬಿ.),
					},
					# Core Unit Identifier
					'megabit' => {
						'name' => q(ಮೆ.ಬಿ.),
						'one' => q({0} ಮೆ.ಬಿ.),
						'other' => q({0} ಮೆ.ಬಿ.),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(ಮೆ.ಬೈ.),
						'one' => q({0} ಮೆ.ಬೈ.),
						'other' => q({0} ಮೆ.ಬೈ.),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(ಮೆ.ಬೈ.),
						'one' => q({0} ಮೆ.ಬೈ.),
						'other' => q({0} ಮೆ.ಬೈ.),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'name' => q(ಪೆಬೈ),
						'one' => q({0} ಪೆಬೈ),
						'other' => q({0} ಪೆಬೈ),
					},
					# Core Unit Identifier
					'petabyte' => {
						'name' => q(ಪೆಬೈ),
						'one' => q({0} ಪೆಬೈ),
						'other' => q({0} ಪೆಬೈ),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'name' => q(ಟೆ.ಬಿ.),
						'one' => q({0} ಟೆ.ಬಿ.),
						'other' => q({0} ಟೆ.ಬಿ.),
					},
					# Core Unit Identifier
					'terabit' => {
						'name' => q(ಟೆ.ಬಿ.),
						'one' => q({0} ಟೆ.ಬಿ.),
						'other' => q({0} ಟೆ.ಬಿ.),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'name' => q(ಟೆ.ಬೈ.),
						'one' => q({0} ಟೆ.ಬೈ.),
						'other' => q({0} ಟೆ.ಬೈ.),
					},
					# Core Unit Identifier
					'terabyte' => {
						'name' => q(ಟೆ.ಬೈ.),
						'one' => q({0} ಟೆ.ಬೈ.),
						'other' => q({0} ಟೆ.ಬೈ.),
					},
					# Long Unit Identifier
					'duration-century' => {
						'name' => q(ಶ),
						'one' => q({0} ಶ),
						'other' => q({0} ಶ),
					},
					# Core Unit Identifier
					'century' => {
						'name' => q(ಶ),
						'one' => q({0} ಶ),
						'other' => q({0} ಶ),
					},
					# Long Unit Identifier
					'duration-day' => {
						'name' => q(ದಿನಗಳು),
						'one' => q({0} ದಿನ),
						'other' => q({0} ದಿನಗಳು),
						'per' => q({0}/ದಿ),
					},
					# Core Unit Identifier
					'day' => {
						'name' => q(ದಿನಗಳು),
						'one' => q({0} ದಿನ),
						'other' => q({0} ದಿನಗಳು),
						'per' => q({0}/ದಿ),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'name' => q(ದಶ),
						'one' => q({0} ದಶ),
						'other' => q({0} ದಶ),
					},
					# Core Unit Identifier
					'decade' => {
						'name' => q(ದಶ),
						'one' => q({0} ದಶ),
						'other' => q({0} ದಶ),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'name' => q(ಗಂಟೆಗಳು),
						'one' => q({0} ಗಂ.),
						'other' => q({0} ಗಂ.),
						'per' => q({0}/ಗಂ),
					},
					# Core Unit Identifier
					'hour' => {
						'name' => q(ಗಂಟೆಗಳು),
						'one' => q({0} ಗಂ.),
						'other' => q({0} ಗಂ.),
						'per' => q({0}/ಗಂ),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'name' => q(μsecs),
					},
					# Core Unit Identifier
					'microsecond' => {
						'name' => q(μsecs),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'name' => q(ಮಿಲಿಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ಮಿ.ಸೆ.),
						'other' => q({0} ಮಿ.ಸೆ.),
					},
					# Core Unit Identifier
					'millisecond' => {
						'name' => q(ಮಿಲಿಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ಮಿ.ಸೆ.),
						'other' => q({0} ಮಿ.ಸೆ.),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'name' => q(ನಿಮಿಷಗಳು),
						'one' => q({0} ನಿಮಿ),
						'other' => q({0} ನಿಮಿ),
						'per' => q({0}/ನಿಮಿ),
					},
					# Core Unit Identifier
					'minute' => {
						'name' => q(ನಿಮಿಷಗಳು),
						'one' => q({0} ನಿಮಿ),
						'other' => q({0} ನಿಮಿ),
						'per' => q({0}/ನಿಮಿ),
					},
					# Long Unit Identifier
					'duration-month' => {
						'name' => q(ತಿಂಗಳು),
						'one' => q({0} ತಿಂ.),
						'other' => q({0} ತಿಂ.ಗಳು),
						'per' => q({0}/ತಿ),
					},
					# Core Unit Identifier
					'month' => {
						'name' => q(ತಿಂಗಳು),
						'one' => q({0} ತಿಂ.),
						'other' => q({0} ತಿಂ.ಗಳು),
						'per' => q({0}/ತಿ),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'name' => q(ನ್ಯಾ.ಸೆ),
						'one' => q({0} ನ್ಯಾ.ಸೆ),
						'other' => q({0} ನ್ಯಾ.ಸೆ),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'name' => q(ನ್ಯಾ.ಸೆ),
						'one' => q({0} ನ್ಯಾ.ಸೆ),
						'other' => q({0} ನ್ಯಾ.ಸೆ),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ರಾತ್ರಿ),
						'one' => q({0} ರಾತ್ರಿಯು),
						'other' => q({0} ರಾತ್ರಿಗಳು),
						'per' => q({0}/ರಾತ್ರಿಗೆ),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ರಾತ್ರಿ),
						'one' => q({0} ರಾತ್ರಿಯು),
						'other' => q({0} ರಾತ್ರಿಗಳು),
						'per' => q({0}/ರಾತ್ರಿಗೆ),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'name' => q(ತ್ರೈಮಾಸಿಕ),
						'one' => q({0} ತ್ರೈ),
						'other' => q({0} ತ್ರೈ.ಗಳು),
						'per' => q({0}/ತ್ರೈಮಾಸಿಕಕ್ಕೆ),
					},
					# Core Unit Identifier
					'quarter' => {
						'name' => q(ತ್ರೈಮಾಸಿಕ),
						'one' => q({0} ತ್ರೈ),
						'other' => q({0} ತ್ರೈ.ಗಳು),
						'per' => q({0}/ತ್ರೈಮಾಸಿಕಕ್ಕೆ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'name' => q(ಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ಸೆಕೆಂ),
						'other' => q({0} ಸೆಕೆಂ),
						'per' => q({0}/ಸೆ),
					},
					# Core Unit Identifier
					'second' => {
						'name' => q(ಸೆಕೆಂಡುಗಳು),
						'one' => q({0} ಸೆಕೆಂ),
						'other' => q({0} ಸೆಕೆಂ),
						'per' => q({0}/ಸೆ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(ವಾರಗಳು),
						'one' => q({0} ವಾರ),
						'other' => q({0} ವಾರಗಳು),
						'per' => q({0}/ವಾ),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(ವಾರಗಳು),
						'one' => q({0} ವಾರ),
						'other' => q({0} ವಾರಗಳು),
						'per' => q({0}/ವಾ),
					},
					# Long Unit Identifier
					'duration-year' => {
						'name' => q(ವರ್ಷಗಳು),
						'one' => q({0} ವರ್ಷ),
						'other' => q({0} ವರ್ಷಗಳು),
						'per' => q({0}/ವ),
					},
					# Core Unit Identifier
					'year' => {
						'name' => q(ವರ್ಷಗಳು),
						'one' => q({0} ವರ್ಷ),
						'other' => q({0} ವರ್ಷಗಳು),
						'per' => q({0}/ವ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(ಆಂ.),
						'one' => q({0} ಆಂ.),
						'other' => q({0} ಆಂ.),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(ಆಂ.),
						'one' => q({0} ಆಂ.),
						'other' => q({0} ಆಂ.),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'name' => q(ಮಿ.ಆಂ.),
						'one' => q({0} ಮಿ.ಆಂ.),
						'other' => q({0} ಮಿ.ಆಂ.),
					},
					# Core Unit Identifier
					'milliampere' => {
						'name' => q(ಮಿ.ಆಂ.),
						'one' => q({0} ಮಿ.ಆಂ.),
						'other' => q({0} ಮಿ.ಆಂ.),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'name' => q(ಓಂಗಳು),
					},
					# Core Unit Identifier
					'ohm' => {
						'name' => q(ಓಂಗಳು),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'name' => q(ವೋ.),
						'one' => q({0} ವೋ),
						'other' => q({0} ವೋ.),
					},
					# Core Unit Identifier
					'volt' => {
						'name' => q(ವೋ.),
						'one' => q({0} ವೋ),
						'other' => q({0} ವೋ.),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(BTU),
						'one' => q({0} ಬ್ರಿಉಘ),
						'other' => q({0} ಬ್ರಿಉಘ),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(BTU),
						'one' => q({0} ಬ್ರಿಉಘ),
						'other' => q({0} ಬ್ರಿಉಘ),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'name' => q(ಕ್ಯಾಲೊ),
						'one' => q({0} ಕ್ಯಾಲೊ),
						'other' => q({0} ಕ್ಯಾಲೊ),
					},
					# Core Unit Identifier
					'calorie' => {
						'name' => q(ಕ್ಯಾಲೊ),
						'one' => q({0} ಕ್ಯಾಲೊ),
						'other' => q({0} ಕ್ಯಾಲೊ),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'name' => q(ಎಲೆಕ್ಟ್ರಾನ್‌ವೋಲ್ಟ್‌),
						'one' => q({0} ಎವೋ),
						'other' => q({0} ಎವೋ),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'name' => q(ಎಲೆಕ್ಟ್ರಾನ್‌ವೋಲ್ಟ್‌),
						'one' => q({0} ಎವೋ),
						'other' => q({0} ಎವೋ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(ಕ್ಯಾಲೊ),
						'one' => q({0} ಕ್ಯಾಲೊ),
						'other' => q({0} ಕ್ಯಾಲೊ),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(ಕ್ಯಾಲೊ),
						'one' => q({0} ಕ್ಯಾಲೊ),
						'other' => q({0} ಕ್ಯಾಲೊ),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'name' => q(ಜೌಲ್‌ಗಳು),
						'one' => q({0} ಜೌ),
						'other' => q({0} ಜೌ),
					},
					# Core Unit Identifier
					'joule' => {
						'name' => q(ಜೌಲ್‌ಗಳು),
						'one' => q({0} ಜೌ),
						'other' => q({0} ಜೌ),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'name' => q(ಕಿ.ಕ್ಯಾ),
						'one' => q({0} ಕಿ.ಕ್ಯಾ),
						'other' => q({0} ಕಿ.ಕ್ಯಾ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'name' => q(ಕಿ.ಕ್ಯಾ),
						'one' => q({0} ಕಿ.ಕ್ಯಾ),
						'other' => q({0} ಕಿ.ಕ್ಯಾ),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'name' => q(ಕಿ.ಜೌ),
						'one' => q({0} ಕಿ.ಜೌ),
						'other' => q({0} ಕಿ.ಜೌ),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'name' => q(ಕಿ.ಜೌ),
						'one' => q({0} ಕಿ.ಜೌ),
						'other' => q({0} ಕಿ.ಜೌ),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'name' => q(ಕಿ.ವ್ಯಾ-ಗಂ),
						'one' => q({0} ಕಿವ್ಯಾಗಂ),
						'other' => q({0} ಕಿವ್ಯಾಗಂ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'name' => q(ಕಿ.ವ್ಯಾ-ಗಂ),
						'one' => q({0} ಕಿವ್ಯಾಗಂ),
						'other' => q({0} ಕಿವ್ಯಾಗಂ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'name' => q(ಯುಎಸ್ ಥರ್ಮ್ಸ್),
						'one' => q({0} ಯುಎಸ್ ಥರ್ಮ್ಸ್),
						'other' => q({0} ಯುಎಸ್ ಥರ್ಮ್ಸ್),
					},
					# Core Unit Identifier
					'therm-us' => {
						'name' => q(ಯುಎಸ್ ಥರ್ಮ್ಸ್),
						'one' => q({0} ಯುಎಸ್ ಥರ್ಮ್ಸ್),
						'other' => q({0} ಯುಎಸ್ ಥರ್ಮ್ಸ್),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'name' => q(ಕಿವ್ಯಾಗಂ/100ಕಿಮೀ),
						'one' => q({0} ಕಿವ್ಯಾಗಂ/100ಕಿಮೀ),
						'other' => q({0} ಕಿವ್ಯಾಗಂ/100ಕಿಮೀ),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'name' => q(ಕಿವ್ಯಾಗಂ/100ಕಿಮೀ),
						'one' => q({0} ಕಿವ್ಯಾಗಂ/100ಕಿಮೀ),
						'other' => q({0} ಕಿವ್ಯಾಗಂ/100ಕಿಮೀ),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(ನ್ಯೂಟೋನ್‌),
						'one' => q({0} ನ್ಯೂ),
						'other' => q({0} ನ್ಯೂ),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(ನ್ಯೂಟೋನ್‌),
						'one' => q({0} ನ್ಯೂ),
						'other' => q({0} ನ್ಯೂ),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ಪೌಂಡ್ - ಫೋರ್ಸ್),
						'one' => q({0} ಎಲ್‌ಬಿಎಫ್),
						'other' => q({0} ಎಲ್‌ಬಿಎಫ್),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ಪೌಂಡ್ - ಫೋರ್ಸ್),
						'one' => q({0} ಎಲ್‌ಬಿಎಫ್),
						'other' => q({0} ಎಲ್‌ಬಿಎಫ್),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'name' => q(ಗಿ.ಹ),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'name' => q(ಗಿ.ಹ),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'name' => q(ಹರ್ಟ್ಸ್‌),
						'one' => q({0} ಹರ್ಟ್ಸ್‌),
						'other' => q({0} ಹರ್ಟ್ಸ್‌),
					},
					# Core Unit Identifier
					'hertz' => {
						'name' => q(ಹರ್ಟ್ಸ್‌),
						'one' => q({0} ಹರ್ಟ್ಸ್‌),
						'other' => q({0} ಹರ್ಟ್ಸ್‌),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'name' => q(ಕಿ.ಹ),
						'one' => q({0} ಕಿ.ಹ),
						'other' => q({0} ಕಿ.ಹ),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'name' => q(ಕಿ.ಹ),
						'one' => q({0} ಕಿ.ಹ),
						'other' => q({0} ಕಿ.ಹ),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'name' => q(ಮೆ.ಹ),
						'one' => q({0} ಮೆ.ಹ),
						'other' => q({0} ಮೆ.ಹ),
					},
					# Core Unit Identifier
					'megahertz' => {
						'name' => q(ಮೆ.ಹ),
						'one' => q({0} ಮೆ.ಹ),
						'other' => q({0} ಮೆ.ಹ),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'name' => q(ಡಾಟ್‌ಗಳು),
						'one' => q({0} ಡಾಟ್),
						'other' => q({0} ಡಾಟ್‌ಗಳು),
					},
					# Core Unit Identifier
					'dot' => {
						'name' => q(ಡಾಟ್‌ಗಳು),
						'one' => q({0} ಡಾಟ್),
						'other' => q({0} ಡಾಟ್‌ಗಳು),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(ಡಿಪಿಸಿಎಂ),
						'one' => q({0} ಡಿಪಿಸಿಎಂ),
						'other' => q({0} ಡಿಪಿಸಿಎಂ),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(ಡಿಪಿಸಿಎಂ),
						'one' => q({0} ಡಿಪಿಸಿಎಂ),
						'other' => q({0} ಡಿಪಿಸಿಎಂ),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(ಡಿಪಿಐ),
						'one' => q({0} ಡಿಪಿಐ),
						'other' => q({0} ಡಿಪಿಐ),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(ಡಿಪಿಐ),
						'one' => q({0} ಡಿಪಿಐ),
						'other' => q({0} ಡಿಪಿಐ),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'name' => q(ಮೆಗಾಪಿಕ್ಸೆಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'megapixel' => {
						'name' => q(ಮೆಗಾಪಿಕ್ಸೆಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'name' => q(ಪಿಕ್ಸೆಲ್‌ಗಳು),
					},
					# Core Unit Identifier
					'pixel' => {
						'name' => q(ಪಿಕ್ಸೆಲ್‌ಗಳು),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(ಅ.ಯೂ),
						'one' => q({0} ಅ.ಯೂ),
						'other' => q({0} ಅ.ಯೂ),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(ಅ.ಯೂ),
						'one' => q({0} ಅ.ಯೂ),
						'other' => q({0} ಅ.ಯೂ),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'name' => q(ಸೆಮೀ),
						'one' => q({0} ಸೆಮೀ),
						'other' => q({0} ಸೆಮೀ),
						'per' => q({0}/ಸೆಂಮೀ),
					},
					# Core Unit Identifier
					'centimeter' => {
						'name' => q(ಸೆಮೀ),
						'one' => q({0} ಸೆಮೀ),
						'other' => q({0} ಸೆಮೀ),
						'per' => q({0}/ಸೆಂಮೀ),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'name' => q(ಡೆಮೀ),
						'one' => q({0} ಡೆಮೀ),
						'other' => q({0} ಡೆಮೀ),
					},
					# Core Unit Identifier
					'decimeter' => {
						'name' => q(ಡೆಮೀ),
						'one' => q({0} ಡೆಮೀ),
						'other' => q({0} ಡೆಮೀ),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'name' => q(ಭೂಮಿಯ ತ್ರಿಜ್ಯ),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'name' => q(ಭೂಮಿಯ ತ್ರಿಜ್ಯ),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ಫ್ಯಾಥಮ್ಸ್),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ಫ್ಯಾಥಮ್ಸ್),
					},
					# Long Unit Identifier
					'length-foot' => {
						'name' => q(ಅಡಿ),
						'one' => q({0} ಅ),
						'other' => q({0} ಅ),
						'per' => q({0}/ಅ),
					},
					# Core Unit Identifier
					'foot' => {
						'name' => q(ಅಡಿ),
						'one' => q({0} ಅ),
						'other' => q({0} ಅ),
						'per' => q({0}/ಅ),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'name' => q(ಫರ್ಲಾಂಗ್ಸ್),
						'one' => q({0} ಫರ್),
						'other' => q({0} ಫರ್),
					},
					# Core Unit Identifier
					'furlong' => {
						'name' => q(ಫರ್ಲಾಂಗ್ಸ್),
						'one' => q({0} ಫರ್),
						'other' => q({0} ಫರ್),
					},
					# Long Unit Identifier
					'length-inch' => {
						'name' => q(ಅಂಗುಲಗಳು),
						'one' => q({0} ಅಂ),
						'other' => q({0} ಅಂ),
						'per' => q({0}/ಅಂ),
					},
					# Core Unit Identifier
					'inch' => {
						'name' => q(ಅಂಗುಲಗಳು),
						'one' => q({0} ಅಂ),
						'other' => q({0} ಅಂ),
						'per' => q({0}/ಅಂ),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'name' => q(ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಕಿಮೀ),
						'other' => q({0} ಕಿಮೀ),
						'per' => q({0}/ಕಿ.ಮೀ),
					},
					# Core Unit Identifier
					'kilometer' => {
						'name' => q(ಕಿಲೋಮೀಟರ್‌ಗಳು),
						'one' => q({0} ಕಿಮೀ),
						'other' => q({0} ಕಿಮೀ),
						'per' => q({0}/ಕಿ.ಮೀ),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'name' => q(ಬೆಳಕಿನ ವರ್ಷಗಳು),
						'one' => q({0} ಬೆ.ವರ್ಷ),
						'other' => q({0} ಬೆ.ವರ್ಷ),
					},
					# Core Unit Identifier
					'light-year' => {
						'name' => q(ಬೆಳಕಿನ ವರ್ಷಗಳು),
						'one' => q({0} ಬೆ.ವರ್ಷ),
						'other' => q({0} ಬೆ.ವರ್ಷ),
					},
					# Long Unit Identifier
					'length-meter' => {
						'name' => q(ಮೀ),
						'one' => q({0} ಮೀ),
						'other' => q({0} ಮೀ),
						'per' => q({0}/ಮೀ),
					},
					# Core Unit Identifier
					'meter' => {
						'name' => q(ಮೀ),
						'one' => q({0} ಮೀ),
						'other' => q({0} ಮೀ),
						'per' => q({0}/ಮೀ),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(μmeters),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(μmeters),
					},
					# Long Unit Identifier
					'length-mile' => {
						'name' => q(ಮೈಲುಗಳು),
						'one' => q({0} ಮೈ.),
						'other' => q({0} ಮೈ.),
					},
					# Core Unit Identifier
					'mile' => {
						'name' => q(ಮೈಲುಗಳು),
						'one' => q({0} ಮೈ.),
						'other' => q({0} ಮೈ.),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'name' => q(ಸ್ಕ್ಯಾಂ.ಮೈ),
						'one' => q({0} smi),
						'other' => q({0} smi),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'name' => q(ಸ್ಕ್ಯಾಂ.ಮೈ),
						'one' => q({0} smi),
						'other' => q({0} smi),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'name' => q(ಮಿಮೀ),
						'one' => q({0} ಮಿಮೀ),
						'other' => q({0} ಮಿಮೀ),
					},
					# Core Unit Identifier
					'millimeter' => {
						'name' => q(ಮಿಮೀ),
						'one' => q({0} ಮಿಮೀ),
						'other' => q({0} ಮಿಮೀ),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'name' => q(ನ್ಯಾ.ಮೀ),
						'one' => q({0} ನ್ಯಾ.ಮೀ),
						'other' => q({0} ನ್ಯಾ.ಮೀ),
					},
					# Core Unit Identifier
					'nanometer' => {
						'name' => q(ನ್ಯಾ.ಮೀ),
						'one' => q({0} ನ್ಯಾ.ಮೀ),
						'other' => q({0} ನ್ಯಾ.ಮೀ),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ನಾ.ಮೈ),
						'one' => q({0} ನಾ.ಮೈ),
						'other' => q({0} ನಾ.ಮೈ),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ನಾ.ಮೈ),
						'one' => q({0} ನಾ.ಮೈ),
						'other' => q({0} ನಾ.ಮೈ),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(ಪಾರ್‌ಸೆಕೆಂ.ಗಳು),
						'one' => q({0} ಪಾ.ಸೆ),
						'other' => q({0} ಪಾ.ಸೆ),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(ಪಾರ್‌ಸೆಕೆಂ.ಗಳು),
						'one' => q({0} ಪಾ.ಸೆ),
						'other' => q({0} ಪಾ.ಸೆ),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'name' => q(ಪಿ.ಮೀ),
						'one' => q({0} ಪಿ.ಮೀ),
						'other' => q({0} ಪಿ.ಮೀ),
					},
					# Core Unit Identifier
					'picometer' => {
						'name' => q(ಪಿ.ಮೀ),
						'one' => q({0} ಪಿ.ಮೀ),
						'other' => q({0} ಪಿ.ಮೀ),
					},
					# Long Unit Identifier
					'length-point' => {
						'name' => q(ಪಾಯಿಂಟ್‌ಗಳು),
						'one' => q({0} ಪಾಯಿಂಟ್),
						'other' => q({0} ಪಾಯಿಂಟ್‌),
					},
					# Core Unit Identifier
					'point' => {
						'name' => q(ಪಾಯಿಂಟ್‌ಗಳು),
						'one' => q({0} ಪಾಯಿಂಟ್),
						'other' => q({0} ಪಾಯಿಂಟ್‌),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(ಸೋಲಾರ್‌ ರೇಡಿ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(ಸೋಲಾರ್‌ ರೇಡಿ),
					},
					# Long Unit Identifier
					'length-yard' => {
						'name' => q(ಗಜಗಳು),
						'one' => q({0} ಗ),
						'other' => q({0} ಗ),
					},
					# Core Unit Identifier
					'yard' => {
						'name' => q(ಗಜಗಳು),
						'one' => q({0} ಗ),
						'other' => q({0} ಗ),
					},
					# Long Unit Identifier
					'light-candela' => {
						'name' => q(ಕ್ಯಾಂ),
						'one' => q({0} ಕ್ಯಾಂ),
						'other' => q({0} ಕ್ಯಾಂ),
					},
					# Core Unit Identifier
					'candela' => {
						'name' => q(ಕ್ಯಾಂ),
						'one' => q({0} ಕ್ಯಾಂ),
						'other' => q({0} ಕ್ಯಾಂ),
					},
					# Long Unit Identifier
					'light-lumen' => {
						'name' => q(ಎಲ್ಎಮ್),
						'one' => q({0} ಎಲ್ಎಮ್),
						'other' => q({0} ಎಲ್ಎಮ್),
					},
					# Core Unit Identifier
					'lumen' => {
						'name' => q(ಎಲ್ಎಮ್),
						'one' => q({0} ಎಲ್ಎಮ್),
						'other' => q({0} ಎಲ್ಎಮ್),
					},
					# Long Unit Identifier
					'light-lux' => {
						'name' => q(ಲಕ್ಸ್),
						'one' => q({0} ಎಲ್‌ಎಕ್ಸ್),
						'other' => q({0} ಎಲ್‌ಎಕ್ಸ್),
					},
					# Core Unit Identifier
					'lux' => {
						'name' => q(ಲಕ್ಸ್),
						'one' => q({0} ಎಲ್‌ಎಕ್ಸ್),
						'other' => q({0} ಎಲ್‌ಎಕ್ಸ್),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'name' => q(ಸೌರ ಪ್ರಕಾಶಗಳು),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'name' => q(ಸೌರ ಪ್ರಕಾಶಗಳು),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'name' => q(ಕ್ಯಾರೆಟ್‌ಗಳು),
						'one' => q({0} ಸಿಡಿ),
						'other' => q({0} ಸಿಡಿ),
					},
					# Core Unit Identifier
					'carat' => {
						'name' => q(ಕ್ಯಾರೆಟ್‌ಗಳು),
						'one' => q({0} ಸಿಡಿ),
						'other' => q({0} ಸಿಡಿ),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'name' => q(ಡಿಎ),
						'one' => q({0} ಡಿಎ),
						'other' => q({0} ಡಿಎ),
					},
					# Core Unit Identifier
					'dalton' => {
						'name' => q(ಡಿಎ),
						'one' => q({0} ಡಿಎ),
						'other' => q({0} ಡಿಎ),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'name' => q(ಭೂಮಿಯ ದೃವ್ಯರಾಶಿ),
						'one' => q({0} ದೃ⊕),
						'other' => q({0} ದೃ⊕),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'name' => q(ಭೂಮಿಯ ದೃವ್ಯರಾಶಿ),
						'one' => q({0} ದೃ⊕),
						'other' => q({0} ದೃ⊕),
					},
					# Long Unit Identifier
					'mass-grain' => {
						'name' => q(ಗ್ರೇನ್),
						'one' => q({0} ಗ್ರೇನ್),
						'other' => q({0} ಗ್ರೇನ್),
					},
					# Core Unit Identifier
					'grain' => {
						'name' => q(ಗ್ರೇನ್),
						'one' => q({0} ಗ್ರೇನ್),
						'other' => q({0} ಗ್ರೇನ್),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'name' => q(ಗ್ರಾಂಗಳು),
						'one' => q({0} ಗ್ರಾ),
						'other' => q({0} ಗ್ರಾ),
						'per' => q({0}/ಗ್ರಾ),
					},
					# Core Unit Identifier
					'gram' => {
						'name' => q(ಗ್ರಾಂಗಳು),
						'one' => q({0} ಗ್ರಾ),
						'other' => q({0} ಗ್ರಾ),
						'per' => q({0}/ಗ್ರಾ),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'name' => q(ಕೆಜಿ),
						'one' => q({0} ಕೆಜಿ),
						'other' => q({0} ಕೆಜಿ),
						'per' => q({0}/ಕೆಜಿ),
					},
					# Core Unit Identifier
					'kilogram' => {
						'name' => q(ಕೆಜಿ),
						'one' => q({0} ಕೆಜಿ),
						'other' => q({0} ಕೆಜಿ),
						'per' => q({0}/ಕೆಜಿ),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'name' => q(ಮೈ.ಗ್ರಾಂ),
						'one' => q({0} ಮೈ.ಗ್ರಾಂ),
						'other' => q({0} ಮೈ.ಗ್ರಾಂ),
					},
					# Core Unit Identifier
					'microgram' => {
						'name' => q(ಮೈ.ಗ್ರಾಂ),
						'one' => q({0} ಮೈ.ಗ್ರಾಂ),
						'other' => q({0} ಮೈ.ಗ್ರಾಂ),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'name' => q(ಮಿ.ಗ್ರಾಂ),
						'one' => q({0} ಮಿ.ಗ್ರಾಂ),
						'other' => q({0} ಮಿ.ಗ್ರಾಂ),
					},
					# Core Unit Identifier
					'milligram' => {
						'name' => q(ಮಿ.ಗ್ರಾಂ),
						'one' => q({0} ಮಿ.ಗ್ರಾಂ),
						'other' => q({0} ಮಿ.ಗ್ರಾಂ),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(ಔ),
						'one' => q({0} ಔ),
						'other' => q({0} ಔ),
						'per' => q({0}/ ಔ),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(ಔ),
						'one' => q({0} ಔ),
						'other' => q({0} ಔ),
						'per' => q({0}/ ಔ),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ಟ್ರಾ.ಔ),
						'one' => q({0} ಟ್ರಾ.ಔ),
						'other' => q({0} ಟ್ರಾ.ಔ),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ಟ್ರಾ.ಔ),
						'one' => q({0} ಟ್ರಾ.ಔ),
						'other' => q({0} ಟ್ರಾ.ಔ),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'name' => q(ಪೌಂ),
						'one' => q({0} ಪೌಂ),
						'other' => q({0} ಪೌಂ),
						'per' => q({0}/ಪೌಂ),
					},
					# Core Unit Identifier
					'pound' => {
						'name' => q(ಪೌಂ),
						'one' => q({0} ಪೌಂ),
						'other' => q({0} ಪೌಂ),
						'per' => q({0}/ಪೌಂ),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'name' => q(ಸೋಲಾರ್‌ ಮಾಸ್‌ಗಳು),
						'one' => q({0} ದೃ☉),
						'other' => q({0} ದೃ☉),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'name' => q(ಸೋಲಾರ್‌ ಮಾಸ್‌ಗಳು),
						'one' => q({0} ದೃ☉),
						'other' => q({0} ದೃ☉),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'name' => q(ಕಲ್ಲುಗಳು),
						'one' => q({0} ಕಲ್ಲು),
						'other' => q({0} ಕಲ್ಲು),
					},
					# Core Unit Identifier
					'stone' => {
						'name' => q(ಕಲ್ಲುಗಳು),
						'one' => q({0} ಕಲ್ಲು),
						'other' => q({0} ಕಲ್ಲು),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(ಟನ್‍ಗಳು),
						'one' => q({0} ಟನ್‌),
						'other' => q({0} ಟನ್‌),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(ಟನ್‍ಗಳು),
						'one' => q({0} ಟನ್‌),
						'other' => q({0} ಟನ್‌),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'name' => q(ಟ),
						'one' => q({0} ಟ),
						'other' => q({0} ಟ),
					},
					# Core Unit Identifier
					'tonne' => {
						'name' => q(ಟ),
						'one' => q({0} ಟ),
						'other' => q({0} ಟ),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'name' => q(ಗಿ.ವ್ಯಾ),
						'one' => q({0} ಗಿ.ವ್ಯಾ),
						'other' => q({0} ಗಿ.ವ್ಯಾ),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'name' => q(ಗಿ.ವ್ಯಾ),
						'one' => q({0} ಗಿ.ವ್ಯಾ),
						'other' => q({0} ಗಿ.ವ್ಯಾ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(ಹೆಚ್‌ಪಿ),
						'one' => q({0} ಹೆಚ್‌ಪಿ),
						'other' => q({0} ಹೆಚ್‌ಪಿ),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(ಹೆಚ್‌ಪಿ),
						'one' => q({0} ಹೆಚ್‌ಪಿ),
						'other' => q({0} ಹೆಚ್‌ಪಿ),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'name' => q(ಕಿ.ವ್ಯಾ),
						'one' => q({0} ಕಿ.ವ್ಯಾ),
						'other' => q({0} ಕಿ.ವ್ಯಾ),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'name' => q(ಕಿ.ವ್ಯಾ),
						'one' => q({0} ಕಿ.ವ್ಯಾ),
						'other' => q({0} ಕಿ.ವ್ಯಾ),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'name' => q(ಮೆ.ವ್ಯಾ),
						'one' => q({0} ಮೆ.ವ್ಯಾ),
						'other' => q({0} ಮೆ.ವ್ಯಾ),
					},
					# Core Unit Identifier
					'megawatt' => {
						'name' => q(ಮೆ.ವ್ಯಾ),
						'one' => q({0} ಮೆ.ವ್ಯಾ),
						'other' => q({0} ಮೆ.ವ್ಯಾ),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'name' => q(ಮಿ.ವ್ಯಾ),
						'one' => q({0} ಮಿ.ವ್ಯಾ),
						'other' => q({0} ಮಿ.ವ್ಯಾ),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'name' => q(ಮಿ.ವ್ಯಾ),
						'one' => q({0} ಮಿ.ವ್ಯಾ),
						'other' => q({0} ಮಿ.ವ್ಯಾ),
					},
					# Long Unit Identifier
					'power-watt' => {
						'name' => q(ವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ವ್ಯಾ.),
						'other' => q({0} ವ್ಯಾ.),
					},
					# Core Unit Identifier
					'watt' => {
						'name' => q(ವ್ಯಾಟ್‌ಗಳು),
						'one' => q({0} ವ್ಯಾ.),
						'other' => q({0} ವ್ಯಾ.),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'name' => q(ವಾತಾವರಣಗಳು),
						'one' => q({0} ವಾತಾವರಣ),
						'other' => q({0} ವಾತಾವರಣ),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'name' => q(ವಾತಾವರಣಗಳು),
						'one' => q({0} ವಾತಾವರಣ),
						'other' => q({0} ವಾತಾವರಣ),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'name' => q(ಬಾರ್‌),
						'one' => q({0} ಬಾರ್‌),
						'other' => q({0} ಬಾರ್‌ಗಳು),
					},
					# Core Unit Identifier
					'bar' => {
						'name' => q(ಬಾರ್‌),
						'one' => q({0} ಬಾರ್‌),
						'other' => q({0} ಬಾರ್‌ಗಳು),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'name' => q(ಹೆ.ಪ್ಯಾ.),
						'one' => q({0} ಹೆ.ಪ್ಯಾ),
						'other' => q({0} ಹೆ.ಪ್ಯಾ),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'name' => q(ಹೆ.ಪ್ಯಾ.),
						'one' => q({0} ಹೆ.ಪ್ಯಾ),
						'other' => q({0} ಹೆ.ಪ್ಯಾ),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'name' => q(ಮರ್ಕ್ಯು.ಅಂ.),
						'one' => q({0} ಮರ್ಕ್ಯುಅಂ),
						'other' => q({0} ಮರ್ಕ್ಯುಅಂ),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'name' => q(ಮರ್ಕ್ಯು.ಅಂ.),
						'one' => q({0} ಮರ್ಕ್ಯುಅಂ),
						'other' => q({0} ಮರ್ಕ್ಯುಅಂ),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'name' => q(ಕೆಪಿಎ),
						'one' => q({0} ಕೆಪಿಎ),
						'other' => q({0} ಕೆಪಿಎ),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'name' => q(ಕೆಪಿಎ),
						'one' => q({0} ಕೆಪಿಎ),
						'other' => q({0} ಕೆಪಿಎ),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'name' => q(ಎಂಪಿಎ),
						'one' => q({0} ಎಂಪಿಎ),
						'other' => q({0} ಎಂಪಿಎ),
					},
					# Core Unit Identifier
					'megapascal' => {
						'name' => q(ಎಂಪಿಎ),
						'one' => q({0} ಎಂಪಿಎ),
						'other' => q({0} ಎಂಪಿಎ),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'name' => q(ಮಿ.ಬಾರ್‌),
						'one' => q({0} ಮಿ.ಬಾರ್),
						'other' => q({0} ಮಿ.ಬಾರ್),
					},
					# Core Unit Identifier
					'millibar' => {
						'name' => q(ಮಿ.ಬಾರ್‌),
						'one' => q({0} ಮಿ.ಬಾರ್),
						'other' => q({0} ಮಿ.ಬಾರ್),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'name' => q(ಮರ್ಕ್ಯು.ಮಿ.ಮೀ.),
						'one' => q({0} ಮರ್ಕ್ಯು ಮಿಮೀ),
						'other' => q({0} ಮರ್ಕ್ಯು ಮಿಮೀ),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'name' => q(ಮರ್ಕ್ಯು.ಮಿ.ಮೀ.),
						'one' => q({0} ಮರ್ಕ್ಯು ಮಿಮೀ),
						'other' => q({0} ಮರ್ಕ್ಯು ಮಿಮೀ),
					},
					# Long Unit Identifier
					'pressure-pascal' => {
						'name' => q(ಪಾ),
						'one' => q({0} ಪಾ),
						'other' => q({0} ಪ್ಯಾ),
					},
					# Core Unit Identifier
					'pascal' => {
						'name' => q(ಪಾ),
						'one' => q({0} ಪಾ),
						'other' => q({0} ಪ್ಯಾ),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(ಪ್ರ.ಚ.ಇಂ.ಪೌಂ.),
						'one' => q({0} ಪ್ರಚಇಂಪೌಂ),
						'other' => q({0} ಪ್ರಚಇಂಪೌಂ),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(ಪ್ರ.ಚ.ಇಂ.ಪೌಂ.),
						'one' => q({0} ಪ್ರಚಇಂಪೌಂ),
						'other' => q({0} ಪ್ರಚಇಂಪೌಂ),
					},
					# Long Unit Identifier
					'speed-beaufort' => {
						'name' => q(ಬಿಎಫ್‌ಟಿ),
						'one' => q(ಬಿ {0}),
						'other' => q(ಬಿ {0}),
					},
					# Core Unit Identifier
					'beaufort' => {
						'name' => q(ಬಿಎಫ್‌ಟಿ),
						'one' => q(ಬಿ {0}),
						'other' => q(ಬಿ {0}),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(ಕಿ.ಮೀ/ಗಂಟೆ),
						'one' => q({0} ಕಿ.ಮೀ./ಗಂ),
						'other' => q({0} ಕಿ.ಮೀ./ಗಂ),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(ಕಿ.ಮೀ/ಗಂಟೆ),
						'one' => q({0} ಕಿ.ಮೀ./ಗಂ),
						'other' => q({0} ಕಿ.ಮೀ./ಗಂ),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'name' => q(ನಾ),
						'one' => q({0} ನಾ),
						'other' => q({0} ನಾ),
					},
					# Core Unit Identifier
					'knot' => {
						'name' => q(ನಾ),
						'one' => q({0} ನಾ),
						'other' => q({0} ನಾ),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(ಲೈಟ್),
						'one' => q({0} ಲೈಟ್),
						'other' => q({0} ಲೈಟ್),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(ಲೈಟ್),
						'one' => q({0} ಲೈಟ್),
						'other' => q({0} ಲೈಟ್),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'name' => q(ಮೀ.ಗಳು/ಸೆ),
						'one' => q({0} ಮೀ/ಸೆ.),
						'other' => q({0} ಮೀ/ಸೆ.),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'name' => q(ಮೀ.ಗಳು/ಸೆ),
						'one' => q({0} ಮೀ/ಸೆ.),
						'other' => q({0} ಮೀ/ಸೆ.),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(ಮೈಲುಗಳು/ಗಂಟೆ),
						'one' => q({0} ಮೈ/ಗಂ),
						'other' => q({0} ಮೈ/ಗಂ),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(ಮೈಲುಗಳು/ಗಂಟೆ),
						'one' => q({0} ಮೈ/ಗಂ),
						'other' => q({0} ಮೈ/ಗಂ),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(ಡಿ.ಸೆ.),
						'one' => q({0}°ಸೆ),
						'other' => q({0}°ಸೆ),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(ಡಿ.ಸೆ.),
						'one' => q({0}°ಸೆ),
						'other' => q({0}°ಸೆ),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(ಡಿ.ಫ್ಯಾ.),
						'one' => q({0}°ಫ್ಯಾ),
						'other' => q({0}°ಫ್ಯಾ),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(ಡಿ.ಫ್ಯಾ.),
						'one' => q({0}°ಫ್ಯಾ),
						'other' => q({0}°ಫ್ಯಾ),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'name' => q(ಕೆ),
						'one' => q({0} ಕೆ),
						'other' => q({0} ಕೆ),
					},
					# Core Unit Identifier
					'kelvin' => {
						'name' => q(ಕೆ),
						'one' => q({0} ಕೆ),
						'other' => q({0} ಕೆ),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(ನ್ಯೂ.ಮೀ),
						'one' => q({0} ನ್ಯೂ.ಮೀ),
						'other' => q({0} ನ್ಯೂ.ಮೀ),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(ನ್ಯೂ.ಮೀ),
						'one' => q({0} ನ್ಯೂ.ಮೀ),
						'other' => q({0} ನ್ಯೂ.ಮೀ),
					},
					# Long Unit Identifier
					'torque-pound-force-foot' => {
						'name' => q(ಎಲ್‌ಬಿಎಫ್⋅ಎಫ್‌ಟಿ),
						'one' => q({0} ಎಲ್‌ಬಿಎಫ್-ಎಫ್‌ಟಿ),
						'other' => q({0} ಎಲ್‌ಬಿಎಫ್-ಎಫ್‌ಟಿ),
					},
					# Core Unit Identifier
					'pound-force-foot' => {
						'name' => q(ಎಲ್‌ಬಿಎಫ್⋅ಎಫ್‌ಟಿ),
						'one' => q({0} ಎಲ್‌ಬಿಎಫ್-ಎಫ್‌ಟಿ),
						'other' => q({0} ಎಲ್‌ಬಿಎಫ್-ಎಫ್‌ಟಿ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ಎಕರೆ ಅಡಿ),
						'one' => q({0} ಎ. ಅ),
						'other' => q({0} ಎ. ಅ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ಎಕರೆ ಅಡಿ),
						'one' => q({0} ಎ. ಅ),
						'other' => q({0} ಎ. ಅ),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(ಬ್ಯಾರೆಲ್),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(ಬ್ಯಾರೆಲ್),
					},
					# Long Unit Identifier
					'volume-bushel' => {
						'name' => q(ಬುಶಲ್‌ಗಳು),
						'one' => q({0} ಬು),
						'other' => q({0} ಬು),
					},
					# Core Unit Identifier
					'bushel' => {
						'name' => q(ಬುಶಲ್‌ಗಳು),
						'one' => q({0} ಬು),
						'other' => q({0} ಬು),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'name' => q(ಸೆಂ.ಲೀ),
						'one' => q({0} ಸೆಂ.ಲೀ),
						'other' => q({0} ಸೆಂ.ಲೀ),
					},
					# Core Unit Identifier
					'centiliter' => {
						'name' => q(ಸೆಂ.ಲೀ),
						'one' => q({0} ಸೆಂ.ಲೀ),
						'other' => q({0} ಸೆಂ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'name' => q(ಸೆಮೀ³),
						'one' => q({0} ಸೆಮೀ³),
						'other' => q({0} ಸೆಮೀ³),
						'per' => q({0}/ಸೆಮೀ³),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'name' => q(ಸೆಮೀ³),
						'one' => q({0} ಸೆಮೀ³),
						'other' => q({0} ಸೆಮೀ³),
						'per' => q({0}/ಸೆಮೀ³),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ಅಡಿ³),
						'one' => q({0} ಅಡಿ³),
						'other' => q({0} ಅಡಿ³),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ಅಡಿ³),
						'one' => q({0} ಅಡಿ³),
						'other' => q({0} ಅಡಿ³),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(ಅಂಗುಲಗಳು³),
						'one' => q({0} ಅಂ³),
						'other' => q({0} ಅಂ³),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(ಅಂಗುಲಗಳು³),
						'one' => q({0} ಅಂ³),
						'other' => q({0} ಅಂ³),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'name' => q(ಕಿಮೀ³),
						'one' => q({0} ಕಿಮೀ³),
						'other' => q({0} ಕಿಮೀ³),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'name' => q(ಕಿಮೀ³),
						'one' => q({0} ಕಿಮೀ³),
						'other' => q({0} ಕಿಮೀ³),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'name' => q(ಮೀ³),
						'one' => q({0} ಮೀ³),
						'other' => q({0} ಮೀ³),
						'per' => q({0}/ಮೀ³),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'name' => q(ಮೀ³),
						'one' => q({0} ಮೀ³),
						'other' => q({0} ಮೀ³),
						'per' => q({0}/ಮೀ³),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(ಮೈ³),
						'one' => q({0} ಮೈ³),
						'other' => q({0} ಮೈ³),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(ಮೈ³),
						'one' => q({0} ಮೈ³),
						'other' => q({0} ಮೈ³),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(ಗಜಗಳು³),
						'one' => q({0} ಗಜ³),
						'other' => q({0} ಗಜ³),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(ಗಜಗಳು³),
						'one' => q({0} ಗಜ³),
						'other' => q({0} ಗಜ³),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'name' => q(ಕಪ್‍ಗಳು),
						'one' => q({0} ಕ),
						'other' => q({0} ಕ),
					},
					# Core Unit Identifier
					'cup' => {
						'name' => q(ಕಪ್‍ಗಳು),
						'one' => q({0} ಕ),
						'other' => q({0} ಕ),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'name' => q(ಮೆ.ಕಪ್‌),
						'one' => q({0} ಮೆ.ಕಪ್‌),
						'other' => q({0} ಮೆ.ಕ),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'name' => q(ಮೆ.ಕಪ್‌),
						'one' => q({0} ಮೆ.ಕಪ್‌),
						'other' => q({0} ಮೆ.ಕ),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'name' => q(ಡೆ.ಲೀ),
						'one' => q({0} ಡೆ.ಲೀ),
						'other' => q({0} ಡೆ.ಲೀ),
					},
					# Core Unit Identifier
					'deciliter' => {
						'name' => q(ಡೆ.ಲೀ),
						'one' => q({0} ಡೆ.ಲೀ),
						'other' => q({0} ಡೆ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'name' => q(ಡೆ.ಸ್ಪೂ),
						'one' => q({0} ಡೆ.ಸ್ಪೂ),
						'other' => q({0} ಡೆ.ಸ್ಪೂ),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'name' => q(ಡೆ.ಸ್ಪೂ),
						'one' => q({0} ಡೆ.ಸ್ಪೂ),
						'other' => q({0} ಡೆ.ಸ್ಪೂ),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'name' => q(ಡೆ.ಸ್ಪೂ.ಇಂಪಿ),
						'one' => q({0} ಡೆ.ಸ್ಪೂ.ಇಂಪಿ),
						'other' => q({0} ಡೆ.ಸ್ಪೂ.ಇಂಪಿ),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'name' => q(ಡೆ.ಸ್ಪೂ.ಇಂಪಿ),
						'one' => q({0} ಡೆ.ಸ್ಪೂ.ಇಂಪಿ),
						'other' => q({0} ಡೆ.ಸ್ಪೂ.ಇಂಪಿ),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'name' => q(ಡ್ರಾಮ್ ಫ್ಲೂಡ್),
						'one' => q({0} ಡ್ರಾಮ್ ಫ್ಲೂ),
						'other' => q({0} ಡ್ರಾಮ್.ಫ್ಲೂ),
					},
					# Core Unit Identifier
					'dram' => {
						'name' => q(ಡ್ರಾಮ್ ಫ್ಲೂಡ್),
						'one' => q({0} ಡ್ರಾಮ್ ಫ್ಲೂ),
						'other' => q({0} ಡ್ರಾಮ್.ಫ್ಲೂ),
					},
					# Long Unit Identifier
					'volume-drop' => {
						'name' => q(ಡ್ರಾಪ್),
						'one' => q({0} ಡ್ರಾಪ್),
						'other' => q({0} ಡ್ರಾಪ್),
					},
					# Core Unit Identifier
					'drop' => {
						'name' => q(ಡ್ರಾಪ್),
						'one' => q({0} ಡ್ರಾಪ್),
						'other' => q({0} ಡ್ರಾಪ್),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(ಫ್ಲೂ.ಔ),
						'one' => q({0} ಫ್ಲೂ.ಔ),
						'other' => q({0} ಫ್ಲೂ.ಔ),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(ಫ್ಲೂ.ಔ),
						'one' => q({0} ಫ್ಲೂ.ಔ),
						'other' => q({0} ಫ್ಲೂ.ಔ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(ಇಂಪಿ. ಫ್ಲೂ. ಔ.),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(ಇಂಪಿ. ಫ್ಲೂ. ಔ.),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(ಗ್ಯಾ),
						'one' => q({0} ಗ್ಯಾ),
						'other' => q({0} ಗ್ಯಾ),
						'per' => q({0}/ಗ್ಯಾ ಯುಎಸ್),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(ಗ್ಯಾ),
						'one' => q({0} ಗ್ಯಾ),
						'other' => q({0} ಗ್ಯಾ),
						'per' => q({0}/ಗ್ಯಾ ಯುಎಸ್),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'name' => q(Imp ಗ್ಯಾಲನ್),
						'one' => q({0} Imp ಗ್ಯಾ),
						'other' => q({0} Imp ಗ್ಯಾ),
						'per' => q({0} / Imp ಗ್ಯಾ),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'name' => q(Imp ಗ್ಯಾಲನ್),
						'one' => q({0} Imp ಗ್ಯಾ),
						'other' => q({0} Imp ಗ್ಯಾ),
						'per' => q({0} / Imp ಗ್ಯಾ),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'name' => q(ಹೆ.ಲೀ),
						'one' => q({0} ಹೆ.ಲೀ),
						'other' => q({0} ಹೆ.ಲೀ),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'name' => q(ಹೆ.ಲೀ),
						'one' => q({0} ಹೆ.ಲೀ),
						'other' => q({0} ಹೆ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-jigger' => {
						'name' => q(ಜಿಗರ್),
						'one' => q({0} ಜಿಗರ್),
						'other' => q({0} ಜಿಗರ್),
					},
					# Core Unit Identifier
					'jigger' => {
						'name' => q(ಜಿಗರ್),
						'one' => q({0} ಜಿಗರ್),
						'other' => q({0} ಜಿಗರ್),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'name' => q(ಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಲೀ),
						'other' => q({0} ಲೀ),
						'per' => q({0}/ಲೀ),
					},
					# Core Unit Identifier
					'liter' => {
						'name' => q(ಲೀಟರ್‌ಗಳು),
						'one' => q({0} ಲೀ),
						'other' => q({0} ಲೀ),
						'per' => q({0}/ಲೀ),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'name' => q(ಮೆ.ಲೀ),
						'one' => q({0} ಮೆ.ಲೀ),
						'other' => q({0} ಮೆ.ಲೀ),
					},
					# Core Unit Identifier
					'megaliter' => {
						'name' => q(ಮೆ.ಲೀ),
						'one' => q({0} ಮೆ.ಲೀ),
						'other' => q({0} ಮೆ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'name' => q(ಮಿ.ಲೀ),
						'one' => q({0} ಮಿ.ಲೀ),
						'other' => q({0} ಮಿ.ಲೀ),
					},
					# Core Unit Identifier
					'milliliter' => {
						'name' => q(ಮಿ.ಲೀ),
						'one' => q({0} ಮಿ.ಲೀ),
						'other' => q({0} ಮಿ.ಲೀ),
					},
					# Long Unit Identifier
					'volume-pinch' => {
						'name' => q(ಪಿಂಚ್),
						'one' => q({0} ಪಿಂಚ್),
						'other' => q({0} ಪಿಂಚ್),
					},
					# Core Unit Identifier
					'pinch' => {
						'name' => q(ಪಿಂಚ್),
						'one' => q({0} ಪಿಂಚ್),
						'other' => q({0} ಪಿಂಚ್),
					},
					# Long Unit Identifier
					'volume-pint' => {
						'name' => q(ಪಿಂಟ್‍ಗಳು),
						'one' => q({0} ಪಿಂಟ್‌),
						'other' => q({0} ಪಿಂಟ್‌),
					},
					# Core Unit Identifier
					'pint' => {
						'name' => q(ಪಿಂಟ್‍ಗಳು),
						'one' => q({0} ಪಿಂಟ್‌),
						'other' => q({0} ಪಿಂಟ್‌),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(ಮೆ.ಪಿಂ),
						'one' => q({0} ಮೆ.ಪಿಂ),
						'other' => q({0} ಮೆ.ಪಿಂ),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(ಮೆ.ಪಿಂ),
						'one' => q({0} ಮೆ.ಪಿಂ),
						'other' => q({0} ಮೆ.ಪಿಂ),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'name' => q(ಕಾ.ಭಾ),
						'one' => q({0} ಕಾ.ಭಾ),
						'other' => q({0} ಕಾ.ಭಾ),
					},
					# Core Unit Identifier
					'quart' => {
						'name' => q(ಕಾ.ಭಾ),
						'one' => q({0} ಕಾ.ಭಾ),
						'other' => q({0} ಕಾ.ಭಾ),
					},
					# Long Unit Identifier
					'volume-quart-imperial' => {
						'name' => q(ಕ್ವಾ.ಇಂಪ್),
						'one' => q({0} ಕ್ವಾ.ಇಂಪ್),
						'other' => q({0} ಕ್ವಾ.ಇಂಪ್),
					},
					# Core Unit Identifier
					'quart-imperial' => {
						'name' => q(ಕ್ವಾ.ಇಂಪ್),
						'one' => q({0} ಕ್ವಾ.ಇಂಪ್),
						'other' => q({0} ಕ್ವಾ.ಇಂಪ್),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'name' => q(ಟೇ.ಸ್ಪೂ),
						'one' => q({0} ಟೇ.ಸ್ಪೂ),
						'other' => q({0} ಟೇ.ಸ್ಪೂ),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'name' => q(ಟೇ.ಸ್ಪೂ),
						'one' => q({0} ಟೇ.ಸ್ಪೂ),
						'other' => q({0} ಟೇ.ಸ್ಪೂ),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'name' => q(ಟೀ ಸ್ಪೂ),
						'one' => q({0} ಟೀ ಸ್ಪೂ),
						'other' => q({0} ಟೀ ಸ್ಪೂ),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'name' => q(ಟೀ ಸ್ಪೂ),
						'one' => q({0} ಟೀ ಸ್ಪೂ),
						'other' => q({0} ಟೀ ಸ್ಪೂ),
					},
				},
			} }
);

has 'yesstr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:ಹೌದು|ಹೌ|yes|y)$' }
);

has 'nostr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:ಇಲ್ಲ|ಇ|no|n)$' }
);

has 'listPatterns' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
				end => q({0}, ಮತ್ತು {1}),
				2 => q({0} ಮತ್ತು {1}),
		} }
);

has native_numbering_system => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> 'knda',
);

has 'number_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		decimalFormat => {
			'long' => {
				'1000' => {
					'one' => '0 ಸಾವಿರ',
					'other' => '0 ಸಾವಿರ',
				},
				'10000' => {
					'one' => '00 ಸಾವಿರ',
					'other' => '00 ಸಾವಿರ',
				},
				'100000' => {
					'one' => '000 ಸಾವಿರ',
					'other' => '000 ಸಾವಿರ',
				},
				'1000000' => {
					'one' => '0 ಮಿಲಿಯನ್',
					'other' => '0 ಮಿಲಿಯನ್',
				},
				'10000000' => {
					'one' => '00 ಮಿಲಿಯನ್',
					'other' => '00 ಮಿಲಿಯನ್',
				},
				'100000000' => {
					'one' => '000 ಮಿಲಿಯನ್',
					'other' => '000 ಮಿಲಿಯನ್',
				},
				'1000000000' => {
					'one' => '0 ಬಿಲಿಯನ್',
					'other' => '0 ಬಿಲಿಯನ್',
				},
				'10000000000' => {
					'one' => '00 ಬಿಲಿಯನ್',
					'other' => '00 ಬಿಲಿಯನ್',
				},
				'100000000000' => {
					'one' => '000 ಬಿಲಿಯನ್',
					'other' => '000 ಬಿಲಿಯನ್',
				},
				'1000000000000' => {
					'one' => '0 ಟ್ರಿಲಿಯನ್‌',
					'other' => '0 ಟ್ರಿಲಿಯನ್‌',
				},
				'10000000000000' => {
					'one' => '00 ಟ್ರಿಲಿಯನ್‌',
					'other' => '00 ಟ್ರಿಲಿಯನ್‌',
				},
				'100000000000000' => {
					'one' => '000 ಟ್ರಿಲಿಯನ್‌',
					'other' => '000 ಟ್ರಿಲಿಯನ್‌',
				},
			},
			'short' => {
				'1000' => {
					'one' => '0ಸಾ',
					'other' => '0ಸಾ',
				},
				'10000' => {
					'one' => '00ಸಾ',
					'other' => '00ಸಾ',
				},
				'100000' => {
					'one' => '000ಸಾ',
					'other' => '000ಸಾ',
				},
				'1000000' => {
					'one' => '0ಮಿ',
					'other' => '0ಮಿ',
				},
				'10000000' => {
					'one' => '00ಮಿ',
					'other' => '00ಮಿ',
				},
				'100000000' => {
					'one' => '000ಮಿ',
					'other' => '000ಮಿ',
				},
				'1000000000' => {
					'one' => '0ಬಿ',
					'other' => '0ಬಿ',
				},
				'10000000000' => {
					'one' => '00ಬಿ',
					'other' => '00ಬಿ',
				},
				'100000000000' => {
					'one' => '000ಬಿ',
					'other' => '000ಬಿ',
				},
				'1000000000000' => {
					'one' => '0ಟ್ರಿ',
					'other' => '0ಟ್ರಿ',
				},
				'10000000000000' => {
					'one' => '00ಟ್ರಿ',
					'other' => '00ಟ್ರಿ',
				},
				'100000000000000' => {
					'one' => '000ಟ್ರಿ',
					'other' => '000ಟ್ರಿ',
				},
			},
		},
} },
);

has 'number_currency_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'latn' => {
			'pattern' => {
				'default' => {
					'accounting' => {
						'negative' => '(¤#,##0.00)',
						'positive' => '¤#,##0.00',
					},
					'standard' => {
						'positive' => '¤#,##0.00',
					},
				},
			},
		},
} },
);

has 'currencies' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'AED' => {
			display_name => {
				'currency' => q(ಸಂಯುಕ್ತ ಅರಬ್‌ ಎಮಿರೇಟ್‌‌ಗಳ ದಿರಾಮ್‌‌),
				'one' => q(ಯುಎಇ ದಿರಾಮ್),
				'other' => q(ಯುಎಇ ದಿರಾಮ್‌ಗಳು),
			},
		},
		'AFN' => {
			display_name => {
				'currency' => q(ಅಫ್‌ಘನ್ ಅಫಘಾನಿ),
				'one' => q(ಅಫ್‌ಘನ್ ಅಫಘಾನಿ),
				'other' => q(ಅಫ್‌ಘನ್ ಅಫಘಾನಿಗಳು),
			},
		},
		'ALL' => {
			display_name => {
				'currency' => q(ಅಲ್‌ಬೇನಿಯನ್ ಲೆಕ್),
			},
		},
		'AMD' => {
			display_name => {
				'currency' => q(ಅರ್ಮೆನಿಯನ್ ಡ್ರಾಮ್),
				'one' => q(ಅರ್ಮೆನಿಯನ್ ಡ್ರಾಮ್),
				'other' => q(ಅರ್ಮೆನಿಯನ್ ಡ್ರಾಮ್‌ಗಳು),
			},
		},
		'ANG' => {
			display_name => {
				'currency' => q(ನೆದರ್ಲೆಂಡ್ಸ್ ಆಂಟಿಲಿಯನ್ ಗಿಲ್ಡರ್),
				'one' => q(ನೆದರ್ಲೆಂಡ್ಸ್ ಆಂಟಿಲಿಯನ್ ಗಿಲ್ಡರ್),
				'other' => q(ನೆದರ್ಲೆಂಡ್ಸ್ ಆಂಟಿಲಿಯನ್ ಗಿಲ್ಡರ್‌ಗಳು),
			},
		},
		'AOA' => {
			display_name => {
				'currency' => q(ಅಂಗೋಲಾದ ಕ್ವಾನ್ಝಾ),
				'one' => q(ಅಂಗೋಲಾದ ಕ್ವಾನ್ಝಾ),
				'other' => q(ಅಂಗೋಲಾದ ಕ್ವಾನ್ಝಾಗಳು),
			},
		},
		'ARS' => {
			display_name => {
				'currency' => q(ಅರ್ಜೆಂಟಿನಾ ಪೆಸೊ),
				'one' => q(ಅರ್ಜೆಂಟಿನಾ ಪೆಸೊ),
				'other' => q(ಅರ್ಜೆಂಟಿನಾ ಪೆಸೊಗಳು),
			},
		},
		'AUD' => {
			display_name => {
				'currency' => q(ಆಸ್ಟ್ರೇಲಿಯನ್ ಡಾಲರ್‌),
				'one' => q(ಆಸ್ಟ್ರೇಲಿಯನ್ ಡಾಲರ್‌),
				'other' => q(ಆಸ್ಟ್ರೇಲಿಯನ್ ಡಾಲರ್‌‌ಗಳು),
			},
		},
		'AWG' => {
			display_name => {
				'currency' => q(ಅರುಬನ್ ಫ್ಲೊರೀನ್‌‌),
			},
		},
		'AZN' => {
			display_name => {
				'currency' => q(ಅಝರ್‌ಬೈಜಾನಿ ಮನಾತ್),
				'one' => q(ಅಝರ್‌ಬೈಜಾನಿ ಮನಾತ್),
				'other' => q(ಅಝರ್‌ಬೈಜಾನಿ ಮನಾತ್‌ಗಳು),
			},
		},
		'BAM' => {
			display_name => {
				'currency' => q(ಬೋಸ್ನಿಯಾ-ಹರ್ಜ್‌ಗೋವಿನ ಪರಿವರ್ತನೀಯ ಗುರುತು),
				'one' => q(ಬೋಸ್ನಿಯಾ-ಹರ್ಜ್‌ಗೋವಿನ ಪರಿವರ್ತನೀಯ ಗುರುತು),
				'other' => q(ಬೋಸ್ನಿಯಾ-ಹರ್ಜ್‌ಗೋವಿನ ಪರಿವರ್ತನೀಯ ಗುರುತುಗಳು),
			},
		},
		'BBD' => {
			display_name => {
				'currency' => q(ಬರ್ಬಾಡಿಯನ್ ಡಾಲರ್),
				'one' => q(ಬರ್ಬಾಡಿಯನ್ ಡಾಲರ್),
				'other' => q(ಬರ್ಬಾಡಿಯನ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'BDT' => {
			display_name => {
				'currency' => q(ಬಾಂಗ್ಲಾದೇಶದ ಟಾಕಾ),
				'one' => q(ಬಾಂಗ್ಲಾದೇಶದ ಟಾಕಾ),
				'other' => q(ಬಾಂಗ್ಲಾದೇಶದ ಟಾಕಾಗಳು),
			},
		},
		'BGN' => {
			display_name => {
				'currency' => q(ಬಲ್ಗೇರಿಯನ್ ಲೆವ್),
				'one' => q(ಬಲ್ಗೇರಿಯನ್ ಲೆವ್),
				'other' => q(ಬಲ್ಗೇರಿಯನ್ ಲೀವಾ),
			},
		},
		'BHD' => {
			display_name => {
				'currency' => q(ಬಹ್‌‌ರೈನಿ ದಿನಾರ್),
				'one' => q(ಬಹ್‌‌ರೈನಿ ದಿನಾರ್),
				'other' => q(ಬಹ್‌‌ರೈನಿ ದಿನಾರ್‌ಗಳು),
			},
		},
		'BIF' => {
			display_name => {
				'currency' => q(ಬುರುಂದಿಯನ್ ಫ್ರಾಂಕ್),
				'one' => q(ಬುರುಂದಿಯನ್ ಫ್ರಾಂಕ್),
				'other' => q(ಬುರುಂದಿಯನ್ ಫ್ರಾಂಕ್‍ಗಳು),
			},
		},
		'BMD' => {
			display_name => {
				'currency' => q(ಬರ್ಮುಡನ್ ಡಾಲರ್),
				'one' => q(ಬರ್ಮುಡನ್ ಡಾಲರ್),
				'other' => q(ಬರ್ಮುಡನ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'BND' => {
			display_name => {
				'currency' => q(ಬ್ರೂನಿ ಡಾಲರ್),
				'one' => q(ಬ್ರೂನಿ ಡಾಲರ್),
				'other' => q(ಬ್ರೂನಿ ಡಾಲರ್‌ಗಳು),
			},
		},
		'BOB' => {
			display_name => {
				'currency' => q(ಬೊಲಿವಿಯಾದ ಬೊಲಿವಿಯಾನೊ),
				'one' => q(ಬೊಲಿವಿಯಾದ ಬೊಲಿವಿಯಾನೊ),
				'other' => q(ಬೊಲಿವಿಯಾದ ಬೊಲಿವಿಯಾನೊಗಳು),
			},
		},
		'BRL' => {
			display_name => {
				'currency' => q(ಬ್ರೆಜಿಲಿಯನ್‌ ರಿಯಲ್),
				'one' => q(ಬ್ರೆಜಿಲಿಯನ್‌ ರಿಯಲ್),
				'other' => q(ಬ್ರೆಜಿಲಿಯನ್ ರಿಯಲ್‍ಗಳು),
			},
		},
		'BSD' => {
			display_name => {
				'currency' => q(ಬಹಾಮಿಯನ್ ಡಾಲರ್),
				'one' => q(ಬಹಾಮಿಯನ್ ಡಾಲರ್),
				'other' => q(ಬಹಾಮಿಯನ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'BTN' => {
			display_name => {
				'currency' => q(ಭೂತಾನೀಸ್ ನುಲ್ತರಮ್),
				'one' => q(ಭೂತಾನೀಸ್ ನುಲ್ತರಮ್),
				'other' => q(ಭೂತಾನೀಸ್ ನುಲ್ತರಮ್‌ಗಳು),
			},
		},
		'BWP' => {
			display_name => {
				'currency' => q(ಬೋಟ್ಸ್‌ವಾನನ್ ಪುಲಾ),
				'one' => q(ಬೋಟ್ಸ್‌ವಾನನ್ ಪುಲಾ),
				'other' => q(ಬೋಟ್ಸ್‌ವಾನನ್ ಪುಲಾಗಳು),
			},
		},
		'BYN' => {
			symbol => 'р.',
			display_name => {
				'currency' => q(ಬೆಲಾರುಸಿಯನ್ ರೂಬಲ್),
				'one' => q(ಬೆಲಾರುಸಿಯನ್ ರೂಬಲ್),
				'other' => q(ಬೆಲಾರುಸಿಯನ್ ರೂಬಲ್‍ಗಳು),
			},
		},
		'BYR' => {
			display_name => {
				'currency' => q(ಬೆಲಾರುಸಿಯನ್ ರೂಬಲ್ \(2000–2016\)),
				'one' => q(ಬೆಲಾರುಸಿಯನ್ ರೂಬಲ್ \(2000–2016\)),
				'other' => q(ಬೆಲಾರುಸಿಯನ್ ರೂಬಲ್‍ಗಳು \(2000–2016\)),
			},
		},
		'BZD' => {
			display_name => {
				'currency' => q(ಬೆಲೀಜ್ ಡಾಲರ್),
				'one' => q(ಬೆಲೀಜ್ ಡಾಲರ್),
				'other' => q(ಬೆಲೀಜ್ ಡಾಲರ್‌‍ಗಳು),
			},
		},
		'CAD' => {
			display_name => {
				'currency' => q(ಕೆನಡಾದ ಡಾಲರ್),
				'one' => q(ಕೆನಡಾದ ಡಾಲರ್),
				'other' => q(ಕೆನಡಾದ ಡಾಲರ್‌ಗಳು),
			},
		},
		'CDF' => {
			display_name => {
				'currency' => q(ಕಾಂಗೋಲೀಸ್ ಫ್ರಾಂಕ್),
				'one' => q(ಕಾಂಗೋಲೀಸ್ ಫ್ರಾಂಕ್),
				'other' => q(ಕಾಂಗೋಲೀಸ್ ಫ್ರಾಂಕ್‍‌ಗಳು),
			},
		},
		'CHF' => {
			display_name => {
				'currency' => q(ಸ್ವಿಸ್ ಫ್ರಾಂಕ್),
				'one' => q(ಸ್ವಿಸ್ ಫ್ರಾಂಕ್),
				'other' => q(ಸ್ವಿಸ್ ಫ್ರಾಂಕ್‍ಗಳು),
			},
		},
		'CLP' => {
			display_name => {
				'currency' => q(ಚಿಲಿಯ ಪೆಸೊ),
				'one' => q(ಚಿಲಿಯ ಪೆಸೊ),
				'other' => q(ಚಿಲಿಯ ಪೆಸೊಗಳು),
			},
		},
		'CNH' => {
			display_name => {
				'currency' => q(ಚೈನೀಸ್ ಯುವಾನ್ \(ಆಫ್‌ಶೋರ್\)),
			},
		},
		'CNY' => {
			display_name => {
				'currency' => q(ಚೈನೀಸ್ ಯುವಾನ್),
			},
		},
		'COP' => {
			display_name => {
				'currency' => q(ಕೊಲೊಂಬಿಯೋದ ಪೆಸೊ),
				'one' => q(ಕೊಲೊಂಬಿಯೋದ ಪೆಸೊ),
				'other' => q(ಕೊಲೊಂಬಿಯೋದ ಪೆಸೊಗಳು),
			},
		},
		'CRC' => {
			display_name => {
				'currency' => q(ಕೋಸ್ಟ ರಿಕನ್ ಕೊಲನ್),
				'one' => q(ಕೋಸ್ಟಾ ರಿಕಾದ ಕೊಲೊನ್‌),
				'other' => q(ಕೋಸ್ಟಾ ರಿಕಾದ ಕೊಲೊನ್‌ಗಳು),
			},
		},
		'CUC' => {
			display_name => {
				'currency' => q(ಕ್ಯುಬಾದ ಪರಿವರ್ತನೀಯ ಪೆಸೊ),
				'one' => q(ಕ್ಯೂಬಾದ ಪರಿವರ್ತನೀಯ ಪೆಸೊ),
				'other' => q(ಕ್ಯೂಬಾದ ಪರಿವರ್ತನೀಯ ಪೆಸೊಗಳು),
			},
		},
		'CUP' => {
			display_name => {
				'currency' => q(ಕ್ಯೂಬಾದ ಪೆಸೊ),
				'one' => q(ಕ್ಯೂಬಾದ ಪೆಸೊ),
				'other' => q(ಕ್ಯೂಬಾದ ಪೆಸೊಗಳು),
			},
		},
		'CVE' => {
			display_name => {
				'currency' => q(ಕೇಪ್ ವರ್ಡಿನ್ ಎಸ್‌ಕೂಡೊ),
				'one' => q(ಕೇಪ್ ವರ್ಡಿನ್ ಎಸ್‌ಕೂಡೊ),
				'other' => q(ಕೇಪ್ ವರ್ಡಿನ್ ಎಸ್‌ಕೂಡೊಗಳು),
			},
		},
		'CZK' => {
			display_name => {
				'currency' => q(ಝೆಕ್ ಗಣರಾಜ್ಯ ಕೊರೂನ),
				'one' => q(ಝೆಕ್ ಗಣರಾಜ್ಯ ಕೊರೂನ),
				'other' => q(ಝೆಕ್ ಗಣರಾಜ್ಯ ಕೊರೂನಗಳು),
			},
		},
		'DJF' => {
			display_name => {
				'currency' => q(ಜಿಬೊಟಿಯನ್ ಫ್ರಾಂಕ್),
				'one' => q(ಜಿಬೊಟಿಯನ್ ಫ್ರಾಂಕ್),
				'other' => q(ಜಿಬೊಟಿಯನ್ ಫ್ರಾಂಕ್‍ಗಳು),
			},
		},
		'DKK' => {
			display_name => {
				'currency' => q(ಡ್ಯಾನಿಶ್ ಕ್ರೋನ್),
				'one' => q(ಡ್ಯಾನಿಶ್ ಕ್ರೋನ್),
				'other' => q(ಡ್ಯಾನಿಶ್ ಕ್ರೋನರ್),
			},
		},
		'DOP' => {
			display_name => {
				'currency' => q(ಡೊಮಿನಿಕನ್ ಪೆಸೊ),
				'one' => q(ಡೊಮಿನಿಕನ್ ಪೆಸೊ),
				'other' => q(ಡೊಮಿನಿಕನ್ ಪೆಸೊಗಳು),
			},
		},
		'DZD' => {
			display_name => {
				'currency' => q(ಅಲ್ಜೀರಿಯನ್ ದಿನಾರ್),
				'one' => q(ಅಲ್ಜೀರಿಯನ್ ದಿನಾರ್),
				'other' => q(ಅಲ್ಜೀರಿಯನ್ ದಿನಾರ್‌ಗಳು),
			},
		},
		'EGP' => {
			display_name => {
				'currency' => q(ಈಜಿಪ್ಷಿಯನ್ ಪೌಂಡ್‍),
				'one' => q(ಈಜಿಪ್ಷಿಯನ್ ಪೌಂಡ್‍),
				'other' => q(ಈಜಿಪ್ಷಿಯನ್ ಪೌಂಡ್‍ಗಳು),
			},
		},
		'ERN' => {
			display_name => {
				'currency' => q(ಎರಿತ್ರಿಯನ್ ನಕ್ಫಾ),
				'one' => q(ಎರಿತ್ರಿಯನ್ ನಕ್ಫಾ),
				'other' => q(ಎರಿತ್ರಿಯನ್ ನಕ್ಫಾಗಳು),
			},
		},
		'ETB' => {
			display_name => {
				'currency' => q(ಇಥಿಯೋಪಿಯನ್ ಬಿರ್),
				'one' => q(ಇಥಿಯೋಪಿಯನ್ ಬಿರ್),
				'other' => q(ಇಥಿಯೋಪಿಯನ್ ಬಿರ್‌ಗಳು),
			},
		},
		'EUR' => {
			display_name => {
				'currency' => q(ಯೂರೊ),
				'one' => q(ಯೂರೊ),
				'other' => q(ಯೂರೊಗಳು),
			},
		},
		'FJD' => {
			display_name => {
				'currency' => q(ಫಿಜಿಯನ್ ಡಾಲರ್),
				'one' => q(ಫಿಜಿಯನ್ ಡಾಲರ್),
				'other' => q(ಫಿಜಿಯನ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'FKP' => {
			display_name => {
				'currency' => q(ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳ ಪೌಂಡ್),
				'one' => q(ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳ ಪೌಂಡ್),
				'other' => q(ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳ ಪೌಂಡ್‍ಗಳು),
			},
		},
		'GBP' => {
			display_name => {
				'currency' => q(ಬ್ರಿಟಿಷ್ ಪೌಂಡ್),
				'one' => q(ಬ್ರಿಟಿಷ್ ಪೌಂಡ್),
				'other' => q(ಬ್ರಿಟಿಷ್ ಪೌಂಡ್‍ಗಳು),
			},
		},
		'GEL' => {
			display_name => {
				'currency' => q(ಜಾರ್ಜಿಯಾದ ಲಾರಿ),
				'one' => q(ಜಾರ್ಜಿಯಾದ ಲಾರಿ),
				'other' => q(ಜಾರ್ಜಿಯಾದ ಲಾರಿಗಳು),
			},
		},
		'GHS' => {
			display_name => {
				'currency' => q(ಘಾನಾದ ಸೆದಿ),
				'one' => q(ಘಾನಾದ ಸೆದಿ),
				'other' => q(ಘಾನಾದ ಸೆದಿಗಳು),
			},
		},
		'GIP' => {
			display_name => {
				'currency' => q(ಗಿಬ್ರಾಲ್ಟರ್ ಪೌಂಡ್),
				'one' => q(ಗಿಬ್ರಾಲ್ಟರ್ ಪೌಂಡ್),
				'other' => q(ಗಿಬ್ರಾಲ್ಟರ್ ಪೌಂಡ್‍ಗಳು),
			},
		},
		'GMD' => {
			display_name => {
				'currency' => q(ಗ್ಯಾಂಬಿಯಾದ ದಲಾಸಿ),
				'one' => q(ಗ್ಯಾಂಬಿಯಾದ ದಲಾಸಿ),
				'other' => q(ಗ್ಯಾಂಬಿಯಾದ ದಲಾಸಿಗಳು),
			},
		},
		'GNF' => {
			display_name => {
				'currency' => q(ಗಿನಿಯನ್ ಫ್ರಾಂಕ್),
				'one' => q(ಗಿನಿಯನ್ ಫ್ರಾಂಕ್),
				'other' => q(ಗಿನಿಯನ್ ಫ್ರಾಂಕ್‌ಗಳು),
			},
		},
		'GTQ' => {
			display_name => {
				'currency' => q(ಗ್ವಾಟೆಮಾಲಾದ ಕುಯಿಟ್ಸಲ್‌‌),
				'one' => q(ಗ್ವಾಟೆಮಾಲಾದ ಕುಯಿಟ್ಸಲ್‌‌),
				'other' => q(ಗ್ವಾಟೆಮಾಲಾದ ಕುಯಿಟ್ಸಲ್‌‌‍ಗಳು),
			},
		},
		'GYD' => {
			display_name => {
				'currency' => q(ಗುಯಾನೀಸ್‌ ಡಾಲರ್‌),
				'one' => q(ಗುಯಾನೀಸ್‌ ಡಾಲರ್‌),
				'other' => q(ಗುಯಾನೀಸ್‌ ಡಾಲರ್‌‌ಗಳು),
			},
		},
		'HKD' => {
			display_name => {
				'currency' => q(ಹಾಂಗ್ ಕಾಂಗ್ ಡಾಲರ್),
				'one' => q(ಹಾಂಗ್ ಕಾಂಗ್ ಡಾಲರ್),
				'other' => q(ಹಾಂಗ್ ಕಾಂಗ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'HNL' => {
			display_name => {
				'currency' => q(ಹೊಂಡುರಾನ್‌ ಲೆಂಪಿರಾ),
				'one' => q(ಹೊಂಡುರಾನ್‌ ಲೆಂಪಿರಾ),
				'other' => q(ಹೊಂಡುರಾನ್‌ ಲೆಂಪಿರಾಗಳು),
			},
		},
		'HRK' => {
			display_name => {
				'currency' => q(ಕ್ರೊಯೆಷ್ಯಾದ ಕೂನಾ),
				'one' => q(ಕ್ರೊಯೆಷ್ಯಾದ ಕೂನಾ),
				'other' => q(ಕ್ರೊಯೆಷ್ಯಾದ ಕೂನಾಗಳು),
			},
		},
		'HTG' => {
			display_name => {
				'currency' => q(ಹೈಟಿಯ ಗೋರ್ದೆ),
				'one' => q(ಹೈಟಿಯ ಗೋರ್ದೆ),
				'other' => q(ಹೈಟಿಯ ಗೋರ್ದೆಗಳು),
			},
		},
		'HUF' => {
			display_name => {
				'currency' => q(ಹಂಗೇರಿಯನ್ ಫೋರಿಂಟ್),
				'one' => q(ಹಂಗೇರಿಯನ್ ಫೋರಿಂಟ್),
				'other' => q(ಹಂಗೇರಿಯನ್ ಫೋರಿಂಟ್‍ಗಳು),
			},
		},
		'IDR' => {
			display_name => {
				'currency' => q(ಇಂಡೊನೇಷ್ಯಾ ರುಪೈ),
			},
		},
		'ILS' => {
			display_name => {
				'currency' => q(ಇಸ್ರೇಲಿ ನ್ಯೂ ಶೇಖಲ್),
				'one' => q(ಇಸ್ರೇಲಿ ನ್ಯೂ ಶೇಖಲ್),
				'other' => q(ಇಸ್ರೇಲಿ ನ್ಯೂ ಶೇಖಲ್‍ಗಳು),
			},
		},
		'INR' => {
			display_name => {
				'currency' => q(ಭಾರತೀಯ ರೂಪಾಯಿ),
				'one' => q(ಭಾರತೀಯ ರೂಪಾಯಿ),
				'other' => q(ಭಾರತೀಯ ರೂಪಾಯಿಗಳು),
			},
		},
		'IQD' => {
			display_name => {
				'currency' => q(ಇರಾಕಿ ದಿನಾರ್),
				'one' => q(ಇರಾಕಿ ದಿನಾರ್),
				'other' => q(ಇರಾಕಿ ದಿನಾರ್‌ಗಳು),
			},
		},
		'IRR' => {
			display_name => {
				'currency' => q(ಇರಾನಿಯನ್ ರಿಯಲ್),
				'one' => q(ಇರಾನಿಯನ್ ರಿಯಲ್),
				'other' => q(ಇರಾನಿಯನ್ ರಿಯಲ್‌ಗಳು),
			},
		},
		'ISK' => {
			display_name => {
				'currency' => q(ಐಸ್‌ಲ್ಯಾಂಡಿಕ್ ಕ್ರೋನಾ),
			},
		},
		'JMD' => {
			display_name => {
				'currency' => q(ಜಮೈಕನ್ ಡಾಲರ್),
				'one' => q(ಜಮೈಕನ್ ಡಾಲರ್),
				'other' => q(ಜಮೈಕನ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'JOD' => {
			display_name => {
				'currency' => q(ಜೋರ್ಡಾನಿಯನ್ ದಿನಾರ್),
				'one' => q(ಜೋರ್ಡಾನಿಯನ್ ದಿನಾರ್),
				'other' => q(ಜೋರ್ಡಾನಿಯನ್ ದಿನಾರ್‌ಗಳು),
			},
		},
		'JPY' => {
			display_name => {
				'currency' => q(ಜಪಾನೀಸ್ ಯೆನ್),
			},
		},
		'KES' => {
			display_name => {
				'currency' => q(ಕೀನ್ಯಾದ ಶಿಲ್ಲಿಂಗ್‌),
				'one' => q(ಕೀನ್ಯಾದ ಶಿಲ್ಲಿಂಗ್‌),
				'other' => q(ಕೀನ್ಯಾದ ಶಿಲ್ಲಿಂಗ್‌ಗಳು),
			},
		},
		'KGS' => {
			display_name => {
				'currency' => q(ಕಿರ್ಗಿಸ್ತಾನಿ ಸೋಮ್),
			},
		},
		'KHR' => {
			display_name => {
				'currency' => q(ಕಾಂಬೋಡಿಯನ್ ರಿಯಲ್),
				'one' => q(ಕಾಂಬೋಡಿಯನ್ ರಿಯಲ್),
				'other' => q(ಕಾಂಬೋಡಿಯನ್ ರಿಯಲ್‍ಗಳು),
			},
		},
		'KMF' => {
			display_name => {
				'currency' => q(ಕೊಮೊರಿಯನ್ ಫ್ರಾಂಕ್),
				'one' => q(ಕೊಮೊರಿಯನ್ ಫ್ರಾಂಕ್),
				'other' => q(ಕೊಮೊರಿಯನ್ ಫ್ರಾಂಕ್‍ಗಳು),
			},
		},
		'KPW' => {
			display_name => {
				'currency' => q(ಉತ್ತರ ಕೊರಿಯನ್ ವೋನ್),
			},
		},
		'KRW' => {
			display_name => {
				'currency' => q(ದಕ್ಷಿಣ ಕೊರಿಯನ್ ವೊನ್),
			},
		},
		'KWD' => {
			display_name => {
				'currency' => q(ಕುವೈತೀ ದಿನಾರ್),
				'one' => q(ಕುವೈತೀ ದಿನಾರ್),
				'other' => q(ಕುವೈತೀ ದಿನಾರ್‌ಗಳು),
			},
		},
		'KYD' => {
			display_name => {
				'currency' => q(ಕೆಮ್ಯಾನ್‌ ಐಲ್ಯಾಂಡ್‌ನ ಡಾಲರ್‌),
				'one' => q(ಕೆಮ್ಯಾನ್‌ ಐಲ್ಯಾಂಡ್‌ನ ಡಾಲರ್‌),
				'other' => q(ಕೆಮ್ಯಾನ್‌ ಐಲ್ಯಾಂಡ್‌ನ ಡಾಲರ್‌‌ಗಳು),
			},
		},
		'KZT' => {
			display_name => {
				'currency' => q(ಕಜಾಕಿಸ್ತಾನಿ ತೆಂಗೆ),
				'one' => q(ಕಜಾಕಿಸ್ತಾನಿ ತೆಂಗೆ),
				'other' => q(ಕಜಾಕಿಸ್ತಾನಿ ತೆಂಗೆಗಳು),
			},
		},
		'LAK' => {
			display_name => {
				'currency' => q(ಲೋಟಿಯನ್ ಕಿಪ್),
				'one' => q(ಲೋಟಿಯನ್ ಕಿಪ್),
				'other' => q(ಲೋಟಿಯನ್ ಕಿಪ್‍ಗಳು),
			},
		},
		'LBP' => {
			display_name => {
				'currency' => q(ಲೆಬೆನೀಸ್ ಪೌಂಡ್),
				'one' => q(ಲೆಬೆನೀಸ್ ಪೌಂಡ್),
				'other' => q(ಲೆಬೆನೀಸ್ ಪೌಂಡ್‍ಗಳು),
			},
		},
		'LKR' => {
			display_name => {
				'currency' => q(ಶ್ರೀಲಂಕಾದ ರುಪೀ),
				'one' => q(ಶ್ರೀಲಂಕಾದ ರುಪೀ),
				'other' => q(ಶ್ರೀಲಂಕಾದ ರುಪೀಗಳು),
			},
		},
		'LRD' => {
			display_name => {
				'currency' => q(ಲಿಬೇರಿಯನ್ ಡಾಲರ್),
				'one' => q(ಲಿಬೇರಿಯನ್ ಡಾಲರ್),
				'other' => q(ಲಿಬೇರಿಯನ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'LSL' => {
			display_name => {
				'currency' => q(ಲೆಸೊತೊ ಲೊತಿ),
				'one' => q(ಲೆಸೊತೊ ಲೊತಿ),
				'other' => q(ಲೆಸೊತೊ ಲೊತಿಗಳು),
			},
		},
		'LTL' => {
			display_name => {
				'currency' => q(ಲಿಥುನಿಯನ್‌ ಲಿತಾಸ್‌),
				'one' => q(ಲಿಥುನಿಯನ್‌ ಲಿತಾಸ್‌),
				'other' => q(ಲಿಥುನಿಯನ್‌ ಲಿತಾಯ್),
			},
		},
		'LVL' => {
			display_name => {
				'currency' => q(ಲ್ಯಾಟ್ವಿಯನ್ ಲ್ಯಾಟ್ಸ್),
				'one' => q(ಲ್ಯಾಟ್ವಿಯನ್ ಲ್ಯಾಟ್ಸ್),
				'other' => q(ಲ್ಯಾಟ್ವಿಯನ್ ಲ್ಯಾಟಿ),
			},
		},
		'LYD' => {
			display_name => {
				'currency' => q(ಲಿಬಿಯಾದ ದಿನಾರ್‌),
				'one' => q(ಲಿಬಿಯಾದ ದಿನಾರ್‌),
				'other' => q(ಲಿಬಿಯಾದ ದಿನಾರ್‌‍ಗಳು),
			},
		},
		'MAD' => {
			display_name => {
				'currency' => q(ಮೊರೊಕನ್ ದಿರ್‌ಹಮ್),
				'one' => q(ಮೊರೊಕನ್ ದಿರ್‌ಹಮ್),
				'other' => q(ಮೊರೊಕನ್ ದಿರ್‌ಹಮ್‌ಗಳು),
			},
		},
		'MDL' => {
			display_name => {
				'currency' => q(ಮಲ್ದೋವಾದ ಲೆವೂ),
				'one' => q(ಮಲ್ದೋವಾದ ಲೆವೂ),
				'other' => q(ಮಲ್ದೋವಾದ ಲೆಯ್),
			},
		},
		'MGA' => {
			display_name => {
				'currency' => q(ಮಲಗಾಸಿ ಅರಿಯಾರಿ),
				'one' => q(ಮಲಗಾಸಿ ಅರಿಯಾರಿ),
				'other' => q(ಮಲಗಾಸಿ ಅರಿಯಾರಿಗಳು),
			},
		},
		'MKD' => {
			display_name => {
				'currency' => q(ಮೆಸಡೋನಿಯನ್ ದಿನಾರ್),
				'one' => q(ಮೆಸಡೋನಿಯನ್ ದಿನಾರ್),
				'other' => q(ಮೆಸಡೋನಿಯನ್ ದಿನಾರಿ),
			},
		},
		'MMK' => {
			display_name => {
				'currency' => q(ಮ್ಯಾನ್ಮಾರ್ ಕ್ಯಾಟ್),
				'one' => q(ಮ್ಯಾನ್ಮಾರ್ ಕ್ಯಾಟ್),
				'other' => q(ಮ್ಯಾನ್ಮಾರ್ ಕ್ಯಾಟ್‍ಗಳು),
			},
		},
		'MNT' => {
			display_name => {
				'currency' => q(ಮಂಗೋಲಿಯಾದ ತುಗ್ರಿಕ್‌‌),
				'one' => q(ಮಂಗೋಲಿಯಾದ ತುಗ್ರಿಕ್‌‌),
				'other' => q(ಮಂಗೋಲಿಯಾದ ತುಗ್ರಿಕ್‌‌‌ಗಳು),
			},
		},
		'MOP' => {
			display_name => {
				'currency' => q(ಮಕಾನಿಸ್ ಪಟಾಕಾ),
				'one' => q(ಮಕಾನಿಸ್ ಪಟಾಕಾ),
				'other' => q(ಮಕಾನಿಸ್ ಪಟಾಕಾಗಳು),
			},
		},
		'MRO' => {
			display_name => {
				'currency' => q(ಮೌರೀಶಿಯನಿಯನ್ ಒಗಿಯ \(1973–2017\)),
				'one' => q(ಮೌರೀಶಿಯನಿಯನ್ ಒಗಿಯ \(1973–2017\)),
				'other' => q(ಮೌರೀಶಿಯನಿಯನ್ ಒಗಿಯಗಳು \(1973–2017\)),
			},
		},
		'MRU' => {
			display_name => {
				'currency' => q(ಮೌರೀಶಿಯನಿಯನ್ ಒಗಿಯ),
				'one' => q(ಮೌರೀಶಿಯನಿಯನ್ ಒಗಿಯ),
				'other' => q(ಮೌರೀಶಿಯನಿಯನ್ ಒಗಿಯಗಳು),
			},
		},
		'MUR' => {
			display_name => {
				'currency' => q(ಮಾರಿಷಿಯನ್ ರುಪಿ),
				'one' => q(ಮಾರಿಷಿಯನ್ ರುಪಿ),
				'other' => q(ಮಾರಿಷಿಯನ್ ರುಪಿಗಳು),
			},
		},
		'MVR' => {
			display_name => {
				'currency' => q(ಮಾಲ್ಡೀವಿಯನ್ ರುಫಿಯಾ),
				'one' => q(ಮಾಲ್ಡೀವಿಯನ್ ರುಫಿಯಾ),
				'other' => q(ಮಾಲ್ಡೀವಿಯನ್ ರುಫಿಯಾಗಳು),
			},
		},
		'MWK' => {
			display_name => {
				'currency' => q(ಮಲಾವಿಯ ಕ್ವಾಚ),
				'one' => q(ಮಲಾವಿಯ ಕ್ವಾಚ),
				'other' => q(ಮಲಾವಿಯ ಕ್ವಾಚಗಳು),
			},
		},
		'MXN' => {
			display_name => {
				'currency' => q(ಮೆಕ್ಸಿಕೊದ ಪೆಸೊ),
				'one' => q(ಮೆಕ್ಸಿಕೊದ ಪೆಸೊ),
				'other' => q(ಮೆಕ್ಸಿಕೊದ ಪೆಸೊಗಳು),
			},
		},
		'MYR' => {
			display_name => {
				'currency' => q(ಮಲೇಶಿಯನ್ ರಿಂಗಿಟ್),
				'one' => q(ಮಲೇಶಿಯನ್ ರಿಂಗಿಟ್),
				'other' => q(ಮಲೇಶಿಯನ್ ರಿಂಗಿಟ್‌ಗಳು),
			},
		},
		'MZN' => {
			display_name => {
				'currency' => q(ಮೊಝಾಂಬಿಕನ್ ಮೆಟಿಕಲ್),
				'one' => q(ಮೊಝಾಂಬಿಕನ್ ಮೆಟಿಕಲ್),
				'other' => q(ಮೊಝಾಂಬಿಕನ್ ಮೆಟಿಕಲ್‍ಗಳು),
			},
		},
		'NAD' => {
			display_name => {
				'currency' => q(ನಮೀಬಿಯನ್ ಡಾಲರ್),
				'one' => q(ನಮೀಬಿಯನ್ ಡಾಲರ್),
				'other' => q(ನಮೀಬಿಯನ್ ಡಾಲರ್‌‍ಗಳು),
			},
		},
		'NGN' => {
			display_name => {
				'currency' => q(ನೈಜೀರಿಯಾದ ನೇರಾ),
				'one' => q(ನೈಜೀರಿಯಾದ ನೇರಾ),
				'other' => q(ನೈಜೀರಿಯಾದ ನೇರಾಗಳು),
			},
		},
		'NIO' => {
			display_name => {
				'currency' => q(ನಿಕಾರಗ್ವಾದ ಕರ್ದೊಬಾ),
				'one' => q(ನಿಕಾರಗ್ವಾದ ಕರ್ದೊಬಾ),
				'other' => q(ನಿಕಾರಗ್ವಾದ ಕರ್ದೊಬಾಗಳು),
			},
		},
		'NOK' => {
			display_name => {
				'currency' => q(ನಾರ್ವೇಯ ಕ್ರೋನ್),
				'one' => q(ನಾರ್ವೇಯ ಕ್ರೋನ್),
				'other' => q(ನಾರ್ವೇಯ ಕ್ರೋನರ್),
			},
		},
		'NPR' => {
			display_name => {
				'currency' => q(ನೇಪಾಳದ ರುಪೀ),
				'one' => q(ನೇಪಾಳದ ರುಪೀ),
				'other' => q(ನೇಪಾಳದ ರುಪೀಗಳು),
			},
		},
		'NZD' => {
			display_name => {
				'currency' => q(ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಡಾಲರ್),
				'one' => q(ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಡಾಲರ್),
				'other' => q(ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'OMR' => {
			display_name => {
				'currency' => q(ಒಮಾನಿ ರಿಯಲ್),
				'one' => q(ಒಮಾನಿ ರಿಯಲ್),
				'other' => q(ಒಮಾನಿ ರಿಯಲ್‍ಗಳು),
			},
		},
		'PAB' => {
			display_name => {
				'currency' => q(ಪನಾಮಾನಿಯನ್ ಬಲ್ಬೋವಾ),
				'one' => q(ಪನಾಮಾನಿಯನ್ ಬಲ್ಬೋವಾ),
				'other' => q(ಪನಾಮಾನಿಯನ್ ಬಲ್ಬೋವಾಗಳು),
			},
		},
		'PEN' => {
			display_name => {
				'currency' => q(ಪೆರುವಿಯನ್ ಸೊಲ್),
				'one' => q(ಪೆರುವಿಯನ್ ಸೊಲ್),
				'other' => q(ಪೆರುವಿಯನ್ ಸೊಲ್‍ಗಳು),
			},
		},
		'PGK' => {
			display_name => {
				'currency' => q(ಪಪುವಾ ನ್ಯೂ ಗಿನಿಯನ್ ಕಿನಾ),
			},
		},
		'PHP' => {
			symbol => 'PHP',
			display_name => {
				'currency' => q(ಫಿಲಿಪ್ಪೈನ್ ಪಿಸೊ),
				'one' => q(ಫಿಲಿಪ್ಪೈನ್ ಪಿಸೊ),
				'other' => q(ಫಿಲಿಪ್ಪೈನ್ ಪಿಸೊಗಳು),
			},
		},
		'PKR' => {
			display_name => {
				'currency' => q(ಪಾಕಿಸ್ತಾನದ ರುಪೀ),
				'one' => q(ಪಾಕಿಸ್ತಾನದ ರುಪೀ),
				'other' => q(ಪಾಕಿಸ್ತಾನದ ರುಪೀಗಳು),
			},
		},
		'PLN' => {
			display_name => {
				'currency' => q(ಪೊಲಿಶ್ ಝ್ಲೋಟಿ),
				'one' => q(ಪೊಲಿಶ್ ಝ್ಲೋಟಿ),
				'other' => q(ಪೊಲಿಶ್ ಝ್ಲೋಟಿಗಳು),
			},
		},
		'PYG' => {
			display_name => {
				'currency' => q(ಪೆರುಗ್ವೇಯ ಗ್ವಾರನೀ),
				'one' => q(ಪೆರುಗ್ವೇಯ ಗ್ವಾರನೀ),
				'other' => q(ಪೆರುಗ್ವೇಯ ಗ್ವಾರನೀಗಳು),
			},
		},
		'QAR' => {
			display_name => {
				'currency' => q(ಖತಾರಿ ರಿಯಲ್),
				'one' => q(ಖತಾರಿ ರಿಯಲ್),
				'other' => q(ಖತಾರಿ ರಿಯಲ್‍ಗಳು),
			},
		},
		'RON' => {
			symbol => 'ಲೀ',
			display_name => {
				'currency' => q(ರೊಮೇನಿಯನ್ ಲೆವು),
				'one' => q(ರೊಮೇನಿಯನ್ ಲೆವು),
				'other' => q(ರೊಮೇನಿಯನ್ ಲೆಯ್),
			},
		},
		'RSD' => {
			display_name => {
				'currency' => q(ಸೆರ್ಬಿಯನ್ ದಿನಾರ್),
				'one' => q(ಸೆರ್ಬಿಯನ್ ದಿನಾರ್),
				'other' => q(ಸೆರ್ಬಿಯನ್ ದಿನಾರ್‌ಗಳು),
			},
		},
		'RUB' => {
			display_name => {
				'currency' => q(ರಶಿಯನ್ ರೂಬಲ್),
				'one' => q(ರಶಿಯನ್ ರೂಬಲ್),
				'other' => q(ರಶಿಯನ್ ರೂಬಲ್‍ಗಳು),
			},
		},
		'RWF' => {
			display_name => {
				'currency' => q(ರುವಾಂಡನ್ ಫ್ರಾಂಕ್),
				'one' => q(ರುವಾಂಡನ್ ಫ್ರಾಂಕ್),
				'other' => q(ರುವಾಂಡನ್ ಫ್ರಾಂಕ್‍ಗಳು),
			},
		},
		'SAR' => {
			display_name => {
				'currency' => q(ಸೌದಿ ರಿಯಾಲ್),
				'one' => q(ಸೌದಿ ರಿಯಾಲ್),
				'other' => q(ಸೌದಿ ರಿಯಾಲ್‍ಗಳು),
			},
		},
		'SBD' => {
			display_name => {
				'currency' => q(ಸೊಲೊಮನ್ ದ್ವೀಪಗಳ ಡಾಲರ್),
				'one' => q(ಸೊಲೊಮನ್ ದ್ವೀಪಗಳ ಡಾಲರ್),
				'other' => q(ಸೊಲೊಮನ್ ದ್ವೀಪಗಳ ಡಾಲರ್‌ಗಳು),
			},
		},
		'SCR' => {
			display_name => {
				'currency' => q(ಸೆಚೊಲಿಯೊಸ್ ರುಪಿ),
				'one' => q(ಸೆಚೊಲಿಯೊಸ್ ರುಪಿ),
				'other' => q(ಸೆಚೊಲಿಯೊಸ್ ರುಪಿಗಳು),
			},
		},
		'SDG' => {
			display_name => {
				'currency' => q(ಸುಡಾನೀಸ್ ಪೌಂಡ್),
			},
		},
		'SEK' => {
			display_name => {
				'currency' => q(ಸ್ವೀಡಿಷ್ ಕ್ರೋನಾ),
				'one' => q(ಸ್ವೀಡಿಷ್ ಕ್ರೋನಾ),
				'other' => q(ಸ್ವೀಡಿಷ್ ಕ್ರೋನರ್),
			},
		},
		'SGD' => {
			display_name => {
				'currency' => q(ಸಿಂಗಾಪುರ್ ಡಾಲರ್‌),
				'one' => q(ಸಿಂಗಾಪುರ್ ಡಾಲರ್‌),
				'other' => q(ಸಿಂಗಾಪುರ್ ಡಾಲರ್‌‌ಗಳು),
			},
		},
		'SHP' => {
			display_name => {
				'currency' => q(ಸೇಂಟ್ ಹೆಲೇನಾ ಪೌಂಡ್),
				'one' => q(ಸೇಂಟ್ ಹೆಲೇನಾ ಪೌಂಡ್),
				'other' => q(ಸೇಂಟ್ ಹೆಲೇನಾ ಪೌಂಡ್‌ಗಳು),
			},
		},
		'SLE' => {
			display_name => {
				'currency' => q(ಸಿಯೆರಾ ಲಿಯೋನಿಯನ್ ಲಿಯೋನ್),
				'one' => q(ಸಿಯೆರಾ ಲಿಯೋನಿಯನ್ ಲಿಯೋನ್),
				'other' => q(ಸಿಯೆರಾ ಲಿಯೋನಿಯನ್ ಲಿಯೋನ್‌ಗಳು),
			},
		},
		'SLL' => {
			display_name => {
				'currency' => q(ಸಿಯೆರಾ ಲಿಯೋನಿಯನ್ ಲಿಯೋನ್ \(1964—2022\)),
				'one' => q(ಸಿಯೆರಾ ಲಿಯೋನಿಯನ್ ಲಿಯೋನ್ \(1964—2022\)),
				'other' => q(ಸಿಯೆರಾ ಲಿಯೋನಿಯನ್ ಲಿಯೋನ್‌ಗಳು \(1964—2022\)),
			},
		},
		'SOS' => {
			display_name => {
				'currency' => q(ಸೊಮಾಲಿ ಶಿಲ್ಲಿಂಗ್),
				'one' => q(ಸೊಮಾಲಿ ಶಿಲ್ಲಿಂಗ್),
				'other' => q(ಸೊಮಾಲಿ ಶಿಲ್ಲಿಂಗ್‍ಗಳು),
			},
		},
		'SRD' => {
			display_name => {
				'currency' => q(ಸುರಿನಾಮೀಸ್ ಡಾಲರ್),
				'one' => q(ಸುರಿನಾಮೀಸ್ ಡಾಲರ್),
				'other' => q(ಸುರಿನಾಮೀಸ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'SSP' => {
			display_name => {
				'currency' => q(ದಕ್ಷಿಣ ಸೂಡಾನೀಸ್ ಪೌಂಡ್‍),
				'one' => q(ದಕ್ಷಿಣ ಸೂಡಾನೀಸ್ ಪೌಂಡ್‍),
				'other' => q(ದಕ್ಷಿಣ ಸೂಡಾನೀಸ್ ಪೌಂಡ್‍‍ಗಳು),
			},
		},
		'STD' => {
			display_name => {
				'currency' => q(ಸಾವೊ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪ್ ದೊಬ್ರಾ \(1977–2017\)),
				'one' => q(ಸಾವೊ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪ್ ದೊಬ್ರಾ \(1977–2017\)),
				'other' => q(ಸಾವೊ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪ್ ದೊಬ್ರಾಗಳು \(1977–2017\)),
			},
		},
		'STN' => {
			display_name => {
				'currency' => q(ಸಾವೊ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪ್ ದೊಬ್ರಾ),
				'one' => q(ಸಾವೊ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪ್ ದೊಬ್ರಾ),
				'other' => q(ಸಾವೊ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪ್ ದೊಬ್ರಾಗಳು),
			},
		},
		'SYP' => {
			display_name => {
				'currency' => q(ಸಿರಿಯನ್ ಪೌಂಡ್),
				'one' => q(ಸಿರಿಯನ್ ಪೌಂಡ್),
				'other' => q(ಸಿರಿಯನ್ ಪೌಂಡ್‌ಗಳು),
			},
		},
		'SZL' => {
			display_name => {
				'currency' => q(ಸ್ವಾಜಿ ಲಿಲಂಗೆನಿ),
				'one' => q(ಸ್ವಾಜಿ ಲಿಲಂಗೆನಿ),
				'other' => q(ಸ್ವಾಜಿ ಎಮಲಂಗೆನಿ),
			},
		},
		'THB' => {
			symbol => '฿',
			display_name => {
				'currency' => q(ಥಾಯ್ ಬಹ್ತ್),
			},
		},
		'TJS' => {
			display_name => {
				'currency' => q(ತಜಕಿಸ್ತಾನಿ ಸೊಮೋನಿ),
				'one' => q(ತಜಕಿಸ್ತಾನಿ ಸೊಮೋನಿ),
				'other' => q(ತಜಕಿಸ್ತಾನಿ ಸೊಮೋನಿಗಳು),
			},
		},
		'TMT' => {
			display_name => {
				'currency' => q(ಟರ್ಕ್‍ಮೆನಿಸ್ತಾನ್ ಮನಾತ್),
			},
		},
		'TND' => {
			display_name => {
				'currency' => q(ಟ್ಯುನೀಷಿಯನ್‌ ದಿನಾರ್),
				'one' => q(ಟ್ಯುನೀಷಿಯನ್‌ ದಿನಾರ್‌),
				'other' => q(ಟ್ಯುನೀಷಿಯನ್‌ ದಿನಾರ್‌ಗಳು),
			},
		},
		'TOP' => {
			display_name => {
				'currency' => q(ಟೊಂಗಾ ಪಾಂಗ),
			},
		},
		'TRY' => {
			display_name => {
				'currency' => q(ಟರ್ಕಿಶ್ ಲಿರಾ),
			},
		},
		'TTD' => {
			display_name => {
				'currency' => q(ಟ್ರಿನಿಡಾಡ್ ಮತ್ತು ಟೊಬಾಗೊ ಡಾಲರ್),
				'one' => q(ಟ್ರಿನಿಡಾಡ್ ಮತ್ತು ಟೊಬಾಗೊ ಡಾಲರ್),
				'other' => q(ಟ್ರಿನಿಡಾಡ್ ಮತ್ತು ಟೊಬಾಗೊ ಡಾಲರ್‌ಗಳು),
			},
		},
		'TWD' => {
			symbol => 'NT$',
			display_name => {
				'currency' => q(ನ್ಯೂ ತೈವಾನ್ ಡಾಲರ್),
				'one' => q(ನ್ಯೂ ತೈವಾನ್ ಡಾಲರ್),
				'other' => q(ನ್ಯೂ ತೈವಾನ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'TZS' => {
			display_name => {
				'currency' => q(ತಾನ್‌ಜೇನಿಯನ್ ಶಿಲ್ಲಿಂಗ್),
				'one' => q(ತಾನ್‌ಜೇನಿಯನ್ ಶಿಲ್ಲಿಂಗ್),
				'other' => q(ತಾನ್‌ಜೇನಿಯನ್ ಶಿಲ್ಲಿಂಗ್‍ಗಳು),
			},
		},
		'UAH' => {
			display_name => {
				'currency' => q(ಉಕ್ರೇನಿಯನ್ ಹ್ರಿವ್ನೀಯ),
				'one' => q(ಉಕ್ರೇನಿಯನ್ ಹ್ರಿವ್ನೀಯ),
				'other' => q(ಉಕ್ರೇನಿಯನ್ ಹ್ರಿವ್ನೀಯಗಳು),
			},
		},
		'UGX' => {
			display_name => {
				'currency' => q(ಉಗಾಂಡನ್ ಶಿಲ್ಲಿಂಗ್),
				'one' => q(ಉಗಾಂಡನ್ ಶಿಲ್ಲಿಂಗ್),
				'other' => q(ಉಗಾಂಡನ್ ಶಿಲ್ಲಿಂಗ್‍ಗಳು),
			},
		},
		'USD' => {
			symbol => '$',
			display_name => {
				'currency' => q(ಅಮೆರಿಕದ ಡಾಲರ್‌),
				'one' => q(ಅಮೆರಿಕದ ಡಾಲರ್‌),
				'other' => q(ಅಮೆರಿಕದ ಡಾಲರ್‌‌ಗಳು),
			},
		},
		'UYU' => {
			display_name => {
				'currency' => q(ಉರುಗ್ವೆಯ ಪೆಸೊ),
				'one' => q(ಉರುಗ್ವೆಯ ಪೆಸೊ),
				'other' => q(ಉರುಗ್ವೆಯ ಪೆಸೊಗಳು),
			},
		},
		'UZS' => {
			display_name => {
				'currency' => q(ಉಜ್ಬೇಕಿಸ್ತಾನ್ ಸೊಮ್),
			},
		},
		'VEF' => {
			display_name => {
				'currency' => q(ವೆನಿಜುಲಿಯನ್ ಬೊಲಿವರ್ \(2008–2018\)),
				'one' => q(ವೆನಿಜುಲಿಯನ್ ಬೊಲಿವರ್ \(2008–2018\)),
				'other' => q(ವೆನಿಜುಲಿಯನ್ ಬೊಲಿವರ್‌ಗಳು \(2008–2018\)),
			},
		},
		'VES' => {
			display_name => {
				'currency' => q(ವೆನಿಜುಲಿಯನ್ ಬೊಲಿವರ್),
				'one' => q(ವೆನಿಜುಲಿಯನ್ ಬೊಲಿವರ್),
				'other' => q(ವೆನಿಜುಲಿಯನ್ ಬೊಲಿವರ್‌ಗಳು),
			},
		},
		'VND' => {
			display_name => {
				'currency' => q(ವಿಯೆಟ್ನಾಮೀಸ್ ಡಾಂಗ್),
			},
		},
		'VUV' => {
			display_name => {
				'currency' => q(ವನೂತು ವತು),
				'one' => q(ವನೂತು ವತು),
				'other' => q(ವನೂತು ವತುಗಳು),
			},
		},
		'WST' => {
			display_name => {
				'currency' => q(ಸಮೋನ್ ತಲಾ),
			},
		},
		'XAF' => {
			display_name => {
				'currency' => q(ಮಧ್ಯ ಆಫ್ರಿಕನ್ CFA ಫ್ರಾಂಕ್),
				'one' => q(ಮಧ್ಯ ಆಫ್ರಿಕನ್ CFA ಫ್ರಾಂಕ್),
				'other' => q(ಮಧ್ಯ ಆಫ್ರಿಕನ್ CFA ಫ್ರಾಂಕ್‌ಗಳು),
			},
		},
		'XCD' => {
			display_name => {
				'currency' => q(ಪೂರ್ವ ಕೆರೀಬಿಯನ್ ಡಾಲರ್),
				'one' => q(ಪೂರ್ವ ಕೆರೀಬಿಯನ್ ಡಾಲರ್),
				'other' => q(ಪೂರ್ವ ಕೆರೀಬಿಯನ್ ಡಾಲರ್‌ಗಳು),
			},
		},
		'XOF' => {
			display_name => {
				'currency' => q(ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾದ CFA ಫ್ರಾಂಕ್),
				'one' => q(ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾದ CFA ಫ್ರಾಂಕ್),
				'other' => q(ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾದ CFA ಫ್ರಾಂಕ್‌ಗಳು),
			},
		},
		'XPF' => {
			display_name => {
				'currency' => q([CFP] ಫ್ರಾಂಕ್),
				'one' => q([CFP] ಫ್ರಾಂಕ್),
				'other' => q([CFP] ಫ್ರಾಂಕ್‌ಗಳು),
			},
		},
		'XXX' => {
			display_name => {
				'currency' => q(ಅಪರಿಚಿತ ಕರೆನ್ಸಿ),
				'one' => q(\(ಅಪರಿಚಿತ ಕರೆನ್ಸಿ ಯುನಿಟ್\)),
				'other' => q(\(ಅಪರಿಚಿತ ಕರೆನ್ಸಿ\)),
			},
		},
		'YER' => {
			display_name => {
				'currency' => q(ಯೆಮೆನಿ ರಿಯಲ್),
				'one' => q(ಯೆಮೆನಿ ರಿಯಲ್),
				'other' => q(ಯೆಮೆನಿ ರಿಯಲ್‍ಗಳು),
			},
		},
		'ZAR' => {
			display_name => {
				'currency' => q(ದಕ್ಷಿಣ ಆಫ್ರಿಕನ್ ರಾಂಡ್),
			},
		},
		'ZMK' => {
			display_name => {
				'currency' => q(ಜಾಂಬಿಯಾ ಕ್ವಾಚ \(1968–2012\)),
			},
		},
		'ZMW' => {
			display_name => {
				'currency' => q(ಜಾಂಬಿಯಾ ಕ್ವಾಚ),
				'one' => q(ಜಾಂಬಿಯಾ ಕ್ವಾಚ),
				'other' => q(ಜಾಂಬಿಯಾ ಕ್ವಾಚಗಳು),
			},
		},
	} },
);


has 'calendar_months' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'coptic' => {
				'format' => {
					wide => {
						nonleap => [
							'ಟೌಟ್',
							'ಬಾಬಾ',
							'ಹ್ಯಾಟರ್',
							'ಕಿಯಾಹ್ಕ್',
							'ತೋಬ',
							'ಅಮ್‌ಶೀರ್',
							'ಬರಮ್‌ಹಟ್',
							'ಬರಾಮೌಡ',
							'ಬ್ಯಾಷನ್ಸ್',
							'ಪವೋನ',
							'ಎಪೆಪ್',
							'ಮೆಸ್ರಾ',
							'ನಾಸಿ'
						],
						leap => [
							
						],
					},
				},
			},
			'ethiopic' => {
				'format' => {
					wide => {
						nonleap => [
							'ಮೆಸ್ಕರೆಮ್',
							'ಟೆಕೆಮ್ಟ್',
							'ಹೆದರ್',
							'ತೆಹ್‌ಸಾಸ್',
							'ಟೆರ್',
							'ಯೆಕಟಿಟ್',
							'ಮೆಗಾಬಿಟ್',
							'ಮೈಝಿಯಾ',
							'ಜೆನ್‌ಬಾಟ್',
							'ಸೆನೆ',
							'ಹ್ಯಾಮ್ಲೆ',
							'ನಿಹಾಸ್ಸೆ',
							'ಪೆಗ್ಯುಮೆನ್'
						],
						leap => [
							
						],
					},
				},
			},
			'gregorian' => {
				'format' => {
					abbreviated => {
						nonleap => [
							'ಜನ',
							'ಫೆಬ್ರ',
							'ಮಾರ್ಚ್',
							'ಏಪ್ರಿ',
							'ಮೇ',
							'ಜೂನ್',
							'ಜುಲೈ',
							'ಆಗ',
							'ಸೆಪ್ಟೆಂ',
							'ಅಕ್ಟೋ',
							'ನವೆಂ',
							'ಡಿಸೆಂ'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'ಜನವರಿ',
							'ಫೆಬ್ರವರಿ',
							'ಮಾರ್ಚ್',
							'ಏಪ್ರಿಲ್',
							'ಮೇ',
							'ಜೂನ್',
							'ಜುಲೈ',
							'ಆಗಸ್ಟ್',
							'ಸೆಪ್ಟೆಂಬರ್',
							'ಅಕ್ಟೋಬರ್',
							'ನವೆಂಬರ್',
							'ಡಿಸೆಂಬರ್'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					abbreviated => {
						nonleap => [
							'ಜನ',
							'ಫೆಬ್ರ',
							'ಮಾರ್ಚ್',
							'ಏಪ್ರಿ',
							'ಮೇ',
							'ಜೂನ್',
							'ಜುಲೈ',
							'ಆಗ',
							'ಸೆಪ್ಟೆಂ',
							'ಅಕ್ಟೋ',
							'ನವೆಂ',
							'ಡಿಸೆಂ'
						],
						leap => [
							
						],
					},
					narrow => {
						nonleap => [
							'ಜ',
							'ಫೆ',
							'ಮಾ',
							'ಏ',
							'ಮೇ',
							'ಜೂ',
							'ಜು',
							'ಆ',
							'ಸೆ',
							'ಅ',
							'ನ',
							'ಡಿ'
						],
						leap => [
							
						],
					},
				},
			},
			'hebrew' => {
				'format' => {
					wide => {
						nonleap => [
							'ಟಿಶ್ರಿ',
							'ಹೆಶ್‌ವಾನ್',
							'ಕಿಸ್ಲೆವ್',
							'ಟೆವೆಟ್',
							'ಶೆವತ್',
							'ಅದಾರ್ I',
							'ಅದಾರ್',
							'ನಿಸಾನ್',
							'ಇಯರ್',
							'ಸಿವನ್',
							'ತಮುಜ್',
							'ಎವಿ',
							'ಎಲುಲ್'
						],
						leap => [
							undef(),
							undef(),
							undef(),
							undef(),
							undef(),
							undef(),
							
						],
					},
				},
			},
			'indian' => {
				'format' => {
					wide => {
						nonleap => [
							'ಚೈತ್ರ',
							'ವೈಶಾಖ',
							'ಜ್ಯೇಷ್ಠ',
							'ಆಷಾಢ',
							'ಶ್ರಾವಣ',
							'ಭಾದ್ರ',
							'ಆಶ್ವೀನ',
							'ಕಾರ್ತೀಕ',
							'ಅಗ್ರಹಯಾನ',
							'ಪುಷ್ಯ',
							'ಮಾಘ',
							'ಫಾಲ್ಗುಣ'
						],
						leap => [
							
						],
					},
				},
			},
			'islamic' => {
				'format' => {
					abbreviated => {
						nonleap => [
							'ಮುಹ್.',
							'ಸಫಾ.',
							'ರಬಿ‘ I',
							'ರಬಿ‘ II',
							'ಜುಮ್. I',
							'ಜುಮ್. II',
							'ರಜ್.',
							'ಶ.',
							'ರಮ್.',
							'ಶವ್.',
							'ಧು‘ಲ್-ಕಿ.',
							'ಧು‘ಲ್-ಹ.'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'ಮುಹರಮ್',
							'ಸಫಾರ್',
							'ರಬಿ‘ I',
							'ರಬಿ‘ II',
							'ಜುಮಾದಾ I',
							'ಜುಮಾದಾ II',
							'ರಜಬ್',
							'ಶ’ಬಾನ್',
							'ರಮದಾನ್',
							'ಶವ್ವಾಲ್',
							'ಧು‘ಲ್-ಕಿ‘ಡಾಹ್',
							'ಧು‘ಲ್-ಹಿಜಾಹ್'
						],
						leap => [
							
						],
					},
				},
			},
			'persian' => {
				'format' => {
					wide => {
						nonleap => [
							'ಫರ್ವರ್ದಿನ್',
							'ಓರ್ದಿಬೆಹೆಶ್ಟ್',
							'ಖೋರ್ಡಾದ್',
							'ಟಿರ್',
							'ಮೊರ್ದಾದ್',
							'ಶಹರಿವಾರ್',
							'ಮೆಹ್ರ್',
							'ಅಬನ್',
							'ಅಝರ್',
							'ಡೇ',
							'ಬಹ್ಮನ್',
							'ಎಸ್ಫಾಂಡ್'
						],
						leap => [
							
						],
					},
				},
			},
	} },
);

has 'calendar_days' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {
						mon => 'ಸೋಮ',
						tue => 'ಮಂಗಳ',
						wed => 'ಬುಧ',
						thu => 'ಗುರು',
						fri => 'ಶುಕ್ರ',
						sat => 'ಶನಿ',
						sun => 'ಭಾನು'
					},
					wide => {
						mon => 'ಸೋಮವಾರ',
						tue => 'ಮಂಗಳವಾರ',
						wed => 'ಬುಧವಾರ',
						thu => 'ಗುರುವಾರ',
						fri => 'ಶುಕ್ರವಾರ',
						sat => 'ಶನಿವಾರ',
						sun => 'ಭಾನುವಾರ'
					},
				},
				'stand-alone' => {
					narrow => {
						mon => 'ಸೋ',
						tue => 'ಮಂ',
						wed => 'ಬು',
						thu => 'ಗು',
						fri => 'ಶು',
						sat => 'ಶ',
						sun => 'ಭಾ'
					},
				},
			},
	} },
);

has 'calendar_quarters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {0 => 'ತ್ರೈ 1',
						1 => 'ತ್ರೈ 2',
						2 => 'ತ್ರೈ 3',
						3 => 'ತ್ರೈ 4'
					},
					wide => {0 => '1ನೇ ತ್ರೈಮಾಸಿಕ',
						1 => '2ನೇ ತ್ರೈಮಾಸಿಕ',
						2 => '3ನೇ ತ್ರೈಮಾಸಿಕ',
						3 => '4ನೇ ತ್ರೈಮಾಸಿಕ'
					},
				},
			},
	} },
);

has 'day_period_data' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub { sub {
		# Time in hhmm format
		my ($self, $type, $time, $day_period_type) = @_;
		$day_period_type //= 'default';
		SWITCH:
		for ($type) {
			if ($_ eq 'coptic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'ethiopic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'generic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'gregorian') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'hebrew') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'indian') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'islamic') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'persian') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
			if ($_ eq 'roc') {
				if($day_period_type eq 'default') {
					return 'midnight' if $time == 0;
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				if($day_period_type eq 'selection') {
					return 'afternoon1' if $time >= 1200
						&& $time < 1800;
					return 'evening1' if $time >= 1800
						&& $time < 2100;
					return 'morning1' if $time >= 600
						&& $time < 1200;
					return 'night1' if $time >= 2100;
					return 'night1' if $time < 600;
				}
				last SWITCH;
				}
		}
	} },
);

around day_period_data => sub {
    my ($orig, $self) = @_;
    return $self->$orig;
};

has 'day_periods' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			'format' => {
				'abbreviated' => {
					'afternoon1' => q{ಮಧ್ಯಾಹ್ನ},
					'evening1' => q{ಸಂಜೆ},
					'midnight' => q{ಮಧ್ಯ ರಾತ್ರಿ},
					'morning1' => q{ಬೆಳಗ್ಗೆ},
					'night1' => q{ರಾತ್ರಿ},
				},
				'narrow' => {
					'afternoon1' => q{ಮಧ್ಯಾಹ್ನ},
					'am' => q{a},
					'evening1' => q{ಸಂಜೆ},
					'midnight' => q{ಮಧ್ಯರಾತ್ರಿ},
					'morning1' => q{ಬೆಳಗ್ಗೆ},
					'night1' => q{ರಾತ್ರಿ},
					'pm' => q{p},
				},
				'wide' => {
					'am' => q{AM},
					'pm' => q{PM},
				},
			},
			'stand-alone' => {
				'abbreviated' => {
					'am' => q{AM},
					'midnight' => q{ಮಧ್ಯರಾತ್ರಿ},
					'pm' => q{PM},
				},
				'narrow' => {
					'am' => q{AM},
					'pm' => q{PM},
				},
				'wide' => {
					'am' => q{AM},
					'pm' => q{PM},
				},
			},
		},
	} },
);

has 'eras' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'coptic' => {
		},
		'ethiopic' => {
		},
		'generic' => {
		},
		'gregorian' => {
			abbreviated => {
				'0' => 'ಕ್ರಿ.ಪೂ',
				'1' => 'ಕ್ರಿ.ಶ'
			},
			wide => {
				'0' => 'ಕ್ರಿಸ್ತ ಪೂರ್ವ',
				'1' => 'ಕ್ರಿಸ್ತ ಶಕ'
			},
		},
		'hebrew' => {
		},
		'indian' => {
			abbreviated => {
				'0' => 'ಶಕ'
			},
		},
		'islamic' => {
		},
		'persian' => {
		},
		'roc' => {
			abbreviated => {
				'0' => 'ಆರ್.ಓ.ಸಿ.ಗೆ ಮುಂಚೆ',
				'1' => 'ಮಿಂಗೋ'
			},
		},
	} },
);

has 'date_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'coptic' => {
		},
		'ethiopic' => {
		},
		'generic' => {
			'full' => q{G y MMMM d, EEEE},
			'long' => q{G y MMMM d},
			'medium' => q{G y MMM d},
			'short' => q{GGGGG y-MM-dd},
		},
		'gregorian' => {
			'full' => q{EEEE, MMMM d, y},
			'long' => q{MMMM d, y},
			'medium' => q{MMM d, y},
			'short' => q{d/M/yy},
		},
		'hebrew' => {
		},
		'indian' => {
		},
		'islamic' => {
		},
		'persian' => {
		},
		'roc' => {
		},
	} },
);

has 'time_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'coptic' => {
		},
		'ethiopic' => {
		},
		'generic' => {
		},
		'gregorian' => {
			'full' => q{hh:mm:ss a zzzz},
			'long' => q{hh:mm:ss a z},
			'medium' => q{hh:mm:ss a},
			'short' => q{hh:mm a},
		},
		'hebrew' => {
		},
		'indian' => {
		},
		'islamic' => {
		},
		'persian' => {
		},
		'roc' => {
		},
	} },
);

has 'datetime_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'coptic' => {
		},
		'ethiopic' => {
		},
		'generic' => {
			'full' => q{{1} {0}},
			'long' => q{{1} {0}},
			'medium' => q{{1} {0}},
			'short' => q{{1} {0}},
		},
		'gregorian' => {
			'full' => q{{1} {0}},
			'long' => q{{1} {0}},
			'medium' => q{{1} {0}},
			'short' => q{{1} {0}},
		},
		'hebrew' => {
		},
		'indian' => {
		},
		'islamic' => {
		},
		'persian' => {
		},
		'roc' => {
		},
	} },
);

has 'datetime_formats_available_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			Ed => q{d E},
			MEd => q{E, d/M},
			MMMEd => q{E, d MMM},
			MMMMd => q{d MMMM},
			MMMd => q{d MMM},
			MMdd => q{dd-MM},
			Md => q{d/M},
			yyyyM => q{M/y GGGGG},
			yyyyMM => q{MM-y G},
		},
		'gregorian' => {
			Ed => q{d E},
			MEd => q{d/M, E},
			MMMEd => q{E, d MMM},
			MMMMd => q{d MMMM},
			MMMd => q{d MMM},
			MMdd => q{dd-MM},
			Md => q{d/M},
			yM => q{M/y},
			yMEd => q{E, M/d/y},
			yMM => q{MM-y},
			yMMM => q{MMM y},
			yMMMEd => q{E, MMM d, y},
			yMMMM => q{MMMM y},
			yMMMd => q{MMM d,y},
			yMd => q{d/M/y},
			yQQQ => q{QQQ y},
			yQQQQ => q{QQQQ y},
		},
	} },
);

has 'datetime_formats_append_item' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
	} },
);

has 'datetime_formats_interval' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			M => {
				M => q{M–M},
			},
			MEd => {
				M => q{d/M, E – d/M, E},
				d => q{d/M, E – d/M, E},
			},
			MMM => {
				M => q{MMM–MMM},
			},
			MMMd => {
				M => q{d MMM – d MMM},
				d => q{d –d MMM},
			},
			Md => {
				M => q{d/M – d/M},
				d => q{d/M – d/M},
			},
			fallback => '{0} – {1}',
			y => {
				y => q{y–y G},
			},
			yM => {
				M => q{M/y – M/y GGGGG},
				y => q{M/y – M/y GGGGG},
			},
			yMEd => {
				M => q{d/M/y, E – d/M/y G},
				y => q{d/M/y, E – d/M/y, E G},
			},
			yMd => {
				M => q{d/M/y – d/M/y G},
				d => q{d/M/y – d/M/y GGGGG},
				y => q{d/M/y – d/M/y G},
			},
		},
		'gregorian' => {
			Hm => {
				H => q{HH:mm – HH:mm},
				m => q{HH:mm – HH:mm},
			},
			Hmv => {
				H => q{HH:mm – HH:mm v},
				m => q{HH:mm – HH:mm v},
			},
			Hv => {
				H => q{HH – HH v},
			},
			M => {
				M => q{M–M},
			},
			MEd => {
				M => q{E, M/d – E, M/d},
				d => q{E, M/d – E, M/d},
			},
			MMM => {
				M => q{MMM–MMM},
			},
			MMMd => {
				M => q{d MMM – d MMM},
				d => q{MMM d – d},
			},
			Md => {
				M => q{M/d – M/d},
				d => q{M/d – M/d},
			},
			fallback => '{0} – {1}',
			hm => {
				m => q{h:mm – h:mm a},
			},
			hmv => {
				h => q{h:mm – h:mm a v},
				m => q{h:mm – h:mm a v},
			},
			yM => {
				M => q{M/y – M/y},
				y => q{M/y – M/y},
			},
			yMEd => {
				M => q{E, M/d/y – E, M/d/y},
				d => q{d/M/y,E – d/M/y,E,},
				y => q{E, M/d/y – E, M/d/y},
			},
			yMMM => {
				M => q{MMM–MMM y},
				y => q{MMM y – MMM y},
			},
			yMMMEd => {
				M => q{E, MMM d – E, MMMM d, y},
				d => q{E, MMM d – E, MMM d,y},
				y => q{d MMM, y E – d MMM, y E},
			},
			yMMMM => {
				M => q{MMMM – MMMM y},
				y => q{MMMM y – MMMM y},
			},
			yMMMd => {
				M => q{d MMM – d MMM, y},
				d => q{MMM d–d,y},
				y => q{d, MMM, y – d, MMM, y},
			},
			yMd => {
				M => q{M/d/y – M/d/y},
				d => q{M/d/y – M/d/y},
				y => q{M/d/y – M/d/y},
			},
		},
	} },
);

has 'time_zone_names' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default	=> sub { {
		regionFormat => q({0} ಸಮಯ),
		regionFormat => q({0} ದಿನದ ಸಮಯ),
		regionFormat => q({0} ಪ್ರಮಾಣಿತ ಸಮಯ),
		'Acre' => {
			long => {
				'daylight' => q#ಏಕರ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಏಕರ್ ಸಮಯ#,
				'standard' => q#ಏಕರ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Afghanistan' => {
			long => {
				'standard' => q#ಅಫಘಾನಿಸ್ತಾನ ಸಮಯ#,
			},
		},
		'Africa/Abidjan' => {
			exemplarCity => q#ಅಬಿದ್‌ಜನ್#,
		},
		'Africa/Accra' => {
			exemplarCity => q#ಅಕ್ರಾ#,
		},
		'Africa/Addis_Ababa' => {
			exemplarCity => q#ಆಡಿಸ್ ಅಬಾಬಾ#,
		},
		'Africa/Algiers' => {
			exemplarCity => q#ಅಲ್ಜೀರ್ಸ್#,
		},
		'Africa/Asmera' => {
			exemplarCity => q#ಅಸ್ಮಾರಾ#,
		},
		'Africa/Bamako' => {
			exemplarCity => q#ಬಮಾಕೊ#,
		},
		'Africa/Bangui' => {
			exemplarCity => q#ಬಾಂಗಿ#,
		},
		'Africa/Banjul' => {
			exemplarCity => q#ಬಂಜುಲ್#,
		},
		'Africa/Bissau' => {
			exemplarCity => q#ಬಿಸ್ಸಾವ್#,
		},
		'Africa/Blantyre' => {
			exemplarCity => q#ಬ್ಲ್ಯಾಂಟೈರ್#,
		},
		'Africa/Brazzaville' => {
			exemplarCity => q#ಬ್ರೆಜಾವೀಲ್#,
		},
		'Africa/Bujumbura' => {
			exemplarCity => q#ಬುಜುಂಬುರಾ#,
		},
		'Africa/Cairo' => {
			exemplarCity => q#ಕೈರೋ#,
		},
		'Africa/Casablanca' => {
			exemplarCity => q#ಕ್ಯಾಸಾಬ್ಲಾಂಕಾ#,
		},
		'Africa/Ceuta' => {
			exemplarCity => q#ಸೆಯುಟಾ#,
		},
		'Africa/Conakry' => {
			exemplarCity => q#ಕೊನಾಕ್ರಿ#,
		},
		'Africa/Dakar' => {
			exemplarCity => q#ಡಾಕರ್#,
		},
		'Africa/Dar_es_Salaam' => {
			exemplarCity => q#ಡಾರ್ ಎಸ್ ಸಲಾಮ್#,
		},
		'Africa/Djibouti' => {
			exemplarCity => q#ಜಿಬೂಟಿ#,
		},
		'Africa/Douala' => {
			exemplarCity => q#ದೌಲಾ#,
		},
		'Africa/El_Aaiun' => {
			exemplarCity => q#ಎಲ್ ಔನ್#,
		},
		'Africa/Freetown' => {
			exemplarCity => q#ಫ್ರೀಟೌನ್#,
		},
		'Africa/Gaborone' => {
			exemplarCity => q#ಗ್ಯಾಬರೋನೆ#,
		},
		'Africa/Harare' => {
			exemplarCity => q#ಹರಾರೆ#,
		},
		'Africa/Johannesburg' => {
			exemplarCity => q#ಜೋಹಾನ್ಸ್‌ಬರ್ಗ್#,
		},
		'Africa/Juba' => {
			exemplarCity => q#ಜುಬಾ#,
		},
		'Africa/Kampala' => {
			exemplarCity => q#ಕಂಪಾಲಾ#,
		},
		'Africa/Khartoum' => {
			exemplarCity => q#ಖರ್ಟೋಮ್#,
		},
		'Africa/Kigali' => {
			exemplarCity => q#ಕಿಗಾಲಿ#,
		},
		'Africa/Kinshasa' => {
			exemplarCity => q#ಕಿನ್ಷಾಸಾ#,
		},
		'Africa/Lagos' => {
			exemplarCity => q#ಲಾಗೋಸ್#,
		},
		'Africa/Libreville' => {
			exemplarCity => q#ಲಿಬ್ರೆವೀಲ್#,
		},
		'Africa/Lome' => {
			exemplarCity => q#ಲೋಮ್#,
		},
		'Africa/Luanda' => {
			exemplarCity => q#ಲುವಾಂಡಾ#,
		},
		'Africa/Lubumbashi' => {
			exemplarCity => q#ಲುಬುಂಬಾಶಿ#,
		},
		'Africa/Lusaka' => {
			exemplarCity => q#ಲುಸಾಕಾ#,
		},
		'Africa/Malabo' => {
			exemplarCity => q#ಮಲಾಬೋ#,
		},
		'Africa/Maputo' => {
			exemplarCity => q#ಮ್ಯಾಪುಟೊ#,
		},
		'Africa/Maseru' => {
			exemplarCity => q#ಮಸೇರು#,
		},
		'Africa/Mbabane' => {
			exemplarCity => q#ಅಂಬಬಾನೆ#,
		},
		'Africa/Mogadishu' => {
			exemplarCity => q#ಮೊಗಾದಿಶು#,
		},
		'Africa/Monrovia' => {
			exemplarCity => q#ಮೊನ್ರೋವಿಯಾ#,
		},
		'Africa/Nairobi' => {
			exemplarCity => q#ನೈರೋಬಿ#,
		},
		'Africa/Ndjamena' => {
			exemplarCity => q#ಡ್ಜಮೇನಾ#,
		},
		'Africa/Niamey' => {
			exemplarCity => q#ನಿಯಾಮೆ#,
		},
		'Africa/Nouakchott' => {
			exemplarCity => q#ನೌಕ್‌ಚೋಟ್ಟ್#,
		},
		'Africa/Ouagadougou' => {
			exemplarCity => q#ಔಗಾಡೋಗು#,
		},
		'Africa/Porto-Novo' => {
			exemplarCity => q#ಪೋರ್ಟೋ-ನೋವೋ#,
		},
		'Africa/Sao_Tome' => {
			exemplarCity => q#ಸಾವ್ ಟೊಮಿ#,
		},
		'Africa/Tripoli' => {
			exemplarCity => q#ಟ್ರೈಪೋಲಿ#,
		},
		'Africa/Tunis' => {
			exemplarCity => q#ಟುನೀಸ್#,
		},
		'Africa/Windhoek' => {
			exemplarCity => q#ವಿಂಡ್ಹೋಕ್#,
		},
		'Africa_Central' => {
			long => {
				'standard' => q#ಮಧ್ಯ ಆಫ್ರಿಕಾ ಸಮಯ#,
			},
		},
		'Africa_Eastern' => {
			long => {
				'standard' => q#ಪೂರ್ವ ಆಫ್ರಿಕಾ ಸಮಯ#,
			},
		},
		'Africa_Southern' => {
			long => {
				'standard' => q#ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Africa_Western' => {
			long => {
				'daylight' => q#ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಸಮಯ#,
				'standard' => q#ಪಶ್ಚಿಮ ಆಫ್ರಿಕಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Alaska' => {
			long => {
				'daylight' => q#‌ಅಲಾಸ್ಕಾ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಅಲಾಸ್ಕಾ ಸಮಯ#,
				'standard' => q#ಅಲಾಸ್ಕಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Almaty' => {
			long => {
				'daylight' => q#ಆಲ್ಮೇಟಿ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಆಲ್ಮೇಟಿ ಸಮಯ#,
				'standard' => q#ಆಲ್ಮೇಟಿ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Amazon' => {
			long => {
				'daylight' => q#ಅಮೆಜಾನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಅಮೆಜಾನ್ ಸಮಯ#,
				'standard' => q#ಅಮೆಜಾನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'America/Adak' => {
			exemplarCity => q#ಅಡಕ್‌‌#,
		},
		'America/Anchorage' => {
			exemplarCity => q#ಆಂಕರೋಜ್#,
		},
		'America/Anguilla' => {
			exemplarCity => q#ಆಂಗ್ವಿಲ್ಲಾ#,
		},
		'America/Antigua' => {
			exemplarCity => q#ಆಂಟಿಗುವಾ#,
		},
		'America/Araguaina' => {
			exemplarCity => q#ಅರಾಗುಯಾನಾ#,
		},
		'America/Argentina/La_Rioja' => {
			exemplarCity => q#ಲಾ ರಿಯೋಜಾ#,
		},
		'America/Argentina/Rio_Gallegos' => {
			exemplarCity => q#ರಿಯೋ ಗಲ್ಲೆಗೊಸ್#,
		},
		'America/Argentina/Salta' => {
			exemplarCity => q#ಸಾಲ್ಟಾ#,
		},
		'America/Argentina/San_Juan' => {
			exemplarCity => q#ಸ್ಯಾನ್ ಜುವಾನ್#,
		},
		'America/Argentina/San_Luis' => {
			exemplarCity => q#ಸ್ಯಾನ್ ಲೂಯೀಸ್#,
		},
		'America/Argentina/Tucuman' => {
			exemplarCity => q#ಟುಕುಮಾನ್#,
		},
		'America/Argentina/Ushuaia' => {
			exemplarCity => q#ಉಶ್ವಾಯ#,
		},
		'America/Aruba' => {
			exemplarCity => q#ಅರುಬಾ#,
		},
		'America/Asuncion' => {
			exemplarCity => q#ಅಸುನ್ಸಿಯಾನ್#,
		},
		'America/Bahia' => {
			exemplarCity => q#ಬಹೀಯಾ#,
		},
		'America/Bahia_Banderas' => {
			exemplarCity => q#ಬಾಹಿಯಾ ಬಂಡೇರಾಸ್#,
		},
		'America/Barbados' => {
			exemplarCity => q#ಬಾರ್ಬಡೋಸ್#,
		},
		'America/Belem' => {
			exemplarCity => q#ಬೇಲೆಂ#,
		},
		'America/Belize' => {
			exemplarCity => q#ಬೆಲೀಜ್#,
		},
		'America/Blanc-Sablon' => {
			exemplarCity => q#ಬ್ಲಾಂಕ್-ಸಾಬ್ಲನ್#,
		},
		'America/Boa_Vista' => {
			exemplarCity => q#ಬೋವಾ ವಿಸ್ಟ#,
		},
		'America/Bogota' => {
			exemplarCity => q#ಬೊಗೋಟ#,
		},
		'America/Boise' => {
			exemplarCity => q#ಬ್ವಾಸಿ#,
		},
		'America/Buenos_Aires' => {
			exemplarCity => q#ಬ್ಯೂನಸ್ ಐರಿಸ್#,
		},
		'America/Cambridge_Bay' => {
			exemplarCity => q#ಕೇಮ್‌ಬ್ರಿಡ್ಜ್ ಬೇ#,
		},
		'America/Campo_Grande' => {
			exemplarCity => q#ಕಾಂಪೊ ಗ್ರಾಂಡೆ#,
		},
		'America/Cancun' => {
			exemplarCity => q#ಕ್ಯಾಂಕನ್#,
		},
		'America/Caracas' => {
			exemplarCity => q#ಕ್ಯಾರಕಾಸ್#,
		},
		'America/Catamarca' => {
			exemplarCity => q#ಕಟಮಾರ್ಕ#,
		},
		'America/Cayenne' => {
			exemplarCity => q#ಕೆಯೆನಿ#,
		},
		'America/Cayman' => {
			exemplarCity => q#ಕೇಮನ್#,
		},
		'America/Chicago' => {
			exemplarCity => q#ಚಿಕಾಗೋ#,
		},
		'America/Chihuahua' => {
			exemplarCity => q#ಚಿವಾವ#,
		},
		'America/Ciudad_Juarez' => {
			exemplarCity => q#ಸಿಯುಡಾಡ್ ವಾರೆಝ್#,
		},
		'America/Coral_Harbour' => {
			exemplarCity => q#ಅಟಿಕೊಕಾನ್#,
		},
		'America/Cordoba' => {
			exemplarCity => q#ಕೊರ್ಡೊಬಾ#,
		},
		'America/Costa_Rica' => {
			exemplarCity => q#ಕೋಸ್ಟಾ ರಿಕಾ#,
		},
		'America/Creston' => {
			exemplarCity => q#ಕ್ರೆಸ್ಟನ್#,
		},
		'America/Cuiaba' => {
			exemplarCity => q#ಕ್ಯೂಇಬಾ#,
		},
		'America/Curacao' => {
			exemplarCity => q#ಕುರಾಕಾವ್#,
		},
		'America/Danmarkshavn' => {
			exemplarCity => q#ಡನ್‌ಮಾರ್ಕ್‌ಶ್ವಾನ್#,
		},
		'America/Dawson' => {
			exemplarCity => q#ಡಾಸನ್#,
		},
		'America/Dawson_Creek' => {
			exemplarCity => q#ಡಾಸನ್ ಕ್ರೀಕ್#,
		},
		'America/Denver' => {
			exemplarCity => q#ಡೆನ್ವರ್#,
		},
		'America/Detroit' => {
			exemplarCity => q#ಡೆಟ್ರಾಯ್ಟ್#,
		},
		'America/Dominica' => {
			exemplarCity => q#ಡೊಮಿನಿಕಾ#,
		},
		'America/Edmonton' => {
			exemplarCity => q#ಎಡ್ಮಂಟನ್‌#,
		},
		'America/Eirunepe' => {
			exemplarCity => q#ಇರುನಿಪೆ#,
		},
		'America/El_Salvador' => {
			exemplarCity => q#ಎಲ್ ಸಾಲ್ವಡೋರ್#,
		},
		'America/Fort_Nelson' => {
			exemplarCity => q#ಫೋರ್ಟ್ ನೆಲ್ಸನ್#,
		},
		'America/Fortaleza' => {
			exemplarCity => q#ಫೊರ್ಟಲೆಜಾ#,
		},
		'America/Glace_Bay' => {
			exemplarCity => q#ಗ್ಲೇಸ್ ಬೇ#,
		},
		'America/Godthab' => {
			exemplarCity => q#ನೂಕ್#,
		},
		'America/Goose_Bay' => {
			exemplarCity => q#ಗೂಸ್ ಬೇ#,
		},
		'America/Grand_Turk' => {
			exemplarCity => q#ಗ್ರ್ಯಾಂಡ್ ಟರ್ಕ್#,
		},
		'America/Grenada' => {
			exemplarCity => q#ಗ್ರೆನಾಡ#,
		},
		'America/Guadeloupe' => {
			exemplarCity => q#ಗ್ವಾಡೆಲೋಪ್#,
		},
		'America/Guatemala' => {
			exemplarCity => q#ಗ್ವಾಟೆಮಾಲಾ#,
		},
		'America/Guayaquil' => {
			exemplarCity => q#ಗುಯಾಕ್ವಿಲ್#,
		},
		'America/Guyana' => {
			exemplarCity => q#ಗಯಾನಾ#,
		},
		'America/Halifax' => {
			exemplarCity => q#ಹ್ಯಾಲಿಫೆಕ್ಸ್#,
		},
		'America/Havana' => {
			exemplarCity => q#ಹವಾನಾ#,
		},
		'America/Hermosillo' => {
			exemplarCity => q#ಹರ್ಮೊಸಿಲ್ಲೋ#,
		},
		'America/Indiana/Knox' => {
			exemplarCity => q#ನಾಕ್ಸ್, ಇಂಡಿಯಾನಾ#,
		},
		'America/Indiana/Marengo' => {
			exemplarCity => q#ಮರೆಂಗೊ, ಇಂಡಿಯಾನಾ#,
		},
		'America/Indiana/Petersburg' => {
			exemplarCity => q#ಪೀಟರ್ಸ್‌ಬರ್ಗ್, ಇಂಡಿಯಾನಾ#,
		},
		'America/Indiana/Tell_City' => {
			exemplarCity => q#ಟೆಲ್ ಸಿಟಿ, ಇಂಡಿಯಾನಾ#,
		},
		'America/Indiana/Vevay' => {
			exemplarCity => q#ವೇವಾಯ್, ಇಂಡಿಯಾನಾ#,
		},
		'America/Indiana/Vincennes' => {
			exemplarCity => q#ವಿನ್‌ಸೆನ್ನೀಸ್, ಇಂಡಿಯಾನಾ#,
		},
		'America/Indiana/Winamac' => {
			exemplarCity => q#ವಿನಾಮ್ಯಾಕ್, ಇಂಡಿಯಾನಾ#,
		},
		'America/Indianapolis' => {
			exemplarCity => q#ಇಂಡಿಯಾನಾಪೊಲಿಸ್#,
		},
		'America/Inuvik' => {
			exemplarCity => q#ಇನುವಿಕ್#,
		},
		'America/Iqaluit' => {
			exemplarCity => q#ಈಕ್ವಾಲಿಟ್#,
		},
		'America/Jamaica' => {
			exemplarCity => q#ಜಮೈಕಾ#,
		},
		'America/Jujuy' => {
			exemplarCity => q#ಜುಜೈ#,
		},
		'America/Juneau' => {
			exemplarCity => q#ಜುನೇವ್#,
		},
		'America/Kentucky/Monticello' => {
			exemplarCity => q#ಮೊಂಟಿಸೆಲ್ಲೋ, ಕೆಂಟುಕಿ#,
		},
		'America/Kralendijk' => {
			exemplarCity => q#ಕ್ರೆಲೆಂಡಿಜ್ಕ್#,
		},
		'America/La_Paz' => {
			exemplarCity => q#ಲಾ ಪೆಜ್#,
		},
		'America/Lima' => {
			exemplarCity => q#ಲಿಮಾ#,
		},
		'America/Los_Angeles' => {
			exemplarCity => q#ಲಾಸ್ ಏಂಜಲೀಸ್#,
		},
		'America/Louisville' => {
			exemplarCity => q#ಲೂಯೀಸ್‌ವಿಲ್ಲೆ#,
		},
		'America/Lower_Princes' => {
			exemplarCity => q#ಲೋವರ್ ಪ್ರಿನ್ಸಸ್ ಕ್ವಾರ್ಟರ್#,
		},
		'America/Maceio' => {
			exemplarCity => q#ಮೆಸೀಯೊ#,
		},
		'America/Managua' => {
			exemplarCity => q#ಮನಾಗುವಾ#,
		},
		'America/Manaus' => {
			exemplarCity => q#ಮನಾವ್ಸ್#,
		},
		'America/Marigot' => {
			exemplarCity => q#ಮರಿಗೊ#,
		},
		'America/Martinique' => {
			exemplarCity => q#ಮಾರ್ಟಿನಿಕ್#,
		},
		'America/Matamoros' => {
			exemplarCity => q#ಮಟಾಮೋರಸ್#,
		},
		'America/Mazatlan' => {
			exemplarCity => q#ಮಜಟ್ಲಾನ್#,
		},
		'America/Mendoza' => {
			exemplarCity => q#ಮೆಂಡೊಜಾ#,
		},
		'America/Menominee' => {
			exemplarCity => q#ಮೆನೊಮಿನೀ#,
		},
		'America/Merida' => {
			exemplarCity => q#ಮೆರಿದಾ#,
		},
		'America/Metlakatla' => {
			exemplarCity => q#ಮೆಟ್ಲಾಕಾಟ್ಲಾ#,
		},
		'America/Mexico_City' => {
			exemplarCity => q#ಮೆಕ್ಸಿಕೋ ನಗರ#,
		},
		'America/Miquelon' => {
			exemplarCity => q#ಮಿಕೆಲಾನ್#,
		},
		'America/Moncton' => {
			exemplarCity => q#ಮಾಂಕ್ಟನ್#,
		},
		'America/Monterrey' => {
			exemplarCity => q#ಮಾಂಟೆರ್ರಿ#,
		},
		'America/Montevideo' => {
			exemplarCity => q#ಮಾಂಟಿವೀಡಿಯೊ#,
		},
		'America/Montserrat' => {
			exemplarCity => q#ಮಾಂಟ್‌ಸೆರೇಟ್#,
		},
		'America/Nassau' => {
			exemplarCity => q#ನಸ್ಸೌವ್#,
		},
		'America/New_York' => {
			exemplarCity => q#ನ್ಯೂಯಾರ್ಕ್#,
		},
		'America/Nome' => {
			exemplarCity => q#ನೋಮ್#,
		},
		'America/Noronha' => {
			exemplarCity => q#ನೊರೊನ್ಹಾ#,
		},
		'America/North_Dakota/Beulah' => {
			exemplarCity => q#ಬ್ಯೂಲಾ, ಉತ್ತರ ಡಕೊಟ#,
		},
		'America/North_Dakota/Center' => {
			exemplarCity => q#ಸೆಂಟರ್, ಉತ್ತರ ಡಕೊಟ#,
		},
		'America/North_Dakota/New_Salem' => {
			exemplarCity => q#ನ್ಯೂ ಸಲೇಂ, ಉತ್ತರ ಡಕೊಟ#,
		},
		'America/Ojinaga' => {
			exemplarCity => q#ಓಜಿನಾಗಾ#,
		},
		'America/Panama' => {
			exemplarCity => q#ಪನಾಮಾ#,
		},
		'America/Paramaribo' => {
			exemplarCity => q#ಪರಮಾರಿಬೋ#,
		},
		'America/Phoenix' => {
			exemplarCity => q#ಫಿನಿಕ್ಸ್#,
		},
		'America/Port-au-Prince' => {
			exemplarCity => q#ಪೋರ್ಟ್-ಒ-ಪ್ರಿನ್ಸ್#,
		},
		'America/Port_of_Spain' => {
			exemplarCity => q#ಪೋರ್ಟ್ ಆಫ್ ಸ್ಪೇನ್#,
		},
		'America/Porto_Velho' => {
			exemplarCity => q#ಪೋರ್ಟೊ ವೆಲ್ಹೋ#,
		},
		'America/Puerto_Rico' => {
			exemplarCity => q#ಪ್ಯುರ್ಟೋ ರಿಕೊ#,
		},
		'America/Punta_Arenas' => {
			exemplarCity => q#ಪುಂತಾ ಅರೇನಾಸ್#,
		},
		'America/Rankin_Inlet' => {
			exemplarCity => q#ರಾಂಕಿನ್ ಇನ್‌ಲೆಟ್#,
		},
		'America/Recife' => {
			exemplarCity => q#ರೆಸಿಫಿ#,
		},
		'America/Regina' => {
			exemplarCity => q#ರೆಜಿನಾ#,
		},
		'America/Resolute' => {
			exemplarCity => q#ರೆಸೊಲ್ಯೂಟ್#,
		},
		'America/Rio_Branco' => {
			exemplarCity => q#ರಿಯೋ ಬ್ರ್ಯಾಂಕೊ#,
		},
		'America/Santarem' => {
			exemplarCity => q#ಸಾಂಟರೆಮ್#,
		},
		'America/Santiago' => {
			exemplarCity => q#ಸ್ಯಾಂಟಿಯಾಗೊ#,
		},
		'America/Santo_Domingo' => {
			exemplarCity => q#ಸ್ಯಾಂಟೋ ಡೊಮಿಂಗೊ#,
		},
		'America/Sao_Paulo' => {
			exemplarCity => q#ಸಾವ್ ಪಾಲೊ#,
		},
		'America/Scoresbysund' => {
			exemplarCity => q#ಇಟ್ಟೊಕ್ಕೊರ್ಟೂಮಿಯೈಟ್#,
		},
		'America/Sitka' => {
			exemplarCity => q#ಸಿತ್ಕಾ#,
		},
		'America/St_Barthelemy' => {
			exemplarCity => q#ಸೇಂಟ್ ಬಾರ್ತೆಲೆಮಿ#,
		},
		'America/St_Johns' => {
			exemplarCity => q#ಸೇಂಟ್ ಜಾನ್ಸ್#,
		},
		'America/St_Kitts' => {
			exemplarCity => q#ಸೇಂಟ್ ಕಿಟ್ಸ್#,
		},
		'America/St_Lucia' => {
			exemplarCity => q#ಸೇಂಟ್ ಲೂಸಿಯಾ#,
		},
		'America/St_Thomas' => {
			exemplarCity => q#ಸೇಂಟ್ ಥಾಮಸ್#,
		},
		'America/St_Vincent' => {
			exemplarCity => q#ಸೇಂಟ್ ವಿನ್ಸೆಂಟ್#,
		},
		'America/Swift_Current' => {
			exemplarCity => q#ಸ್ವಿಫ್ಟ್ ಕರೆಂಟ್#,
		},
		'America/Tegucigalpa' => {
			exemplarCity => q#ತೆಗುಸಿಗಲ್ಪಾ#,
		},
		'America/Thule' => {
			exemplarCity => q#ಥೂಲೆ#,
		},
		'America/Tijuana' => {
			exemplarCity => q#ತಿಜ್ವಾನಾ#,
		},
		'America/Toronto' => {
			exemplarCity => q#ಟೊರೊಂಟೋ#,
		},
		'America/Tortola' => {
			exemplarCity => q#ಟಾರ್ಟೊಲಾ#,
		},
		'America/Vancouver' => {
			exemplarCity => q#ವ್ಯಾಂಕೊವರ್‌#,
		},
		'America/Whitehorse' => {
			exemplarCity => q#ವೈಟ್‌ಹಾರ್ಸ್#,
		},
		'America/Winnipeg' => {
			exemplarCity => q#ವಿನ್ನಿಪೆಗ್#,
		},
		'America/Yakutat' => {
			exemplarCity => q#ಯಾಕುಟಾಟ್#,
		},
		'America_Central' => {
			long => {
				'daylight' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರೀಯ ದಿನದ ಸಮಯ#,
				'generic' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಸಮಯ#,
				'standard' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಕೇಂದ್ರ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'America_Eastern' => {
			long => {
				'daylight' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ದಿನದ ಸಮಯ#,
				'generic' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಸಮಯ#,
				'standard' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪೂರ್ವದ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'America_Mountain' => {
			long => {
				'daylight' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ದಿನದ ಸಮಯ#,
				'generic' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಸಮಯ#,
				'standard' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪರ್ವತ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'America_Pacific' => {
			long => {
				'daylight' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ದಿನದ ಸಮಯ#,
				'generic' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ಸಮಯ#,
				'standard' => q#ಉತ್ತರ ಅಮೆರಿಕದ ಪೆಸಿಫಿಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Anadyr' => {
			long => {
				'daylight' => q#ಅನಡೀರ್‌ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಅನಡೀರ್‌ ಸಮಯ#,
				'standard' => q#ಅನಡೀರ್‌ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Antarctica/Casey' => {
			exemplarCity => q#ಕೇಸಿ#,
		},
		'Antarctica/Davis' => {
			exemplarCity => q#ಡೇವೀಸ್#,
		},
		'Antarctica/DumontDUrville' => {
			exemplarCity => q#ಡುಮಂಟ್ ಡಿ ಉರ್ವಿಲೆ#,
		},
		'Antarctica/Macquarie' => {
			exemplarCity => q#ಮ್ಯಾಕ್ವೆರಿ#,
		},
		'Antarctica/Mawson' => {
			exemplarCity => q#ಮಾವ್ಸನ್#,
		},
		'Antarctica/McMurdo' => {
			exemplarCity => q#ಮ್ಯಾಕ್‍ಮುರ್ಡೊ#,
		},
		'Antarctica/Palmer' => {
			exemplarCity => q#ಪಾಲ್ಮರ್#,
		},
		'Antarctica/Rothera' => {
			exemplarCity => q#ರೊಥೇರಾ#,
		},
		'Antarctica/Syowa' => {
			exemplarCity => q#ಸ್ಯೋವಾ#,
		},
		'Antarctica/Troll' => {
			exemplarCity => q#ಟ್ರಾಲ್#,
		},
		'Antarctica/Vostok' => {
			exemplarCity => q#ವೋಸ್ಟೋಕ್#,
		},
		'Apia' => {
			long => {
				'daylight' => q#ಅಪಿಯಾ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಅಪಿಯಾ ಸಮಯ#,
				'standard' => q#ಅಪಿಯಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Aqtau' => {
			long => {
				'daylight' => q#ಅಕ್ಟೌ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಅಕ್ಟೌ ಸಮಯ#,
				'standard' => q#ಅಕ್ಟೌ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Aqtobe' => {
			long => {
				'daylight' => q#ಅಕ್ಟೋಬೆ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಅಕ್ಟೋಬೆ ಸಮಯ#,
				'standard' => q#ಅಕ್ಟೋಬೆ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Arabian' => {
			long => {
				'daylight' => q#ಅರೇಬಿಯನ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಅರೇಬಿಯನ್ ಸಮಯ#,
				'standard' => q#ಅರೇಬಿಯನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Arctic/Longyearbyen' => {
			exemplarCity => q#ಲಾಂಗ್ಯೀರ್ಬೆನ್#,
		},
		'Argentina' => {
			long => {
				'daylight' => q#ಅರ್ಜೆಂಟಿನಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಅರ್ಜೆಂಟೀನಾ ಸಮಯ#,
				'standard' => q#ಅರ್ಜೆಂಟೀನಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Argentina_Western' => {
			long => {
				'daylight' => q#ಪಶ್ಚಿಮ ಅರ್ಜೆಂಟೀನಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪಶ್ಚಿಮ ಅರ್ಜೆಂಟೀನಾ ಸಮಯ#,
				'standard' => q#ಪಶ್ಚಿಮ ಅರ್ಜೆಂಟೀನಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Armenia' => {
			long => {
				'daylight' => q#ಅರ್ಮೇನಿಯ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಅರ್ಮೇನಿಯ ಸಮಯ#,
				'standard' => q#ಅರ್ಮೇನಿಯ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Asia/Aden' => {
			exemplarCity => q#ಏಡನ್#,
		},
		'Asia/Almaty' => {
			exemplarCity => q#ಅಲ್ಮಾಟಿ#,
		},
		'Asia/Amman' => {
			exemplarCity => q#ಅಮ್ಮಾನ್#,
		},
		'Asia/Anadyr' => {
			exemplarCity => q#ಅನದ್ಯರ್#,
		},
		'Asia/Aqtau' => {
			exemplarCity => q#ಅಕ್ತಾವ್#,
		},
		'Asia/Aqtobe' => {
			exemplarCity => q#ಅಕ್ಟೋಬೆ#,
		},
		'Asia/Ashgabat' => {
			exemplarCity => q#ಅಶ್ಗಬಾತ್#,
		},
		'Asia/Atyrau' => {
			exemplarCity => q#ಅಟ್ರಾವ್#,
		},
		'Asia/Baghdad' => {
			exemplarCity => q#ಬಾಗ್ದಾದ್#,
		},
		'Asia/Bahrain' => {
			exemplarCity => q#ಬಹ್ರೇನ್#,
		},
		'Asia/Baku' => {
			exemplarCity => q#ಬಕು#,
		},
		'Asia/Bangkok' => {
			exemplarCity => q#ಬ್ಯಾಂಕಾಕ್#,
		},
		'Asia/Barnaul' => {
			exemplarCity => q#ಬಾರ್ನೌಲ್#,
		},
		'Asia/Beirut' => {
			exemplarCity => q#ಬೀರಟ್#,
		},
		'Asia/Bishkek' => {
			exemplarCity => q#ಬಿಶ್ಕೆಕ್#,
		},
		'Asia/Brunei' => {
			exemplarCity => q#ಬ್ರೂನಿ#,
		},
		'Asia/Calcutta' => {
			exemplarCity => q#ಕೊಲ್ಕತ್ತಾ#,
		},
		'Asia/Chita' => {
			exemplarCity => q#ಚಿಟ#,
		},
		'Asia/Colombo' => {
			exemplarCity => q#ಕೊಲಂಬೊ#,
		},
		'Asia/Damascus' => {
			exemplarCity => q#ಡಮಾಸ್ಕಸ್#,
		},
		'Asia/Dhaka' => {
			exemplarCity => q#ಢಾಕಾ#,
		},
		'Asia/Dili' => {
			exemplarCity => q#ದಿಲಿ#,
		},
		'Asia/Dubai' => {
			exemplarCity => q#ದುಬೈ#,
		},
		'Asia/Dushanbe' => {
			exemplarCity => q#ದುಶಾಂಬೆ#,
		},
		'Asia/Famagusta' => {
			exemplarCity => q#ಫಮಾಗುಸ್ತಾ#,
		},
		'Asia/Gaza' => {
			exemplarCity => q#ಗಾಜಾ#,
		},
		'Asia/Hebron' => {
			exemplarCity => q#ಹೆಬ್ರಾನ್#,
		},
		'Asia/Hong_Kong' => {
			exemplarCity => q#ಹಾಂಗ್ ಕಾಂಗ್#,
		},
		'Asia/Hovd' => {
			exemplarCity => q#ಹೋವ್ಡ್#,
		},
		'Asia/Irkutsk' => {
			exemplarCity => q#ಇರಕುಟ್ಸ್ಕ್#,
		},
		'Asia/Jakarta' => {
			exemplarCity => q#ಜಕಾರ್ತಾ#,
		},
		'Asia/Jayapura' => {
			exemplarCity => q#ಜಯಪುರ#,
		},
		'Asia/Jerusalem' => {
			exemplarCity => q#ಜೆರುಸಲೆಮ್#,
		},
		'Asia/Kabul' => {
			exemplarCity => q#ಕಾಬೂಲ್#,
		},
		'Asia/Kamchatka' => {
			exemplarCity => q#ಕಂಚಟ್ಕ್#,
		},
		'Asia/Karachi' => {
			exemplarCity => q#ಕರಾಚಿ#,
		},
		'Asia/Katmandu' => {
			exemplarCity => q#ಕಠ್ಮಂಡು#,
		},
		'Asia/Khandyga' => {
			exemplarCity => q#ಖಂಡ್ಯಾಗಾ#,
		},
		'Asia/Krasnoyarsk' => {
			exemplarCity => q#ಕ್ರಾಸ್ನೊಯಾರ್ಸ್ಕ್#,
		},
		'Asia/Kuala_Lumpur' => {
			exemplarCity => q#ಕೌಲಾ ಲಂಪುರ#,
		},
		'Asia/Kuching' => {
			exemplarCity => q#ಕುಚಿಂಗ್#,
		},
		'Asia/Kuwait' => {
			exemplarCity => q#ಕುವೈತ್#,
		},
		'Asia/Macau' => {
			exemplarCity => q#ಮಕಾವು#,
		},
		'Asia/Magadan' => {
			exemplarCity => q#ಮಗದನ್‌#,
		},
		'Asia/Makassar' => {
			exemplarCity => q#ಮೆಕಾಸ್ಸರ್#,
		},
		'Asia/Manila' => {
			exemplarCity => q#ಮನಿಲಾ#,
		},
		'Asia/Muscat' => {
			exemplarCity => q#ಮಸ್ಕಟ್#,
		},
		'Asia/Nicosia' => {
			exemplarCity => q#ನಿಕೋಸಿಯಾ#,
		},
		'Asia/Novokuznetsk' => {
			exemplarCity => q#ನೋವೋಕುಜೆ#,
		},
		'Asia/Novosibirsk' => {
			exemplarCity => q#ನೊವೋಸಿಬಿಸ್ಕ್#,
		},
		'Asia/Omsk' => {
			exemplarCity => q#ಒಮ್ಸ್ಕ್#,
		},
		'Asia/Oral' => {
			exemplarCity => q#ಒರಲ್#,
		},
		'Asia/Phnom_Penh' => {
			exemplarCity => q#ನೋಮ್ ಪೆನ್#,
		},
		'Asia/Pontianak' => {
			exemplarCity => q#ಪೊಂಟಿಯಾನಕ್#,
		},
		'Asia/Pyongyang' => {
			exemplarCity => q#ಪ್ಯೊಂಗ್‍ಯಾಂಗ್#,
		},
		'Asia/Qatar' => {
			exemplarCity => q#ಖತಾರ್#,
		},
		'Asia/Qostanay' => {
			exemplarCity => q#ಕೊಸ್ಟನಯ್#,
		},
		'Asia/Qyzylorda' => {
			exemplarCity => q#ಕಿಜೈಲೋರ್ದ#,
		},
		'Asia/Rangoon' => {
			exemplarCity => q#ಯಾಂಗೊನ್#,
		},
		'Asia/Riyadh' => {
			exemplarCity => q#ರಿಯಾದ್#,
		},
		'Asia/Saigon' => {
			exemplarCity => q#ಹೊ ಚಿ ಮಿನ್ ಸಿಟಿ#,
		},
		'Asia/Sakhalin' => {
			exemplarCity => q#ಸಖಾಲಿನ್#,
		},
		'Asia/Samarkand' => {
			exemplarCity => q#ಸಮರಖಂಡ#,
		},
		'Asia/Seoul' => {
			exemplarCity => q#ಸಿಯೋಲ್#,
		},
		'Asia/Shanghai' => {
			exemplarCity => q#ಶಾಂಘೈ#,
		},
		'Asia/Singapore' => {
			exemplarCity => q#ಸಿಂಗಪುರ್#,
		},
		'Asia/Srednekolymsk' => {
			exemplarCity => q#ಸ್ರೇದ್ನೇಕೋಲೀಮಸ್ಕ#,
		},
		'Asia/Taipei' => {
			exemplarCity => q#ತೈಪೆ#,
		},
		'Asia/Tashkent' => {
			exemplarCity => q#ತಾಶ್ಕೆಂಟ್#,
		},
		'Asia/Tbilisi' => {
			exemplarCity => q#ಟಿಬಿಲಿಸಿ#,
		},
		'Asia/Tehran' => {
			exemplarCity => q#ತೆಹ್ರಾನ್#,
		},
		'Asia/Thimphu' => {
			exemplarCity => q#ಥಿಂಪು#,
		},
		'Asia/Tokyo' => {
			exemplarCity => q#ಟೋಕಿಯೊ#,
		},
		'Asia/Tomsk' => {
			exemplarCity => q#ಟೋಮ್‌ಸ್ಕ್#,
		},
		'Asia/Ulaanbaatar' => {
			exemplarCity => q#ಉಲಾನ್ ಬತೊರ್#,
		},
		'Asia/Urumqi' => {
			exemplarCity => q#ಉರುಮ್‍ಕಿ#,
		},
		'Asia/Ust-Nera' => {
			exemplarCity => q#ಉಸ್ತ್-ನೆರಾ#,
		},
		'Asia/Vientiane' => {
			exemplarCity => q#ವಿಯೆಂಟಿಯಾನ್#,
		},
		'Asia/Vladivostok' => {
			exemplarCity => q#ವ್ಲಾದಿವೊಸ್ಟಾಕ್‌#,
		},
		'Asia/Yakutsk' => {
			exemplarCity => q#ಯಕುಟ್ಸ್ಕ್#,
		},
		'Asia/Yekaterinburg' => {
			exemplarCity => q#ಎಕ್ಯಾಟೆರಿನ್ಬರ್ಗ್#,
		},
		'Asia/Yerevan' => {
			exemplarCity => q#ಯೆರೆವಾನ್#,
		},
		'Atlantic' => {
			long => {
				'daylight' => q#ಅಟ್ಲಾಂಟಿಕ್ ದಿನದ ಸಮಯ#,
				'generic' => q#ಅಟ್ಲಾಂಟಿಕ್ ಸಮಯ#,
				'standard' => q#ಅಟ್ಲಾಂಟಿಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Atlantic/Azores' => {
			exemplarCity => q#ಅಝೋರಿಸ್#,
		},
		'Atlantic/Bermuda' => {
			exemplarCity => q#ಬರ್ಮುಡಾ#,
		},
		'Atlantic/Canary' => {
			exemplarCity => q#ಕ್ಯಾನರಿ#,
		},
		'Atlantic/Cape_Verde' => {
			exemplarCity => q#ಕೇಪ್ ವೆರ್ಡ್#,
		},
		'Atlantic/Faeroe' => {
			exemplarCity => q#ಫ್ಯಾರೊ#,
		},
		'Atlantic/Madeira' => {
			exemplarCity => q#ಮೆಡಿರಾ#,
		},
		'Atlantic/Reykjavik' => {
			exemplarCity => q#ರೈಕ್ಜಾವಿಕ್#,
		},
		'Atlantic/South_Georgia' => {
			exemplarCity => q#ದಕ್ಷಿಣ ಜಾರ್ಜಿಯಾ#,
		},
		'Atlantic/St_Helena' => {
			exemplarCity => q#ಸೇಂಟ್ ಹೆಲೆನಾ#,
		},
		'Atlantic/Stanley' => {
			exemplarCity => q#ಸ್ಟ್ಯಾನ್ಲಿ#,
		},
		'Australia/Adelaide' => {
			exemplarCity => q#ಅಡಿಲೇಡ್#,
		},
		'Australia/Brisbane' => {
			exemplarCity => q#ಬ್ರಿಸ್ಬೇನ್‌#,
		},
		'Australia/Broken_Hill' => {
			exemplarCity => q#ಬ್ರೊಕನ್ ಹಿಲ್#,
		},
		'Australia/Darwin' => {
			exemplarCity => q#ಡಾರ್ವಿನ್#,
		},
		'Australia/Eucla' => {
			exemplarCity => q#ಯುಕ್ಲಾ#,
		},
		'Australia/Hobart' => {
			exemplarCity => q#ಹೋಬಾರ್ಟ್‌#,
		},
		'Australia/Lindeman' => {
			exemplarCity => q#ಲಿಂಡಿಮಾನ್#,
		},
		'Australia/Lord_Howe' => {
			exemplarCity => q#ಲಾರ್ಡ್ ಹೋವ್#,
		},
		'Australia/Melbourne' => {
			exemplarCity => q#ಮೆಲ್ಬರ್ನ್#,
		},
		'Australia/Perth' => {
			exemplarCity => q#ಪರ್ಥ್#,
		},
		'Australia/Sydney' => {
			exemplarCity => q#ಸಿಡ್ನಿ#,
		},
		'Australia_Central' => {
			long => {
				'daylight' => q#ಆಸ್ಟ್ರೇಲಿಯಾದ ಕೇಂದ್ರ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಕೇಂದ್ರ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ#,
				'standard' => q#ಆಸ್ಟ್ರೇಲಿಯಾದ ಕೇಂದ್ರ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Australia_CentralWestern' => {
			long => {
				'daylight' => q#ಆಸ್ಟ್ರೇಲಿಯಾದ ಕೇಂದ್ರ ಪಶ್ಚಿಮ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಆಸ್ಟ್ರೇಲಿಯಾದ ಕೇಂದ್ರ ಪಶ್ಚಿಮ ಸಮಯ#,
				'standard' => q#ಆಸ್ಟ್ರೇಲಿಯಾದ ಕೇಂದ್ರ ಪಶ್ಚಿಮ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Australia_Eastern' => {
			long => {
				'daylight' => q#ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾದ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಪೂರ್ವ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ#,
				'standard' => q#ಆಸ್ಟ್ರೇಲಿಯಾದ ಪೂರ್ವ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Australia_Western' => {
			long => {
				'daylight' => q#ಆಸ್ಟ್ರೇಲಿಯಾದ ಪಶ್ಚಿಮ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಪಶ್ಚಿಮ ಆಸ್ಟ್ರೇಲಿಯಾ ಸಮಯ#,
				'standard' => q#ಆಸ್ಟ್ರೇಲಿಯಾದ ಪಶ್ಚಿಮ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Azerbaijan' => {
			long => {
				'daylight' => q#ಅಜರ್ಬೈಜಾನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಅಜರ್ಬೈಜಾನ್ ಸಮಯ#,
				'standard' => q#ಅಜರ್ಬೈಜಾನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Azores' => {
			long => {
				'daylight' => q#ಅಜೋರಸ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಅಜೋರಸ್ ಸಮಯ#,
				'standard' => q#ಅಜೋರಸ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Bangladesh' => {
			long => {
				'daylight' => q#ಬಾಂಗ್ಲಾದೇಶ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಬಾಂಗ್ಲಾದೇಶ ಸಮಯ#,
				'standard' => q#ಬಾಂಗ್ಲಾದೇಶ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Bhutan' => {
			long => {
				'standard' => q#ಭೂತಾನ್ ಸಮಯ#,
			},
		},
		'Bolivia' => {
			long => {
				'standard' => q#ಬೊಲಿವಿಯಾ ಸಮಯ#,
			},
		},
		'Brasilia' => {
			long => {
				'daylight' => q#ಬ್ರೆಸಿಲಿಯಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಬ್ರೆಸಿಲಿಯಾದ ಸಮಯ#,
				'standard' => q#ಬ್ರೆಸಿಲಿಯಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Brunei' => {
			long => {
				'standard' => q#ಬ್ರೂನಿ ದಾರುಸಲೆಮ್ ಸಮಯ#,
			},
		},
		'Cape_Verde' => {
			long => {
				'daylight' => q#ಕೇಪ್ ವರ್ಡ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಕೇಪ್ ವರ್ಡ್ ಸಮಯ#,
				'standard' => q#ಕೇಪ್ ವರ್ಡ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Chamorro' => {
			long => {
				'standard' => q#ಚಮೋರೋ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Chatham' => {
			long => {
				'daylight' => q#ಚಥಾಮ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಚಥಾಮ್ ಸಮಯ#,
				'standard' => q#ಚಥಾಮ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Chile' => {
			long => {
				'daylight' => q#ಚಿಲಿ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಚಿಲಿ ಸಮಯ#,
				'standard' => q#ಚಿಲಿ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'China' => {
			long => {
				'daylight' => q#ಚೀನಾ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಚೀನಾ ಸಮಯ#,
				'standard' => q#ಚೀನಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Christmas' => {
			long => {
				'standard' => q#ಕ್ರಿಸ್ಮಸ್ ದ್ವೀಪ ಸಮಯ#,
			},
		},
		'Cocos' => {
			long => {
				'standard' => q#ಕೋಕೋಸ್ ದ್ವೀಪಗಳ ಸಮಯ#,
			},
		},
		'Colombia' => {
			long => {
				'daylight' => q#ಕೊಲಂಬಿಯಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಕೊಲಂಬಿಯಾ ಸಮಯ#,
				'standard' => q#ಕೊಲಂಬಿಯಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Cook' => {
			long => {
				'daylight' => q#ಕುಕ್ ದ್ವೀಪಗಳ ಮಧ್ಯಕಾಲೀನ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಕುಕ್ ದ್ವೀಪಗಳ ಸಮಯ#,
				'standard' => q#ಕುಕ್ ದ್ವೀಪಗಳ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Cuba' => {
			long => {
				'daylight' => q#ಕ್ಯೂಬಾ ದಿನದ ಸಮಯ#,
				'generic' => q#ಕ್ಯೂಬಾ ಸಮಯ#,
				'standard' => q#ಕ್ಯೂಬಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Davis' => {
			long => {
				'standard' => q#ಡೇವಿಸ್ ಸಮಯ#,
			},
		},
		'DumontDUrville' => {
			long => {
				'standard' => q#ಡುಮಂಟ್-ಡಿ ಉರ್ವಿಲೆ ಸಮಯ#,
			},
		},
		'East_Timor' => {
			long => {
				'standard' => q#ಪೂರ್ವ ಟಿಮೋರ್ ಸಮಯ#,
			},
		},
		'Easter' => {
			long => {
				'daylight' => q#ಈಸ್ಟರ್ ದ್ವೀಪ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಈಸ್ಟರ್ ದ್ವೀಪ ಸಮಯ#,
				'standard' => q#ಈಸ್ಟರ್ ದ್ವೀಪ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Ecuador' => {
			long => {
				'standard' => q#ಈಕ್ವೆಡಾರ್ ಸಮಯ#,
			},
		},
		'Etc/UTC' => {
			long => {
				'standard' => q#ಸಂಘಟಿತ ಸಾರ್ವತ್ರಿಕ ಸಮಯ#,
			},
		},
		'Etc/Unknown' => {
			exemplarCity => q#ಅಪರಿಚಿತ ನಗರ#,
		},
		'Europe/Amsterdam' => {
			exemplarCity => q#ಆಮ್‌ಸ್ಟೆರ್‌ಡ್ಯಾಂ#,
		},
		'Europe/Andorra' => {
			exemplarCity => q#ಅಂಡೋರಾ#,
		},
		'Europe/Astrakhan' => {
			exemplarCity => q#ಆಸ್ಟ್ರಾಖಾನ್#,
		},
		'Europe/Athens' => {
			exemplarCity => q#ಅಥೆನ್ಸ್#,
		},
		'Europe/Belgrade' => {
			exemplarCity => q#ಬೆಲ್‌ಗ್ರೇಡ್#,
		},
		'Europe/Berlin' => {
			exemplarCity => q#ಬರ್ಲಿನ್#,
		},
		'Europe/Bratislava' => {
			exemplarCity => q#ಬ್ರಾಟಿಸ್ಲಾವ#,
		},
		'Europe/Brussels' => {
			exemplarCity => q#ಬ್ರಸ್ಸೆಲ್ಸ್#,
		},
		'Europe/Bucharest' => {
			exemplarCity => q#ಬುಕಾರೆಸ್ಟ್#,
		},
		'Europe/Budapest' => {
			exemplarCity => q#ಬುಡಾಪೆಸ್ಟ್#,
		},
		'Europe/Busingen' => {
			exemplarCity => q#ಬುಸಿಂಜೆನ್#,
		},
		'Europe/Chisinau' => {
			exemplarCity => q#ಚಿಸಿನಾವ್#,
		},
		'Europe/Copenhagen' => {
			exemplarCity => q#ಕೋಪೆನ್‌ಹೇಗನ್#,
		},
		'Europe/Dublin' => {
			exemplarCity => q#ಡುಬ್ಲಿನ್#,
			long => {
				'daylight' => q#ಐರಿಷ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Europe/Gibraltar' => {
			exemplarCity => q#ಜಿಬ್ರಾಲ್ಟರ್#,
		},
		'Europe/Guernsey' => {
			exemplarCity => q#ಗ್ಯುರ್ನ್‍ಸೆ#,
		},
		'Europe/Helsinki' => {
			exemplarCity => q#ಹೆಲ್ಸಿಂಕಿ#,
		},
		'Europe/Isle_of_Man' => {
			exemplarCity => q#ಐಲ್ ಆಫ್ ಮ್ಯಾನ್#,
		},
		'Europe/Istanbul' => {
			exemplarCity => q#ಇಸ್ತಾನ್‌ಬುಲ್#,
		},
		'Europe/Jersey' => {
			exemplarCity => q#ಜೆರ್ಸಿ#,
		},
		'Europe/Kaliningrad' => {
			exemplarCity => q#ಕಲಿನಿನ್‌ಗ್ರಾಡ್#,
		},
		'Europe/Kiev' => {
			exemplarCity => q#ಕಿವ್#,
		},
		'Europe/Kirov' => {
			exemplarCity => q#ಕಿರಾವ್#,
		},
		'Europe/Lisbon' => {
			exemplarCity => q#ಲಿಸ್ಬನ್#,
		},
		'Europe/Ljubljana' => {
			exemplarCity => q#ಲ್ಯೂಬ್ಲ್ಯಾನಾ#,
		},
		'Europe/London' => {
			exemplarCity => q#ಲಂಡನ್#,
			long => {
				'daylight' => q#ಬ್ರಿಟಿಷ್ ಬೇಸಿಗೆ ಸಮಯ#,
			},
		},
		'Europe/Luxembourg' => {
			exemplarCity => q#ಲಕ್ಸೆಂಬರ್ಗ್#,
		},
		'Europe/Madrid' => {
			exemplarCity => q#ಮ್ಯಾಡ್ರಿಡ್#,
		},
		'Europe/Malta' => {
			exemplarCity => q#ಮಾಲ್ಟಾ#,
		},
		'Europe/Mariehamn' => {
			exemplarCity => q#ಮರಿಹಮ್ನ್#,
		},
		'Europe/Minsk' => {
			exemplarCity => q#ಮಿನ್‌ಸ್ಕ್#,
		},
		'Europe/Monaco' => {
			exemplarCity => q#ಮೊನಾಕೊ#,
		},
		'Europe/Moscow' => {
			exemplarCity => q#ಮಾಸ್ಕೋ#,
		},
		'Europe/Oslo' => {
			exemplarCity => q#ಓಸ್ಲೋ#,
		},
		'Europe/Paris' => {
			exemplarCity => q#ಪ್ಯಾರಿಸ್#,
		},
		'Europe/Podgorica' => {
			exemplarCity => q#ಪೊಡ್ಗೊರಿಕ#,
		},
		'Europe/Prague' => {
			exemplarCity => q#ಪ್ರಾಗ್ವೆ#,
		},
		'Europe/Riga' => {
			exemplarCity => q#ರಿಗಾ#,
		},
		'Europe/Rome' => {
			exemplarCity => q#ರೋಮ್#,
		},
		'Europe/Samara' => {
			exemplarCity => q#ಸಮರ#,
		},
		'Europe/San_Marino' => {
			exemplarCity => q#ಸ್ಯಾನ್ ಮರೀನೊ#,
		},
		'Europe/Sarajevo' => {
			exemplarCity => q#ಸರಯೇವೊ#,
		},
		'Europe/Saratov' => {
			exemplarCity => q#ಸರಾಟೋವ್#,
		},
		'Europe/Simferopol' => {
			exemplarCity => q#ಸಿಮ್ಫೆರೋಪೋಲ್#,
		},
		'Europe/Skopje' => {
			exemplarCity => q#ಸ್ಕಾಪಿಯಾ#,
		},
		'Europe/Sofia' => {
			exemplarCity => q#ಸೋಫಿಯಾ#,
		},
		'Europe/Stockholm' => {
			exemplarCity => q#ಸ್ಟಾಕ್‍ಹೋಮ್#,
		},
		'Europe/Tallinn' => {
			exemplarCity => q#ಟ್ಯಾಲಿನ್#,
		},
		'Europe/Tirane' => {
			exemplarCity => q#ಟಿರಾನೆ#,
		},
		'Europe/Ulyanovsk' => {
			exemplarCity => q#ಉಲ್ಯಾನೊವಸ್ಕ್#,
		},
		'Europe/Vaduz' => {
			exemplarCity => q#ವಡೂಜ್#,
		},
		'Europe/Vatican' => {
			exemplarCity => q#ವ್ಯಾಟಿಕನ್#,
		},
		'Europe/Vienna' => {
			exemplarCity => q#ವಿಯೆನ್ನಾ#,
		},
		'Europe/Vilnius' => {
			exemplarCity => q#ವಿಲ್ನಿಯಸ್#,
		},
		'Europe/Volgograd' => {
			exemplarCity => q#ವೊಲ್ಗೊಗ್ರಾಡ್#,
		},
		'Europe/Warsaw' => {
			exemplarCity => q#ವಾರ್ಸಾ#,
		},
		'Europe/Zagreb' => {
			exemplarCity => q#ಜಾಗ್ರೆಬ್‌#,
		},
		'Europe/Zurich' => {
			exemplarCity => q#ಜ್ಯೂರಿಕ್#,
		},
		'Europe_Central' => {
			long => {
				'daylight' => q#ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಸಮಯ#,
				'standard' => q#ಮಧ್ಯ ಯುರೋಪಿಯನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Europe_Eastern' => {
			long => {
				'daylight' => q#ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ#,
				'standard' => q#ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Europe_Further_Eastern' => {
			long => {
				'standard' => q#ಮತ್ತಷ್ಟು-ಪೂರ್ವ ಯುರೋಪಿಯನ್ ಸಮಯ#,
			},
		},
		'Europe_Western' => {
			long => {
				'daylight' => q#ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಸಮಯ#,
				'standard' => q#ಪಶ್ಚಿಮ ಯುರೋಪಿಯನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Falkland' => {
			long => {
				'daylight' => q#ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳ ಸಮಯ#,
				'standard' => q#ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Fiji' => {
			long => {
				'daylight' => q#ಫಿಜಿ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಫಿಜಿ ಸಮಯ#,
				'standard' => q#ಫಿಜಿ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'French_Guiana' => {
			long => {
				'standard' => q#ಫ್ರೆಂಚ್ ಗಯಾನಾ ಸಮಯ#,
			},
		},
		'French_Southern' => {
			long => {
				'standard' => q#ದಕ್ಷಿಣ ಫ್ರೆಂಚ್ ಮತ್ತು ಅಂಟಾರ್ಟಿಕಾ ಸಮಯ#,
			},
		},
		'GMT' => {
			long => {
				'standard' => q#ಗ್ರೀನ್‌ವಿಚ್ ಸರಾಸರಿ ಕಾಲಮಾನ#,
			},
		},
		'Galapagos' => {
			long => {
				'standard' => q#ಗಾಲಾಪಾಗೋಸ್ ಸಮಯ#,
			},
		},
		'Gambier' => {
			long => {
				'standard' => q#ಗ್ಯಾಂಬಿಯರ್ ಸಮಯ#,
			},
		},
		'Georgia' => {
			long => {
				'daylight' => q#ಜಾರ್ಜಿಯಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಜಾರ್ಜಿಯಾ ಸಮಯ#,
				'standard' => q#ಜಾರ್ಜಿಯಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Gilbert_Islands' => {
			long => {
				'standard' => q#ಗಿಲ್ಬರ್ಟ್ ದ್ವೀಪಗಳ ಸಮಯ#,
			},
		},
		'Greenland_Eastern' => {
			long => {
				'daylight' => q#ಪೂರ್ವ ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪೂರ್ವ ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ#,
				'standard' => q#ಪೂರ್ವ ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Greenland_Western' => {
			long => {
				'daylight' => q#ಪಶ್ಚಿಮ ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪಶ್ಚಿಮ ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಸಮಯ#,
				'standard' => q#ಪಶ್ಚಿಮ ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Guam' => {
			long => {
				'standard' => q#ಗುವಾಮ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Gulf' => {
			long => {
				'standard' => q#ಗಲ್ಫ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Guyana' => {
			long => {
				'standard' => q#ಗಯಾನಾ ಸಮಯ#,
			},
		},
		'Hawaii_Aleutian' => {
			long => {
				'daylight' => q#ಹವಾಯಿ-ಅಲ್ಯುಟಿಯನ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಹವಾಯಿ-ಅಲ್ಯುಟಿಯನ್ ಸಮಯ#,
				'standard' => q#ಹವಾಯಿ-ಅಲ್ಯುಟಿಯನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Hong_Kong' => {
			long => {
				'daylight' => q#ಹಾಂಗ್ ಕಾಂಗ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಹಾಂಗ್ ಕಾಂಗ್ ಸಮಯ#,
				'standard' => q#ಹಾಂಗ್ ಕಾಂಗ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Hovd' => {
			long => {
				'daylight' => q#ಹವ್ಡ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಹವ್ಡ್ ಸಮಯ#,
				'standard' => q#ಹವ್ಡ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'India' => {
			long => {
				'standard' => q#ಭಾರತೀಯ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
			short => {
				'standard' => q#IST#,
			},
		},
		'Indian/Antananarivo' => {
			exemplarCity => q#ಅಂಟಾನನಾರಿವೊ#,
		},
		'Indian/Chagos' => {
			exemplarCity => q#ಚಾಗೊಸ್#,
		},
		'Indian/Christmas' => {
			exemplarCity => q#ಕ್ರಿಸ್ಮಸ್#,
		},
		'Indian/Cocos' => {
			exemplarCity => q#ಕೊಕೋಸ್#,
		},
		'Indian/Comoro' => {
			exemplarCity => q#ಕೊಮೋರೊ#,
		},
		'Indian/Kerguelen' => {
			exemplarCity => q#ಕೆರ್ಗ್ಯುಲೆನ್#,
		},
		'Indian/Mahe' => {
			exemplarCity => q#ಮಾಹೆ#,
		},
		'Indian/Maldives' => {
			exemplarCity => q#ಮಾಲ್ಡೀವ್ಸ್#,
		},
		'Indian/Mauritius' => {
			exemplarCity => q#ಮಾರಿಷಸ್#,
		},
		'Indian/Mayotte' => {
			exemplarCity => q#ಮಯೊಟ್ಟೆ#,
		},
		'Indian/Reunion' => {
			exemplarCity => q#ರೀಯೂನಿಯನ್#,
		},
		'Indian_Ocean' => {
			long => {
				'standard' => q#ಹಿಂದೂ ಮಹಾಸಾಗರ ಸಮಯ#,
			},
		},
		'Indochina' => {
			long => {
				'standard' => q#ಇಂಡೊಚೈನಾ ಸಮಯ#,
			},
		},
		'Indonesia_Central' => {
			long => {
				'standard' => q#ಮಧ್ಯ ಇಂಡೋನೇಷಿಯಾ ಸಮಯ#,
			},
		},
		'Indonesia_Eastern' => {
			long => {
				'standard' => q#ಪೂರ್ವ ಇಂಡೋನೇಷಿಯಾ ಸಮಯ#,
			},
		},
		'Indonesia_Western' => {
			long => {
				'standard' => q#ಪಶ್ಚಿಮ ಇಂಡೋನೇಷಿಯ ಸಮಯ#,
			},
		},
		'Iran' => {
			long => {
				'daylight' => q#ಇರಾನ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಇರಾನ್ ಸಮಯ#,
				'standard' => q#ಇರಾನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Irkutsk' => {
			long => {
				'daylight' => q#ಇರ್‌ಕುಟಸ್ಕ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಇರ್‌ಕುಟಸ್ಕ್ ಸಮಯ#,
				'standard' => q#ಇರ್‌ಕುಟಸ್ಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Israel' => {
			long => {
				'daylight' => q#ಇಸ್ರೇಲ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಇಸ್ರೇಲ್ ಸಮಯ#,
				'standard' => q#ಇಸ್ರೇಲ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Japan' => {
			long => {
				'daylight' => q#ಜಪಾನ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಜಪಾನ್ ಸಮಯ#,
				'standard' => q#ಜಪಾನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Kamchatka' => {
			long => {
				'daylight' => q#ಪೆತ್ರೋಪಾವ್ಲೋಸ್ಕ್‌‌-ಕಮ್ಚತ್ಸ್‌ಕೀ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪೆತ್ರೋಪಾವ್ಲೋಸ್ಕ್‌‌-ಕಮ್ಚತ್ಸ್‌ಕೀ ಸಮಯ#,
				'standard' => q#ಪೆತ್ರೋಪಾವ್ಲೋಸ್ಕ್‌‌-ಕಮ್ಚತ್ಸ್‌ಕೀ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Kazakhstan' => {
			long => {
				'standard' => q#ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ#,
			},
		},
		'Kazakhstan_Eastern' => {
			long => {
				'standard' => q#ಪೂರ್ವ ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ#,
			},
		},
		'Kazakhstan_Western' => {
			long => {
				'standard' => q#ಪಶ್ಚಿಮ ಕಝಾಖ್‌ಸ್ತಾನ್ ಸಮಯ#,
			},
		},
		'Korea' => {
			long => {
				'daylight' => q#ಕೊರಿಯನ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಕೊರಿಯನ್ ಸಮಯ#,
				'standard' => q#ಕೊರಿಯನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Kosrae' => {
			long => {
				'standard' => q#ಕೊಸರೆ ಸಮಯ#,
			},
		},
		'Krasnoyarsk' => {
			long => {
				'daylight' => q#ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಸಮಯ#,
				'standard' => q#ಕ್ರಾಸ್‌ನೊಯಾರ್ಸ್ಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Kyrgystan' => {
			long => {
				'standard' => q#ಕಿರ್ಗಿಸ್ತಾನ್ ಸಮಯ#,
			},
		},
		'Lanka' => {
			long => {
				'standard' => q#ಲಂಕಾ ಸಮಯ#,
			},
		},
		'Line_Islands' => {
			long => {
				'standard' => q#ಲೈನ್ ದ್ವೀಪಗಳ ಸಮಯ#,
			},
		},
		'Lord_Howe' => {
			long => {
				'daylight' => q#ಲಾರ್ಡ್ ಹೋವ್ ಬೆಳಗಿನ ಸಮಯ#,
				'generic' => q#ಲಾರ್ಡ್ ಹೋವ್ ಸಮಯ#,
				'standard' => q#ಲಾರ್ಡ್ ಹೋವ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Macau' => {
			long => {
				'daylight' => q#ಮಕಾವ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಮಕಾವ್ ಸಮಯ#,
				'standard' => q#ಮಕಾವ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Magadan' => {
			long => {
				'daylight' => q#ಮಗಡಾನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಮಗಡಾನ್ ಸಮಯ#,
				'standard' => q#ಮಗಡಾನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Malaysia' => {
			long => {
				'standard' => q#ಮಲೇಷಿಯಾ ಸಮಯ#,
			},
		},
		'Maldives' => {
			long => {
				'standard' => q#ಮಾಲ್ಡೀವ್ಸ್ ಸಮಯ#,
			},
		},
		'Marquesas' => {
			long => {
				'standard' => q#ಮಾರ್ಕ್ಯುಸಸ್ ಸಮಯ#,
			},
		},
		'Marshall_Islands' => {
			long => {
				'standard' => q#ಮಾರ್ಷಲ್ ದ್ವೀಪಗಳ ಸಮಯ#,
			},
		},
		'Mauritius' => {
			long => {
				'daylight' => q#ಮಾರಿಷಸ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಮಾರಿಷಸ್ ಸಮಯ#,
				'standard' => q#ಮಾರಿಷಸ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Mawson' => {
			long => {
				'standard' => q#ಮಾವ್‌ಸನ್ ಸಮಯ#,
			},
		},
		'Mexico_Pacific' => {
			long => {
				'daylight' => q#ಮೆಕ್ಸಿಕನ್ ಪೆಸಿಫಿಕ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಮೆಕ್ಸಿಕನ್ ಪೆಸಿಫಿಕ್ ಸಮಯ#,
				'standard' => q#ಮೆಕ್ಸಿಕನ್ ಪೆಸಿಫಿಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Mongolia' => {
			long => {
				'daylight' => q#ಉಲಾನ್ ಬತೊರ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಉಲಾನ್ ಬತೊರ್ ಸಮಯ#,
				'standard' => q#ಉಲಾನ್ ಬತೊರ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Moscow' => {
			long => {
				'daylight' => q#ಮಾಸ್ಕೋ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಮಾಸ್ಕೋ ಸಮಯ#,
				'standard' => q#ಮಾಸ್ಕೋ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Myanmar' => {
			long => {
				'standard' => q#ಮ್ಯಾನ್ಮಾರ್ ಸಮಯ#,
			},
		},
		'Nauru' => {
			long => {
				'standard' => q#ನೌರು ಸಮಯ#,
			},
		},
		'Nepal' => {
			long => {
				'standard' => q#ನೇಪಾಳ ಸಮಯ#,
			},
		},
		'New_Caledonia' => {
			long => {
				'daylight' => q#ಹೊಸ ಕ್ಯಾಲೆಡೋನಿಯಾ ಬೇಸಿಗೆಯ ಸಮಯ#,
				'generic' => q#ಹೊಸ ಕ್ಯಾಲೆಡೋನಿಯಾ ಸಮಯ#,
				'standard' => q#ಹೊಸ ಕ್ಯಾಲೆಡೋನಿಯಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'New_Zealand' => {
			long => {
				'daylight' => q#ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಸಮಯ#,
				'standard' => q#ನ್ಯೂಜಿಲ್ಯಾಂಡ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Newfoundland' => {
			long => {
				'daylight' => q#ನ್ಯೂಫೌಂಡ್‌ಲ್ಯಾಂಡ್ ದಿನದ ಸಮಯ#,
				'generic' => q#ನ್ಯೂಫೌಂಡ್‌ಲ್ಯಾಂಡ್ ಸಮಯ#,
				'standard' => q#ನ್ಯೂಫೌಂಡ್‌ಲ್ಯಾಂಡ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Niue' => {
			long => {
				'standard' => q#ನಿಯು ಸಮಯ#,
			},
		},
		'Norfolk' => {
			long => {
				'daylight' => q#ನಾರ್ಫೋಕ್ ದ್ವೀಪ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ನಾರ್ಫೋಕ್ ದ್ವೀಪ ಸಮಯ#,
				'standard' => q#ನಾರ್ಫೋಕ್ ದ್ವೀಪ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Noronha' => {
			long => {
				'daylight' => q#ಫರ್ನಾಂಡೋ ದೆ ನೊರೊನ್ಹಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಫೆರ್ನಾಂಡೋ ಡೆ ನೊರೊನ್ಹಾ ಸಮಯ#,
				'standard' => q#ಫೆರ್ನಾಂಡೋ ಡೆ ನೊರೊನ್ಹಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'North_Mariana' => {
			long => {
				'standard' => q#ಉತ್ತರ ಮರಿಯಾನಾ ದ್ವೀಪಗಳ ಸಮಯ#,
			},
		},
		'Novosibirsk' => {
			long => {
				'daylight' => q#ನೊವೊಸಿಬಿರ್‌ಸ್ಕ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ನೊವೊಸಿಬಿರ್‌ಸ್ಕ್ ಸಮಯ#,
				'standard' => q#ನೊವೊಸಿಬಿರ್‌ಸ್ಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Omsk' => {
			long => {
				'daylight' => q#ಒಮಾಸ್ಕ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಒಮಾಸ್ಕ್ ಸಮಯ#,
				'standard' => q#ಒಮಾಸ್ಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Pacific/Apia' => {
			exemplarCity => q#ಅಪಿಯಾ#,
		},
		'Pacific/Auckland' => {
			exemplarCity => q#ಆಕ್ ಲ್ಯಾಂಡ್#,
		},
		'Pacific/Bougainville' => {
			exemplarCity => q#ಬೌಗೆನ್‍ವಿಲ್ಲೆ#,
		},
		'Pacific/Chatham' => {
			exemplarCity => q#ಚಥಾಮ್#,
		},
		'Pacific/Easter' => {
			exemplarCity => q#ಈಸ್ಟರ್#,
		},
		'Pacific/Efate' => {
			exemplarCity => q#ಇಫೇಟ್#,
		},
		'Pacific/Enderbury' => {
			exemplarCity => q#ಎಂಡರ್ಬರಿ#,
		},
		'Pacific/Fakaofo' => {
			exemplarCity => q#ಫಕೋಫೋ#,
		},
		'Pacific/Fiji' => {
			exemplarCity => q#ಫಿಜಿ#,
		},
		'Pacific/Funafuti' => {
			exemplarCity => q#ಫುನಾಫುಟಿ#,
		},
		'Pacific/Galapagos' => {
			exemplarCity => q#ಗಲಾಪಗೋಸ್#,
		},
		'Pacific/Gambier' => {
			exemplarCity => q#ಗ್ಯಾಂಬಿಯರ್#,
		},
		'Pacific/Guadalcanal' => {
			exemplarCity => q#ಗ್ವಾಡಲ್ಕೆನಾಲ್#,
		},
		'Pacific/Guam' => {
			exemplarCity => q#ಗ್ವಾಮ್#,
		},
		'Pacific/Honolulu' => {
			exemplarCity => q#ಹೊನಲುಲು#,
		},
		'Pacific/Kanton' => {
			exemplarCity => q#ಕ್ಯಾಂಟನ್#,
		},
		'Pacific/Kiritimati' => {
			exemplarCity => q#ಕಿರಿತಿಮತಿ#,
		},
		'Pacific/Kosrae' => {
			exemplarCity => q#ಕೋಸ್ರೆ#,
		},
		'Pacific/Kwajalein' => {
			exemplarCity => q#ಕ್ವಾಜಲೇನ್#,
		},
		'Pacific/Majuro' => {
			exemplarCity => q#ಮಜುರೊ#,
		},
		'Pacific/Marquesas' => {
			exemplarCity => q#ಮಾರ್ಕ್ಯೂಸಸ್#,
		},
		'Pacific/Midway' => {
			exemplarCity => q#ಮಿಡ್‌ವೇ#,
		},
		'Pacific/Nauru' => {
			exemplarCity => q#ನೌರು#,
		},
		'Pacific/Niue' => {
			exemplarCity => q#ನಿಯು#,
		},
		'Pacific/Norfolk' => {
			exemplarCity => q#ನಾರ್ಫೋಕ್#,
		},
		'Pacific/Noumea' => {
			exemplarCity => q#ನ್ಯೂಮಿಯಾ#,
		},
		'Pacific/Pago_Pago' => {
			exemplarCity => q#ಪಾಗೊ ಪಾಗೊ#,
		},
		'Pacific/Palau' => {
			exemplarCity => q#ಪಾಲಾವ್#,
		},
		'Pacific/Pitcairn' => {
			exemplarCity => q#ಪಿಟ್‌ಕೈರ್ನ್#,
		},
		'Pacific/Ponape' => {
			exemplarCity => q#ಪೋನ್‌ಪೆ#,
		},
		'Pacific/Port_Moresby' => {
			exemplarCity => q#ಪೋರ್ಟ್ ಮೋರಿಸ್‌ಬೈ#,
		},
		'Pacific/Rarotonga' => {
			exemplarCity => q#ರರೋಟೋಂಗಾ#,
		},
		'Pacific/Saipan' => {
			exemplarCity => q#ಸೈಪನ್#,
		},
		'Pacific/Tahiti' => {
			exemplarCity => q#ತಹಿತಿ#,
		},
		'Pacific/Tarawa' => {
			exemplarCity => q#ತರಾವಾ#,
		},
		'Pacific/Tongatapu' => {
			exemplarCity => q#ಟೊಂಗಾಟಾಪು#,
		},
		'Pacific/Truk' => {
			exemplarCity => q#ಚುಕ್#,
		},
		'Pacific/Wake' => {
			exemplarCity => q#ವೇಕ್#,
		},
		'Pacific/Wallis' => {
			exemplarCity => q#ವ್ಯಾಲಿಸ್#,
		},
		'Pakistan' => {
			long => {
				'daylight' => q#ಪಾಕಿಸ್ತಾನ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪಾಕಿಸ್ತಾನ ಸಮಯ#,
				'standard' => q#ಪಾಕಿಸ್ತಾನ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Palau' => {
			long => {
				'standard' => q#ಪಾಲಾವ್ ಸಮಯ#,
			},
		},
		'Papua_New_Guinea' => {
			long => {
				'standard' => q#ಪಪುವಾ ನ್ಯೂ ಗಿನಿಯಾ ಸಮಯ#,
			},
		},
		'Paraguay' => {
			long => {
				'daylight' => q#ಪರಾಗ್ವೇ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪರಾಗ್ವೇ ಸಮಯ#,
				'standard' => q#ಪರಾಗ್ವೇ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Peru' => {
			long => {
				'daylight' => q#ಪೆರು ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಪೆರು ಸಮಯ#,
				'standard' => q#ಪೆರು ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Philippines' => {
			long => {
				'daylight' => q#ಫಿಲಿಫೈನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಫಿಲಿಫೈನ್ ಸಮಯ#,
				'standard' => q#ಫಿಲಿಫೈನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Phoenix_Islands' => {
			long => {
				'standard' => q#ಫಿನಿಕ್ಸ್ ದ್ವೀಪಗಳ ಸಮಯ#,
			},
		},
		'Pierre_Miquelon' => {
			long => {
				'daylight' => q#ಸೇಂಟ್ ಪಿಯರ್ ಮತ್ತು ಮಿಕ್ವೆಲನ್ ಹಗಲು ಸಮಯ#,
				'generic' => q#ಸೇಂಟ್ ಪಿಯರ್ ಮತ್ತು ಮಿಕ್ವೆಲನ್ ಸಮಯ#,
				'standard' => q#ಸೇಂಟ್ ಪಿಯರ್ ಮತ್ತು ಮಿಕ್ವೆಲನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Pitcairn' => {
			long => {
				'standard' => q#ಪಿಟ್‌ಕೈರ್ನ್ ಸಮಯ#,
			},
		},
		'Ponape' => {
			long => {
				'standard' => q#ಪೊನಾಪೆ ಸಮಯ#,
			},
		},
		'Pyongyang' => {
			long => {
				'standard' => q#ಪ್ಯೊಂಗ್ಯಾಂಗ್ ಸಮಯ#,
			},
		},
		'Qyzylorda' => {
			long => {
				'daylight' => q#ಕೋಜಿಲೋರ್ಡಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಕೋಜಿಲೋರ್ಡಾ ಸಮಯ#,
				'standard' => q#ಕೋಜಿಲೋರ್ಡಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Reunion' => {
			long => {
				'standard' => q#ರಿಯೂನಿಯನ್ ಸಮಯ#,
			},
		},
		'Rothera' => {
			long => {
				'standard' => q#ರೊತೇರಾ ಸಮಯ#,
			},
		},
		'Sakhalin' => {
			long => {
				'daylight' => q#ಸ್ಯಾಕ್‌ಹಲಿನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಸ್ಯಾಕ್‌ಹಲಿನ್ ಸಮಯ#,
				'standard' => q#ಸ್ಯಾಕ್‌ಹಲಿನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Samara' => {
			long => {
				'daylight' => q#ಸಮರ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಸಮರ ಸಮಯ#,
				'standard' => q#ಸಮರ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Samoa' => {
			long => {
				'daylight' => q#ಸಮೋವಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಸಮೋವಾ ಸಮಯ#,
				'standard' => q#ಸಮೋವಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Seychelles' => {
			long => {
				'standard' => q#ಸೀಷೆಲ್ಸ್ ಸಮಯ#,
			},
		},
		'Singapore' => {
			long => {
				'standard' => q#ಸಿಂಗಪುರ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Solomon' => {
			long => {
				'standard' => q#ಸಾಲಮನ್ ದ್ವೀಪಗಳ ಸಮಯ#,
			},
		},
		'South_Georgia' => {
			long => {
				'standard' => q#ದಕ್ಷಿಣ ಜಾರ್ಜಿಯಾ ಸಮಯ#,
			},
		},
		'Suriname' => {
			long => {
				'standard' => q#ಸುರಿನೇಮ್ ಸಮಯ#,
			},
		},
		'Syowa' => {
			long => {
				'standard' => q#ಸ್ಯೊವಾ ಸಮಯ#,
			},
		},
		'Tahiti' => {
			long => {
				'standard' => q#ತಾಹಿತಿ ಸಮಯ#,
			},
		},
		'Taipei' => {
			long => {
				'daylight' => q#ತೈಪೆ ಹಗಲು ಸಮಯ#,
				'generic' => q#ತೈಪೆ ಸಮಯ#,
				'standard' => q#ತೈಪೆ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Tajikistan' => {
			long => {
				'standard' => q#ತಝಕಿಸ್ತಾನ್ ಸಮಯ#,
			},
		},
		'Tokelau' => {
			long => {
				'standard' => q#ಟೊಕೆಲಾವ್ ಸಮಯ#,
			},
		},
		'Tonga' => {
			long => {
				'daylight' => q#ಟೊಂಗಾ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಟೊಂಗಾ ಸಮಯ#,
				'standard' => q#ಟೊಂಗಾ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Truk' => {
			long => {
				'standard' => q#ಚುಕ್ ಸಮಯ#,
			},
		},
		'Turkmenistan' => {
			long => {
				'daylight' => q#ತುರ್ಕ್‌ಮೇನಿಸ್ತಾನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ತುರ್ಕ್‌ಮೇನಿಸ್ತಾನ್ ಸಮಯ#,
				'standard' => q#ತುರ್ಕ್‌ಮೇನಿಸ್ತಾನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Tuvalu' => {
			long => {
				'standard' => q#ತುವಾಲು ಸಮಯ#,
			},
		},
		'Uruguay' => {
			long => {
				'daylight' => q#ಉರುಗ್ವೇ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಉರುಗ್ವೇ ಸಮಯ#,
				'standard' => q#ಉರುಗ್ವೇ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Uzbekistan' => {
			long => {
				'daylight' => q#ಉಜ್ಬೇಕಿಸ್ತಾನ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಉಜ್ಬೇಕಿಸ್ತಾನ್ ಸಮಯ#,
				'standard' => q#ಉಜ್ಬೇಕಿಸ್ತಾನ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Vanuatu' => {
			long => {
				'daylight' => q#ವನೌತು ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ವನೌತು ಸಮಯ#,
				'standard' => q#ವನೌತು ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Venezuela' => {
			long => {
				'standard' => q#ವೆನಿಜುವೆಲಾ ಸಮಯ#,
			},
		},
		'Vladivostok' => {
			long => {
				'daylight' => q#ವ್ಲಾಡಿವೋಸ್ಟೋಕ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ವ್ಲಾಡಿವೋಸ್ಟೋಕ್ ಸಮಯ#,
				'standard' => q#ವ್ಲಾಡಿವೋಸ್ಟೋಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Volgograd' => {
			long => {
				'daylight' => q#ವೋಲ್ಗೋಗಾರ್ಡ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ವೋಲ್ಗೋಗಾರ್ಡ್ ಸಮಯ#,
				'standard' => q#ವೋಲ್ಗೋಗಾರ್ಡ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Vostok' => {
			long => {
				'standard' => q#ವೋಸ್ಟೊಕ್ ಸಮಯ#,
			},
		},
		'Wake' => {
			long => {
				'standard' => q#ವೇಕ್ ದ್ವೀಪ ಸಮಯ#,
			},
		},
		'Wallis' => {
			long => {
				'standard' => q#ವ್ಯಾಲೀಸ್ ಮತ್ತು ಫ್ಯುಟುನಾ ಸಮಯ#,
			},
		},
		'Yakutsk' => {
			long => {
				'daylight' => q#ಯಾಕುಟ್ಸಕ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಯಾಕುಟ್ಸಕ್ ಸಮಯ#,
				'standard' => q#ಯಾಕುಟ್ಸಕ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Yekaterinburg' => {
			long => {
				'daylight' => q#ಯೇಕೇಟರಿನ್‍ಬರ್ಗ್ ಬೇಸಿಗೆ ಸಮಯ#,
				'generic' => q#ಯೇಕಟರಿನ್‌ಬರ್ಗ್ ಸಮಯ#,
				'standard' => q#ಯೇಕಟರಿನ್‌ಬರ್ಗ್ ಪ್ರಮಾಣಿತ ಸಮಯ#,
			},
		},
		'Yukon' => {
			long => {
				'standard' => q#ಯುಕಾನ್ ಸಮಯ#,
			},
		},
	 } }
);
no Moo;

1;

# vim: tabstop=4
